(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9793,        280]*)
(*NotebookOutlinePosition[     12131,        352]*)
(*  CellTagsIndexPosition[     11966,        342]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Automata", "Section"],

Cell[TextData[{
  StyleBox["Automata", "MR"],
  "  is an add-on package that contains some 450 functions in automata theory \
and related areas. Detailed examples of the use of most of the commands in \
the package can be found in the Overview section of the browser.  \n\n",
  StyleBox["Note",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  ":  The individual browser messages are currently under development and \
contain essentially only the usages messages. \n\nRecent updates as well as \
more application examples can be found at my homepage:\n\n\t\t",
  StyleBox["www.cs.cmu.edu/~sutner",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\t\t\nBug reports should be sent to  ",
  StyleBox["sutner@cs.cmu.edu",
    FontFamily->"Courier"],
  ". \n"
}], "Text",
  CellTags->{"S5.18.1", "1.2"}],

Cell["This loads only the discrete math part of the package. ", "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],

Cell["Needs[\"Automata`dimath`\"]", "Input",
  CellLabel->"In[146]:="],

Cell["This loads the whole package. ", "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],

Cell["Needs[\"Automata`automata`\"]", "Input",
  CellLabel->"In[147]:="],

Cell["\<\
The package comes with a collection of experimental macros that can \
be loaded thus. \
\>", "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],

Cell["Get[\"Automata`experimental`\"]", "Input",
  CellLabel->"In[148]:="],

Cell["You can check the state of affairs. ", "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],

Cell[CellGroupData[{

Cell["Status[]", "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    InterpretationBox[\("4.2 for Linux (February 28, \
2002)"\[InvisibleSpace]", RN: "\[InvisibleSpace]0\[InvisibleSpace]"\n"\
\[InvisibleSpace]"dimath:     "\[InvisibleSpace]"4.5"\[InvisibleSpace]"\n"\
\[InvisibleSpace]"automata:   "\[InvisibleSpace]"4.5"\[InvisibleSpace]"\n"\
\[InvisibleSpace]"time:       "\[InvisibleSpace]"21:31:27  2002/6/6"\
\[InvisibleSpace]"\n"\[InvisibleSpace]"time used:  "\[InvisibleSpace]38.35`\
\[InvisibleSpace]"\n"\[InvisibleSpace]"memory:     \
"\[InvisibleSpace]5.792137145996094`\[InvisibleSpace]"\n\
"\[InvisibleSpace]"packages:   "\[InvisibleSpace]{"Automata`automata`", 
          "Automata`dimath`"}\[InvisibleSpace]"\n"\[InvisibleSpace]"links:    \
  "\[InvisibleSpace]{LinkObject["ParentLink", 1, 1], 
          LinkObject[
            "/usr/local/Wolfram/Mathematica/4.2/SystemFiles/Converters/\
Binaries/Linux/XML.exe", 2, 2]}\),
      SequenceForm[ 
      "4.2 for Linux (February 28, 2002)", ", RN: ", 0, "\n", "dimath:     ", 
        "4.5", "\n", "automata:   ", "4.5", "\n", "time:       ", 
        "21:31:27  2002/6/6", "\n", "time used:  ", 38.350000000000001, "\n", 
        "memory:     ", 5.7921371459960938, "\n", "packages:   ", {
        "Automata`automata`", "Automata`dimath`"}, "\n", "links:      ", {
        LinkObject[ "ParentLink", 1, 1], 
        LinkObject[ 
        "/usr/local/Wolfram/Mathematica/4.2/SystemFiles/Converters/Binaries/\
Linux/XML.exe", 2, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[149]:="]
}, Open  ]],

Cell[TextData[{
  "Formatting can be controlled is several ways.  This is important if you \
are dealing with large machines. The default setting is ",
  StyleBox["Automatic", "MR"],
  ". "
}], "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],

Cell[CellGroupData[{

Cell["\<\
FormatAutomata[None]
IthSymbolFA[ a, -20 ]\
\>", "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \(FA[21, 
      2, {{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 3}, {3, 1, 
          4}, {3, 2, 4}, {4, 1, 5}, {4, 2, 5}, {5, 1, 6}, {5, 2, 6}, {6, 1, 
          7}, {6, 2, 7}, {7, 1, 8}, {7, 2, 8}, {8, 1, 9}, {8, 2, 9}, {9, 1, 
          10}, {9, 2, 10}, {10, 1, 11}, {10, 2, 11}, {11, 1, 12}, {11, 2, 
          12}, {12, 1, 13}, {12, 2, 13}, {13, 1, 14}, {13, 2, 14}, {14, 1, 
          15}, {14, 2, 15}, {15, 1, 16}, {15, 2, 16}, {16, 1, 17}, {16, 2, 
          17}, {17, 1, 18}, {17, 2, 18}, {18, 1, 19}, {18, 2, 19}, {19, 1, 
          20}, {19, 2, 20}, {20, 1, 21}, {20, 2, 
          21}}, {1}, {21}, {}, {}]\)], "Output",
  CellLabel->"Out[151]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FormatAutomata[Automatic]
IthSymbolFA[ a, -20 ]\
\>", "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"21", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}, {4, 1, 
                5}, \[LeftSkeleton]25\[RightSkeleton], {17, 1, 18}, {17, 2, 
                18}, {18, 1, 19}, {18, 2, 19}, {19, 1, 20}, {19, 2, 20}, {20, 
                1, 21}, {20, 2, 21}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({21}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[153]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FormatAutomata[Full]
IthSymbolFA[ a, -20 ]\
\>", "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \("-FA-"\)], "Output",
  CellLabel->"Out[155]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["External Code", "Subsubsection",
  CellTags->{"S5.18.1", "1.4"}],

Cell[TextData[{
  "For many users it will be sufficient to load the internal part of the \
package only, as described in the previous section.  If speed is of the \
essence, the user may install the external part of the package which can be \
invoked via ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  ". The following commands are currently supported externally. The left \
colun lists the external command, and the right the corresponding internal \
comand, if applicable. \n\nNote that when the system variable ",
  StyleBox["$defaultexternal", "MR"],
  " is set to true, the internal commands automatically call the external \
ones.  Locally one can use the option ",
  StyleBox["External", "MR"],
  " to control the execution of a command. \n"
}], "Text",
  CellTags->{"S5.18.1", "1.5"}],

Cell[BoxData[
    FormBox[GridBox[{
          {"ExtAccessibleFA", "AccessibleFA"},
          {"ExtBalancedQCA", "-"},
          {"ExtClassifyCA", "ClassifyCA"},
          {"ExtComposeCA", "ComposeCA"},
          {"ExtDefiniteQFA", "DefiniteQFA"},
          {"ExtEpsilonEliminationFA", "EpsilonEliminationFA"},
          {"ExtEquivalentQFA", "EquivalentQFA"},
          {"ExtGenerateSG", "GenerateSG"},
          {"ExtIsomorphicQDFA", "IsomorphicQDFA"},
          {"ExtMinimizeFASize", "MinimizeFA"},
          {"ExtMinimizeFA", "MinimizeFA"},
          {"ExtOrbitCA", "OrbitCA"},
          {"ExtProductFA", "ProductFA"},
          {"ExtQuotientFA", "QuotientDFA"},
          {"ExtREToFA", "RegularExpressionToFA"},
          {"ExtStronglyConnectedComponents", "StronglyConnectedComponents"},
          {"ExtSyntacticSG", "SyntacticSG"},
          {"ExtToDFASize", "ToDFA"},
          {"ExtToDFAWitnesses", "ToDFA"},
          {"ExtToDFA", "ToDFA"},
          {"ExtToKernelFA", "ToKernelFA"},
          {"ExtToWelchCA", "ToWelchCA"},
          {"ExtWelchCA", "WelchCA"}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DefinitionBox",
  GridBoxOptions->{RowSpacings->0.4,
  RowLines->False},
  CellTags->"S5.18.1"],

Cell[TextData[{
  "Externally implemented functions that can be called via ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  "."
}], "Caption",
  CellTags->"S5.18.1"],

Cell[TextData[{
  "In the internal code one can use options to control the behavior of \
closely related functions such as the variants of ",
  StyleBox["ToDFA", "MR"],
  ". \n\nNote the the external code can also be used directly without ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  StyleBox["in several ways.  It can be called from C/C++ programs, via \
wrappers directly from the commandline, or in form of a little interactive \
FSM calculator. See the documentation in the external part for details. \n",
    FontVariations->{"CompatibilityType"->0}]
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{1005, 759},
WindowMargins->{{51, Automatic}, {4, Automatic}},
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S5.18.1"->{
    Cell[1757, 54, 819, 19, 315, "Text",
      CellTags->{"S5.18.1", "1.2"}],
    Cell[2579, 75, 110, 1, 42, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[2765, 81, 85, 1, 42, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[2928, 87, 149, 4, 42, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[3157, 96, 91, 1, 42, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[4849, 133, 240, 6, 63, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[6902, 205, 70, 1, 50, "Subsubsection",
      CellTags->{"S5.18.1", "1.4"}],
    Cell[6975, 208, 799, 16, 204, "Text",
      CellTags->{"S5.18.1", "1.5"}],
    Cell[7777, 226, 1232, 29, 519, "DefinitionBox",
      CellTags->"S5.18.1"],
    Cell[9012, 257, 170, 6, 22, "Caption",
      CellTags->"S5.18.1"]},
  "1.2"->{
    Cell[1757, 54, 819, 19, 315, "Text",
      CellTags->{"S5.18.1", "1.2"}]},
  "1.3"->{
    Cell[2579, 75, 110, 1, 42, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[2765, 81, 85, 1, 42, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[2928, 87, 149, 4, 42, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[3157, 96, 91, 1, 42, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}],
    Cell[4849, 133, 240, 6, 63, "MathCaption",
      CellTags->{"S5.18.1", "1.3"}]},
  "1.4"->{
    Cell[6902, 205, 70, 1, 50, "Subsubsection",
      CellTags->{"S5.18.1", "1.4"}]},
  "1.5"->{
    Cell[6975, 208, 799, 16, 204, "Text",
      CellTags->{"S5.18.1", "1.5"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S5.18.1", 10429, 297},
  {"1.2", 11248, 318},
  {"1.3", 11338, 321},
  {"1.4", 11764, 332},
  {"1.5", 11861, 335}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 27, 0, 84, "Section"],
Cell[1757, 54, 819, 19, 315, "Text",
  CellTags->{"S5.18.1", "1.2"}],
Cell[2579, 75, 110, 1, 42, "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],
Cell[2692, 78, 70, 1, 40, "Input"],
Cell[2765, 81, 85, 1, 42, "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],
Cell[2853, 84, 72, 1, 40, "Input"],
Cell[2928, 87, 149, 4, 42, "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],
Cell[3080, 93, 74, 1, 40, "Input"],
Cell[3157, 96, 91, 1, 42, "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],

Cell[CellGroupData[{
Cell[3273, 101, 51, 1, 40, "Input"],
Cell[3327, 104, 1507, 26, 237, "Print"]
}, Open  ]],
Cell[4849, 133, 240, 6, 63, "MathCaption",
  CellTags->{"S5.18.1", "1.3"}],

Cell[CellGroupData[{
Cell[5114, 143, 93, 4, 64, "Input"],
Cell[5210, 149, 682, 11, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5929, 165, 98, 4, 64, "Input"],
Cell[6030, 171, 636, 16, 76, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6703, 192, 93, 4, 64, "Input"],
Cell[6799, 198, 66, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6902, 205, 70, 1, 50, "Subsubsection",
  CellTags->{"S5.18.1", "1.4"}],
Cell[6975, 208, 799, 16, 204, "Text",
  CellTags->{"S5.18.1", "1.5"}],
Cell[7777, 226, 1232, 29, 519, "DefinitionBox",
  CellTags->"S5.18.1"],
Cell[9012, 257, 170, 6, 22, "Caption",
  CellTags->"S5.18.1"],
Cell[9185, 265, 580, 11, 162, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

