(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    130376,       4168]*)
(*NotebookOutlinePosition[    136358,       4384]*)
(*  CellTagsIndexPosition[    135385,       4343]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\[Copyright] 1997-2001 K. Sutner ", "SmallText"],

Cell[TextData[StyleBox["Linear Cellular Automata",
  FontFamily->"Charter"]], "Title",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:1"],

Cell[CellGroupData[{

Cell["Linear Cellular Automata", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:2"],

Cell[CellGroupData[{

Cell["Motivation", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:3"],

Cell[CellGroupData[{

Cell["Symbolic Dynamics", "Subsubsection",
  CellTags->"c:4"],

Cell[TextData[{
  "Dynamical system\n\t",
  Cell[BoxData[
      \(TraditionalForm\`T\  : \ \[ScriptCapitalX] \[RightArrow] \
\[ScriptCapitalX]\)]],
  "\nConsider orbits of points  ",
  Cell[BoxData[
      \(TraditionalForm\`X\_0\  \[Element] \ \[ScriptCapitalX]\)]],
  ":    \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\((X\_\(\(\ \)\(i\)\))\)\_\(i\  \[Element] \ \
\[DoubleStruckCapitalZ]\)\)]],
  "   such that   ",
  Cell[BoxData[
      \(TraditionalForm\`X\_\(i + 1\) = \ T(X\_i)\)]],
  "\nPartition  \[ScriptCapitalX]  into finitely many regions   ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\({\ \[ScriptCapitalX]\_0, \[Ellipsis], \
\[ScriptCapitalX]\_\(k - 1\)}\)\)\)]],
  "\nInterpret orbit as biinfinite word over some alphabet  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\  = \ {0, 1, \[Ellipsis], 
          k - 1}\)]],
  ":\n\treplace  ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i\)]],
  " by  ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "  such that  ",
  Cell[BoxData[
      \(TraditionalForm\`X\_i\  \[Element] \ \[ScriptCapitalX]\_s\)]],
  ".\t\nConfiguration space:   \t\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[CapitalSigma]\^\[Infinity]\)\(\ \)\(=\)\)\(\ \
\ \)\)\)]],
  " biinfinite words over ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\)]],
  ".\nOrbit of  ",
  Cell[BoxData[
      \(TraditionalForm\`T(X)\)]],
  "  is the ",
  StyleBox["shift",
    FontColor->RGBColor[0, 0, 1]],
  " of the orbit of ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  ":\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma](\ \((X\_i)\)\ )\  = \ X\_\(i + 1\)\)]],
  "\n",
  "\nSubshift  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[LeftAngleBracket]\ 
        S, \ \[Sigma]\ \[RightAngleBracket]\)\(\ \)\)\)]],
  ":    \t\t",
  Cell[BoxData[
      \(TraditionalForm\`S\  \[SubsetEqual] \ \
\[CapitalSigma]\^\[Infinity]\)]],
  " closed shift-invariant subspace\nSofic System:    \t\t\tfinite subwords \
of ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "  ",
  StyleBox["regular",
    FontColor->RGBColor[0, 0, 1]],
  " \nSubshift of finite type:  \t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \ \ \ \)\)\( = \
\^\[Omega]\)\[CapitalSigma]\ \ F\ \ \ \[CapitalSigma]\^\(\(\[Omega]\)\(\ \ \)\
\)\)]],
  "     where  ",
  Cell[BoxData[
      \(TraditionalForm\`F\  \[Subset] \ \ \ \ \(\[CapitalSigma]\^*\)\)]],
  "  finite."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Morphisms", "Subsubsection",
  CellTags->"c:5"],

Cell[TextData[{
  "Morphisms for subshifts: continuous shift-invariant maps.\nA linear \
cellular automaton (or LCA) consists of a ",
  StyleBox["local  map",
    FontColor->RGBColor[0, 0, 1]],
  "    \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  : \ \[CapitalSigma]\^\(\(\ \)\(w\)\)\
\[LongRightArrow]\ \[CapitalSigma]\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`w\  > \ 0\)]],
  "  width."
}], "Text"],

Cell[TextData[{
  "\[Rho]  extends naturally to ",
  StyleBox["global map",
    FontColor->RGBColor[0, 0, 1]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(:\)\(\ \ \ \
\)\(\[CapitalSigma]\))\)\^\[Infinity]\ \[LongRightArrow]\ \ \[CapitalSigma]\^\
\[Infinity]\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Rho](X))\)\_i\  := \ \[Rho](\(X\_i\) \(X\_\(i + 
                  1\)\) \[Ellipsis]\ X\_\(i + w - 1\))\)]]
}], "Text"],

Cell[TextData[{
  "\nTopology/dynamical systems:  \n",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\^\(\(\ \)\(\[Infinity]\)\)\)]],
  "  totally disconnected compact Hausdorff space.\n\n",
  StyleBox["Theorem",
    FontWeight->"Bold"],
  ":  Hedlund\nThese are precisely the continuous shift-invariant maps on  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\^\[Infinity]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Theorem",
    FontWeight->"Bold"],
  ":  Weiss\nSofic systems are precisely the images of subshifts of finite \
type under the global maps of cellular automata. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Dimension ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(>\)\(1\)\)\)]]
}], "Subsubsection",
  CellTags->"c:6"],

Cell[TextData[{
  "Naturally extends to higher-dimensional case \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\ \  : \ \ \[CapitalSigma]\^\(\
\[DoubleStruckCapitalZ]\^\(\(\[VeryThinSpace]\[ThinSpace]\ \)\(d\)\)\)\
\[LongRightArrow]\ \ \[CapitalSigma]\^\(\(\[DoubleStruckCapitalZ]\^\(\(\
\[VeryThinSpace]\[ThinSpace]\ \)\(d\)\)\)\(\ \)\)\)]],
  "\nThe 1-dimensional case is special, though, since automata theory can be \
brought to bear on some of the questions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Cellular Automata", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:7"],

Cell[CellGroupData[{

Cell["Local Maps", "Subsubsection",
  CellTags->"c:8"],

Cell[TextData[{
  "A ",
  StyleBox["linear cellular automaton",
    FontColor->RGBColor[0, 0, 1]],
  " (or simply CA) consists of \n\t- a finite alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ", the ",
  StyleBox["alphabet",
    FontColor->RGBColor[0, 0, 1]],
  " of the CA,\n\t- a positive integer ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ", the ",
  StyleBox["width",
    FontColor->RGBColor[0, 0, 1]],
  " of the CA, \n\t- a map  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] : K\^w \[RightArrow] K\)]],
  ", the ",
  StyleBox["local map",
    FontColor->RGBColor[0, 0, 1]],
  " of the CA.\nAs is customary, we will often use alphabets of the  form \n\t\
",
  Cell[BoxData[
      \(TraditionalForm\`K\_k\  = \ {0, 1, \[Ellipsis], k - 1}\)]],
  ".\nNote that these alphabets are abbreviated as ",
  Cell[BoxData[
      \(TraditionalForm\`\(-k\)\)]],
  " in the automata package. There is a standard coding for linear cellular \
automata of a given width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " over alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ":  Let  ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] c < k\^w\)]],
  ", enumerate the words of length ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " in natural order and assign the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "-th digit of ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " in base ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " (padded on the left to exactly ",
  Cell[BoxData[
      \(TraditionalForm\`k\^w\)]],
  " digits) to the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "-th word. \nTo save space we will usually deal with coded CAs. If need be, \
the local map of a coded CA can be translated into the more explicit labeled \
form using the command  ",
  StyleBox["ToLabelCA", "SmallText"],
  ". Command ",
  StyleBox["ToRuleCA", "SmallText"],
  " performs the opposite translation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(C150 = CA[150, 3, \(-2\)]\), "\n", 
    \(ToLabelCA[C150]\), "\n", 
    \(PrintCA[C150]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "CAs can also be generated from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions that represent the local map. These functions must be defined \
on ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " integer arguments (in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0\  \[LessEqual] \ x\  < \ k\)]],
  "). Here is an example:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[loc]\), "\n", 
    \(loc[x_, y_, z_] := Mod[x + y + z, 2]\), "\n", 
    \(FunctionToCA[loc, 3, \(-2\)]\), "\n", 
    \(loc[x_, y_, z_] := Mod[x + z, 2]\), "\n", 
    \(FunctionToCA[loc, 3, \(-2\)]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus, rule 150 corresponds to adding the states of all three cells modulo \
2, whereas rule 90 corresponds to adding only the states of the two \
neighboring states.\nModular arithmetic in general is a good source of \
examples for cellular automata.  If the corresponding local function can be \
described in terms of a polynomial, one can generate the CA very conveniently \
using command ",
  StyleBox["PolynomialToCA", "SmallText"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(PolynomialToCA[x1 + x2 + x3, 3, 2]\), "\n", 
    \(PolynomialToCA[x1 + x4, 4]\), "\n", 
    \(PolynomialToCA[z1\ z2 + z3, 3, 2, "\<z\>"]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Lastly, there is a command to convert a Boolean polynomial into a \
binary CA. Writing a Boolean function as a polynomial is sometimes more \
convenient as with logical operators. Of course, we use binary functions \
rather than Boolean ones and identify 0  with False and 1 with True.  Boolean \
variables are x1, x2, ... and their negation can be expressed as xx1, xx2, \
....  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(BFunctionToCA[x1 + xx2\ x3, 3]\), "\n", 
    \(PrintCA[%]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(BFunctionToCA[x1\ xx3 + xx1\ x3, 3]\), "\n", 
    \(PrintCA[%]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "If it is necessary to convert the expression representing a CA, and thus \
in essence the local map of the automaton, into a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function we can use the command ",
  StyleBox["LocalMapCA", "SmallText"],
  " :"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(LocalMapCA[rho, C150]\), "\n", 
    \(rho /@ Words[3, \(-2\)]\), "\n", 
    \(Information["\<rho\>", LongForm \[Rule] True]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Global\ Maps\)], "Subsubsection",
  CellTags->"c:9"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`K\^\[Infinity]\)]],
  " be the set of all biinfinite sequences of symbols from K. The elements of \
",
  Cell[BoxData[
      \(TraditionalForm\`K\^\[Infinity]\)]],
  " are called configurations over K. Linear cellular automata are \
traditionally considered as endomorphisms of the space ",
  Cell[BoxData[
      \(TraditionalForm\`K\^\[Infinity]\)]],
  " of all configurations. More precisely, ",
  Cell[BoxData[
      \(TraditionalForm\`K\^\[Infinity]\)]],
  " is a totally disconnected compact Hausdorff space and the local map gives \
rise to a global map  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  : \ 
        K\^\[Infinity]\[LongRightArrow]\ K\^\[Infinity]\)]],
  " that is easily seen to be a continuous map on this space. The \
configuration ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](X)\)]],
  " is generated by dividing ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " into overlapping blocks of width w and applying the local map to all \
these blocks in parallel. Clearly, the global map commutes with the shift. In \
fact, all continuous maps that commute with the shift arise in this way. \n",
  Cell[BoxData[
      \(TraditionalForm\`K\^\[Infinity]\)]],
  " together with the shift forms a primitive dynamical system, the full \
shift. It is often more interesting to consider a subshift, i.e., a closed \
subset  ",
  Cell[BoxData[
      \(TraditionalForm\`C\  \[SubsetEqual] K\^\[Infinity]\)]],
  " that is invariant under the shift. The simplest type of such subshifts \
are topological Markov shifts (TMS) and are described by a list of forbidden \
subwords of length 2. If one excludes a finite number of words of arbitrary \
length one obtains a subshift of finite type (SFT). Unlike TMSs, the latter \
class of shifts is closed under homeomorphisms. It is not closed under global \
maps as described above (or rather their obvious generalizations to \
subshifts). The shifts that can occur as the range of a global map are known \
as sofic systems (SoS). \nThere is a slight ambiguity in the construction of \
the global map from the local map: the blocks of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " obtained from a biinfinite sequence are only unique up to a shift. We \
will use the convention that the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  "-th block is centered at symbol ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " (for even ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " we choose the left center symbol). \nAlternatively, we may consider ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " as a map on finite words over ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ". Note that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\(|\)\(\[Rho](
            x)\)\(|\)\)\  = \ \(\(|\)\(x\)\(|\)\(\ \)\(-\ w\)\)\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " is the width of the CA (strictly speaking, this map is defined only for \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \
\)\(\(|\)\(x\)\(|\)\(\(\[GreaterEqual]\)\(w\)\)\)\)\)]],
  "; for completeness sake define ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\  = \ \[Epsilon]\)]],
  " for shorter words ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". We will refer to this map as the word map of the CA. \n\nThe command ",
  StyleBox["GlobalMapCA ", "SmallText"],
  " generates the word map of a CA. Unlike with the executable function \
generated by ",
  StyleBox["LocalMapCA", "SmallText"],
  ", the function produced by the global map command accepts as input words \
of arbitrary length. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(GlobalMapCA[rho, C150, Boundary \[Rule] None, 
      WordMap \[Rule] True]\), "\n", 
    \(ColumnForm[NestList[rho, "\<00000100000\>", 6]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
As the example shows, the word map is shrinking and can be iterated \
only a bounded number of times. In order to get a more useful analogue to the \
infinitary global map of a CA we can use one of two standard \
conventions:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\[EmptyCircle]  Peridic (cyclic) boundary conditions\nOne may think of the \
word as a cyclic string so that the last symbol is adjacent to the first. The \
global map can be defined for such cyclic strings in exactly the same way as \
for biinfinite words (in fact, cyclic words correspond precisely to periodic \
biinfinite words). \n\[EmptyCircle]  Fixed boundary conditions\n\
Alternatively, we can attach a prefix and suffix of length ",
  Cell[BoxData[
      \(TraditionalForm\`\((w - 1)\)/2\)]],
  " to the string, usually ",
  Cell[BoxData[
      \(TraditionalForm\`0\^\(\((w - 1)\)/2\)\)]],
  ", and apply the ordinary map to this augmented string. Again, length will \
be preserved and we can generate orbits of arbitrary length. Note that this \
approach does not have any immediate counterpart in the realm of biinfinite \
words. \n"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(GlobalMapCA[rhop, C150, Boundary \[Rule] Cyclic, 
      WordMap \[Rule] True]\), "\n", 
    \(GlobalMapCA[rhof, C150, Boundary \[Rule] Fixed, 
      WordMap \[Rule] True]\), "\n", 
    \(With[{L = Words[3, \(-2\)]}, 
      TableForm[{L, rhop /@ L, rhof /@ L}]]\)}], "Input"],

Cell[BoxData[
    \(ColumnForm[NestList[rhof, "\<000000010000000\>", 6]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note the use of the option WordMap->True everywhere.  Without, the global \
map expects lists as inputs rather than words, a format that is often more \
convenient since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provide numerous tools to manipulate lists. "
}], "Text"],

Cell[BoxData[{
    \(\(GlobalMapCA[rho, C150];\)\), "\n", 
    \(\(X = SeedConfiguration[{1}, 11];\)\), "\n", 
    \(\(orb = NestList[rho, X, 10];\)\), "\n", 
    \(MatrixForm[orb]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
For example, it is now easy to perform a frequency analysis on this \
orbit:\
\>", "Text"],

Cell[BoxData[
    \(Frequencies[Flatten[orb]]\)], "Input"],

Cell[TextData[{
  "Clearly, orbits can be nicely represented graphically. \nFor example, for \
C150 we obtain the following well-known pattern. The initial configuration is \
a one-point seed of the form ",
  Cell[BoxData[
      \(TraditionalForm\`00  \[Ellipsis]010\[Ellipsis]00\)]],
  "  and we generate the first 64 steps in the orbit."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(EvolutionCA[C150, 64, GridLines \[Rule] False];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The orbit (or rather, an initial segment thereof) of a configuration can \
be generated by the command ",
  StyleBox["OrbitCA", "SmallText"],
  ", which returns a list of configurations. "
}], "Text"],

Cell[BoxData[
    \(OrbitCA[C150, {0, 0, 0, 1, 0, 0, 0}, 30]\)], "Input"],

Cell[TextData[{
  " ",
  StyleBox["OrbitCA", "SmallText"],
  " accepts optional arguments that control periodic versus fixed boundary \
conditions. "
}], "Text"],

Cell[BoxData[{
    \(OrbitCA[C150, {1, 0, 0, 0}, 5]\), "\n", 
    \(OrbitCA[C150, {1, 0, 0, 0}, 5, Boundary \[Rule] Fixed]\)}], "Input"],

Cell[TextData[{
  "To generate seed configurations of the form  ",
  Cell[BoxData[
      \(TraditionalForm\`00  \[Ellipsis]0\ L\ 0  \[Ellipsis]00\)]],
  "  for some list ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and a given length we can use the command SeedConfiguration."
}], "Text"],

Cell[BoxData[{
    \(SeedConfiguration[{1}, 20]\), "\n", 
    \(SeedConfiguration[{1, 1, 1, 1, 1}, 20]\)}], "Input"],

Cell[TextData[{
  "We can pipe the output of ",
  StyleBox["OrbitCA", "SmallText"],
  " to ",
  StyleBox["PlotMatrix", "SmallText"],
  " to obtain the usual pictures. "
}], "Text"],

Cell[BoxData[{
    \(\(orb = 
        OrbitCA[C150, SeedConfiguration[{1, 1, 1, 1}, 20], 20];\)\), "\n", 
    \(\(PlotMatrix[orb];\)\), "\n", 
    \(\(PlotMatrix[orb, GridLines \[Rule] False];\)\)}], "Input"],

Cell[TextData[{
  "Alternatively, we can use the command ",
  StyleBox["EvolutionCA", "SmallText"],
  " which combines an orbit calculation with a plotting routine. "
}], "Text"],

Cell[BoxData[{
    \(\(Unprotect[X];\)\), "\n", 
    \(\(X = {1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1};\)\), "\n", 
    \(\(gr1 = 
        EvolutionCA[C150, X, 40, Boundary \[Rule] Fixed, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(gr2 = 
        EvolutionCA[C150, X, 40, Boundary \[Rule] Cyclic, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(ShowArray[{gr1, gr2}];\)\)}], "Input"],

Cell[BoxData[{
    \(\(X = 
        SeedConfiguration[{1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 1}, 
          40];\)\), "\n", 
    \(\(EvolutionCA[CA[110], X, 25];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Here are the orbits of a one-point seed pattern, traced for 25 \
steps, for all (2,2)-CAs.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(w = SeedConfiguration[{1}, 31];\)\), "\n", 
    \(\(gr = \((EvolutionCA[CA[#1, 2, \(-2\)], w, 25, 
                GridLines \[Rule] False, 
                DisplayFunction \[Rule] Identity] &)\) /@ 
          Range[0, 15];\)\), "\n", 
    \(\(ShowArray[gr];\)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Rules based on addition modulo ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " are easily generated using ",
  StyleBox["FunctionToCA", "SmallText"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Unprotect[C];\)\), "\[IndentingNewLine]", 
    \(C = FunctionToCA[Mod[\(+##1\), 4] &, 3, \(-4\)]\), "\n", 
    \(\(w = SeedConfiguration[Table[1, {10}], 50];\)\), "\n", 
    \(\(EvolutionCA[C, w, 50];\)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(EvolutionCA[C, w, 100, Cyclic \[Rule] False, 
        GridLines \[Rule] False];\)\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Here is Wolfram's example of a exceedingly simple rule that \
nonetheless appears to produce random patterns starting from a one-point \
seed. It is built from the Boolean operations 'or' and 'exclusive or':\
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[loc];\)\), "\n", 
    \(loc[x_, y_, z_] := Mod[x + Max[y, z], 2]\), "\n", 
    \(C = FunctionToCA[loc, 3, \(-2\)]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(EvolutionCA[C, 60, GridLines \[Rule] False];\)\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
No method is known to compute, say, the bit pattern down the middle \
column other than brute force simulation. Even for fairly small grids, rule \
30 produces long transients and cycles. Here is a glimpse at steps 800 - 1000 \
on a grid of size 200. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(orb = OrbitCA[C, SeedConfiguration[{1}, 200], 1000];\)\), "\n", 
    \(\(PlotMatrix[Drop[orb, 800], GridLines \[Rule] False];\)\)}], "Input"],

Cell[BoxData[
    \(Length[Union[orb]]\)], "Input"],

Cell[TextData[{
  "The left and right shift are generated by the commands ",
  StyleBox["LeftShiftCA", "SmallText"],
  " and ",
  StyleBox["RightShiftCA", "SmallText"],
  ", respectively."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(L = LeftShiftCA[\(-2\)]\), "\n", 
    \(R = RightShiftCA[\(-2\)]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(EvolutionCA[L, Table[Random[Integer, {0, 1}], {20}], 
        20];\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Composing\ CAs\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:10"],

Cell[TextData[{
  "Given two CAs  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  : \ 
        K\^\[Infinity]\ \  \[RightArrow] \ K\^\[Infinity]\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\  : \ \ K\^\[Infinity]\ \  \[RightArrow] \ 
          K\^\[Infinity]\)]],
  "  over the same alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " one can compose the maps to obtain a new CA  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\[VeryThinSpace]\[ThinSpace]\(\[Tau]\  : 
          K\^\[Infinity]\ \  \[RightArrow] \ K\^\[Infinity]\)\)]],
  ". The width of the composite CA is  ",
  Cell[BoxData[
      \(TraditionalForm\`w(\[Rho])\  + \ w(\[Tau])\  - \ 1\)]],
  ". Command ",
  StyleBox["ComposeCA", "SmallText"],
  " generates the appropriate CA. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C150 = CA[150, 3, \(-2\)];\)\), "\n", 
    \(\(C90 = CA[90, 3, \(-2\)];\)\), "\n", 
    \(CC = ComposeCA[C150, C90, External \[Rule] False]\), "\n", 
    \(PrintCA[CC]\), "\n", 
    \(\(EvolutionCA[CC, 40];\)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that there is an exponential increase in the size of the rule table, \
so one has to use composition with caution.\nCommand ",
  StyleBox["IterateCA", "SmallText"],
  " computes compositions of a CA with itself. Thus, starting at a CA ca[1] \
we can generate a sequence ca[t] of CAs of increasing width. One step in the \
evolution of a word on ca[t] coresponds to t steps in the evolution of the \
base automaton ca[1]. The width of  ca[t]  is  ",
  Cell[BoxData[
      \(TraditionalForm\`w\  + \ 2 \((t - 1)\)\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " is the width of ca[1]. Hence the size of  ca[t]  is  ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(w + 2 \((t - 1)\)\)\)]],
  "  (assuming a binary alphabet) and gets out of hand rather quickly. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ca[t_] := IterateCA[C150, t]\), "\n", 
    \(\(EvolutionCA[ca[3], 40];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Here is the result of composition with the left and right \
shift.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(L = LeftShiftCA[\(-2\)]\), "\n", 
    \(R = RightShiftCA[\(-2\)]\), "\n", 
    \(C = CA[51, 3, \(-2\)]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(EvolutionCA[C, 20];\)\), "\n", 
    \(\(EvolutionCA[ComposeCA[L, C], 20];\)\), "\n", 
    \(\(EvolutionCA[ComposeCA[R, C], 20];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Cellular automata (or rather, their global maps) commute with the \
shift.\
\>", "Text"],

Cell[BoxData[{
    \(ComposeCA[C, L] == ComposeCA[L, C]\), "\n", 
    \(ComposeCA[C, R] == ComposeCA[R, C]\)}], "Input"],

Cell["\<\
Applying a shift, or an iterated shift, is often helpful to get \
better of visual representations of orbits. Here is an example of a rule of \
width 5 that boils down to a \"Pascal's triangle mod 2\" after a shift. \
\
\>", "Text"],

Cell[BoxData[{
    \(C = CA[1717986918, 5, \(-2\)]\), "\n", 
    \(CR = ComposeCA[C, R]\)}], "Input"],

Cell[BoxData[{
    \(\(EvolutionCA[C, 40];\)\), "\n", 
    \(\(EvolutionCA[CR, 40];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
In this example, eliminating useless variables is actually a better \
line of attack.\
\>", "Text"],

Cell[BoxData[{
    \(CS = ShrinkCA[C]\), "\n", 
    \(\(EvolutionCA[CS, 50, GridLines \[Rule] False];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Elementary\ CAs\ and\ Symmetries\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:11"],

Cell[TextData[{
  "Binary CAs of width 3 are often referred to as elementary CAs. There are \
only 256 such automata, but they still display a wide variety of behaviors. \
Hence, they are ideally suited as a standard test set for algorithms. \
Actually, it is sometimes possible to limit one's attention to even fewer \
machines since they are already equivalent in some sense to the collection of \
all elementary CAs. An example are properties of the global maps of a CA such \
as injectivity and surjectivity. It is clear that these properties are \
invariant under permutations of the underlying alphabet. Thus, to speed up \
searches, we can eliminate CAs that can be obtained by such permutiations. \n\
As another example, let us determine how many elementary CAs are relevant to \
the study of their associated regular languages (see the next section). We \
can reduce the number of machines to be considered by interchanging 0 and 1 \
in the domain and/or range of the local map. Hence, we can associate any rule \
\[Rho] with four rules ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  = \ \[Rho]\_0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_3\)]],
  " (which are not necessarily all distinct). Note that this is not the same \
as topological conjugacy. \nFor example, for rule number 89 we get the four \
following labelings: "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lab0 = IntegerDigits[89, 2, 8];\)\), "\n", 
    \(\(lab1 = Reverse[lab0];\)\), "\n", 
    \(\(lab2 = 1 - lab0;\)\), "\n", 
    \(\(lab3 = Reverse[lab2];\)\), "\n", 
    \(ColumnForm[{lab0, lab1, lab2, lab3}]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "In general, these variants are obtained by defining local maps\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_0\)(X) = \[Rho](X)\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_1\)(X) = \[Rho](X\^c)\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_2\)(X) = \(\[Rho](X)\)\^c\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho]\_3\)(X) = \(\[Rho](X\^c)\)\^c\)]],
  "\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`Z\^c\)]],
  " denotes the result of exchanging 0's and 1's.  We call a rule \[Rho] is \
essential  iff  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  \[LessEqual] \ \[Rho]\_i\)]],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`i\  = \ 0, \[Ellipsis], 3\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "By Burnside's lemma, there are  ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(n - 2\) + 2\^\(n/2 - 1\)\)]],
  "  essential binary rules of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\^w\)]],
  ". In particular, there are 72 essential binary rules of width 3:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(L1 = \((Prepend[#1, 0] &)\) /@ KPermutationsR[{0, 1}, 7];\)\), "\n", 
    \(\(L2 = \((Union[{#1, Reverse[#1], 1 - #1, 1 - Reverse[#1]}] &)\) /@ 
          L1;\)\), "\n", 
    \(\(essentialrules = \((FromDigits[#1, 2] &)\) /@ 
          Union[First /@ L2];\)\), "\n", 
    \(essentialrules\), "\n", 
    \(Length[essentialrules]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Quiescent rules, i.e., those that map 000 to 0, have even code \
numbers.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(quiesc = Select[essentialrules, EvenQ]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Here are pictures of the evolution of a one point seed pattern for \
some essential quiescent binary rules of width 3. Note the size of the \
graphics object. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(gr = \((EvolutionCA[CA[#1, 3, 2], 40, GridLines \[Rule] False, 
                DisplayFunction \[Rule] Identity] &)\) /@ 
          quiesc;\)\)], "Input"],

Cell[BoxData[
    \(\(ShowArray[
        gr\[LeftDoubleBracket]{9, 11, 13, 
            15}\[RightDoubleBracket]];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ShowArray[Take[gr, \(-16\)]];\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cellular Automata and Regular Languages", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:12"],

Cell[CellGroupData[{

Cell[" de Bruijn Graphs and Fischer Automata", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:13"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Fischer\ Automata\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:14"],

Cell[TextData[{
  "As mentioned in the last section, the range of the global map ",
  StyleBox["\[Rho]",
    FontFamily->"Symbol"],
  " is a regular language ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL](\[Rho])\)]],
  " and one can use methods from automata theory to analyze these languages \
and their corresponding CAs. First, we need to convert a CA into a FSM that \
accepts ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL](\[Rho])\)]],
  ". There is an elegant construction of a FSM for a CA based on labeled de \
Bruijn graphs. (See also the section on local universal machines in the \
Guide.)  Suppose  ",
  Cell[BoxData[
      \(TraditionalForm\`B(r, K)\)]],
  "  is  the de Bruijn graph on vertex set K",
  StyleBox["r",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  ". Thus the edges are of the form \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\((a, \(x\_1\) \[Ellipsis]\ x\_\(r - 1\))\) \
\[RightArrow] \((\(x\_1\) \[Ellipsis]\ x\_\(r - 1\), b)\)\)]],
  ".\nNow suppose C is a CA over K with width ",
  Cell[BoxData[
      \(TraditionalForm\`w\  = \ r + 1\)]],
  ". Then the local map  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] : K\^\(r + 1\) \[RightArrow] K\)]],
  "   can be used to label the edges of the de Bruijn graph:  edge   ",
  Cell[BoxData[
      \(TraditionalForm\`\((a\[VeryThinSpace]x, x\[VeryThinSpace]b)\)\)]],
  "   is labeled by  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](a\[VeryThinSpace]x\[VeryThinSpace]b)\)]],
  ". Thus we obtain a semiautomaton whose transition diagram is the labeled \
de Bruijn graph. We will refer to this machine as ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho], r, K)\)]],
  " or simply ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  ". \nA Fischer automaton is a semiautomaton whose transition diagram is \
strongly connected. De Bruijn graphs are strongly connected (and even \
Hamiltonian), hence ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  " is a Fischer automaton. \[ScriptCapitalL](\[Rho]) is the acceptance \
language of this automaton and the configurations in the range of the global \
map  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  StyleBox["  ",
    FontFamily->"Symbol"],
  "correspond to (the labels of) biinfinite paths in ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  StyleBox[".\n\n",
    FontFamily->"Symbol"],
  "Here is a plain de Bruin graph: ",
  Cell[BoxData[
      \(TraditionalForm\`B(2, 3)\)]],
  ". Since the graph is ",
  Cell[BoxData[
      \(TraditionalForm\`\((3, 3)\)\)]],
  "-regular the number of paths of length ",
  Cell[BoxData[
      \(TraditionalForm\`r \[GreaterEqual] 2\)]],
  " from any vertex ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " to any other vertex ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  "  is  ",
  Cell[BoxData[
      \(TraditionalForm\`3\^\(r - 2\)\)]],
  StyleBox[". ",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  "The spectral radius of ",
  Cell[BoxData[
      \(TraditionalForm\`B(2, 3)\)]],
  " is 3. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(g = DeBruijnGraph[2, \(-3\), Normalize \[Rule] 1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(mat = Edges[ToAdjMatrix[g]];\)\), "\n", 
    \(MatrixForm[mat]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(MatrixForm[MatrixPower[mat, 5]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Max[Eigenvalues[mat]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Subgraphs of a de Bruijn graph are also useful to represent subshifts. In \
general, the number of words of length ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " in a subshift is ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\[CapitalTheta](\[Lambda]\^r)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " is the spectral radius of the corresponding adjacency matrix. For \
example, for the Fibonacci shift ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "is the golden ratio:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(mat = {{1, 1}, {1, 0}};\)\), "\n", 
    \(Eigenvalues[mat]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

Returning to CAs, we can use the command ToSA to transforms a CA into the \
corrseponding de Bruijn automaton. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(C150 = CA[150, 3, \(-2\)]\), "\n", 
    \(m150 = ToSA[C150]\)}], "Input",
  AspectRatioFixed->True],

Cell["Here are some words accepted by m150:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[LanguageFA[m150, \(-5\)]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Thus, m150 accepts all words up to lenght 5. In fact, m150 accepts \
all inputs: \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(MinimizeFA[m150]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "By compactness, it follows that the global map ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  : \ C\  \[RightArrow] \ C\)]],
  " is surjective. \nHere is a more interesting example: rule 76."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C76 = CA[76, 3, \(-2\)];\)\), "\n", 
    \(PrintCA[C76]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m76 = ToSA[C76];\)\), "\n", 
    \(mm76 = MinimizeFA[m76]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(L76 = LanguageFA[mm76, \(-5\)];\)\), "\n", 
    \(ColumnForm[L76]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordSort[Complement[Words[\(-5\), {0, 1}], Flatten[L76]]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
This suggests that the range of C76 is a subshift of finite type \
(SFT), i.e., the language of B(76,2,2) is a finite complement language: it \
consists of all words not containing a block 111. It is easy to verify this \
conjecture:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquivalentQFA[mm76, 
      ComplementFA[InfixFA["\<111\>", {0, 1}]]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\

As usual, the state set of mm76 has additional structure which is hidden by \
normalization. It can be make visible by repeating the computation with \
option Normalize->2 everywhere. We will come back to the structure of the \
states in a related power automaton in the section on inversion of reversible \
CAs below. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m0 = ToSA[C76, Normalize \[Rule] 2];\)\), "\n", 
    \(\(m1 = ToDFA[m0, Normalize \[Rule] 2];\)\), "\n", 
    \(\(m2 = MinimizeFA[m1, Normalize \[Rule] 2];\)\), "\n", 
    \(ColumnForm[States[m1]]\), "\n", 
    \(ColumnForm[States[m2]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A more systematic way to check whether a CA defines a SFT is to use the \
procedure ",
  StyleBox["NoProperInfixDFA", "SmallText"],
  " defined in the section Guide7. ",
  StyleBox["NoFactorFA[m]", "SmallText"],
  " builds an automaton that accepts all words x in the language of m such \
that no proper infix of x is also in the language. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(InfiniteQFA[
      MinimizeFA[NoFactorFA[ComplementFA[MinimizeFA[ToSA[C76]]]]]]\)], "Input",\

  AspectRatioFixed->True],

Cell[TextData[{
  "Since any Fischer automaton ",
  Cell[BoxData[
      \(TraditionalForm\`B(c, 2, 2)\)]],
  " has only four states, the corresponding minimal automaton can have no \
more than 16 states. Here is an example of a CA that reaches this bound: rule \
73."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C73 = CA[73, 3, \(-2\)];\)\), "\n", 
    \(mm73 = MinimizeFA[ToSA[C73]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((TableForm[#1, TableSpacing \[Rule] 1] &)\)[{Range[0, 10], 
        LanguageFA[mm73, \(-10\), SizeOnly \[Rule] True]}]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Thus, we have to consider words of length at least 6 before \
anything interesting happens.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(L6 = Complement[Words[6, 2], LanguageFA[mm73, 6]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(It\ appears\ that\ rule\ 73\ is\ symmetric . 
        One\ can\ check\ the\ rule\ table\)], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintCA[C73]\)], "Input",
  AspectRatioFixed->True],

Cell["or write a little program that does the checking.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(blocks = Words[3, \(-2\)];\)\), "\n", 
    \(\(rules = First[ToRulesCA[C73]];\)\), "\n", 
    \(\((blocks /. \[InvisibleSpace]rules)\) === \((WordReverse /@ 
            blocks /. \[InvisibleSpace]rules)\)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "One should not make premature conjectures, though, with respect to the \
language of C73: excluding blocks 111001 and 100111 is not enough. In fact, \
C73 is not a SFT. This can be verified using ",
  StyleBox["NoProperInfixDFA", "SmallText"],
  " as above.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(InfiniteQFA[MinimizeFA[NoFactorFA[ComplementFA[mm73]]]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Deterministic\ Semiautomata\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:15"],

Cell[TextData[{
  "A language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is ",
  StyleBox["factorial",
    FontColor->RGBColor[0, 0, 1]],
  " (or closed under infixes) iff  \n\t",
  Cell[BoxData[
      \(TraditionalForm\`u\ x\ v\ \  \[Element] \ L\)]],
  "  implies ",
  Cell[BoxData[
      \(TraditionalForm\`x\  \[Element] \ L\)]],
  ". \nA language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is ",
  StyleBox["transitive",
    FontColor->RGBColor[0, 0, 1]],
  " iff \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[ForAll] \ u, 
      v\  \[Element] \ 
        L\ \ \(\[Exists] \ x\ \((\ \ u\ x\ v\  \[Element] \ L\ )\)\)\)]],
  ". \n",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is strongly transitive iff all the words ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in the last definition can be chosen with uniform length. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "It is clear that the acceptance language of a Fischer automaton is \
factorial and transitive. The languages ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL](\[Rho])\)]],
  " are strongly transitive. One can show that the converse is also true for \
regular languages. In fact, there always is a deterministic Fischer automaton \
for any given factorial, transitive, regular language.  \n\nSuppose we have \
the minimal automaton of a factorial, transitive language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". We can decompose the automaton into its strongly connected components \
and pick one such component as the diagram for the Fischer automaton. \
Ignoring possible edges to the sink of the minimal automaton, the component \
has to have out-degree 0. As it turns out, there is only one such strongly \
connected component and the minimal deterministic Fischer automaton (i.e., \
with smallest possible state set) is unique up to isomorphism. \n\nWe \
construct the minimal automaton for rule 172, convert it to a graph ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ", and compute the non-transient strongly connected components of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C = CA[172, 3, \(-2\)];\)\), "\n", 
    \(ToSA[C]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m = MinimizeFA[ToSA[C]];\)\), "\n", 
    \({Size[m], TheSinkDFA[m]}\), "\n", 
    \(\(g = ToGraphFA[m];\)\), "\n", 
    \(gg = NonTransientGraph[g]\), "\n", 
    \(scc = 
      StronglyConnectedComponents[g, NonTrivial \[Rule] True]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
State 7 is the sink in m, so the first component is what we are \
after. Thus, we construct a new semiautomaton mm by restricting m to that \
component.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(mm = 
      ToSA[SelectFA[m, 
          scc\[LeftDoubleBracket]2\[RightDoubleBracket]]]\)], "Input",
  AspectRatioFixed->True],

Cell["The two machines ought to be equivalent:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquivalentQFA[m, mm]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Machine mm is minimal in the sense that it is accessible and \
different states have different behaviors. To see this we generate the \
minimal automata of the machines obtained by moving the initial state and \
check that they are non-isomorphic. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(minaut = \((MinimizeFA[SetInitialFA[mm, {#1}]] &)\) /@ 
          Range[7];\)\), "\n", 
    \(\(class = ToClasses[minaut, IsomorphicQDFA];\)\), "\n", 
    \(Length[class]\), "\n", 
    \(TableForm[class]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The union of the behavior of the 7 partial machines must be the \
full language (we convert the DFAs to FAs to speed up the union operation):\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(mmm = UnionFA @@ \(ToFA /@ minaut\)\), "\n", 
    \(IsomorphicQDFA[m, MinimizeFA[mmm]]\)}], "Input",
  AspectRatioFixed->True],

Cell["The next plot shows that CA[172,3,-2] is not surjective.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotComputationFA[ToSA[CA[172]], "\<1010\>"];\)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Direct\ Construction\ of\ a\ DFA\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:16"],

Cell[TextData[{
  "The de Bruiijn automata introduced above are naturally nondeterministic, \
except for a special rules. However,  it is quite straightforward to \
construct an equivalent DFA directly by hand (rather than resorting to \
deterministic simulation via the command ToDFA). The state set of the machine \
is ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP](K\^\(w - 1\))\)]],
  ", the initial state ",
  Cell[BoxData[
      \(TraditionalForm\`K\^\(w - 1\)\)]],
  ", all states other than ",
  Cell[BoxData[
      \(TraditionalForm\`\[EmptySet]\)]],
  StyleBox[" ",
    FontFamily->"Symbol"],
  "are final and the transition relation is defined by \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](A, 
          s)\  := \ {\ \ x\[VeryThinSpace]b\  | \ \ \[Exists] \ 
                a\  \[Element] \ \(K\  : \ 
                    a\[VeryThinSpace]x\  \[Element] \ A\ \  \[And] \ \ \[Rho](
                        a\[VeryThinSpace]x\[VeryThinSpace]b)\)\  = \ 
            s\ \ \ }\)]],
  ". \nOf course, there is no particular reason why one would want to \
construct this machine, but it makes for a nice exercise in programming in ",
  StyleBox["automata", "SmallText"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[CAToDFA];\)\), "\n", 
    \(\(Options[CAToDFA] = {Normalize \[Rule] 0};\)\), "\n", 
    \(\(CAToDFA[C_CA, opts___Rule] := 
        Module[{k, alph, w, n, lab, lab1, lab2, norm, Q, next, nextall}, 
          norm = \(Normalize /. \[InvisibleSpace]{opts}\) \
/. \[InvisibleSpace]Options[CAToDFA]; 
          next[S_, s_] := 
            Sort[Last /@ 
                Select[lab2\[LeftDoubleBracket]s\[RightDoubleBracket], 
                  MemberQ[S, First[#1]] &]]; 
          nextall[s_] := \((next[#1, s] &)\) /@ Q; 
          w = WidthCA[C]; {k, alph} = FullAlphabet[C]; 
          lab = First[ToRulesCA[C]] /. \[InvisibleSpace]Rule \[Rule] List; 
          lab1 = \((First /@ Cases[lab, {_, #1}] &)\) /@ alph; 
          lab2 = Map[{StringTake[#1, w - 1], StringTake[#1, 1 - w]} &, 
              lab1, {\(-1\)}]; Q = PowerSet[Words[w - 1, \(-k\)]]; 
          tr = \((PositionList[Q, nextall[#1]] &)\) /@ Range[k]; 
          n = 2\^\(k\^\(w - 1\)\); 
          If[norm == 0, DFA[n, Drei[C], tr, n, Range[2, n]], 
            DFA[Q, Drei[C], tr, n, Range[2, n]]]];\)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "As an example, we convert C150 to a DFA, once using ",
  StyleBox["CAToDFA", "SmallText"],
  " and once by constructing the full power set automaton from the \
corresponding semiautomaton."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C150 = CA[150, 3, \(-2\)];\)\), "\n", 
    \(m1 = CAToDFA[C150]\), "\n", 
    \(\(m2 = 
        ToDFA[ToSA[C150], Full \[Rule] True, 
          External \[Rule] False];\)\), "\n", 
    \(m1 === m2\)}], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Minimal\ DFAs\ for\ all\ Elementary\ CAs\)], \
"Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:17"],

Cell["\<\
We will compute all minimal automata associated with binary CAs of \
width 3. Clearly it would suffice to consider only all essential rules, but \
we will carry out the computation for all 256 elementary CAs. On a slow \
machine without the external code this may take a bit. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Timing[\(CAmin = \(({#1, MinimizeFA[ToSA[CA[#1]]]} &)\) /@ 
            Range[0, 255];\)]\)], "Input",
  AspectRatioFixed->True],

Cell["Here are the 30  surjective (3,2)-rules: ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(First /@ Cases[CAmin, {_, DFA[1, __]}]\), "\n", 
    \(Length[%]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
On the other end, there are 16 rules whose minimal DFAs have 16 \
states. The distribution of sizes is shown in the next plot. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(First /@ Cases[CAmin, {_, DFA[16, __]}]\), "\n", 
    \(Length[%]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[Frequencies[Size /@ \(Last /@ CAmin\)]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\((ListPlot[#1, PlotRange \[Rule] {{0, 256}, {0, 17}}, 
              Prolog \[Rule] PointSize[0.01], PlotStyle \[Rule] Blue, 
              Ticks \[Rule] {50\ Range[0, 5], Range[17]}] &)\)[
        Size[Last /@ CAmin]];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Removing duplicate machines from the list ",
  StyleBox["CAmin", "SmallText"],
  " leaves 85 DFAs. This can be done conveniently with the command ",
  StyleBox["RemoveDuplicates", "SmallText"],
  " from dimath.m. As it turns out, these remaining 85 machines are all \
non-isomorphic. See the section on isomorphism testing for an explanation of \
the test used below."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(CAmin1 = 
        Reverse /@ 
          RemoveDuplicates[Last /@ CAmin, First /@ CAmin, 
            OutPairs \[Rule] True];\)\), "\n", 
    \(Length[CAmin1]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Length[Union[AccessibleFA /@ \(Last /@ CAmin1\)]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
We can now visualize the languages of these automata. The following \
picture shows the acceptanced words of length k for all 85 machines as a \
raster plot. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(k = 6;\)\), "\n", 
    \(\(W = Words[k, \(-2\)];\)\), "\n", 
    \(\(lang = \((ToBitVector[
                LanguageFA[
                  CAmin1\[LeftDoubleBracket]#1, 2\[RightDoubleBracket], k], 
                W] &)\) /@ Range[85];\)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotMatrix[lang + 5, AspectRatio \[Rule] 1];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since all the languages ",
  Cell[BoxData[
      \(TraditionalForm\`L(\[Rho])\)]],
  " are factorial, it is of interest to find the shortest excluded words in \
these languages. In fact, many of these languages are finite complement: \
there are finitely words w such that all excluded words are of the form uwv. \
\nAs one can see from the picture (?) some of the machines accept all words \
of length 6. Here are the shortest words not accepted by the machines:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(sw = 
      TransferSequenceFA /@ \(ComplementFA /@ \(Last /@ CAmin1\)\)\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[{
    \(WordLength /@ Flatten[sw]\), "\n", 
    \(Max[%]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Machine number 44 (which corresponds to rule 37) misses a few words \
of length 9.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Cases[CAmin1, {37, _}]\), "\n", 
    \(\(m37 = Last[Last[%]];\)\)}], "Input"],

Cell[BoxData[
    \(LanguageFA[ComplementFA[m37], 9]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Minimizing\ Iterated\ CAs\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:18"],

Cell[TextData[{
  "We can generate a sequence ca[t] of CAs by starting with a fixed automaton \
ca[1] and applying it repeatedly. Thus, one step in the evolution of ca[t] \
coresponds to t steps in the evolution of the base automaton ca[1]. Note that \
the width of  ca[t]  is  w + 2(t-1)  where w is the width of ca[1]. Hence the \
size of  ca[t]  is  2",
  StyleBox["w + 2(t-1) ",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  " (assuming a binary alphabet) and gets out of hand rather quickly. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[ca];\)\), "\n", 
    \(\(ca[1] = \(C20 = CA[20, 3, \(-2\)]\);\)\), "\n", 
    \(\(ca[n_Integer?Positive] := \(ca[n] = 
          ComposeCA[C20, ca[n - 1]]\);\)\), "\n", 
    \(Scan[ca, Range[5]]\)}], "Input"],

Cell["The code numbers also grow exponentially: ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ca[5]\), "\n", 
    \(\((N[Log[First[ca[#1]]]] &)\) /@ Range[5]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Computation of the minimal automata will also take a few seconds, \
since the largest semiautomaton has 512 states. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[m];\)\), "\n", 
    \(m[i_] := \(m[i] = MinimizeFA[ToSA[ca[i]]]\)\)}], "Input"],

Cell[BoxData[
    \(m /@ Range[5]\)], "Input"],

Cell["\<\
Here are the growth functions of the automata up to length 12. As \
one can see, up to words of length 5 the functions agree. The values are \
decreasing since the languages form a descending sequence (by  definition of \
the automata). \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cencus = \((LanguageFA[m[#1], \(-12\), SizeOnly \[Rule] True] &)\) /@ 
          Range[5];\)\), "\n", 
    \(\((TableForm[#1, TableSpacing \[Rule] {1, 2}] &)\)[
      Prepend[cencus, Range[0, 12]]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Words of length 8 that are accepted by m[i] but rejected by m[i+1] \
are\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(k = 8;\)\), "\n", 
    \(\(diff = \((Complement[LanguageFA[m[#1], k], 
                LanguageFA[m[#1 + 1], k]] &)\) /@ Range[3];\)\), "\n", 
    \(ColumnForm[diff]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Surjectivity, Openess and Injectivity", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:19"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`The\ Method\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:20"],

Cell[TextData[{
  "The de Bruijn graph of a one-dimensional CA is also useful in determining \
certain properties of the global map of the CA. In this section we will show \
how to determine whether the map is injective, open or surjective. One can \
show that injectivity implies openess which implies surjectivity (the \
converse is false in each case). \nBy compactness, the global map is \
surjective iff the associated de Bruijn machine accepts",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(K\^*\)\)\)]],
  ". The latter property is often referred to as NFA Universality. \
Unfortunately, it is PSPACE-hard to test NFA Universality for general \
nondeterministic automata and the problem remains hard for Fischer automata.  \
However, there are quadratic time algorithms for all three properties based \
on the product of the de Bruijn graph with itself. \nThe key concept here is \
borrowed from automata theory: a finites state machine ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is unambiguous iff  there is no pair of states ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  "  in ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " such that there is are two distinct paths labeled ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  ". \nPut loosely: the unfolding of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " along ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " contains no diamonds, for all ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". \nAs it turns out, unambiguity of the associated de Bruijn automaton is \
equivalent with surjectivity of the local map, and stronger properties such \
openess and injectivity correspond to stronger notions of unambiguity. \nHere \
is an example:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C = CA[3915, 4, \(-2\)];\)\), "\n", 
    \(\(EvolutionCA[C, Table[Random[Integer, {0, 1}], {81}], 
        50];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
From the picture, it seems plausible that the global map is \
injective.  Let's take a look at the de Bruijn automaton. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(db = ToSA[C]\), "\n", 
    \(TableForm[DegreesFA[db]]\), "\n", 
    \(TableForm[DegreesFA[ReverseFA[db]]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since the machine as well as its reverse is non-deterministic,  it is \
quite conceivable that the there are two different computations on the same \
input, starting at some state ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and ending at some state ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  ". We can take a look at the unfolding of the de Bruijn automaton along \
some random word to check that in fact no diamonds seem to appear. "
}], "Text"],

Cell[BoxData[{
    \(w = RandomWord[10, \(-2\)]\), "\n", 
    \(\(PlotComputationFA[db, w];\)\)}], "Input"],

Cell[TextData[{
  "Here is a slightly more systematic approach: we look at the multiplicities \
of all words of length at most 8 in an associated unitary FA. Since the \
machine is strongly connected, we may safely consider only the case, say,  ",
  Cell[BoxData[
      \(TraditionalForm\`p\  = \ \(q\  = \ 1\)\)]],
  " (though the length of a hypothetical counterexample might decrease by a \
different choice). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(fa = SetInitialFinalFA[db, {1}, {1}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[
      ToSeries[FlattenOne[
          LanguageFA[fa, \(-8\), Multiplicity \[Rule] True]]]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "All words in this language have multiplicity 1, as required. Of course, \
this last computation proves nothing. To demonstrate that the CA is \
injective, we have to use a product automaton construction. \nThe product of \
two labeled graphs is defined by \n\t",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ V\_1\[Cross]\ V\_2\)]],
  " \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\)\(\ \)\(=\)\(\ \)\({\ \ \((\ \((u\_1, 
                u\_2)\), \ 
              a, \ \((v\_1, 
                v\_2)\)\ )\)\ \  | \ \ \ \ \((u\_1, a, v\_1)\)\  \[Element] \ 
                E\_1\  \[And] \ \ \ \((u\_2, a, v\_2)\)\  \[Element] \ 
                E\_\(\(2\)\(\ \)\)}\)\(\ \)\)\)]],
  "\nA strongly connected component (SCC) of a digraph  is a maximal vertex \
induced subgraph with every two nodes lying on a cycle. A strongly connected \
component is non-trivial iff it contains an edge.\n\nThe algorithms are based \
on the following proposition. Let \[Rho] be a one-dimensional cellular \
automaton and ",
  Cell[BoxData[
      \(TraditionalForm\`B\^2\)]],
  " the product of ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  " with itself. Note that ",
  Cell[BoxData[
      \(TraditionalForm\`B\^2\)]],
  " contains a copy of the original graph, namely the diagonal which we will \
call ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  ". \n\n(1) The global map is surjective iff ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  "  is unambiguous  iff  the strongly connected component in ",
  Cell[BoxData[
      \(TraditionalForm\`B\^2\)]],
  " that contains ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  ".\n(2)  The global map is open  iff  the strongly connected component of \
",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " and is isolated (there are no paths from or to other nontrivial strongly \
connected components). \n(3)  The global map is reversible (injective) iff ",
  Cell[BoxData[
      \(TraditionalForm\`B\^2\)]],
  " has only one nontrivial strongly connected component, namely ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  ". \n\nTo illustrate this method we first generate the labeled de Bruijn \
graph B150 for rule 150. The we compute the product BB, translate it into a \
graph suitable as input for the command StronglyConnectedComponents and \
compute the strongly connected components. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
All words in this language have multiplicity 1, as required. Of \
course, this last computation proves nothing. To demonstrate that the CA is \
injective, we have to use a product automaton construction. First, we compute \
the product automaton db2. 
Then, we translate db2 into a dircted graph gr and compute the strongly \
connected components. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(db2 = ProductFA[db, db]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(gr = ToGraphFA[db2]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(StronglyConnectedComponents[gr]\), "\n", 
    \(\(\(Curry[StronglyConnectedComponents]\)[NonTrivial \[Rule] True]\)[
      gr]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The first component is the diagonal, an isomorpic copy of the \
original automaton, and all the other vertices form trivial SCCs. Thus, the \
CA is indeed injective. 

Here is another example:  rule 150. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(db = ToSA[CA[150, 3, \(-2\)]];\)\), "\n", 
    \(TableForm[DegreesFA[db]]\), "\n", 
    \(TableForm[DegreesFA[ReverseFA[db]]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
So, rule 150 is biderministic and might look like a promising \
candidate for an injecive rule.  However, a moment's thought reveals that the \
sequence  ...0110110110110.. is mapped to 0 by rule 150, as is the \
0-sequence. 
The problem here is that the source and target p and q have moved out into \
infinity. To take into account this and similar problems we have to insist \
that the diagonal is the only non-trivial strongly connected components in \
the product automaton, a test that rule 150 promptly fails.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(StronglyConnectedComponents[ToGraphFA[ProductFA[db, db]]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
The first component is the diagonal, the other compises all \
remaining vertices. Thus, there are two SCCs and there are no edges between \
them. Hence the global map is open (and thus surjective) but not reversible. \
The command ClassifyCA performs all these operations. The internal version \
has the option Full->True which causes the collapse of the square of the de \
Bruijn graph to be displayed. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Information["\<ClassifyCA\>", LongForm \[Rule] False]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[ClassifyCA[CA[51, 3, \(-2\)], Full \[Rule] True]]\)], "Input",\

  AspectRatioFixed->True],

Cell["\<\
In this case, there is only one nontrivial \
StronglyConnectedComponents, namely the diagonal. Hence, rule 51 is \
reversible. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[ClassifyCA[CA[60, 3, \(-2\)], Full \[Rule] True]]\)], "Input",\

  AspectRatioFixed->True],

Cell["\<\
Rule 60 is open: there is a component other than the diagonal, but \
there are no paths between the components. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[ClassifyCA[CA[89, 3, \(-2\)], Full \[Rule] True]]\)], "Input",\

  AspectRatioFixed->True],

Cell["\<\
Rule 89 is surjective but not open: for example, there is a path \
from some component to the diagonal. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[ClassifyCA[CA[22, 3, \(-2\)], Full \[Rule] True]]\)], "Input",\

  AspectRatioFixed->True],

Cell[TextData[{
  "Lastly, rule 22 is not even surjective. The whole product graph forms one \
strongly connected component. \n\nNote that the product graph as defined \
above ought to have 16 nodes. To speed up computation, the procedure \
ClassifyCA exploits symmetries in that graph and computes only the part above \
the diagonal (i.e., nodes ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(1\  \[LessEqual] \ i\  \[LessEqual] \ 
        j\  \[LessEqual] \ n\)\)\)]],
  "). Thus, there are only  ",
  Cell[BoxData[
      \(TraditionalForm\`\(n(n + 1)\)/2\)]],
  " nodes. \n\nCommand ClassifyCA works for CAs of arbitrary width--in \
principle. Since the size of the graph is exponential in the width of the \
automaton, width 5 is a realistic barrier. For larger alphabets smaller \
widths are appropriate. \n\nThe identity map is always injective: there is \
exactly one non-trivial SCC, namely the copy of the original de Bruijn graph. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(id[w_, k_] := 
      FunctionToCA[{##1}\[LeftDoubleBracket]
            Ceiling[w\/2]\[RightDoubleBracket] &, w, k]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(id[4, \(-3\)]\), "\n", 
    \(Timing[ClassifyCA[id[4, \(-3\)]]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The following three rules of width four are injective, open but not \
injective, and not even surjective, respectively.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ClassifyCA[CA[43690, 4, \(-2\)]]\), "\n", 
    \(ClassifyCA[CA[38505, 4, \(-2\)]]\), "\n", 
    \(ClassifyCA[CA[43754, 4, \(-2\)]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The second rule corresponds to addition modulo 2 and is easily \
generalized to arbitrary widths.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[sigma];\)\), "\n", 
    \(\(sigma[w_Integer] := 
        FunctionToCA[Mod[\(+##1\), 2] &, w, \(-2\)];\)\), "\n", 
    \(TableForm[sigma /@ Range[6]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((ClassifyCA[sigma[#1]] &)\) /@ Range[6]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Thus, addition modulo 2 seems to produce an open but not reversible \
rule, except in the trivial case width = 1. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

Here is another example of a rule of width 4 that is surjective but fails to \
be open. There are four nontrivial SCCs in the product graph and there is a \
path from the  diagonal to two of them (the diagonal is the component of size \
8, in the current implementation it appears in position 9). \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \({i, g} = ClassifyCA[CA[19890, 4, \(-2\)], Full \[Rule] True]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(V = VertexSet[g];\)\), "\n", 
    \(nontriv = PositionList[V, Select[V, Length[#1] > 1 &]]\), "\n", 
    \(EnumForm[\((WeaklyConnectedComponents[g, #1] &)\) /@ 
        nontriv]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Binary\ CAs\ of\ Width\ 3\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:21"],

Cell["\<\
To test all binary CAs of width 3 for injectivity, openess and \
surjectivity we could use the list  essentialrules from above (the \
equivalence of isomorphic rules defined in the last section clearly preserves \
these properties). To speed things up we will only consider those labelings \
that are 1-balanced, i.e., that have the same number of 0's and 1's. As is \
pointed out in the section on multiplicity below, all surjective rules are \
1-balanced (and in fact are balanced in a much stronger sense). Only 23 rules \
remain. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ess1bal = 
      Select[essentialrules, 
        Plus @@ IntegerDigits[#1, 2, 8] == 4 &]\), "\n", 
    \(Length[ess1bal]\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ess1bal = 
      Select[Range[0, 127], Plus @@ IntegerDigits[#1, 2, 8] == 4 &]\), "\n", 
    \(Length[ess1bal]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({15, 23, 27, 29, 30, 39, 43, 45, 46, 51, 53, 54, 57, 58, 60, 71, 75, 
      77, 78, 83, 85, 86, 89, 90, 92, 99, 101, 102, 105, 106, 108, 113, 114, 
      116, 120}\)], "Output"],

Cell[BoxData[
    \(35\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(class = \(({#1, ClassifyCA[CA[#1, 3, 2]]} &)\) /@ 
          ess1bal;\)\)], "Input",
  AspectRatioFixed->True],

Cell["We can now extract the various types of rules as follows.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(inj = First /@ Cases[class, {_, 3}]\), "\n", 
    \(open0 = First /@ Cases[class, {_, 2}]\), "\n", 
    \(surj0 = First /@ Cases[class, {_, 1}]\), "\n", 
    \(open = Sort[Join[inj, open0]]\), "\n", 
    \(surj = Sort[Join[surj0, open]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({15, 51, 85}\)], "Output"],

Cell[BoxData[
    \({60, 90, 102, 105}\)], "Output"],

Cell[BoxData[
    \({30, 45, 75, 86, 89, 101, 106, 120}\)], "Output"],

Cell[BoxData[
    \({15, 51, 60, 85, 90, 102, 105}\)], "Output"],

Cell[BoxData[
    \({15, 30, 45, 51, 60, 75, 85, 86, 89, 90, 101, 102, 105, 106, 
      120}\)], "Output"]
}, Open  ]],

Cell["\<\
Note that for all the injective CAs the local maps are simply \
Boolean functions of one of the arguments (since we only consider essential \
rules,only complement occurs):\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[
      Transpose[\((First[ToRulesCA[CA[#1, 3, \(-2\)]]] &)\) /@ 
          inj]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
This can be made very clearly visible by deleting variables that \
the local map does not depend on:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[\((ShrinkCA[CA[#1, 3, \(-2\)]] &)\) /@ inj]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`F - surjective\ CAs\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:22"],

Cell[TextData[{
  "Another interesting property of the global map of a CA is its behavior on \
finite configurations. Here a configuration is called finite iff its support \
is finite, i.e., if only finitely many cells are in a state different from 0. \
The automata under consideration will always assumed to be quiescent: the all \
0's configuration ",
  StyleBox["0",
    FontWeight->"Bold"],
  " is mapped to itself. \nBy compactness, F-surjective implies surjective. \n\
One can show that a surjective CA is F-surjective iff the preimage of ",
  StyleBox["0",
    FontWeight->"Bold"],
  " is ",
  StyleBox["0",
    FontWeight->"Bold"],
  ". The latter property is easily tested by searching for cycles labeled 0 \
in the de Bruijn graph after deletion of the edge ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 0, 0)\)\)]],
  ". \n\nHere are all the quiescent binary rules of width 2 (up to \
isomorphism, see the previous section). Command FSurjectiveCA tests for \
F-surjectivity. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(surjq = \((If[EvenQ[#1], #1, 255 - #1] &)\) /@ surj\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({240, 30, 210, 204, 60, 180, 170, 86, 166, 90, 154, 102, 150, 106, 
      120}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L1 = \((FSurjectiveCA[CA[#1, 3, \(-2\)]] &)\) /@ surjq;\)\), "\n", 
    \(\(L2 = \((ClassifyCA[CA[#1, 3, \(-2\)]] &)\) /@ surjq;\)\), "\n", 
    \(\((TableForm[#1, TableSpacing \[Rule] {1, 2}] &)\)[{surjq, L1, 
        L2}]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    TagBox[GridBox[{
          {"240", "30", "210", "204", "60", "180", "170", "86", "166", "90", 
            "154", "102", "150", "106", "120"},
          {"1", "0", "0", "1", "0", "1", "1", "0", "1", "0", "0", "0", "0", 
            "0", "0"},
          {"3", "1", "1", "3", "2", "1", "3", "1", "1", "2", "1", "2", "2", 
            "1", "1"}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {1, 2}]]]], "Output"]
}, Open  ]],

Cell["\<\
Thus, with the exception of rule 166, all F-surjetive (3,2)-CAs are \
aleady injective. Note that F-sujective CAs may or may not be open. \
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Highly\ Symmetric\ Rules\)], "Subsection",
  CellTags->"c:23"],

Cell[TextData[{
  "One can use  the operation ",
  StyleBox["ListMultiply", "SmallText"],
  "  to generate highly symmetric rule tables that produce surjective (albeit \
trivial) automata. The basic idea is to define a function on binary lists as \
follows.\n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`F(\ L, \ {0})\  = \ Join[L, L]\)]],
  ",\n\t",
  Cell[BoxData[
      \(TraditionalForm\`F(\ L, \ {1}\ )\  = \ Join[\ L, \ 1 - L\ ]\)]],
  "\n\t\nExtend  to  ",
  Cell[BoxData[
      \(TraditionalForm\`F(\ L, \ B\ )\)]],
  "  in the obvious way.  "
}], "Text"],

Cell[BoxData[{
    \(ClearAll[F, ff, L, b]\), "\n", 
    \(\(ff[L_List, b_Integer] := ListMultiply[L, {0, b}];\)\), "\n", 
    \(\(F[L_List, B_List] := Fold[ff, L, B];\)\), "\n", 
    \(\(F[B_List] := Fold[ff, {0}, B];\)\)}], "Input"],

Cell[TextData[{
  "Here is a trace of the computation of  ",
  Cell[BoxData[
      \(TraditionalForm\`F[{0}, \ {0, 1, 0, 1, 0}]\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(L = FoldList[ff, {0}, {0, 1, 0, 1, 0}];\)\), "\n", 
    \(\((TableForm[#1, TableSpacing \[Rule] {0, 0}] &)\)[L]\), "\n", 
    \(Frequencies[Last[L]]\)}], "Input"],

Cell[TextData[{
  "It is not hard to show that for any binary list ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " of length ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " other than ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 0, \[Ellipsis], 0)\)\)]],
  "  we always have ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(#\_0\) \(F({0}, 
            B)\)\  = \ \ \(#\_1\) \(F({0}, B)\)\)\)\)]],
  ".  Here is a test for all lists of length 32. "
}], "Text"],

Cell[BoxData[{
    \(\(BB = F /@ Rest[CartesianProduct @@ Table[{0, 1}, {5}]];\)\), "\n", 
    \(\((Count[#1, 1] &)\) /@ BB\)}], "Input"],

Cell[BoxData[
    \(\(PlotMatrix[BB];\)\)], "Input"],

Cell["\<\
And here are the corresponding binary cellular automata of width 5.\
\
\>", "Text"],

Cell[BoxData[
    \(\(class = \((With[{rr = FromDigits[#1, 2]}, {ClassifyCA[
                    CA[rr, 5, \(-2\)]], rr}] &)\) /@ BB;\)\)], "Input"],

Cell[BoxData[
    \(TableForm[Frequencies[First /@ class]]\)], "Input"],

Cell["\<\
All the CAs are open or even reversible.  Perhaps surprisingly, we \
can make things a bit more complicated by rotating the lists and still obtain \
only surjective automata. 
Unfortunately, the reversible ones are not very interesting. \
\>", "Text"],

Cell["\<\
But the open ones are at least in part real width 5 automata. \
\
\>", "Text"],

Cell["Alas, they are all deterministic.", "Text"],

Cell[BoxData[{
    \(\(rot[L_List] := \((RotateLeft[L, #1] &)\) /@ 
          Range[Length[L]];\)\), "\n", 
    \(\(BBB = Union[FlattenOne[rot /@ BB]];\)\), "\n", 
    \(Length[BBB]\)}], "Input"],

Cell["Without the external code this will take a bit. ", "Text"],

Cell[BoxData[
    \(\(class = \((With[{rr = FromDigits[#1, 2]}, {ClassifyCA[
                    CA[rr, 5, \(-2\)]], rr}] &)\) /@ BBB;\)\)], "Input"],

Cell[BoxData[
    \(TableForm[Frequencies[First /@ class]]\)], "Input"],

Cell["\<\
Unfortunately, the reversible ones are not very interesting: they \
shrink to width 1.\
\>", "Text"],

Cell[BoxData[
    \(Union[\((ShrinkCA[CA[#1, 5, 2]] &)\) /@ \(Last /@ 
          Cases[class, {3, _}]\)]\)], "Input"],

Cell["\<\
And the open maps turn out to be somewhat boring, too: the ones of \
real width 5 are all deterministic. \
\>", "Text"],

Cell[BoxData[
    \(\(\((ShrinkCA[CA[#1, 5, 2]] &)\) /@ \(Last /@ 
          Cases[class, {2, _}]\);\)\)], "Input"],

Cell[BoxData[
    \(W5 = Select[%, WidthCA[#1] == 5 &]\)], "Input"],

Cell[BoxData[
    \(Union[\((DeterministicQFA[ToSA[#1]] &)\) /@ W5]\)], "Input"],

Cell["\<\
There remain 128 surjective automata that all fail to be \
deterministic, but they are codeterministic.\
\>", "Text"],

Cell[BoxData[{
    \(\(W5 = 
        Select[\((ShrinkCA[CA[#1, 5, \(-2\)]] &)\) /@ \(Last /@ 
              Cases[class, {1, _}]\), WidthCA[#1] == 5 &];\)\), "\n", 
    \(Length[W5]\)}], "Input"],

Cell[BoxData[{
    \(Union[\((DeterministicQFA[ToSA[#1]] &)\) /@ W5]\), "\n", 
    \(Union[\((CodeterministicQFA[ToSA[#1]] &)\) /@ W5]\)}], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiplicity and Welch Indices", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:24"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Multiplicity\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:25"],

Cell[TextData[{
  "There is a wealth of information about the connections between properties \
of the global map of a one-dimensional CA such as surjectivity and properties \
of the corresponding finite state machines. For example, \n- the global map \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  : 
        K\^\[Infinity]\ \[LongRightArrow]\ K\^\[Infinity]\)]],
  " is surjective iff \n- the acceptance language of the de Bruijn automaton \
",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  " is the set of all finite strings over the alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  "  iff \n- every word has multiplicity ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ k\^\(w - 1\)\)]],
  " is the number of states of ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Balance\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:26"],

Cell["\<\
As pointed out above, surjectivity testing via acceptance languages \
is computationally very inefficient. In general, the problem of testing \
whether a Fischer automaton accepts all inputs is PSPACE-complete (at least \
for alphabets of size larger than 2). However, we can use minimization to \
verify that all the (3,2)-CAs computed above are at indeed surjective.\
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Union[\((MinimizeFA[ToSA[CA[#1]]] &)\) /@ surj]\)], "Input"],

Cell[BoxData[
    \(The\ multiplicities\ of\ accepted\ words\ can\ be\ determined\ using\ \
option\ Multiplicity\ in\ the\ command\ LanguageFA . 
        For\ rule\ 60\ for\ example\ all\ words\ have\ multiplicity\ 4. \)], \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[
      ToSeries[LanguageFA[ToSA[CA[60, 3, 2]], 5, 
          Multiplicity \[Rule] True]]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We have switched to alphabet  ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " for the sake of legibility.  For the nonsurjective rule 73 on the other \
hand we obtain:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(L = 
        LanguageFA[ToSA[CA[73, 3, 2]], 6, 
          Multiplicity \[Rule] True];\)\), "\n", 
    \(ColumnForm[ToSeries[L]]\), "\n", 
    \(Plus @@ \(Last /@ L\)\), "\n", 
    \(Complement[Words[6, 2], First /@ L]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Option ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["Multiplicity",
            "SmallText"], "\.08"], TraditionalForm]]],
  " surpresses words with multiplicity 0, thus the two missing words are not \
listed and have to be computed separately. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the multiplicity characterization for surjective rules implies \
that labelings in a surjective rule must be ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "-balanced for all ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ": every word of lenght ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " is accepted equally often by the de Bruijn semiautomaton. Hence we can \
weed out all rules that fail to be ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "-balanced without using the classification algorithm. \nThe following \
procedure tests whether a CA is ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "-balanced. It assumes that all symbols in ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " appear in the range of the local map. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[balanceQ];\)\), "\n", 
    \(\(balanceQ[C_CA, 1] := 
        Equal @@ \(Last /@ Frequencies[ToLabelCA[C]]\);\)\), "\n", 
    \(\(balanceQ[C_CA, b_Integer] := 
        Equal @@ \(Last /@ 
            LanguageFA[ToSA[C], b, 
              Multiplicity \[Rule] True]\);\)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "For example, ",
  Cell[BoxData[
      \(TraditionalForm\`CA[11173, 4, 2]\)]],
  " is 1-balanced but not 2-balanced (and therefore not surjective). \
Similarly, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(CA[194310571, 3, 3]\)\(\ \ \)\)\)]],
  " is 3-balanced but not 4-balanced."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(C = CA[11173, 4, 2]\), "\n", 
    \(balanceQ[C, 1]\), "\n", 
    \(balanceQ[C, 2]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(C = CA[194310571, 3, 3]\), "\n", 
    \(balanceQ[C, 3]\), "\n", 
    \(balanceQ[C, 4]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The function ",
  StyleBox["balanceQ", "SmallText"],
  " can be iterated to filter out ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "-balanced rules (this takes a few seconds):"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(pick[LL_List, b_Integer] := 
      Select[LL, balanceQ[CA[#1], b] &]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cnt = 0;\)\), "\n", 
    \(\(bal = FixedPointList[pick[#1, \(++cnt\)] &, Range[254]];\)\), "\n", 
    \(Length[bal]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Last[bal]\)], "Input"],

Cell[BoxData[
    \(\((ClassifyCA[CA[#1]] &)\) /@ Last[bal]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus, all 3-balanced binary rules of width 3 are already surjective.\n\nOf \
course, the use of ",
  StyleBox["LanguageFA", "SmallText"],
  " in ",
  StyleBox["balanceQ", "SmallText"],
  " makes this approach very inefficient. To obtain a better algorithm it is \
best to use an external program that generates only 1-balanced labelings to \
start with and then eliminates ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "-unbalanced rules for some small value of ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ". This provides a speed-up since testing for ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "-balance takes some ",
  Cell[BoxData[
      \(TraditionalForm\`O(k\^\(w + b - 1\))\)]],
  " steps and the classification algorithm is ",
  Cell[BoxData[
      \(TraditionalForm\`O(k\^\(2  w\))\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`The\ multilplicity\ matrix\ semigroup\)], \
"Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:27"],

Cell[TextData[{
  "The multiplicity property of surjective CAs can also be visualized using \
the semigroup of integer matrices associated with the de Bruijn automaton ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\  = \[LeftAngleBracket]Q, 
          K, \[Delta]\[RightAngleBracket]\)]],
  ". For any symbol ",
  Cell[BoxData[
      \(TraditionalForm\`a\  \[Element] \ K\)]],
  " let ",
  Cell[BoxData[
      \(TraditionalForm\`M\_a\)]],
  " be the ",
  Cell[BoxData[
      \(TraditionalForm\`Q\[Cross]Q\)]],
  " matrix defined by\n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`M\_a[p, q] = 1\)]],
  "  if there is a transition ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, a, q)\)\)]],
  ", and 0 otherwise. \n\t\nWe can extend this definition to words over ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " and obtain a homomorphism\n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\  : \ \(K\^*\)\[LongRightArrow]\ Q\ \[Cross]\ 
          Q\ \[LongRightArrow]\ \[DoubleStruckCapitalN]\)]],
  "\n\t\nfrom the words over ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  "  to non-negative integer matrices. The image of this homomorphism is the \
semigroup ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(\ \)\)\)]],
  " generated by ",
  Cell[BoxData[
      \(TraditionalForm\`M\_a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\  \[Element] \ K\)]],
  ".  The most important property of this semigroup is captured in the \
following theorem."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Theorem",
    FontWeight->"Bold"],
  ":  The cellular automaton \[Rho] is surjective iff the associated matrix \
semigroup ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is finite."
}], "Text"],

Cell[TextData[{
  "One can provide a direct proof of this fact using the Frobenius-Perron \
theorem (i.e., circumventing automata theory).  The key observation is that \
the matrix semigroup is finite iff it fails to contain the 0 matrix. It \
follows that all the multiplicity matrices of surjective automaton are \
actually 0/1-matrices. Moreover, their  1-norm is always  ",
  Cell[BoxData[
      \(TraditionalForm\`n = \(\(\(|\)\(Q\)\(|\)\) = k\^\(w - 1\)\)\)]],
  ". \nHere is an example. We define an auxiliary procedure  ",
  StyleBox["makematrix", "SmallText"],
  "  that computes a list of the generator matrices ",
  Cell[BoxData[
      \(TraditionalForm\`M\_a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\  \[Element] \ K\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(makematrix[
        C_CA] := \[IndentingNewLine]Module[{sa, ff}, \[IndentingNewLine]\t
        sa = ToSA[C]; \[IndentingNewLine]\t
        TransitionMatrixFA[sa, ff]; \[IndentingNewLine]\t
        ff /@ Alphabet[sa]\[IndentingNewLine]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gen = makematrix[CA[150, 3, 2]];\)\), "\n", 
    \(MatrixForm /@ gen\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
At current, the external code handles only transition semigroups, \
so we have to use the internal algorithm to generate the semigroup. Also note \
that it is a good idea to test for surjectiveness first so that one does not \
attempt to generate an infinite semigroup. \
\>", "Text"],

Cell[BoxData[
    \(oneNorm[M_] := Plus @@ Abs[Flatten[M]]\)], "Input"],

Cell[BoxData[{
    \(\(S = GenerateSG[GEN[4, 2, gen], External \[Rule] False];\)\), "\n", 
    \(Length[S]\), "\n", 
    \(oneNorm /@ ToList[S]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
A picture of the matrix semigroup shows that there is a unique \
computation starting at each state for each input. \
\>", "Text"],

Cell[BoxData[{
    \(\(gr = \((PlotMatrix[#1, DisplayFunction \[Rule] Identity] &)\) /@ 
          ToList[S];\)\), "\n", 
    \(\(ShowArray[gr, 4, GraphicsSpacing \[Rule]  .2];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Since the de Bruijn automaton is a permutation automaton \
(deterministic and codeterministic), all the matrices are permutation \
matrices. 
For injective rule 51 there are only 4 matrices:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gen = makematrix[CA[51, 3, 2]];\)\), "\n", 
    \(MatrixForm /@ gen\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(S = GenerateSG[GEN[4, 2, gen], External \[Rule] False];\)\), "\n", 
    \(Length[S]\), "\n", 
    \(oneNorm /@ ToList[S]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gr = \((PlotMatrix[#1, DisplayFunction \[Rule] Identity] &)\) /@ 
          ToList[S];\)\), "\n", 
    \(\(ShowArray[gr];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Note that these matrices have rank 1 and fail to be invertible. 
Lastly, an example for a rule of width 4. This time, the semigroup has size \
77. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ClassifyCA[CA[13628, 4, 2]]\), "\n", 
    \(\(gen = makematrix[CA[13628, 4, 2]];\)\), "\n", 
    \(\({S, wit, eq} = 
        GenerateSG[GEN[8, 2, gen], External \[Rule] False, 
          Equations \[Rule] True];\)\), "\n", 
    \(Length[S]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
For the further study of this matrix semigroup the collection of \
matrices of minimal rank turns out to be important. \
\>", "Text"],

Cell[BoxData[{
    \(\(rank[m_?MatrixQ] := 
        Last[Dimensions[m]] - Length[NullSpace[m]];\)\), "\n", 
    \(\(SS = ToList[S];\)\), "\n", 
    \(\(rk = rank /@ SS;\)\), "\n", 
    \(TableForm[Frequencies[rk]]\)}], "Input"],

Cell["There are 24 matrices of minimal rank 1.", "Text"],

Cell[BoxData[{
    \(\(pos = Flatten[Position[rk, Min[rk]]];\)\), "\n", 
    \(\(mS = SS\[LeftDoubleBracket]pos\[RightDoubleBracket];\)\), "\n", 
    \(\(gr = \((PlotMatrix[#1, DisplayFunction \[Rule] Identity] &)\) /@ 
          mS;\)\), "\n", 
    \(\(ShowArray[gr, 6];\)\)}], "Input"],

Cell[TextData[{
  "These matrices form an ideal ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  ", i.e., we have  ",
  Cell[BoxData[
      \(TraditionalForm\`S\ I\ S\  \[SubsetEqual] \ I\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(eqq = SimplifyRewriteSystem[eq];\)\), "\n", 
    \(mwit = wit\[LeftDoubleBracket]pos\[RightDoubleBracket]\), "\n", 
    \(Length[mwit]\)}], "Input"],

Cell[BoxData[{
    \(w = 
      RandomWord[10, 2] <> 
        mwit\[LeftDoubleBracket]Random[
            Integer, {1, 24}]\[RightDoubleBracket] <> 
        RandomWord[10, 2]\), "\n", 
    \(WordReduce[w, eqq]\), "\n", 
    \(Position[mwit, %]\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Welch\ Indices\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:28"],

Cell[TextData[{
  "There are several interesting numerical parameters that can be associated \
with a surjective one-dimensional CA. \nThe first such parameter is the least \
number of preimages of any biinfinite word under ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " which we will denote ",
  Cell[BoxData[
      FormBox[
        FormBox[\(\(W\_m\)(\[Rho])\),
          "TraditionalForm"], TraditionalForm]]],
  ". Hence for an injective rule we have ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(W\_m\)(\[Rho]) = \ 1\)\)\)]],
  ", and, more generally, for any open rule the number of preimages of any \
biinfinite word in the range of \[Rho]  is always equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_m\)(\[Rho])\)]],
  ". One can show that this number is always realized by some bilaterally \
transitive word (a biinfinte word such that every finite word occurs to the \
left as well as to the right of the origin). In terms of the de Bruijn \
automaton ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  " we can describe ",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_m\)(\[Rho])\)]],
  " as follows. For any finite word ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " let ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho], x)\)]],
  " be the graph obtained by unfolding ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  " according to labeling ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ": the nodes of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(B(\[Rho], x)\)\(\ \)\)\)]],
  "are pairs ",
  Cell[BoxData[
      \(TraditionalForm\`\((u, i)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is a node in ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  "  and  ",
  Cell[BoxData[
      \(TraditionalForm\`0\  \[LessEqual] \ 
          i\  \[LessEqual] \  | \(\(x\)\(|\)\)\)]],
  ".  The edges are of the form",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((\ \((u, i - 1)\), \ \((v, 
          i)\)\ )\)\)\)]],
  "  where",
  Cell[BoxData[
      \(TraditionalForm\`\((u, x\_i, v)\)\)]],
  " is a labeled edge in ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  ". The core of ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho], x)\)]],
  ", denoted ",
  Cell[BoxData[
      \(TraditionalForm\`cB(\[Rho], x)\)]],
  ", is the subgraph induced by all paths in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(B(\[Rho], x)\)\(\ \)\)\)]],
  "from some vertex ",
  Cell[BoxData[
      \(TraditionalForm\`\((u, 0)\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\((v, \(\(|\)\(x\)\(|\)\))\)\)]],
  ". Note that the multiplicity of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is the number of such paths. \nHere are a few examples. The thin gray \
lines indicate ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho], x)\)]],
  " and the solid black lines joining red vertices represent ",
  Cell[BoxData[
      \(TraditionalForm\`cB(\[Rho], x)\)]],
  ". For the sake of clarity we draw the full vertex set in both cases. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(m = ToSA[CA[51, 3, \(-2\)]]\)], "Input"],

Cell[BoxData[
    \(\(PlotComputationFA[m, "\<000111000\>", ShowAll \[Rule] True, 
        PlotStyle \[Rule] {0.02, 0.03}, 
        LabelGrid \[Rule] Automatic];\)\)], "Input"],

Cell[TextData[{
  "Rule 90 has a deterministic de Bruijn automaton, as a consequence the core \
of ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho], x)\)]],
  " is the whole graph."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m = ToSA[CA[90, 3, \(-2\)]];\)\), "\n", 
    \(DeterministicQFA[m]\), "\n", 
    \(\(PlotComputationFA[m, "\<000111000\>", ShowAll \[Rule] True, 
        PlotStyle \[Rule] {0.02, 0.02}, 
        LabelGrid \[Rule] Automatic];\)\)}], "Input"],

Cell["Here is an example for width 4.", "Text"],

Cell[BoxData[{
    \(\(m = ToNFA[ToSA[CA[7770, 4, \(-2\)]]];\)\), "\n", 
    \(\(PlotComputationFA[m, "\<000000000\>", ShowAll \[Rule] True, 
        PlotStyle \[Rule] {0.02, 0.02}, 
        LabelGrid \[Rule] Automatic];\)\)}], "Input"],

Cell[TextData[{
  "One can show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(Wm\_m\)(\[Rho])\)]],
  " is the minimum number of connected components of ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho], x)\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " varies over all finite words. As one can see from the pictures, the \
connected components have the form of two trees connected via a path. We will \
call such graphs bi-trees and their component trees in-trees and out-trees, \
respectively (the decomposition is not unique but that does not matter here). \
That the connected components of any unfolding ",
  Cell[BoxData[
      \(TraditionalForm\`cB(\[Rho], x)\)]],
  " are always bi-trees follows from the fact that any surjective rule is \
locally injective (no two nontrivial paths in have the same source and \
target). \nThe other two indices have to do with the maximum number of leaves \
in the in- and out-trees. Put differently, consider the the semiautomaton  ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\  = \ \((Q, K, \[Delta])\)\)]],
  ". Define \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_r\)(\[Rho])\  = \ \(\(max\)\(\ \)\(|\)\(\ \)\(\
\[Delta](p, x)\)\(\ \)\(|\)\(\ \)\)\)]],
  "\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is in ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " ranges over ",
  Cell[BoxData[
      \(TraditionalForm\`\(K\^*\)\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  " is strongly connected, the choice of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " does not matter here. Then ",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_l\)(\[Rho])\)]],
  " is the maximum number of leaves in any out-tree. Similarly we define \n\t\
",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_l\)(\[Rho]) = 
        max | \[Delta]\^\(r(p, x)\) | \)]],
  "\nwhere  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\^r\)]],
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  "is the reverse transition function.  Note that in a deterministic de \
Bruijn automaton we have ",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_r\)(\[Rho]) = \ 1\)]],
  " and similarly in a codeterministic automaton ",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_l\)(\[Rho])\  = \ 1\)]],
  ". \nA bi-tree in ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho], x)\)]],
  " is maximal iff its in-tree has ",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_l\)(\[Rho])\)]],
  " leaves and its out-tree has ",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_r\)(\[Rho])\)]],
  " leaves. Using transitivity it is not hard to see that there always is a \
word such that all its bi-trees are maximal. With a little more effort one \
can show further that \n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(W\_l\)(\[Rho])\) \(\(W\_m\)(\[Rho])\) \
\(\(W\_r\)(\[Rho])\) = k\^\(w - 1\)\)],
    FontColor->RGBColor[0, 0, 1]],
  "\n\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " is the alphabet size and ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " the width of the CA.\nWe can easily compute the Welch indices using a \
variation of the deterministic simulation algorithm. Instead of constructing \
all states in the power set machine reachable from the initial state of the \
nondeterministic machine (i.e., the full state set in this case) we only \
construct the states reachable from ",
  Cell[BoxData[
      \(TraditionalForm\`{1}\)]],
  ". See the section on kernel automata in the Guides. The maximum \
cardinality of the state sets in these machines are the Welch indices. \nHere \
are the results for all essential surjective binary CAs of width 3. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[ndb,rndb,ddb,rddb]
Scan[(ndb[#] = ToSA[CA[#]]) & , surj]
Scan[(rndb[#] = ReverseFA[ndb[#]]) & , surj]
Scan[(ddb[#] = ToKernelFA[ndb[#], 1]) & , surj]
Scan[(rddb[#] = ToKernelFA[rndb[#], 1]) & , surj]
weight[m_SA] := Max[Length /@ States[m]]
wr = (weight[ddb[#]] & ) /@ surj; 
wl = (weight[rddb[#]] & ) /@ surj; 
det = (DeterministicQFA[ndb[#]] & ) /@ surj; 
cod = (DeterministicQFA[rndb[#]] & ) /@ surj; \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[
      Prepend[Thread[{surj, wl, 4\/\(wl\ wr\), wr, cod, 
            det}], {"\<rule\>", "\<Wl\>", "\<Wm\>", "\<Wr\>", "\<codet\>", \
"\<det\>"}]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Command ",
  StyleBox["WelchCA", "SmallText"],
  " computes the three indices. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WelchCA[CA[102, 3, 2]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
The Welch coefficients of the right and left shifts for alphabets \
of size 2 to 5 are:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[\((WelchCA[RightShiftCA[#1]] &)\) /@ Range[2, 5]]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[\((WelchCA[LeftShiftCA[#1]] &)\) /@ Range[2, 5]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Note that every CA whose de Bruijn automaton is deterministic or \
codeterministic is automatically surjective. CAs of this type are easily \
generated by glueing together random permutations of the underlying alphabet. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(k = 3;\)\), "\n", 
    \(\(w = 3;\)\), "\n", 
    \(\(L = Permutations[Range[0, k - 1]];\)\), "\n", 
    \(dig1 = 
      Flatten[\((L\[LeftDoubleBracket]
                Random[Integer, {1, \(k!\)}]\[RightDoubleBracket] &)\) /@ 
          Range[k\^\(w - 1\)]]\), "\n", 
    \(dig2 = 
      Flatten[Transpose[\((L\[LeftDoubleBracket]
                  Random[Integer, {1, \(k!\)}]\[RightDoubleBracket] &)\) /@ 
            Range[k\^\(w - 1\)]]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(C1 = CA[FromDigits[dig1, k], w, \(-k\)]\), "\n", 
    \(C2 = CA[FromDigits[dig2, k], w, \(-k\)]\), "\n", 
    \(ClassifyCA[C1]\), "\n", 
    \(ClassifyCA[C2]\), "\n", 
    \(WelchCA[C1]\), "\n", 
    \(WelchCA[C2]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To obtain a CA whose de Bruijn automaton is both deterministic and \
codeterministic  we can pick a random permutation of order at least k of the \
underlying alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{0, \[Ellipsis], k - 1}\)]],
  " and define \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](
          a\[VeryThinSpace]x\[VeryThinSpace]b) = \[Pi]\^\(a(b)\)\)]],
  " .\nThe corresponding global map is always open and fails to be injective. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(t = T[2, 3, 1];\)\), "\n", 
    \(\(grid = 
        Pairs[Flatten[\((Table[#1, {k\^\(w - 1\)}] &)\) /@ Range[0, k - 1]], 
          Flatten[\((Range[0, k - 1] &)\) /@ 
              Range[k\^\(w - 1\)]]];\)\), "\n", 
    \(\(make[{a_Integer, b_Integer}] := \(t\^a\)\[LeftDoubleBracket]
            b + 1\[RightDoubleBracket] - 1;\)\), "\n", 
    \(dig = make /@ grid\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(C = CA[FromDigits[dig, k], w, \(-k\)]\), "\n", 
    \(\(sa = ToSA[C];\)\), "\n", 
    \(DeterministicQFA[sa]\), "\n", 
    \(CodeterministicQFA[sa]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ClassifyCA[C]\), "\n", 
    \(WelchCA[C]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Note that one can extract the Welch indices also from the matrix \
semigroups constructed in the last section. One only has to compute the \
maximum row and column norms:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C = CA[13628, 4, \(-2\)];\)\), "\n", 
    \(WelchCA[C]\), "\n", 
    \(\(gen = makematrix[C];\)\), "\n", 
    \(\(S = 
        ToList[GenerateSG[GEN[8, 2, gen], 
            External \[Rule] False]];\)\), "\n", 
    \(Max[\((Plus @@ #1 &)\) /@ Flatten[Transpose /@ S, 1]]\), "\n", 
    \(Max[\((Plus @@ #1 &)\) /@ Flatten[S, 1]]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Welch\ Automata\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:29"],

Cell["\<\
The deterministic semiautomata used in the computation of the Welch \
parameters are also of interest. By selecting all state sets in the power set \
machine of maximal cardinality we obtain a deterministic semiautomaton. Doing \
this for both the forward and backward machine one constructs two such \
automata, which we will call the Welch pair of the CA. The Welch pair of a CA \
can be generated by the command ToWelchCA. The output consists of two pieces:
\t-  the Welch indices,
\t-  the Welch pair itself. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
For example, for the automaton CA[7770,4,2] from above we \
find\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({ind, {sl, sr}} = 
        WelchCA[CA[7770, 4, \(-2\)], Full \[Rule] True, 
          Normalize \[Rule] 2];\)\), "\n", 
    \(ind\), "\n", 
    \(sl\), "\n", 
    \(sr\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence, in the picture above, the bi-trees associated with word 0",
  StyleBox["10",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  " were not maximal.  To find a suitable word x we can use the semiautomata \
ml and mr obtained by performing the power automaton construction to sa, the \
de Bruijn automaton of the CA, starting with all singleton states:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sa = ToSA[CA[7770, 4, \(-2\)]];\)\), "\n", 
    \(\(mr = ToKernelFA[sa, \(({#1} &)\) /@ Range[8]];\)\), "\n", 
    \(\(ml = ToKernelFA[ReverseFA[sa], \(({#1} &)\) /@ Range[8]];\)\), "\n", 
    \(Fl = Select[States[ml], Length[#1] == 2 &]\), "\n", 
    \(Fr = Select[States[mr], Length[#1] == 4 &]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[
      TransferSequenceFA[ml, Range[8], 
        PositionList[States[ml], Fl]]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ts = 
        TransferSequenceFA[mr, Range[8], 
          PositionList[States[mr], Fr]];\)\), "\n", 
    \(ColumnForm[ts]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotComputationFA[sa, 
        ts\[LeftDoubleBracket]1, 1\[RightDoubleBracket]];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Voila.\n\nSince ",
  Cell[BoxData[
      \(TraditionalForm\`\(W\_m\)(C)\  = \ 1\)]],
  " the states of sl and sr have intersections of cardinality 1:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(sl1 = States[sl]\), "\n", 
    \(sr1 = States[sr]\), "\n", 
    \(Apply[Intersection, CartesianProduct[sl1, sr1], {1}]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Welch\ Indices\ and\ Composition\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:30"],

Cell[TextData[{
  "The maps ",
  Cell[BoxData[
      \(TraditionalForm\`W\_l\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`W\_r\)]],
  " are multiplicative under composition (monoid homomorphisms from the \
epimorphisms of ",
  Cell[BoxData[
      \(TraditionalForm\`K\^\[Infinity]\)]],
  " under composition to \[DoubleStruckCapitalN] under mulitplication). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C51 = CA[51];\)\), "\n", 
    \(\(C102 = CA[102];\)\), "\n", 
    \(CC = ComposeCA[C51, C102]\), "\n", 
    \(PrintCA[CC]\), "\n", 
    \(\(EvolutionCA[CC, 40, GridLines \[Rule] False];\)\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
All three global maps are open, the first one is even a \
bijection.\
\>", "Text"],

Cell[BoxData[
    \(ClassifyCA /@ {C51, C102, CC}\)], "Input"],

Cell["\<\
The Welch indices of CC are the product of the respective indices \
of C51 and C102.\
\>", "Text"],

Cell[BoxData[
    \(ColumnForm[WelchCA /@ {C51, C102, CC}]\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Inverting\ CAs\)], "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:31"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`The\ Method\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:32"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Finding\ Bottlenecks\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:33"],

Cell[TextData[{
  "All injective global maps are open and surjective, and hence \
homoemorphisms of ",
  Cell[BoxData[
      \(TraditionalForm\`K\^\[Infinity]\)]],
  ". By Hedlund's theorem, the inverse maps must also be given by a suitable \
CA. To determine the appropriate local rule one can proceed as follows.  \
Suppose we are given a reversible automaton  ",
  Cell[BoxData[
      \(TraditionalForm\`CA[\[Rho], w, k]\)]],
  " with local rule ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ". We have to find a sufficiently large width ",
  Cell[BoxData[
      \(TraditionalForm\`w\^\[Prime]\)]],
  " so that every word ",
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ \[Rho](x)\)]],
  " of length ",
  Cell[BoxData[
      \(TraditionalForm\`w\^\[Prime]\)]],
  " contains enough information to reconstruct at least one symbol in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  We can then design an inverse CA of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\^\[Prime]\)]],
  " by mapping ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " to that one symbol. In terms of the de Bruijn automaton, this means that \
all the accepting computations of ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Rho])\)]],
  " on input ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " must pass through a bottleneck: a particular state ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " reached after scanning a certain number of symbols in ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ". Here is a simple example. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(C = CA[51, 3, \(-2\)];\)\), "\n", 
    \(m = ToSA[C, Normalize \[Rule] 1]\), "\n", 
    \(States[m]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gr = \((PlotComputationFA[m, #1, PlotStyle \[Rule] {0.05, 0.05}, 
                DisplayFunction \[Rule] Identity] &)\) /@ 
          Words[4, \(-2\)];\)\), "\n", 
    \(\(ShowArray[gr];\)\)}], "Input"],

Cell[TextData[{
  "As one can see, all computations are in the same state even after just one \
step. In fact, for ",
  Cell[BoxData[
      \(TraditionalForm\`CA[51, 3, 2]\)]],
  " it suffices to use ",
  Cell[BoxData[
      \(TraditionalForm\`w\^\[Prime] = \ w\_l + w\_r\)]],
  "  where  ",
  Cell[BoxData[
      \(TraditionalForm\`w\_l = \ 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`w\_r = \ 1\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gr = \((PlotComputationFA[m, #1, PlotStyle \[Rule] {0.05, 0.05}, 
                DisplayFunction \[Rule] Identity] &)\) /@ 
          Words[2, \(-2\)];\)\), "\n", 
    \(\(ShowArray[gr];\)\)}], "Input"],

Cell["\<\
To find the appropriate states we have to trace the computation of \
m. This can be done--albeit in an exceedingly inefficient way--by inspecting \
all possible computations of the semiautomaton on some input. For example, \
for the string \"01\" we have:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[ComputationFA[m, "\<01\>"]]\)], "Input"],

Cell[TextData[{
  "which shows that state 3 is a bottleneck, corresponding to the second \
picture in the first row. \nWe repeat this operation for all words ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " of length 2 and obtain the local rule for the inverse CA. Note the \
reversal operation, by convention the least significant digit of the rule \
number is on the right. "
}], "Text"],

Cell[BoxData[{
    \(\(getstate[z_] := \(ComputationFA[m, z]\)\[LeftDoubleBracket]1, 
          3\[RightDoubleBracket];\)\), "\n", 
    \(states = \(States[m]\)\[LeftDoubleBracket]
        getstate /@ Words[2, \(-2\)]\[RightDoubleBracket]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(lab = \((StringTake[#1, 1] &)\) /@ states\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Ci = LabelToCodeCA[CA[Reverse[lab], 2, \(-2\)]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
To make sure that Ci works properly we compute the composition and \
eliminate superfluous variables.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(CC = ComposeCA[C, Ci]\), "\n", 
    \(ShrinkCA[CC]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The Welch indices show the appropriate multiplicative behavior. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[WelchCA /@ {C, Ci, CC}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(PrintCA[CCC = ComposeCA[C, CC]]\), "\[IndentingNewLine]", 
    \(ShrinkCA[CCC]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Another\ Example\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:34"],

Cell[TextData[{
  "Let us perform the necessary computations by hand for another example, a \
binary CA of width 4. In order to determine the proper choice of ",
  Cell[BoxData[
      \(TraditionalForm\`w\^\[Prime] = \ w\_l\  + \ w\_r\)]],
  "  we use the Welch automata associated with the CA. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(C = CA[3915, 4, \(-2\)]\), "\n", 
    \(sa = ToSA[C, Normalize \[Rule] 1]\), "\n", 
    \(PrintCA[C]\), "\n", 
    \(ClassifyCA[C]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
First we compute the Welch automata. The indices turn out to be 4 \
and 2, respectively. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WelchCA[C]\)], "Input"],

Cell[BoxData[{
    \(\({Wl, Wr} = Last[WelchCA[C, Full \[Rule] True]];\)\), "\n", 
    \(States[Wl]\), "\n", 
    \(States[Wr]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The procedure ",
  StyleBox["DefiniteQFA", "SmallText"],
  " tests whether an automaton is definite, and also determines the maximum \
number of steps before any two computations with the same input in a definite \
automaton merge."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(defl = DefiniteQFA[Wl, Full \[Rule] True];\)\), "\n", 
    \(\(defr = DefiniteQFA[Wr, Full \[Rule] True];\)\), "\n", 
    \({defl, defr, ww = defl + defr}\)}], "Input",
  AspectRatioFixed->True],

Cell["Let's try for the left Welch automaton. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(TransitionFunctionFA[Wl, dell]\), "\n", 
    \(\((dell[#1, "\<0000\>"] &)\) /@ Range[6]\), "\n", 
    \(\((dell[#1, "\<0001\>"] &)\) /@ Range[6]\), "\n", 
    \(\((dell[#1, "\<1111\>"] &)\) /@ Range[6]\), "\n", 
    \(\((dell[#1, "\<0011\>"] &)\) /@ Range[6]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Seems to work. Let's also try a few random words of length 6 to \
check if the computations of the de Bruijn automaton really all have a bottle \
neck. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(W = \((RandomWord[6, \(-2\)] &)\) /@ Range[4]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gr = \((PlotComputationFA[sa, #1, PlotStyle \[Rule] { .02,  .03}, 
                LineStyle \[Rule] { .005,  .015}, 
                DisplayFunction \[Rule] Identity] &)\) /@ W;\)\), "\n", 
    \(\(ShowArray[gr];\)\)}], "Input"],

Cell[TextData[{
  "From the pictures, it seems that words of length 2 + 4 produce the desired \
bottleneck after two steps in the computation.  Let's take a closer look at \
one of these computations. The bottleneck here is at state ",
  Cell[BoxData[
      \(TraditionalForm\`p = 8\)]],
  ", after two steps."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[ComputationFA[sa, "\<100010\>"]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Moreover, only computations starting at ",
  Cell[BoxData[
      \(TraditionalForm\`{2, 3}\)]],
  " and ending at ",
  Cell[BoxData[
      \(TraditionalForm\`{3, 5, 6, 8}\)]],
  " survive, two states in Wl and Wr, respectively. To find the bottleneck \
for all words of length 6, we compute all words of length ",
  Cell[BoxData[
      \(TraditionalForm\`defl = 2\)]],
  " that lead to the same state in Wl and similarly all words of length ",
  Cell[BoxData[
      \(TraditionalForm\`defr = 4\)]],
  " that lead to the same state in Wr. This can be accomplished with the \
procedure ",
  StyleBox["fullanguage", "SmallText"],
  ", a private function in automata. It will output a list of all words of a \
given length that label a computation starting at a specific state ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ", for all states ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Lr = Automata`automata`Private`fullanguage[sa, defl]\), "\n", 
    \(Ll = 
      Automata`automata`Private`fullanguage[ReverseFA[sa], defr]\)}], "Input",\

  AspectRatioFixed->True],

Cell[TextData[{
  "Since the words in Ll are backwards from the point of view of the cellular \
automaton, we have to revert them before we glue them to their counterparts \
in Lr. We use ",
  StyleBox["MapIndexed", "SmallText"],
  " to keep track of the state where the strings join."
}], "Text"],

Cell[BoxData[{
    \(\(join[{L1_List, L2_List}] := 
        Apply[StringJoin, CartesianProduct[StringReverse /@ L1, L2], 
          1];\)\), "\n", 
    \(LL = 
      Sort[FlattenOne[
          MapIndexed[CartesianProduct, join /@ Pairs[Ll, Lr]]]]\)}], "Input"],

Cell["\<\
Note that reversal/append operation has indeed produced all strings \
of length 6. Since the cellular automaton under consideration is surjective, \
this better be the case. The associated states, or rather, their structured \
counterparts in the de Bruijn automaton determine the image of the string \
under the local map of the inverse CA. \
\>", "Text"],

Cell[BoxData[
    \(States[sa]\)], "Input"],

Cell[BoxData[
    \(rul = Thread[Range[8] \[Rule] \((StringTake[#1, 1] &)\) /@ States[sa]]; 
    lab = Reverse[Last /@ LL /. \[InvisibleSpace]rul]\)], "Input"],

Cell["\<\
After some some cleaning up we obtain the local map for the inverse \
CA. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(LabelToCodeCA[lab, ww, \(-2\)]\), "\n", 
    \(Ci = CA[%, ww, \(-2\)]\)}], "Input"],

Cell["\<\
To check, we compute the composition of C with Ci. To speed up \
composition we first shrink Ci. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Ci = ShrinkCA[Ci]\), "\n", 
    \(CC = ComposeCA[Ci, C]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Looks wrong, but after elimination of useless variables we get the \
right answer.\
\>", "Text"],

Cell[BoxData[
    \(ShrinkCA[CC]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`A\ Real\ Algorithm\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:35"],

Cell[TextData[StyleBox[">>>>>>>>>>>>>>>More explanations \
later.<<<<<<<<<<<<<<<<<",
  FontWeight->"Bold"]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The reader will have noticed that a crucial step in inversion process is \
to decide how far computations have to be traced forward and backward to \
ensure the existence of bottlenecks. As it turns out, the proper choice of ",
  Cell[BoxData[
      \(TraditionalForm\`w\^\[Prime]\  = \ w\_l\  + \ w\_r\)]],
  " can be determined from the Welch automata. For injective rules these \
automata are always definite and their definiteness numbers are equal to ",
  Cell[BoxData[
      \(TraditionalForm\`w\_l\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`w\_r\)]],
  ". The necessary computations are carried out in the procedure ",
  StyleBox["InverseCA", "SmallText"],
  ". Note that in general ",
  StyleBox["InverseCA", "SmallText"],
  " will only construct a CA whose composition with the original machine is a \
shift, but not necessarily the exact inverse. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(C = CA[3915, 4, \(-2\)]\), "\n", 
    \(Ci = InverseCA[C]\), "\n", 
    \(CC = ComposeCA[C, Ci]\), "\n", 
    \(ShrinkCA[CC]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CA[3915, 4, \(-2\)]\)], "Output"],

Cell[BoxData[
    \(CA[11535, 4, \(-2\)]\)], "Output"],

Cell[BoxData[
    \(CA[340277174703306882242637262502835978240, 7, \(-2\)]\)], "Output"],

Cell[BoxData[
    \(CA[2, 1, \(-2\)]\)], "Output"]
}, Open  ]],

Cell["\<\
The last CA is remarkable because it is the smallest example of a \
CA whose reversibility is not caused by simple properties of the local \
function. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintCA[C]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The second bit is always flipped, except in the context ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, \(-\(\(,\)\(1\)\(,\)\(0\)\)\))\)\)]],
  ".\nAnother interesting example is the following machine based on addition \
modulo 2, but over an alphabet of size 8 (so that every state can be \
construed as a 3-bit block).  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[loc]\), "\n", 
    \(\(loc[x_, y_] := 
        Module[{x0, x1, x2, y0, y1, y2}, {x0, x1, x2} = 
            Reverse[IntegerDigits[x, 2, 3]]; {y0, y1, y2} = 
            Reverse[IntegerDigits[y, 2, 3]]; 
          FromDigits[{Mod[x1 + y2, 2], Mod[x0 + y1, 2], y0}, 2]];\)\), "\n", 
    \(C = FunctionToCA[loc, 2, \(-8\)]\), "\n", 
    \(PrintCA[C]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To understand how the machine works it is best to think of the \
cells as consisting of three layers of bits. The top bit is unchanged, the \
second is obtained by xor with the top bit of the cell on the left, and the \
bottom bit is obtained from xor with the second bit on the left.
Note that the corresponding de Bruijn automaton is deterministic, but not \
co-deterministic. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sa = ToSA[C];\)\), "\n", 
    \(\(sar = ReverseFA[sa];\)\), "\n", 
    \(DeterministicQFA[sa]\), "\n", 
    \(DeterministicQFA[sar]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(TableForm[DegreesFA[sa]]\), "\n", 
    \(TableForm[DegreesFA[sar]]\)}], "Input",
  AspectRatioFixed->True],

Cell["The Welch coefficients are 8 and 1 for C. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WelchCA[C]\)], "Input",
  AspectRatioFixed->True],

Cell["Hence, C is reversible. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ClassifyCA[C]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Ci = InverseCA[C]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "If you have enough patience, you may wish to verify that the composition \
of C and Ci really is a shift, it takes a bit of time to do so.\n\nNote that \
the width of the inverse automaton is 3. It is quite straightforward to \
generalize this example to produce a CA of width 2 and an alphabet of size ",
  Cell[BoxData[
      \(TraditionalForm\`2\^k\)]],
  " whose inverse CA has width ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Binary\ width\ 4\ CAs\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:36"],

Cell["\<\
We will now compute the inverse CAs for all reversible binary CAs \
of width 4. We start with a list of all essential reversible CAs:\
\>", "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(inj4 = \((CA[#1, 4, \(-2\)] &)\) /@ {255, 3855, 3915, 11535, 13107, 
            13155, 14643, 21845};\)\), "\n", 
    \(TableForm[inj4]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(CA[255, 4, \(-2\)]\)},
          {\(CA[3855, 4, \(-2\)]\)},
          {\(CA[3915, 4, \(-2\)]\)},
          {\(CA[11535, 4, \(-2\)]\)},
          {\(CA[13107, 4, \(-2\)]\)},
          {\(CA[13155, 4, \(-2\)]\)},
          {\(CA[14643, 4, \(-2\)]\)},
          {\(CA[21845, 4, \(-2\)]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        CA[ 255, 4, -2], 
        CA[ 3855, 4, -2], 
        CA[ 3915, 4, -2], 
        CA[ 11535, 4, -2], 
        CA[ 13107, 4, -2], 
        CA[ 13155, 4, -2], 
        CA[ 14643, 4, -2], 
        CA[ 21845, 4, -2]}]]], "Output"]
}, Open  ]],

Cell["\<\
To speed up the computation a little, we first shrink the automata. \
As it turns out, only 4 rules that depend on all 4 variables remain. \
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sinj4 = ShrinkCA /@ inj4;\)\), "\n", 
    \(TableForm[sinj4]\), "\n", 
    \(\(sinj4 = Select[sinj4, WidthCA[#1] == 4 &];\)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(CA[1, 1, \(-2\)]\)},
          {\(CA[1, 1, \(-2\)]\)},
          {\(CA[3915, 4, \(-2\)]\)},
          {\(CA[11535, 4, \(-2\)]\)},
          {\(CA[1, 1, \(-2\)]\)},
          {\(CA[13155, 4, \(-2\)]\)},
          {\(CA[14643, 4, \(-2\)]\)},
          {\(CA[1, 1, \(-2\)]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        CA[ 1, 1, -2], 
        CA[ 1, 1, -2], 
        CA[ 3915, 4, -2], 
        CA[ 11535, 4, -2], 
        CA[ 1, 1, -2], 
        CA[ 13155, 4, -2], 
        CA[ 14643, 4, -2], 
        CA[ 1, 1, -2]}]]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(Timing[\(inv4 = ShrinkCA /@ \(InverseCA /@ sinj4\);\)]\), "\n", 
    \(TableForm[Thread[{sinj4, inv4}]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Note that the first CA is the inverse of the second, and the third \
the inverse of the fourth. 
To check the results we compute the compositions. After shrinking the \
automata all turn out to produce the identity map. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cc = Apply[ComposeCA, Pairs[sinj4, inv4], {1}];\)\), "\n", 
    \(TableForm[cc]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ShrinkCA /@ Union[cc]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1065, 992},
WindowMargins->{{Automatic, 1}, {-130, Automatic}},
PrintingStartingPageNumber->91,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
CellLabelAutoDelete->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->Automatic,
Magnification->1.5,
StyleDefinitions -> "Demo.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1762, 52, 153, 4, 88, "Title",
      Evaluatable->False,
      CellTags->"c:1"]},
  "c:2"->{
    Cell[1940, 60, 110, 3, 124, "Section",
      Evaluatable->False,
      CellTags->"c:2"]},
  "c:3"->{
    Cell[2075, 67, 99, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:3"]},
  "c:4"->{
    Cell[2199, 74, 61, 1, 64, "Subsubsection",
      CellTags->"c:4"]},
  "c:5"->{
    Cell[4738, 158, 53, 1, 50, "Subsubsection",
      CellTags->"c:5"]},
  "c:6"->{
    Cell[6403, 218, 131, 5, 50, "Subsubsection",
      CellTags->"c:6"]},
  "c:7"->{
    Cell[7117, 242, 113, 3, 55, "Subsection",
      Evaluatable->False,
      CellTags->"c:7"]},
  "c:8"->{
    Cell[7255, 249, 54, 1, 64, "Subsubsection",
      CellTags->"c:8"]},
  "c:9"->{
    Cell[12255, 414, 89, 2, 56, "Subsubsection",
      CellTags->"c:9"]},
  "c:10"->{
    Cell[24217, 768, 137, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:10"]},
  "c:11"->{
    Cell[27955, 890, 155, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:11"]},
  "c:12"->{
    Cell[32544, 1028, 126, 3, 124, "Section",
      Evaluatable->False,
      CellTags->"c:12"]},
  "c:13"->{
    Cell[32695, 1035, 128, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:13"]},
  "c:14"->{
    Cell[32848, 1042, 143, 4, 57, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:14"]},
  "c:15"->{
    Cell[42695, 1364, 153, 4, 57, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:15"]},
  "c:16"->{
    Cell[47300, 1510, 158, 4, 57, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:16"]},
  "c:17"->{
    Cell[50457, 1593, 165, 5, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:17"]},
  "c:18"->{
    Cell[54700, 1733, 148, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:18"]},
  "c:19"->{
    Cell[57253, 1816, 124, 3, 124, "Section",
      Evaluatable->False,
      CellTags->"c:19"]},
  "c:20"->{
    Cell[57402, 1823, 134, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:20"]},
  "c:21"->{
    Cell[70834, 2219, 148, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:21"]},
  "c:22"->{
    Cell[73893, 2326, 142, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:22"]},
  "c:23"->{
    Cell[76519, 2406, 99, 2, 57, "Subsection",
      CellTags->"c:23"]},
  "c:24"->{
    Cell[80833, 2553, 117, 3, 124, "Section",
      Evaluatable->False,
      CellTags->"c:24"]},
  "c:25"->{
    Cell[80975, 2560, 135, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:25"]},
  "c:26"->{
    Cell[82150, 2600, 133, 4, 57, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:26"]},
  "c:27"->{
    Cell[87689, 2788, 165, 5, 43, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:27"]},
  "c:28"->{
    Cell[94529, 3005, 137, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:28"]},
  "c:29"->{
    Cell[107072, 3382, 138, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:29"]},
  "c:30"->{
    Cell[109918, 3472, 155, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:30"]},
  "c:31"->{
    Cell[111180, 3523, 134, 4, 66, "Section",
      Evaluatable->False,
      CellTags->"c:31"]},
  "c:32"->{
    Cell[111339, 3531, 134, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:32"]},
  "c:33"->{
    Cell[111498, 3539, 146, 4, 57, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:33"]},
  "c:34"->{
    Cell[116347, 3698, 142, 4, 43, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:34"]},
  "c:35"->{
    Cell[122545, 3900, 144, 4, 43, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:35"]},
  "c:36"->{
    Cell[127193, 4053, 144, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:36"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 131511, 4201},
  {"c:2", 131613, 4205},
  {"c:3", 131718, 4209},
  {"c:4", 131824, 4213},
  {"c:5", 131907, 4216},
  {"c:6", 131991, 4219},
  {"c:7", 132076, 4222},
  {"c:8", 132184, 4226},
  {"c:9", 132268, 4229},
  {"c:10", 132354, 4232},
  {"c:11", 132465, 4236},
  {"c:12", 132576, 4240},
  {"c:13", 132686, 4244},
  {"c:14", 132798, 4248},
  {"c:15", 132913, 4252},
  {"c:16", 133028, 4256},
  {"c:17", 133143, 4260},
  {"c:18", 133255, 4264},
  {"c:19", 133367, 4268},
  {"c:20", 133477, 4272},
  {"c:21", 133589, 4276},
  {"c:22", 133701, 4280},
  {"c:23", 133813, 4284},
  {"c:24", 133898, 4287},
  {"c:25", 134008, 4291},
  {"c:26", 134120, 4295},
  {"c:27", 134235, 4299},
  {"c:28", 134350, 4303},
  {"c:29", 134462, 4307},
  {"c:30", 134575, 4311},
  {"c:31", 134688, 4315},
  {"c:32", 134798, 4319},
  {"c:33", 134911, 4323},
  {"c:34", 135027, 4327},
  {"c:35", 135143, 4331},
  {"c:36", 135259, 4335}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 54, 0, 40, "SmallText"],
Cell[1762, 52, 153, 4, 88, "Title",
  Evaluatable->False,
  CellTags->"c:1"],

Cell[CellGroupData[{
Cell[1940, 60, 110, 3, 124, "Section",
  Evaluatable->False,
  CellTags->"c:2"],

Cell[CellGroupData[{
Cell[2075, 67, 99, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:3"],

Cell[CellGroupData[{
Cell[2199, 74, 61, 1, 64, "Subsubsection",
  CellTags->"c:4"],
Cell[2263, 77, 2438, 76, 476, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4738, 158, 53, 1, 50, "Subsubsection",
  CellTags->"c:5"],
Cell[4794, 161, 424, 13, 134, "Text"],
Cell[5221, 176, 511, 16, 105, "Text"],
Cell[5735, 194, 418, 11, 196, "Text"],
Cell[6156, 207, 210, 6, 103, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6403, 218, 131, 5, 50, "Subsubsection",
  CellTags->"c:6"],
Cell[6537, 225, 531, 11, 103, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7117, 242, 113, 3, 55, "Subsection",
  Evaluatable->False,
  CellTags->"c:7"],

Cell[CellGroupData[{
Cell[7255, 249, 54, 1, 64, "Subsubsection",
  CellTags->"c:8"],
Cell[7312, 252, 2090, 69, 318, "Text",
  Evaluatable->False],
Cell[9405, 323, 148, 4, 91, "Input"],
Cell[9556, 329, 437, 14, 60, "Text",
  Evaluatable->False],
Cell[9996, 345, 263, 6, 137, "Input"],
Cell[10262, 353, 521, 11, 113, "Text",
  Evaluatable->False],
Cell[10786, 366, 197, 4, 91, "Input"],
Cell[10986, 372, 452, 9, 98, "Text",
  Evaluatable->False],
Cell[11441, 383, 118, 3, 68, "Input"],
Cell[11562, 388, 123, 3, 68, "Input"],
Cell[11688, 393, 343, 10, 63, "Text",
  Evaluatable->False],
Cell[12034, 405, 184, 4, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12255, 414, 89, 2, 56, "Subsubsection",
  CellTags->"c:9"],
Cell[12347, 418, 3752, 91, 486, "Text",
  Evaluatable->False],
Cell[16102, 511, 199, 4, 68, "Input"],
Cell[16304, 517, 297, 7, 60, "Text",
  Evaluatable->False],
Cell[16604, 526, 924, 18, 241, "Text",
  Evaluatable->False],
Cell[17531, 546, 295, 6, 91, "Input"],
Cell[17829, 554, 111, 2, 45, "Input"],
Cell[17943, 558, 305, 7, 60, "Text"],
Cell[18251, 567, 220, 5, 114, "Input"],
Cell[18474, 574, 100, 3, 41, "Text"],
Cell[18577, 579, 58, 1, 45, "Input"],
Cell[18638, 582, 399, 9, 91, "Text",
  Evaluatable->False],
Cell[19040, 593, 110, 2, 45, "Input"],
Cell[19153, 597, 219, 5, 63, "Text"],
Cell[19375, 604, 73, 1, 45, "Input"],
Cell[19451, 607, 161, 5, 44, "Text"],
Cell[19615, 614, 136, 2, 68, "Input"],
Cell[19754, 618, 298, 8, 60, "Text"],
Cell[20055, 628, 116, 2, 68, "Input"],
Cell[20174, 632, 180, 6, 44, "Text"],
Cell[20357, 640, 208, 4, 91, "Input"],
Cell[20568, 646, 178, 4, 44, "Text"],
Cell[20749, 652, 430, 9, 137, "Input"],
Cell[21182, 663, 201, 5, 68, "Input"],
Cell[21386, 670, 162, 5, 41, "Text",
  Evaluatable->False],
Cell[21551, 677, 323, 7, 137, "Input"],
Cell[21877, 686, 241, 9, 44, "Text",
  Evaluatable->False],
Cell[22121, 697, 265, 5, 114, "Input"],
Cell[22389, 704, 142, 3, 45, "Input"],
Cell[22534, 709, 281, 7, 60, "Text",
  Evaluatable->False],
Cell[22818, 718, 182, 4, 91, "Input"],
Cell[23003, 724, 107, 2, 45, "Input"],
Cell[23113, 728, 323, 7, 79, "Text",
  Evaluatable->False],
Cell[23439, 737, 164, 2, 68, "Input"],
Cell[23606, 741, 51, 1, 45, "Input"],
Cell[23660, 744, 248, 8, 44, "Text",
  Evaluatable->False],
Cell[23911, 754, 125, 3, 68, "Input"],
Cell[24039, 759, 129, 3, 45, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24217, 768, 137, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:10"],
Cell[24357, 774, 847, 24, 82, "Text",
  Evaluatable->False],
Cell[25207, 800, 271, 6, 137, "Input"],
Cell[25481, 808, 866, 19, 134, "Text",
  Evaluatable->False],
Cell[26350, 829, 133, 3, 68, "Input"],
Cell[26486, 834, 138, 5, 41, "Text",
  Evaluatable->False],
Cell[26627, 841, 163, 4, 91, "Input"],
Cell[26793, 847, 192, 4, 91, "Input"],
Cell[26988, 853, 98, 3, 41, "Text"],
Cell[27089, 858, 120, 2, 68, "Input"],
Cell[27212, 862, 242, 5, 60, "Text"],
Cell[27457, 869, 101, 2, 68, "Input"],
Cell[27561, 873, 125, 3, 68, "Input"],
Cell[27689, 878, 109, 3, 41, "Text"],
Cell[27801, 883, 117, 2, 68, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[27955, 890, 155, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:11"],
Cell[28113, 896, 1552, 31, 255, "Text",
  Evaluatable->False],
Cell[29668, 929, 270, 6, 137, "Input"],
Cell[29941, 937, 829, 26, 196, "Text",
  Evaluatable->False],
Cell[30773, 965, 414, 13, 63, "Text",
  Evaluatable->False],
Cell[31190, 980, 390, 8, 137, "Input"],
Cell[31583, 990, 145, 5, 41, "Text",
  Evaluatable->False],
Cell[31731, 997, 97, 2, 45, "Input"],
Cell[31831, 1001, 231, 6, 60, "Text",
  Evaluatable->False],
Cell[32065, 1009, 177, 3, 91, "Input"],
Cell[32245, 1014, 155, 4, 45, "Input"],
Cell[32403, 1020, 92, 2, 45, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32544, 1028, 126, 3, 124, "Section",
  Evaluatable->False,
  CellTags->"c:12"],

Cell[CellGroupData[{
Cell[32695, 1035, 128, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:13"],

Cell[CellGroupData[{
Cell[32848, 1042, 143, 4, 57, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:14"],
Cell[32994, 1048, 3158, 86, 394, "Text",
  Evaluatable->False],
Cell[36155, 1136, 108, 2, 45, "Input"],
Cell[36266, 1140, 125, 3, 68, "Input"],
Cell[36394, 1145, 90, 2, 45, "Input"],
Cell[36487, 1149, 80, 2, 45, "Input"],
Cell[36570, 1153, 729, 23, 80, "Text",
  Evaluatable->False],
Cell[37302, 1178, 121, 3, 68, "Input"],
Cell[37426, 1183, 184, 6, 72, "Text",
  Evaluatable->False],
Cell[37613, 1191, 120, 3, 68, "Input"],
Cell[37736, 1196, 101, 2, 41, "Text",
  Evaluatable->False],
Cell[37840, 1200, 95, 2, 45, "Input"],
Cell[37938, 1204, 153, 5, 41, "Text",
  Evaluatable->False],
Cell[38094, 1211, 75, 2, 45, "Input"],
Cell[38172, 1215, 276, 7, 72, "Text",
  Evaluatable->False],
Cell[38451, 1224, 118, 3, 68, "Input"],
Cell[38572, 1229, 120, 3, 68, "Input"],
Cell[38695, 1234, 128, 3, 68, "Input"],
Cell[38826, 1239, 116, 2, 45, "Input"],
Cell[38945, 1243, 305, 7, 60, "Text",
  Evaluatable->False],
Cell[39253, 1252, 127, 3, 45, "Input"],
Cell[39383, 1257, 392, 9, 110, "Text",
  Evaluatable->False],
Cell[39778, 1268, 298, 6, 137, "Input"],
Cell[40079, 1276, 420, 10, 85, "Text",
  Evaluatable->False],
Cell[40502, 1288, 140, 4, 45, "Input"],
Cell[40645, 1294, 327, 9, 60, "Text",
  Evaluatable->False],
Cell[40975, 1305, 134, 3, 68, "Input"],
Cell[41112, 1310, 179, 3, 68, "Input"],
Cell[41294, 1315, 163, 5, 41, "Text",
  Evaluatable->False],
Cell[41460, 1322, 108, 2, 45, "Input"],
Cell[41571, 1326, 167, 4, 43, "Text",
  Evaluatable->False],
Cell[41741, 1332, 71, 2, 45, "Input"],
Cell[41815, 1336, 113, 2, 41, "Text",
  Evaluatable->False],
Cell[41931, 1340, 268, 5, 91, "Input"],
Cell[42202, 1347, 339, 8, 63, "Text",
  Evaluatable->False],
Cell[42544, 1357, 114, 2, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42695, 1364, 153, 4, 57, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:15"],
Cell[42851, 1370, 932, 33, 165, "Text",
  Evaluatable->False],
Cell[43786, 1405, 1305, 26, 298, "Text",
  Evaluatable->False],
Cell[45094, 1433, 112, 3, 68, "Input"],
Cell[45209, 1438, 295, 7, 137, "Input"],
Cell[45507, 1447, 224, 6, 60, "Text",
  Evaluatable->False],
Cell[45734, 1455, 146, 4, 45, "Input"],
Cell[45883, 1461, 104, 2, 41, "Text",
  Evaluatable->False],
Cell[45990, 1465, 79, 2, 45, "Input"],
Cell[46072, 1469, 320, 7, 79, "Text",
  Evaluatable->False],
Cell[46395, 1478, 266, 6, 114, "Input"],
Cell[46664, 1486, 215, 6, 60, "Text",
  Evaluatable->False],
Cell[46882, 1494, 147, 3, 68, "Input"],
Cell[47032, 1499, 120, 2, 41, "Text",
  Evaluatable->False],
Cell[47155, 1503, 108, 2, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47300, 1510, 158, 4, 57, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:16"],
Cell[47461, 1516, 1271, 30, 185, "Text",
  Evaluatable->False],
Cell[48735, 1548, 1140, 21, 340, "Input"],
Cell[49878, 1571, 268, 7, 63, "Text",
  Evaluatable->False],
Cell[50149, 1580, 259, 7, 114, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[50457, 1593, 165, 5, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:17"],
Cell[50625, 1600, 348, 7, 79, "Text",
  Evaluatable->False],
Cell[50976, 1609, 148, 3, 45, "Input"],
Cell[51127, 1614, 105, 2, 41, "Text",
  Evaluatable->False],
Cell[51235, 1618, 125, 3, 68, "Input"],
Cell[51363, 1623, 199, 5, 60, "Text",
  Evaluatable->False],
Cell[51565, 1630, 126, 3, 68, "Input"],
Cell[51694, 1635, 108, 2, 45, "Input"],
Cell[51805, 1639, 283, 5, 68, "Input"],
Cell[52091, 1646, 447, 10, 85, "Text",
  Evaluatable->False],
Cell[52541, 1658, 220, 6, 68, "Input"],
Cell[52764, 1666, 108, 2, 45, "Input"],
Cell[52875, 1670, 230, 6, 60, "Text",
  Evaluatable->False],
Cell[53108, 1678, 299, 7, 91, "Input"],
Cell[53410, 1687, 107, 2, 45, "Input"],
Cell[53520, 1691, 543, 11, 129, "Text",
  Evaluatable->False],
Cell[54066, 1704, 133, 4, 45, "Input"],
Cell[54202, 1710, 109, 3, 68, "Input"],
Cell[54314, 1715, 154, 5, 41, "Text",
  Evaluatable->False],
Cell[54471, 1722, 98, 2, 68, "Input"],
Cell[54572, 1726, 91, 2, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54700, 1733, 148, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:18"],
Cell[54851, 1739, 573, 11, 110, "Text",
  Evaluatable->False],
Cell[55427, 1752, 237, 5, 114, "Input"],
Cell[55667, 1759, 106, 2, 41, "Text",
  Evaluatable->False],
Cell[55776, 1763, 124, 3, 68, "Input"],
Cell[55903, 1768, 188, 5, 41, "Text",
  Evaluatable->False],
Cell[56094, 1775, 108, 2, 68, "Input"],
Cell[56205, 1779, 46, 1, 45, "Input"],
Cell[56254, 1782, 309, 7, 60, "Text",
  Evaluatable->False],
Cell[56566, 1791, 260, 5, 68, "Input"],
Cell[56829, 1798, 144, 5, 41, "Text",
  Evaluatable->False],
Cell[56976, 1805, 228, 5, 114, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[57253, 1816, 124, 3, 124, "Section",
  Evaluatable->False,
  CellTags->"c:19"],

Cell[CellGroupData[{
Cell[57402, 1823, 134, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:20"],
Cell[57539, 1829, 1990, 50, 329, "Text",
  Evaluatable->False],
Cell[59532, 1881, 176, 4, 68, "Input"],
Cell[59711, 1887, 192, 5, 41, "Text",
  Evaluatable->False],
Cell[59906, 1894, 166, 4, 91, "Input"],
Cell[60075, 1900, 486, 11, 79, "Text"],
Cell[60564, 1913, 107, 2, 68, "Input"],
Cell[60674, 1917, 474, 10, 79, "Text",
  Evaluatable->False],
Cell[61151, 1929, 95, 2, 45, "Input"],
Cell[61249, 1933, 160, 4, 45, "Input"],
Cell[61412, 1939, 2568, 64, 530, "Text",
  Evaluatable->False],
Cell[63983, 2005, 420, 9, 110, "Text",
  Evaluatable->False],
Cell[64406, 2016, 82, 2, 45, "Input"],
Cell[64491, 2020, 78, 2, 45, "Input"],
Cell[64572, 2024, 187, 4, 68, "Input"],
Cell[64762, 2030, 276, 8, 122, "Text",
  Evaluatable->False],
Cell[65041, 2040, 188, 4, 91, "Input"],
Cell[65232, 2046, 588, 11, 129, "Text",
  Evaluatable->False],
Cell[65823, 2059, 116, 2, 45, "Input"],
Cell[65942, 2063, 476, 9, 98, "Text",
  Evaluatable->False],
Cell[66421, 2074, 112, 2, 45, "Input"],
Cell[66536, 2078, 121, 3, 45, "Input"],
Cell[66660, 2083, 199, 6, 60, "Text",
  Evaluatable->False],
Cell[66862, 2091, 121, 3, 45, "Input"],
Cell[66986, 2096, 184, 5, 41, "Text",
  Evaluatable->False],
Cell[67173, 2103, 121, 3, 45, "Input"],
Cell[67297, 2108, 176, 5, 41, "Text",
  Evaluatable->False],
Cell[67476, 2115, 121, 3, 45, "Input"],
Cell[67600, 2120, 1081, 23, 303, "Text",
  Evaluatable->False],
Cell[68684, 2145, 174, 4, 71, "Input"],
Cell[68861, 2151, 124, 3, 68, "Input"],
Cell[68988, 2156, 191, 5, 41, "Text",
  Evaluatable->False],
Cell[69182, 2163, 191, 4, 91, "Input"],
Cell[69376, 2169, 169, 5, 41, "Text",
  Evaluatable->False],
Cell[69548, 2176, 217, 5, 91, "Input"],
Cell[69768, 2183, 100, 2, 45, "Input"],
Cell[69871, 2187, 186, 5, 41, "Text",
  Evaluatable->False],
Cell[70060, 2194, 370, 8, 110, "Text",
  Evaluatable->False],
Cell[70433, 2204, 121, 3, 45, "Input"],
Cell[70557, 2209, 240, 5, 91, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70834, 2219, 148, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:21"],
Cell[70985, 2225, 606, 11, 117, "Text",
  Evaluatable->False],
Cell[71594, 2238, 181, 5, 68, "Input"],

Cell[CellGroupData[{
Cell[71800, 2247, 171, 4, 68, "Input"],
Cell[71974, 2253, 197, 3, 90, "Output"],
Cell[72174, 2258, 36, 1, 67, "Output"]
}, Open  ]],
Cell[72225, 2262, 132, 3, 45, "Input"],
Cell[72360, 2267, 121, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[72506, 2273, 297, 6, 137, "Input"],
Cell[72806, 2281, 46, 1, 67, "Output"],
Cell[72855, 2284, 52, 1, 67, "Output"],
Cell[72910, 2287, 69, 1, 67, "Output"],
Cell[72982, 2290, 64, 1, 67, "Output"],
Cell[73049, 2293, 106, 2, 67, "Output"]
}, Open  ]],
Cell[73170, 2298, 244, 6, 60, "Text",
  Evaluatable->False],
Cell[73417, 2306, 149, 4, 45, "Input"],
Cell[73569, 2312, 172, 5, 41, "Text",
  Evaluatable->False],
Cell[73744, 2319, 112, 2, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73893, 2326, 142, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:22"],
Cell[74038, 2332, 1052, 24, 241, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[75115, 2360, 110, 2, 45, "Input"],
Cell[75228, 2364, 112, 2, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75377, 2371, 286, 5, 91, "Input"],
Cell[75666, 2378, 589, 14, 133, "Output"]
}, Open  ]],
Cell[76270, 2395, 212, 6, 60, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[76519, 2406, 99, 2, 57, "Subsection",
  CellTags->"c:23"],
Cell[76621, 2410, 566, 15, 218, "Text"],
Cell[77190, 2427, 234, 4, 114, "Input"],
Cell[77427, 2433, 151, 5, 41, "Text"],
Cell[77581, 2440, 185, 3, 91, "Input"],
Cell[77769, 2445, 486, 15, 60, "Text"],
Cell[78258, 2462, 137, 2, 68, "Input"],
Cell[78398, 2466, 52, 1, 45, "Input"],
Cell[78453, 2469, 93, 3, 41, "Text"],
Cell[78549, 2474, 148, 2, 45, "Input"],
Cell[78700, 2478, 71, 1, 45, "Input"],
Cell[78774, 2481, 261, 5, 91, "Text"],
Cell[79038, 2488, 88, 3, 41, "Text"],
Cell[79129, 2493, 49, 0, 41, "Text"],
Cell[79181, 2495, 195, 4, 91, "Input"],
Cell[79379, 2501, 64, 0, 41, "Text"],
Cell[79446, 2503, 149, 2, 45, "Input"],
Cell[79598, 2507, 71, 1, 45, "Input"],
Cell[79672, 2510, 110, 3, 41, "Text"],
Cell[79785, 2515, 117, 2, 45, "Input"],
Cell[79905, 2519, 129, 3, 41, "Text"],
Cell[80037, 2524, 115, 2, 45, "Input"],
Cell[80155, 2528, 67, 1, 45, "Input"],
Cell[80225, 2531, 80, 1, 45, "Input"],
Cell[80308, 2534, 127, 3, 41, "Text"],
Cell[80438, 2539, 195, 4, 91, "Input"],
Cell[80636, 2545, 148, 2, 68, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[80833, 2553, 117, 3, 124, "Section",
  Evaluatable->False,
  CellTags->"c:24"],

Cell[CellGroupData[{
Cell[80975, 2560, 135, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:25"],
Cell[81113, 2566, 1012, 30, 153, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[82150, 2600, 133, 4, 57, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:26"],
Cell[82286, 2606, 442, 9, 98, "Text",
  Evaluatable->False],
Cell[82731, 2617, 80, 1, 45, "Input"],
Cell[82814, 2620, 280, 6, 66, "Text",
  Evaluatable->False],
Cell[83097, 2628, 159, 4, 45, "Input"],
Cell[83259, 2634, 259, 8, 41, "Text",
  Evaluatable->False],
Cell[83521, 2644, 280, 7, 114, "Input"],
Cell[83804, 2653, 356, 11, 63, "Text",
  Evaluatable->False],
Cell[84163, 2666, 858, 25, 129, "Text",
  Evaluatable->False],
Cell[85024, 2693, 337, 8, 114, "Input"],
Cell[85364, 2703, 362, 11, 60, "Text",
  Evaluatable->False],
Cell[85729, 2716, 142, 4, 91, "Input"],
Cell[85874, 2722, 146, 4, 91, "Input"],
Cell[86023, 2728, 264, 9, 44, "Text",
  Evaluatable->False],
Cell[86290, 2739, 127, 3, 45, "Input"],
Cell[86420, 2744, 178, 4, 91, "Input"],
Cell[86601, 2750, 42, 1, 45, "Input"],
Cell[86646, 2753, 98, 2, 45, "Input"],
Cell[86747, 2757, 905, 26, 168, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[87689, 2788, 165, 5, 43, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:27"],
Cell[87857, 2795, 1547, 45, 327, "Text",
  Evaluatable->False],
Cell[89407, 2842, 229, 8, 41, "Text"],
Cell[89639, 2852, 814, 19, 134, "Text",
  Evaluatable->False],
Cell[90456, 2873, 294, 6, 160, "Input"],
Cell[90753, 2881, 131, 3, 68, "Input"],
Cell[90887, 2886, 294, 5, 79, "Text"],
Cell[91184, 2893, 71, 1, 45, "Input"],
Cell[91258, 2896, 183, 4, 91, "Input"],
Cell[91444, 2902, 140, 3, 41, "Text"],
Cell[91587, 2907, 218, 4, 68, "Input"],
Cell[91808, 2913, 262, 7, 91, "Text",
  Evaluatable->False],
Cell[92073, 2922, 130, 3, 68, "Input"],
Cell[92206, 2927, 183, 4, 91, "Input"],
Cell[92392, 2933, 186, 4, 68, "Input"],
Cell[92581, 2939, 219, 6, 72, "Text",
  Evaluatable->False],
Cell[92803, 2947, 300, 7, 114, "Input"],
Cell[93106, 2956, 143, 3, 41, "Text"],
Cell[93252, 2961, 227, 5, 114, "Input"],
Cell[93482, 2968, 56, 0, 41, "Text"],
Cell[93541, 2970, 287, 5, 114, "Input"],
Cell[93831, 2977, 215, 8, 41, "Text"],
Cell[94049, 2987, 171, 3, 91, "Input"],
Cell[94223, 2992, 257, 7, 91, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[94529, 3005, 137, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:28"],
Cell[94669, 3011, 3137, 93, 274, "Text",
  Evaluatable->False],
Cell[97809, 3106, 60, 1, 45, "Input"],
Cell[97872, 3109, 176, 3, 68, "Input"],
Cell[98051, 3114, 245, 8, 41, "Text",
  Evaluatable->False],
Cell[98299, 3124, 263, 5, 114, "Input"],
Cell[98565, 3131, 47, 0, 41, "Text"],
Cell[98615, 3133, 236, 4, 91, "Input"],
Cell[98854, 3139, 3833, 99, 666, "Text",
  Evaluatable->False],
Cell[102690, 3240, 461, 12, 224, "Input"],
Cell[103154, 3254, 216, 5, 104, "Input"],
Cell[103373, 3261, 159, 6, 44, "Text",
  Evaluatable->False],
Cell[103535, 3269, 81, 2, 45, "Input"],
Cell[103619, 3273, 159, 5, 41, "Text",
  Evaluatable->False],
Cell[103781, 3280, 120, 3, 45, "Input"],
Cell[103904, 3285, 117, 2, 45, "Input"],
Cell[104024, 3289, 294, 7, 60, "Text",
  Evaluatable->False],
Cell[104321, 3298, 506, 12, 152, "Input"],
Cell[104830, 3312, 274, 7, 160, "Input"],
Cell[105107, 3321, 542, 14, 122, "Text",
  Evaluatable->False],
Cell[105652, 3337, 429, 9, 154, "Input"],
Cell[106084, 3348, 208, 5, 114, "Input"],
Cell[106295, 3355, 101, 3, 68, "Input"],
Cell[106399, 3360, 242, 6, 60, "Text",
  Evaluatable->False],
Cell[106644, 3368, 391, 9, 160, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[107072, 3382, 138, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:29"],
Cell[107213, 3388, 585, 11, 160, "Text",
  Evaluatable->False],
Cell[107801, 3401, 136, 5, 41, "Text",
  Evaluatable->False],
Cell[107940, 3408, 230, 7, 114, "Input"],
Cell[108173, 3417, 447, 9, 91, "Text",
  Evaluatable->False],
Cell[108623, 3428, 359, 6, 137, "Input"],
Cell[108985, 3436, 149, 4, 45, "Input"],
Cell[109137, 3442, 184, 5, 68, "Input"],
Cell[109324, 3449, 143, 3, 45, "Input"],
Cell[109470, 3454, 229, 7, 103, "Text",
  Evaluatable->False],
Cell[109702, 3463, 179, 4, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[109918, 3472, 155, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:30"],
Cell[110076, 3478, 431, 14, 60, "Text",
  Evaluatable->False],
Cell[110510, 3494, 250, 6, 137, "Input"],
Cell[110763, 3502, 92, 3, 41, "Text"],
Cell[110858, 3507, 62, 1, 45, "Input"],
Cell[110923, 3510, 108, 3, 41, "Text"],
Cell[111034, 3515, 97, 2, 45, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[111180, 3523, 134, 4, 66, "Section",
  Evaluatable->False,
  CellTags->"c:31"],

Cell[CellGroupData[{
Cell[111339, 3531, 134, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:32"],

Cell[CellGroupData[{
Cell[111498, 3539, 146, 4, 57, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:33"],
Cell[111647, 3545, 1618, 47, 155, "Text",
  Evaluatable->False],
Cell[113268, 3594, 162, 4, 91, "Input"],
Cell[113433, 3600, 226, 4, 114, "Input"],
Cell[113662, 3606, 482, 17, 60, "Text",
  Evaluatable->False],
Cell[114147, 3625, 226, 4, 114, "Input"],
Cell[114376, 3631, 327, 7, 79, "Text",
  Evaluatable->False],
Cell[114706, 3640, 70, 1, 45, "Input"],
Cell[114779, 3643, 395, 8, 91, "Text"],
Cell[115177, 3653, 278, 5, 68, "Input"],
Cell[115458, 3660, 100, 2, 45, "Input"],
Cell[115561, 3664, 106, 2, 45, "Input"],
Cell[115670, 3668, 173, 5, 41, "Text",
  Evaluatable->False],
Cell[115846, 3675, 111, 3, 68, "Input"],
Cell[115960, 3680, 138, 5, 41, "Text",
  Evaluatable->False],
Cell[116101, 3687, 93, 2, 45, "Input"],
Cell[116197, 3691, 113, 2, 68, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[116347, 3698, 142, 4, 43, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:34"],
Cell[116492, 3704, 356, 8, 60, "Text",
  Evaluatable->False],
Cell[116851, 3714, 191, 5, 114, "Input"],
Cell[117045, 3721, 161, 5, 41, "Text",
  Evaluatable->False],
Cell[117209, 3728, 43, 1, 45, "Input"],
Cell[117255, 3731, 166, 4, 91, "Input"],
Cell[117424, 3737, 311, 8, 63, "Text",
  Evaluatable->False],
Cell[117738, 3747, 217, 4, 91, "Input"],
Cell[117958, 3753, 104, 2, 41, "Text",
  Evaluatable->False],
Cell[118065, 3757, 319, 6, 137, "Input"],
Cell[118387, 3765, 224, 6, 60, "Text",
  Evaluatable->False],
Cell[118614, 3773, 104, 2, 45, "Input"],
Cell[118721, 3777, 252, 4, 114, "Input"],
Cell[118976, 3783, 370, 9, 60, "Text",
  Evaluatable->False],
Cell[119349, 3794, 102, 2, 45, "Input"],
Cell[119454, 3798, 979, 27, 120, "Text",
  Evaluatable->False],
Cell[120436, 3827, 202, 5, 68, "Input"],
Cell[120641, 3834, 297, 6, 63, "Text"],
Cell[120941, 3842, 260, 6, 91, "Input"],
Cell[121204, 3850, 366, 6, 79, "Text"],
Cell[121573, 3858, 43, 1, 45, "Input"],
Cell[121619, 3861, 159, 2, 68, "Input"],
Cell[121781, 3865, 146, 5, 41, "Text",
  Evaluatable->False],
Cell[121930, 3872, 104, 2, 68, "Input"],
Cell[122037, 3876, 169, 5, 41, "Text",
  Evaluatable->False],
Cell[122209, 3883, 116, 3, 68, "Input"],
Cell[122328, 3888, 106, 3, 41, "Text"],
Cell[122437, 3893, 71, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[122545, 3900, 144, 4, 43, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:35"],
Cell[122692, 3906, 164, 4, 41, "Text",
  Evaluatable->False],
Cell[122859, 3912, 951, 21, 142, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[123835, 3937, 185, 5, 114, "Input"],
Cell[124023, 3944, 53, 1, 67, "Output"],
Cell[124079, 3947, 54, 1, 67, "Output"],
Cell[124136, 3950, 88, 1, 67, "Output"],
Cell[124227, 3953, 50, 1, 67, "Output"]
}, Open  ]],
Cell[124292, 3957, 223, 6, 60, "Text",
  Evaluatable->False],
Cell[124518, 3965, 69, 2, 45, "Input"],
Cell[124590, 3969, 404, 9, 91, "Text",
  Evaluatable->False],
Cell[124997, 3980, 413, 9, 183, "Input"],
Cell[125413, 3991, 451, 9, 110, "Text",
  Evaluatable->False],
Cell[125867, 4002, 194, 5, 114, "Input"],
Cell[126064, 4009, 127, 3, 68, "Input"],
Cell[126194, 4014, 106, 2, 41, "Text",
  Evaluatable->False],
Cell[126303, 4018, 69, 2, 45, "Input"],
Cell[126375, 4022, 88, 2, 41, "Text",
  Evaluatable->False],
Cell[126466, 4026, 72, 2, 45, "Input"],
Cell[126541, 4030, 76, 2, 45, "Input"],
Cell[126620, 4034, 524, 13, 144, "Text",
  Evaluatable->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[127193, 4053, 144, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:36"],
Cell[127340, 4059, 207, 6, 60, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[127572, 4069, 199, 4, 68, "Input"],
Cell[127774, 4075, 728, 23, 253, "Output"]
}, Open  ]],
Cell[128517, 4101, 213, 6, 60, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[128755, 4111, 186, 4, 91, "Input"],
Cell[128944, 4117, 702, 23, 253, "Output"]
}, Open  ]],
Cell[129661, 4143, 164, 3, 68, "Input"],
Cell[129828, 4148, 292, 7, 91, "Text",
  Evaluatable->False],
Cell[130123, 4157, 142, 3, 68, "Input"],
Cell[130268, 4162, 80, 2, 45, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

