(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    123222,       4343]*)
(*NotebookOutlinePosition[    132310,       4648]*)
(*  CellTagsIndexPosition[    130788,       4590]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\[Copyright] 1997-2002 K. Sutner ", "SmallText"],

Cell[TextData[StyleBox["Finite State Machines",
  FontFamily->"Charter"]], "Title",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:1"],

Cell[CellGroupData[{

Cell["Acceptance and Multiplicity", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:2"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Acceptance\ of\ a\ FSM\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Acceptance", "c:3"}],

Cell[TextData[{
  "We are mostly interested in using FSMs as acceptors:  machines that read \
an input string and then return yes or no depending on whether the string has \
certain properties.  The collection of all strings that pass the test is the \
acceptance language of the machine. More precisely, a finite state machine ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " accepts a word ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " if there is a computation of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " from an initial state to a final state that has ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " as its label. The acceptance language of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is the collection of all accepted words:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL](M)\  = \ {\ 
          w\  \[Element] \ \(\[CapitalSigma]\^*\)\  | \ \ M\ \ accepts\ w\ \ \
}\)]],
  "\nThere are several commands relating to acceptance of a FSM. To determine \
acceptance of a single word by an automaton there is the command ",
  StyleBox["AcceptQFA",
    FontFamily->"Courier"],
  ".  Like many other commands in this package, ",
  StyleBox["AcceptQFA",
    FontFamily->"Courier"],
  " is polymorphic: it applies to all four types of machines.\n\nHere is a \
simple example:  a machine that accepts only words over alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " that contain exactly 3 a's. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(m3 = CounterDFA[a, 3, {a, b}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintFA[m3]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To test whether ",
  StyleBox["m3", "SmallText"],
  " works, modify the input string below. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(AcceptQFA[m3, aababb]\), "\n", 
    \(AcceptQFA[m3, aabbbbb]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
It is often more interesting to see the details of the computation, \
say, the whole computation\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ComputationFA[m3, aababb]\)], "Input",
  AspectRatioFixed->True],

Cell["or a trace of the states entered during the computation:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(AcceptQFA[m3, aababb, DoTrace \[Rule] True]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["ComputationFA",
    FontFamily->"Courier"],
  " returns a list of computations.  Since ",
  StyleBox["m3", "SmallText"],
  " is deterministic there is only one computation on input aababb, we will \
see multiple computations in a moment."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "For example, let Mb3 be the FA  that accepts all words whose third symbol \
from the end is a ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " (over the alphabet  ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " ).  ",
  StyleBox["Mb3", "SmallText"],
  " can be generated directly using the command ",
  StyleBox["IthSymbolFA",
    FontFamily->"Courier"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Mb3 = IthSymbolFA[b, \(-3\), {a, b}];\)\), "\n", 
    \(PrintFA[Mb3]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To test whether ",
  StyleBox["Mb3", "SmallText"],
  " works, modify the input string below. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(AcceptQFA[Mb3, aababb]\), "\n", 
    \(AcceptQFA[Mb3, aabbbbb]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True",
    FontFamily->"Courier"],
  " here produces a list of subsets of the state set: the i-th entry being \
the collection of all states that the machine could be in after scanning the \
(i -1)-st symbol of the input."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[AcceptQFA[Mb3, aabbbbb, DoTrace \[Rule] True]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To determine all possible computations one use the command ",
  StyleBox["ComputationFA",
    FontFamily->"Courier"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[ComputationFA[Mb3, aabbaabba]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus, there are three possible computations on input ",
  StyleBox["aabbaabba ",
    FontSlant->"Italic"],
  "and one of those leads to a final state. Computations can be displayed \
graphically using the command ",
  StyleBox["PlotComputationFA[x,M]",
    FontFamily->"Courier"],
  ". If option ",
  StyleBox["ShowAll",
    FontFamily->"Courier"],
  " is turned off (the default), then only those computations are shown that \
have length |x|.  Setting this option to ",
  StyleBox["True",
    FontFamily->"Courier"],
  " will produce all computations associated with prefixes of the input. \n\n\
States are shown bottom-to-top so that in our example the final state 4 is in \
the top row. Hence the computation is accepting. One can also see from the \
picture that x has multiplicity 1 with respect to ",
  StyleBox["Mb3. ",
    FontFamily->"Courier"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Options[PlotComputationFA]\)], "Input"],

Cell[BoxData[{
    \(\(x = baaabaaabbbbbaabab;\)\), "\n", 
    \(\(PlotComputationFA[Mb3, x, LabelGrid \[Rule] Automatic];\)\)}], "Input"],

Cell["A little crude, but sometimes helpful. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To generate (a finite segment of) the acceptance language of a FSM  use \
the  command ",
  StyleBox["LanguageFA[M,r]",
    FontFamily->"Courier"],
  ". It will generate a list of all words of length r accepted by M for r \
non-negative. For negative r all such lists up to length |r| are generated. \
It is usually a good idea to send the output to ",
  StyleBox["ColumnForm",
    FontFamily->"Courier"],
  ". Piping the output to ",
  StyleBox["Flatten",
    FontFamily->"Courier"],
  " will produce the acceptance language for words up to length |r|.  ",
  StyleBox["EnumForm",
    FontFamily->"Courier"],
  " will produce a table. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(EnumForm0 = \(Curry[EnumForm]\)[Index \[Rule] 0];\)\)], "Input"],

Cell[BoxData[{
    \(LanguageFA[Mb3, 4]\), "\n", 
    \(ColumnForm[LanguageFA[Mb3, \(-4\)]]\), "\n", 
    \(EnumForm0[LanguageFA[Mb3, \(-4\)]]\), "\n", 
    \(Flatten[LanguageFA[Mb3, \(-4\)]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "If only the growth function is of interest (i.e., the size of the \
fragments  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[CapitalSigma]\)\(\ \)\)\^n \[Intersection] 
        L\)]],
  "), the computation can usually be speeded up with the option ",
  StyleBox["SizeOnly->True",
    FontFamily->"Courier"],
  ". Note, though, that internally multiplication of ",
  Cell[BoxData[
      \(TraditionalForm\`n\ \[Cross]\ n\)]],
  " integer matrices is used (which becomes excruciatingly slow for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "). Also, the algorithm only works for machines with only one initial state \
(actually, the behaviors of the initial states have to be disjoint).  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(LanguageFA[ToDFA[Mb3], \(-16\), SizeOnly \[Rule] True]\)], "Input"],

Cell[BoxData[{
    \(\(freq = 
        LanguageFA[ToDFA[Mb3], \(-16\), SizeOnly \[Rule] True];\)\), "\n", 
    \(\(\((ListPlot[#1, PlotStyle \[Rule] {PointSize[0.02], Blue}] &)\)[
        freq];\)\)}], "Input"],

Cell["We can see the expected exponential growth. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\((ListPlot[#1, 
              PlotStyle \[Rule] {PointSize[0.02], Blue}] &)\)[\((N[
                Log[2, #1]] &)\) /@ Drop[freq, 3]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`LanguageFA\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"LanguageFA", "c:4"}],

Cell[TextData[{
  "Generating a part of the acceptance language of a finite state machine is \
often a time consuming process, since machines often accept exponentially \
many words of a certain length. The automata package contains different \
algorithms that will produce all accepted words of a certain length, three \
for deterministic machines and two for nondeterministic machines. They can be \
selected with the option ",
  StyleBox["Implementation->i", "SmallText"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1\)]],
  " is the default. \n\nFor the deterministic machines, the default algorithm \
generates pairs\n\t",
  Cell[BoxData[
      \(TraditionalForm\`{w, q}\)]],
  "  where  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](w, q\_0)\  = \ q\)]],
  ".\nThe second algorithm uses the natural correspondence between words of \
length ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " over a ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-symbol alphabet and numbers from 0 to ",
  Cell[BoxData[
      \(TraditionalForm\`k\^r - 1\)]],
  " and generates a complete list\n\t   ",
  Cell[BoxData[
      \(TraditionalForm\`{\ \[Delta](w\_i, q\_0) | \ 
          0 \[LessEqual] i < k\^r}\)]],
  ".  \nLastly, the third algorithm is based on recursive computation of the \
function  \n\t",
  Cell[BoxData[
      \(TraditionalForm\`L[s, p, q]\  = \ 
        all\ words\ of\ length\ s\ that\ lead\ from\ state\ p\ to\ state\ \
q\)]],
  ". \nFor nondeterministic machines the two algorithms are analogous to \
deterministic algorithm one and two. Regrettably, there are no simple rules \
as to which algorithm is faster: you have to experiment."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Command ",
  StyleBox["LanguageFA",
    FontFamily->"Courier"],
  " also has an option ",
  StyleBox["MakeTrim",
    FontFamily->"Courier"],
  " which will convert the input automaton into an equivalent FA that is trim \
(accessible as well as coaccessible). It is recommended to use this option \
when dealing with large machines that have large inaccessible parts. Of \
course, on occasion it may also be helpful to minimize the machine first. \n\
",
  StyleBox["\n",
    FontFamily->"Courier"],
  "The function ",
  StyleBox["L[s,p,q]",
    FontFamily->"Courier"],
  " for the third deterministic algorithm uses the system variable ",
  StyleBox["$LLL",
    FontFamily->"Courier"],
  ". In connection with the Trace facility this allows one to demonstrate the \
recursive computation for didactic purposes. Of course, the output of ",
  StyleBox["Trace", "SmallText"],
  " has to be massaged into useful form first. Furthermore, the machine must \
be reasonably small. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(m = IthSymbolDFA[a, \(-2\), {a, b}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(trc = 
        Flatten[Trace[
            LanguageFA[m, 5, 
              Implementation \[Rule] 3], $LLL[__] = _List]];\)\), "\n", 
    \(\(trc = Sort[Cases[trc, HoldForm[__ = {__}]]];\)\), "\n", 
    \(Length[trc]\), "\n", 
    \(ColumnForm[trc /. \[InvisibleSpace]{$LLL \[Rule] "\<L\>"}]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Transition\ Relations\ and\ Functions\)], "Subsection",\

  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:5"],

Cell[TextData[{
  "The transition relation of a FSM can naturally be extended to a relation \n\
\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau]\^*\) \[SubsetEqual] 
        Q\ \[Cross]\ \(\[CapitalSigma]\^*\)\ \[Cross]\ Q\)]],
  ". \nThe crucial property of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau]\^*\)\)]],
  " is that   ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau]\^*\)(p, x, q)\)]],
  "  iff there is a computation of the machine with source ",
  StyleBox["p",
    FontSlant->"Italic"],
  ", target ",
  StyleBox["q",
    FontSlant->"Italic"],
  " and trace ",
  StyleBox["x",
    FontSlant->"Italic"],
  ".\t\nSince relations are somewhat difficult to deal with, it is often \
convenient to think of the extended transition relation instead as of a \
(possibly partial and multivalued) function \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\) : \ 
        Q\ \[Cross]\ \(\[CapitalSigma]\^*\)\[LongRightArrow]\ Q\)]],
  ".\nIf the underlying machine is a DFA, then ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)\)]],
  " is indeed a function and can be defined inductively by"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)(p, \[Epsilon]) = p\)]],
  ", \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)(\ p, \ 
          x\ a\ )\  = \ \[Delta](\ \(\[Delta]\^*\)(p, x), \ a\ )\)]],
  StyleBox[",\n\t",
    FontFamily->"Symbol"],
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)\  : \ \(\[ScriptCapitalP](
            Q)\)\ \[Cross]\ \(\[CapitalSigma]\^*\)\[LongRightArrow]\ \(\
\[ScriptCapitalP](Q)\)\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Then ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)(p, x) = p\)]],
  StyleBox["  ",
    FontSlant->"Italic"],
  "iff there is a computation of the machine with source ",
  StyleBox["p",
    FontSlant->"Italic"],
  ", target ",
  StyleBox["q",
    FontSlant->"Italic"],
  ", and trace ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". For nondeterministic machines we can either consider  as a partial and \
multivalued function, or change the signature of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)\)]],
  " slightly as indicated.  Then  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)(P, x) = P'\)]],
  StyleBox["  ",
    FontSlant->"Italic"],
  "iff ",
  Cell[BoxData[
      \(TraditionalForm\`P'\)]],
  " is the set of all targets of computations with source in ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " and trace ",
  StyleBox["x.",
    FontSlant->"Italic"],
  "\n\nThe transition function of an automaton in the sense of the last \
definition can be generated by the command ",
  StyleBox["TransitionFunctionFA", "SmallText"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(TransitionFunctionFA[m = IthSymbolDFA[b, 2, {a, b}], 
        del];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can verify the composition law for  the transition function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)\)]],
  ":  \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^*\)(\(\[Delta]\^*\)(p, u), 
          v) = \(\[Delta]\^*\)(p, u\ v)\)]],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(u = RandomWord[10, {a, b}]\), "\n", 
    \(v = RandomWord[10, {a, b}]\), "\n", 
    \(del[del[1, u], v] == del[1, Concatenate[u, v]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The function ",
  StyleBox["del",
    FontFamily->"Courier"],
  " can also handle lists of states (in positional notation) as input. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(del[{1, 2, 3}, abbbabbab]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "With option ",
  StyleBox["Full->True ",
    FontFamily->"Courier"],
  "we obtain a trace of the computation starting at p under input w, not just \
the last state."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(TransitionFunctionFA[m, del, Full \[Rule] True];\)\), "\n", 
    \(del[1, abaabaa]\)}], "Input"],

Cell["The transition function still works on sets of states:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(del[{1, 2}, abbbabbab]\)], "Input",
  AspectRatioFixed->True],

Cell["And on nondeterministic machines:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(TransitionFunctionFA[IthSymbolFA[b, \(-3\), {a, b}], del, 
        Full \[Rule] True];\)\)], "Input"],

Cell[BoxData[
    \(del[1, abbbabbab]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(del[{1, 2}, abbbabbab]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Boolean\ Matrix\ Representation\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:6"],

Cell[TextData[{
  "There is yet another way we can think of the transition relation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau]\^*\) \[SubsetEqual] 
        Q\[Cross]\(K\^*\)\ \[Cross]\ Q\)]],
  ". By currying, we can write ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau]\^*\)\)]],
  " as a map  \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau]\^\(\(*\)\(\ \)\)\) : \ \(\[CapitalSigma]\^*\
\)\ \[LongRightArrow]\ \ \(Rel(Q, Q)\)\)]],
  "\t\nthat associates every word ",
  StyleBox["w",
    FontSlant->"Italic"],
  " with a binary relation  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau]\_w\%*\)\)]],
  " on ",
  StyleBox["Q",
    FontSlant->"Italic"],
  ". To simplify notation a little, let us write  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_w\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Tau]\_w\%*\)\)]],
  ". The most important property of this family of relations is that \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_u\[SmallCircle]\ \[Tau]\_v = \[Tau]\_uv\)]],
  ".\nwhere the operation on the left is relational composition.  In other \
words, we have a homomorphism from the semigroup ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^+\)\)]],
  " to the semigroup of relantions on ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  ". In fact, if the machine is epsilon-free, then we get a monoid \
homomorphism ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[CapitalSigma]\^*\)\ \[LongRightArrow]\ \
\ \(Rel(Q, Q)\)\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Clearly,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_w\)]],
  " can be represented as a ",
  Cell[BoxData[
      \(TraditionalForm\`Q\ \[Cross]\ Q\)]],
  " boolean matrix. Hence there is a homomorphism ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Beta]\)\)\)]],
  StyleBox["   ",
    FontFamily->"Symbol"],
  "from ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^*\)\)]],
  " into the monoid of boolean matrices:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\ \  : \ \ \(\[CapitalSigma]\^*\)\ \
\[LongRightArrow]\ Q\ \[Cross]\ Q\ \[LongRightArrow]\ Bool\)]],
  ".\nThis function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " can be constructed using the command ",
  StyleBox["TransitionMatrixFA",
    FontFamily->"Courier"],
  " with option ",
  StyleBox["Boolean->True", "SmallText"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Mb4 = IthSymbolFA[b, \(-4\), {a, b}];\)\), "\n", 
    \(TransitionMatrixFA[Mb4, beta, Boolean \[Rule] True]\)}], "Input"],

Cell[BoxData[
    \(MatrixForm[beta[a]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Again ",
  StyleBox["beta", "SmallText"],
  " extends to arbitrary words over ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(MatrixForm[beta[ba]]\), "\n", 
    \(MatrixForm[beta[baa]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Acceptance is now reduced to boolean matrix multiplication (using ",
  StyleBox["Dot",
    FontFamily->"Courier"],
  " and the overlay on ",
  StyleBox["Times",
    FontFamily->"Courier"],
  " and ",
  StyleBox["Plus",
    FontFamily->"Courier"],
  ")."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(i = InitialVectorFA[Mb4, Boolean \[Rule] True]\), "\n", 
    \(o = FinalVectorFA[Mb4, Boolean \[Rule] True]\), "\n", 
    \(i . beta[bbbaa] . o\), "\n", 
    \(i . beta[aabaa] . o\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can generate the semigroup of all matrices ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta](\(\[CapitalSigma]\^*\))\)]],
  " using the command ",
  StyleBox["GenerateSG",
    FontFamily->"Courier"],
  ". In this case the semigroup turns out to have 30 elements. Note that we \
have to use the internal implementation here since the external algorithm \
cannot cope with matrix semigroups."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(S = GenerateSG[GEN[5, 2, {beta[a], beta[b]}]];\)\), "\n", 
    \(Length[S]\)}], "Input"],

Cell[BoxData[
    \(MatrixForm[S\[LeftDoubleBracket]5\[RightDoubleBracket]]\)], "Input"],

Cell["\<\
We can visualize the semigroup elements as square Boolean matrices: \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(gr = \((PlotMatrix[#1, DisplayFunction \[Rule] Identity] &)\) /@ 
          ToList[S];\)\)], "Input"],

Cell[BoxData[
    \(\(ShowArray[gr];\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Multiplicity\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Multiplicity", "c:7"}],

Cell[TextData[{
  "We now give some examples for testing the multiplicity of a string with \
respect to a given machine. The first machine, ",
  StyleBox["Mcount", "SmallText"],
  ", accepts a string ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " of 0's and 1's in exactly  ",
  Cell[BoxData[
      \(TraditionalForm\`val(w)\)]],
  "  ways, where  ",
  Cell[BoxData[
      \(TraditionalForm\`val(w)\)]],
  "  is the number whose binary expansion is ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " (ignoring leading zeros). \nOption ",
  StyleBox["Multiplicity->True",
    FontFamily->"Courier"],
  " applies to both ",
  StyleBox["LanguageFA",
    FontFamily->"Courier"],
  " and ",
  StyleBox["AcceptQFA.\n",
    FontFamily->"Courier"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Mcount = 
        FA[3, \(-2\), {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 2}, {2, 2, 
              2}, {2, 1, 3}, {2, 2, 3}, {3, 1, 3}, {3, 2, 3}, {3, 1, 2}, {3, 
              2, 2}}, {1}, {2, 3}];\)\), "\n", 
    \(\(W = {"\<10\>", "\<100\>", "\<00100\>", "\<1111\>", "\<11001100\>"};\)\
\), "\n", 
    \(acc = \((AcceptQFA[Mcount, #1, Multiplicity \[Rule] True] &)\) /@ 
        W\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(W\), "\n", 
    \(BaseForm[acc, 2]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The very patient user can also verify multiplicities by counting \
paths in the computation diagram. Actually it is not too hard to read off the \
structure of a general diagram from the one example below and to show that \
the number of paths from vertex 1 to vertices 2 and 3 is as required. \
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotComputationFA[Mcount, "\<0110010111\>"];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that we had to specify the input in string form to keep ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " from converting, say, 00100 to 100.  It is usually more efficient to \
determine multiplicity by using option ",
  StyleBox["Multiplicity->True",
    FontFamily->"Courier"],
  " in ",
  StyleBox["LanguageFA",
    FontFamily->"Courier"],
  ". The output is an initial segment of a  formal power series in  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalN] \[LeftAngleBracket]\
\[LeftAngleBracket]\(\[CapitalSigma]\^*\)\[RightAngleBracket]\
\[RightAngleBracket]\)]],
  "  and can be piped into ",
  StyleBox["ToSeries",
    FontFamily->"Courier"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(lm = 
        LanguageFA[Mcount, \(-4\), Multiplicity \[Rule] True];\)\), "\n", 
    \(ColumnForm[lm]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ToSeries[\((Flatten[#1, 1] &)\)[lm]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Hold",
    FontFamily->"Courier"],
  " is necessary to keep ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " form rearranging the terms in a confusing way."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Release[%]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "It can be made invisible by using ",
  StyleBox["ColumnForm",
    FontFamily->"Courier"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[%%]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The next machine ",
  StyleBox["Mfibo",
    FontFamily->"Courier"],
  " accepts a string of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s of length ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(i + 2\)\)]],
  " ways  where ",
  Cell[BoxData[
      \(TraditionalForm\`F\_n\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-th Fibonacci number."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Mfibo = 
      FA[2, 1, {{1, 1, 1}, {1, 1, 2}, {2, 1, 1}}, {1}, {1, 2}]\), "\n", 
    \(\(lm = 
        LanguageFA[Mfibo, \(-10\), Multiplicity \[Rule] True];\)\), "\n", 
    \(ColumnForm[ToSeries[\((Flatten[#1, 1] &)\)[lm]]]\), "\n", 
    \(Fibonacci[Range[2, 12]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nTo determine multiplicities, we can use the natural homomorphism ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " from  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^*\)\)]],
  " into the monoid of non-negative ",
  StyleBox["Q",
    FontSlant->"Italic"],
  " by ",
  StyleBox["Q",
    FontSlant->"Italic"],
  " integer matrices:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\ \  : \ \ \(\[CapitalSigma]\^*\)\ \
\[LongRightArrow]\ Q\ \[Cross]\ 
          Q\ \[LongRightArrow]\ \[DoubleStruckCapitalN]\)]],
  ".\nThus ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Mu](w)\) \((p, q)\)\)]],
  "  is the number of  computations from state ",
  StyleBox["p",
    FontSlant->"Italic"],
  " to state ",
  StyleBox["q",
    FontSlant->"Italic"],
  " under input ",
  StyleBox["w",
    FontSlant->"Italic"],
  ".  The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " can be constructed using the command ",
  StyleBox["TransitionMatrixFA",
    FontFamily->"Courier"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "As an example, we extract the homomorphism from ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({a}\)\(*\)\)\)]],
  " to the monoid of ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Cross]\ 2\)]],
  " integer matrices for ",
  StyleBox["Mfibo",
    FontFamily->"Courier"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(TransitionMatrixFA[Mfibo, mu];\)\), "\n", 
    \(TableForm[mu[a]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[mu[w = MakeWord[a, 30]]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Function ",
  StyleBox["mu", "SmallText"],
  " is now defined on all strings of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s. Of course, we can obtain  ",
  Cell[BoxData[
      \(TraditionalForm\`mu[a\^i]\)]],
  "  also by computing matrix powers  ",
  Cell[BoxData[
      \(TraditionalForm\`mu[a]\^i\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(mu[w] === MatrixPower[mu[a], WordLength[w]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The function ",
  StyleBox["mu", "SmallText"],
  " has been assigned the attribute ",
  StyleBox["Listable",
    FontFamily->"Courier"],
  " and thus can be applied to a list of words:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(mu10 = mu[Words[\(-10\), {a}]];\)\), "\n", 
    \(MatrixForm /@ mu10\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "This provides another fast method to compute multiplicities for ",
  StyleBox["Mfibo",
    FontFamily->"Courier"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((Plus @@ First[#1] &)\) /@ mu10\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Alternatively, we may multiply these matrices with the vectors for \
the initial and final states. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ini = InitialVectorFA[Mfibo];\)\), "\n", 
    \(\(fin = FinalVectorFA[Mfibo];\)\), "\n", 
    \(\((ini . #1 . fin &)\) /@ mu10\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "For the machine ",
  StyleBox["Mcount", "SmallText"],
  " defined above we have similarly:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mcount\)], "Input"],

Cell[BoxData[{
    \(\(TransitionMatrixFA[Mcount, mu];\)\), "\n", 
    \(MatrixForm[mu["\<0\>"]]\), "\n", 
    \(MatrixForm[mu["\<1\>"]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To obtain the number of computations of ",
  StyleBox["Mcount",
    FontFamily->"Courier"],
  " on all inputs of length ",
  StyleBox["r",
    FontSlant->"Italic"],
  "  we can simply add ",
  StyleBox["mu[0]",
    FontFamily->"Courier"],
  " and ",
  StyleBox["mu[1]",
    FontFamily->"Courier"],
  ". This approach is used internally in ",
  StyleBox["LanguageFA",
    FontFamily->"Courier"],
  " when option ",
  StyleBox["SizeOnly",
    FontFamily->"Courier"],
  " is set True."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(mu01 = mu["\<0\>"] + mu["\<1\>"];\)\), "\n", 
    \(MatrixForm /@ FoldList[Dot, mu01, Table[mu01, {5}]]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Building Finite State Machines", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:8"],

Cell[CellGroupData[{

Cell["  Accessible, Coaccessible and Trim Machines", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:9"],

Cell[TextData[{
  "A finite state machine may well contain states that are superfluous in the \
sense that their deletion does not affect the acceptance language. A state is \
accessible iff there it lies on a path starting at an initial state, and \
coaccessible iff it lies on a path ending at a final state. A machine is \
accessible (coaccessible) iff all its states are accessible (coaccessible). A \
machine that is both accessible and coaccessible is called trim. \nMost \
algorithms in ",
  StyleBox["automata",
    FontFamily->"Courier"],
  " automatically generate only accessible machines. If a full machine is \
wanted one can force the some of the algorithms to include inaccessible state \
by setting option ",
  StyleBox["Full->True",
    FontFamily->"Courier"],
  ", see for example the discussion of ",
  StyleBox["ToDFA",
    FontFamily->"Courier"],
  " below.  \nNote that the accessible part of a DFA is always a DFA. \
However, in general the coaccessible part of a DFA is not complete. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["m = CounterDFA[ b, 3, {a,b} ]", "Input",
  AspectRatioFixed->True],

Cell["\<\
AccessibleFA[m]
CoAccessibleFA[m]
TrimFA[m]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
m = IthSymbolFA[ a, 3, {a,b} ]
mm = CompleteFA[ m ]\
\>", "Input",
  AspectRatioFixed->True],

Cell["TrimFA[mm]===m", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  Disjoint Sum and Product of Semiautomata", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:10"],

Cell["\<\
For semiautomata there is a natural way to form a (disjoint) sum \
and product of two machines. The sum is obtained by considering two machines \
as one (which causes problems if the state sets are not disjoint; by renaming \
of states we can clearly always insure that the state sets are in fact \
disjoint).  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = ModCounterDFA[a,0,3,{a,b}] // ToSA
m2 = ModCounterDFA[b,0,4,{a,b}] // ToSA\
\>", "Input",
  AspectRatioFixed->True],

Cell["SumFA[ m1, m2, Normalize->1 ]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Similarly we can define a product ",
  Cell[BoxData[
      \(TraditionalForm\`M\_\(\(1\)\(\ \)\)\[Cross]\ M\_\(\(2\)\(\ \)\)\)]],
  "of two semiautomata ",
  Cell[BoxData[
      \(TraditionalForm\`M\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  ": the state set is the Cartesian product of the two machines and the \
transitions are defined by\n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\((p, q)\), 
          a, \((p\^\[Prime], q\^\[Prime])\))\)\ \  \[Element] \ \ Trans(
          M\_\(\(1\)\(\ \)\)\[Cross]\ M\_\(\(2\)\(\ \)\))\)]],
  "   iff  \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\((p, a, p\^\[Prime])\)\  \[Element] \ 
        Trans(M\_1)\)]],
  "  and  ",
  Cell[BoxData[
      \(TraditionalForm\`\((q, a, q\^\[Prime])\)\  \[Element] \ 
        Trans(M\_2)\)]],
  "\n\t\nNote that the product construction is quadratic time whereas sum is \
linear."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
ProductFA[ m1, m2, Normalize->1 ]
Transitions[%]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Computations in a sum automaton are the union of the computations in the \
component machines. In a product automaton, however, every computation \
corresponds to a pair of computations in the component automata with the same \
input sequence. This can be used to generate automata that accept unions and \
intersections of given acceptance languages.  \n\nNote that there is a little \
twist in the construction of the product automaton if one of the two machines \
contains epsilon moves. In this case we have to add trivial transitions  ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, \[Epsilon], p)\)\)]],
  "  to both machines (otherwise there may be computations with the same \
input sequence in both machines but no corresponding computation in the \
product automaton). \nThe following example shows that the resulting product \
machines may have numerous epsilon transitions. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
sa1 = RegularExpressionToFA[RES[aa+bb], 3, 
\t\tThompson->True, EpsElim->False ] // ToSA
sa2 = RegularExpressionToFA[RES[aa+cc], 3, 
\t\tThompson->True, EpsElim->False ] // ToSA
sa  = ProductFA[sa1,sa2]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Of course, the language accepted by the product automaton is simply \
all words consisting only of a's.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["LanguageFA[ MinimizeFA[sa], -8 ]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  Boolean Operations", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Boolean Operations", "c:11"}],

Cell[TextData[{
  "By choosing appropriate initial and final states in a sum or product \
automaton as defined in the last section we can construct machines for union, \
intersection and even complement (provided we start from DFAs). Note, though, \
that the sum operation necessarily produces a machine with multiple initial \
states, and in particular not a DFA. Also note that machines obtained from \
sums and products are in general not accessible. Thus, in our implementation, \
only the accessible part of these machines is generated.  The commands ",
  StyleBox["UnionFA",
    FontFamily->"Courier"],
  " and ",
  StyleBox["IntersectionFA",
    FontFamily->"Courier"],
  " preserve DFAs when given DFAs as input. ",
  StyleBox["ComplementFA",
    FontFamily->"Courier"],
  " converts to DFAs first and is thus potentially exponential.\n\nAs a \
simple example, consider the language  ",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ {\ aaa, \ bb\ }\)]],
  ". We can use a product machine construction to get a DFA for the language. \
 "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = BuildDFA[aaa,{a,b}];
m2 = BuildDFA[bb,{a,b}];
m3 = UnionFA[m1,m2]
LanguageFA[ m3, -5 ]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Machine ",
  StyleBox["m3", "SmallText"],
  " is the accessible part of the full product machine. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m4 = UnionFA[m1,m2,Full->True]
m5 = AccessibleFA[ m4 ]\
\>", "Input",
  AspectRatioFixed->True],

Cell["IsomorphicQDFA[m3,m5]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Of course, we could obtain a DFA for ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " directly from ",
  StyleBox["BuildDFA",
    FontFamily->"Courier"],
  ".  Internally, ",
  StyleBox["BuildDFA",
    FontFamily->"Courier"],
  " uses a quotient machine construction and therefore produces the minimal \
automaton which turns out to have only 6 states in this case."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["BuildDFA[aaa,bb,{a,b}] // Size", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "As another example, let us compute the intersection machine of two \
mod-counters to obtain an automaton that accepts all strings with an even \
number of a's and b's. Mod-counters naturally have state set ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1, \(\(..\)\(,\)\(n\)\) - 1}\)]],
  ". This state set can be preserved by option ",
  StyleBox["Normalize->1",
    FontFamily->"Courier"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Ma = ModCounterDFA[a,0,2,{a,b},Normalize->1];
Mb = ModCounterDFA[b,0,2,{a,b},Normalize->1];
m  = IntersectionFA[ Ma, Mb, Normalize->1];
PrintFA[ m, LongForm->True,TransOnly->True ]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
As one can see clearly, the first component of each state in m \
counts a's modulo 2 and the second component counts b's modulo 2. \
Normalization hides this information. Here are some words in the language of \
m:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
L = LanguageFA[ m, -6 ];
L // ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To check if these strings are all have even-even parity use the command ",
  StyleBox["ParikhVector",
    FontFamily->"Courier"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ParikhVector[ Flatten[L],{a,b}]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mod[\ %, \ 2]\  // \ Union\)], "Input"],

Cell["\<\
To make the operations visually more obvious it is often good to \
use infix notation in conjunction with abbreviations. The union and \
complement machines only differ in the choice of final states:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Ma ~IntersectionFA~ Mb
Ma ~UnionFA~ Mb
Ma ~ComplementFA~ Mb\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\

Complementation of m produces a machine for all strings with an odd number of \
a's or b's.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["mcomp = ComplementFA[m]", "Input",
  AspectRatioFixed->True],

Cell["\<\
L = LanguageFA[ mcomp, -6 ];
L // ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell["ParikhVector[Flatten[L],{a,b}]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mod[\ %, \ 2\ ]\  // \ Union\)], "Input"],

Cell["Union of FAs is linear but intersection is quadratic:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = IthSymbolFA[ a, 3, {a,b} ];
m2 = IthSymbolFA[ b, 2, {a,b} ];
{m1,m2} // Size
UnionFA[ m1, m2 ]
IntersectionFA[ m1, m2 ]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  Concatenation and Kleene Star", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Concatenation Star", "c:12"}],

Cell[TextData[{
  StyleBox["ConcatenateFA",
    FontFamily->"Courier"],
  " is a polyadic command that concatenates FSMs. Here is an example:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Nall = AllDFA[{a,b,c}];
Na   = BuildDFA[a,{a,b,c}];
Nabc = BuildDFA[a,b,c,{a,b,c}];
N3a  = ConcatenateFA[ Nall, Na, Nabc, Nabc ]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ConcatenateFA",
    FontFamily->"Courier"],
  " uses epsilon transitions to glue the machines together and then removes \
them afterwards. The corresponding machine with epsilon transitions is \
obtained by setting option ",
  StyleBox["EpsElim->False",
    FontFamily->"Courier"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ConcatenateFA[ Nall, Na, Nabc, Nabc, EpsElim->False ]", "Input",
  AspectRatioFixed->True],

Cell["EpsilonEliminationFA[%] === N3a", "Input",
  AspectRatioFixed->True],

Cell["Check the acceptance language:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["LanguageFA[ N3a, -4 ] // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Command ",
  StyleBox["StarFA",
    FontFamily->"Courier"],
  " also has the option ",
  StyleBox["EpsElim->False",
    FontFamily->"Courier"],
  " which turns off automatic epsilon elimination.  For example, let"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["M1 = StarFA[ EmptyDFA[3], EpsElim->False ]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[EmptySet]\^*\)\(\ \)\(=\)\(\ \
\)\({\[Epsilon]}\)\(\ \)\)\)]],
  "  we have "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["EquivalentQFA[ ToDFA[M1], BuildDFA[Eps,3] ]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  Shuffle Product", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Shuffle", "c:13"}],

Cell[TextData[{
  "The command ",
  StyleBox["WordShuffle",
    FontFamily->"Courier"],
  " implements the shuffle operation on words and (finite) languages."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["WordShuffle[ bbb, aa ]", "Input",
  AspectRatioFixed->True],

Cell["WordShuffle[ {aa,bb}, {ab,ba} ]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Regular languages are closed under shuffle product.  Accordingly, we \
provide a command ",
  StyleBox["ShuffleProductFA",
    FontFamily->"Courier"],
  " that generates an FA for the shuffle product of the languages of the two \
input machines. Here is an example of a shuffle product of two regular \
languages:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\ \  = \ \ \({aa}\ \  || \ \ \(b\^*\)\  = \ \ all\ \
words\ with\ exactly\ two\ a' s\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = ShuffleProductFA[ 
\t\tBuildStarDFA[b,{a,b}], BuildDFA[aa,{a,b}]  ]\
\>", "Input",
  AspectRatioFixed->True],

Cell["Of course, there is a smaller DFA for L.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
mm = m1 // MinimizeFA
LanguageFA[mm,-5] // ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The command ",
  StyleBox["ShuffleProductFA",
    FontFamily->"Courier"],
  " has the usual option ",
  StyleBox["Normalize",
    FontFamily->"Courier"],
  ". As with product automata, the state set is a Cartesian product. However, \
only one component state is updated, rather than both at the same time. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
mmm = ShuffleProductFA[ 
\t\tBuildStarDFA[b,{a,b}], BuildDFA[aa,{a,b}], 
\t\tNormalize->1  ]\
\>", "Input",
  AspectRatioFixed->True],

Cell["PlotComputationFA[mmm, bbabbabb];", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(mmm\)], "Input"],

Cell[BoxData[
    \(AcceptQFA[mmm, bbabbabb, DoTrace \[Rule] True] // \(Curry[TableForm]\)[
        TableDepth \[Rule] 2]\)], "Input"],

Cell[TextData[{
  "\nThe Shuffle operation corresponds to Hurwitz products in  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalN] \[LeftAngleBracket]\
\[LeftAngleBracket]\(\[CapitalSigma]\^*\)\[RightAngleBracket]\
\[RightAngleBracket]\)]],
  ", the formal power series over ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^*\)\)]],
  " with non-negative integer coefficients.\nTo use the command ",
  StyleBox["HurwitzProduct",
    FontFamily->"Courier"],
  " we first translate languages  ",
  Cell[BoxData[
      \(TraditionalForm\`{aa}\)]],
  "  and  ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Epsilon], b, bb, bbb}\)]],
  "  into corresponding series  (or rather polynomials)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["S1 = {aa} // LanguageToSeries", "Input",
  AspectRatioFixed->True],

Cell["S2 = {Eps,b,bb,bbb,bbbb} // LanguageToSeries", "Input",
  AspectRatioFixed->True],

Cell["HurwitzProduct[S1,S2]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The command ",
  StyleBox["ToSeries",
    FontFamily->"Courier"],
  " displays the result as a power series in  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalN] \[LeftAngleBracket]\
\[LeftAngleBracket]\(\[CapitalSigma]\^*\)\[RightAngleBracket]\
\[RightAngleBracket]\)]],
  ".  In order to prevent ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " from rearranging the terms according to its own sorting algorithm we have \
wrapped the sum into a ",
  StyleBox["Hold", "SmallText"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["% // ToSeries", "Input",
  AspectRatioFixed->True],

Cell["\<\
Clearly, every word in the shuffle product has multiplicity 1. \
Hence the coefficients in the last sum are all 1. 

Higher multiplicities occur in the next example.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
L = {aa,ab,ba,bb};
WordShuffle[L,L]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
LL = L // LanguageToSeries;
H = HurwitzProduct[LL,LL]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Last /@ H // 
        ListPlot[#, PlotJoined \[Rule] True, 
            PlotStyle \[Rule] Blue] &;\)\)], "Input"],

Cell["H // ToSeries", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Conversion Algorithms", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:14"],

Cell[TextData[{
  "There are algorithms to convert a finite state machine of some type into \
an equivalent machine of another type. The conversions from DFA to NFA to FA \
are trivial and amount to rewriting the data structure. Also, FAs without \
eps-moves are easily converted into NFAs and vice versa. Thus we are left \
with two interesting conversion problems: from an FA with eps-moves to an FA \
without eps-moves and from there to an DFA. \nThe two corresponding \
algorithms are usually referred to as eps-elimination and deterministic \
simulation. In automata, the commands that perform type conversions are ",
  StyleBox["EpsilonEliminationFA",
    FontFamily->"Courier"],
  ", ",
  StyleBox["ToFA",
    FontFamily->"Courier"],
  ", ",
  StyleBox["ToNFA",
    FontFamily->"Courier"],
  ", and ",
  StyleBox["ToDFA",
    FontFamily->"Courier"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["  Simple Conversions", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Conversion", "c:15"}],

Cell[TextData[{
  "Recall the machine ",
  StyleBox["Mb3",
    FontFamily->"Courier"],
  " from above. ",
  StyleBox["Mb3",
    FontFamily->"Courier"],
  " is an epsilon-free FA:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Mb3 = IthSymbolFA[b,-3,{a,b}]
Mb3 // EpsFreeQ\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
The conversion of an epsilon-free FA to an NFA is quite \
straightforward and easily reversible.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = ToNFA[Mb3]
Mb3===ToFA[m1]\
\>", "Input",
  AspectRatioFixed->True],

Cell["DFAs are readily converted to NFAs or FAs. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m = BuildDFA[ aaa, bbb, {a,b} ]
m // ToNFA\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  Epsilon Elimination", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Epsilon Elimination", "c:16"}],

Cell[TextData[{
  "Our first non-trivial conversion procedure translates an FA with \
epsilon-moves into and equivalent, epsilon-free machine. The algorithm \
basically computes the transitive, reflexive closure of the relation  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_\[Epsilon]\)]],
  " and then replaces ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " by the product of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " and this relation. Note that this procedure does not affect the number of \
states, however, it will in general increase the number of transitions. \n\
First, we have to construct a machine with epsilon-moves. Epsilon elimination \
is performed automatically inside ",
  StyleBox["StarFA",
    FontFamily->"Courier"],
  " and ",
  StyleBox["ConcatenateFA",
    FontFamily->"Courier"],
  " (also in  ",
  StyleBox["RegularExpressionFA",
    FontFamily->"Courier"],
  ") described below. Option ",
  StyleBox["EpsElim->False",
    FontFamily->"Courier"],
  " will override this default. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m1 = 
        StarFA[BuildDFA[aab, {a, b}], EpsElim \[Rule] False];\)\), "\n", 
    \(\(m2 = 
        StarFA[BuildDFA[bba, {a, b}], EpsElim \[Rule] False];\)\), "\n", 
    \(m3 = 
      ConcatenateFA[m1, m2, BuildDFA[bbb, {a, b}], 
        EpsElim \[Rule] False]\)}], "Input"],

Cell["m4 = m3 // EpsilonEliminationFA", "Input",
  AspectRatioFixed->True],

Cell["\<\
Note that the number of initial states has increased. The total \
number of transitions in this example remains nearly the same.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m3 // NumTransitions
m4 // NumTransitions\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["EpsilonEliminationFA",
    FontFamily->"Courier"],
  " has on option ",
  StyleBox["DoTrace",
    FontFamily->"Courier"],
  ", set ",
  StyleBox["False", "SmallText"],
  " by default, that causes the command to output a list \n",
  StyleBox["\t",
    FontFamily->"Courier"],
  Cell[BoxData[
      \(TraditionalForm\`\(\({\ M, \ T\_\[Epsilon], \ 
        T\_\(non - \[Epsilon]\), \ A}\)\(\ \)\)\)]],
  StyleBox[" \n",
    FontFamily->"Courier"],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is the machine after epsilon elimination, ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\[Epsilon]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(non - \[Epsilon]\)\)]],
  " are the epsilon transitions and non-epsilon transitions in the old \
machine, respectively.  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\)\(\ \ \)\)\)]],
  "is the adjacency list of the transitive closure graph induced on the state \
set by ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(non - \[Epsilon]\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\({t1, t2, t3} = 
        Rest@EpsilonEliminationFA[m3, DoTrace \[Rule] True, 
            External \[Rule] False];\)\)], "Input"],

Cell["\<\
MatrixForm[t1]
MatrixForm[Thread@t2]
ColumnForm[t3]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  Deterministic Simulation", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Conversion", "c:17"}],

Cell[TextData[{
  "The epsilon elimation algorithm from the last section returns a machine of \
essentially the same size as the input machine (i.e., the number of states \
remains constant, but the number of transitions may increase) and clearly has \
polynomial running time. Deterministic simulation, however, constructs a new \
machine whose state set is a subset of the power set of the input machine. As \
we will see, in some cases the full power set or at least a large part of it \
is encountered during the construction. As a result, the algorithm used in ",
  StyleBox["ToDFA",
    FontFamily->"Courier"],
  " may have exponential running time (and, what's worse, its space \
requirement may also be exponential). \n\nHere is an example. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m = IthSymbolFA[b,-3,{a,b}]
mm = ToDFA[ m ]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["ToDFA",
    FontFamily->"Courier"],
  " constructs only the accessible part fo the power set machine. Also, it \
automatically normalizes the output. We can override both defaults (together \
or independently). Note that it is necessary to use the internal algorithm \
here since the external one always generates only the accessible part.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(mmm = 
        ToDFA[m, Full \[Rule] True, Normalize \[Rule] 1, 
          External \[Rule] False];\)\), "\n", 
    \(PrintFA[mmm, LongForm \[Rule] True, TransOnly \[Rule] True]\)}], "Input"],

Cell[TextData[{
  "The machine has now  ",
  Cell[BoxData[
      \(TraditionalForm\`2\^4 = 16\)]],
  " states.  Its accessible part can be extracted using command ",
  StyleBox["AccessibleFA",
    FontFamily->"Courier"],
  " and is isomorphic to ",
  StyleBox["m2.", "SmallText"],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["AccessibleFA[ mmm ]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["AccessibleFA",
    FontFamily->"Courier"],
  " has option ",
  StyleBox["Normalize",
    FontFamily->"Courier"],
  ", which, when set to ",
  StyleBox["False", "SmallText"],
  ", will preserve the original state set."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["macc = AccessibleFA[ mmm, Normalize->2 ]", "Input",
  AspectRatioFixed->True],

Cell["\<\
It is now easy to see that exactly all those states p of mmm are \
accessible that contain (old) state 1.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["macc // States // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The same states are obtained by setting the option ",
  StyleBox["Normalize->1",
    FontFamily->"Courier"],
  " in ",
  StyleBox["ToDFA",
    FontFamily->"Courier"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ToDFA[ m, Normalize->2 ] // States // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The accessible parts of ",
  StyleBox["mmm", "SmallText"],
  " and ",
  StyleBox["mm", "SmallText"],
  " are isomorphic."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["IsomorphicQDFA[ macc, mm ]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  ToSA", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:18"],

Cell["\<\
Unlike the other conversion operations, conversion to a \
semiautomaton usually changes the acceptance language since in an SA all \
states are considered initial as well as final. For example, the SA obtained \
from a suffix automaton accepts all factors. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["m = SuffixesFA[ abcd, {a,b,c,d} ]", "Input",
  AspectRatioFixed->True],

Cell["mm = m // ToSA", "Input",
  AspectRatioFixed->True],

Cell["LanguageFA[mm,-6] // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell["mm // ToFA", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The Transition Diagram", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Graphs", "c:19"}],

Cell[TextData[{
  "A finite state machine can be construed as a labelled graph, the so-called \
transition diagram of the machine, perhaps with additional information about \
initial and final states.  Several important properties of a FSM can be most \
conveniently expressed in terms of the transition diagram of the machine.  \
Moreover, standard graph algorithms can then be used to test these \
properties. The command ",
  StyleBox["ToGraphFA",
    FontFamily->"Courier"],
  " translates a finite state machine into the corresponding labeled or \
unlabeled directed graph. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Accessible/Coaccessible Machines", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:20"],

Cell[TextData[{
  "The acceptance language of a FSM is clearly not affected by deletion of \
all states that fail to be accessible from an initial state and coaccessible \
from a final state. Finding theses states boils down to computing weakly \
connected components in the transition diagram. \nSince DFAs are not usually \
accessible and coaccessible, the command ",
  StyleBox["TrimFA",
    FontFamily->"Courier"],
  " returns an FA (or NFA). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m = 
        RegularExpressionToFA[a ** RES[b] + b ** RES[a], {a, b}];\)\), "\n", 
    \(\(m1 = ToDFA[m, Full \[Rule] True, External \[Rule] False];\)\), "\n", 
    \(m1 // Size\), "\n", 
    \(i = Initial[m1]\), "\n", 
    \(f = Final[m1]\)}], "Input"],

Cell["\<\
g   = ToGraphFA[m1,Unlabeled\[Rule]True];
acc = WeaklyConnectedComponents[g,i]
coa = WeaklyConnectedComponents[g//ReverseGraph,f]
Q   = Intersection[acc,coa]\
\>", "Input",
  AspectRatioFixed->True],

Cell["m2 = SelectFA[m1,Q]", "Input",
  AspectRatioFixed->True],

Cell["m3 = TrimFA[m1]", "Input",
  AspectRatioFixed->True],

Cell["EquivalentQFA[m2,m3]", "Input",
  AspectRatioFixed->True],

Cell["LanguageFA[m3,-6] // EnumForm0", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Finite Acceptance Languages", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:21"],

Cell["\<\
The most basic property of regular languages that can be expressed \
in terms of the transition diagram is finiteness: a FSM accepts infinitely \
many words iff its transition diagram contains a loop (not labeled Eps) that \
is accessible from the initial state and coaccessible from the set of final \
states. The latter condition is easily tested using standard graph \
algorithms. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["m = BuildDFA[ Eps, aa, bb, abab,{a,b,c}]", "Input",
  AspectRatioFixed->True],

Cell["\<\
g = ToGraphFA[m]
ToGraphFA[m,Unlabeled->False]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
We can now compute the strongly connected components of this graph.\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["StronglyConnectedComponents[g]", "Input",
  AspectRatioFixed->True],

Cell["All the components other than the sink are trivial:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
TheSinkDFA[m]
StronglyConnectedComponents[g,NonTrivial->True]\
\>", "Input",
  AspectRatioFixed->True],

Cell["Hence the acceptance language is finite:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["InfiniteQFA[m]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To obtain a more interesting underlying graph, consider a machine for the \
language   ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((aa)\)\^*\)\(\ \)\(\((bb)\)\^*\)\(\ \)\(\((aa)\
\)\^*\)\(\ \)\)\)]],
  " (an even number of a's, followed by an even number of b's, followed by an \
even number of a's). We use a regular expression to generate the machine. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
mm = RegularExpressionToFA[ RES[aa]**RES[bb]**RES[aa], {a,b} ];
mm = MinimizeFA[mm]\
\>", "Input",
  AspectRatioFixed->True],

Cell["gg = ToGraphFA[mm]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The transition diagram of ",
  StyleBox["mm", "SmallText"],
  " has three strongly connected components of size 2 and the sink."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["StronglyConnectedComponents[gg,NonTrivial->True]", "Input",
  AspectRatioFixed->True],

Cell["TheSinkDFA[mm]", "Input",
  AspectRatioFixed->True],

Cell["InfiniteQFA[mm]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A DFA is called transitive iff its transition diagram has only one \
strongly connected component. The command ",
  StyleBox["TransitiveQFA",
    FontFamily->"Courier"],
  " tests whether an FA is transitive. The option ",
  StyleBox["DoTrace->True", "SmallText"],
  " causes the strongly connected components of the transition diagram of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " to be displayed."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m = IthSymbolFA[b,-3,2] // MinimizeFA;
TransitiveQFA[m]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
We can also compute the collapse of the transition diagram \
(obtained by collapsing the strongly connected components into points). \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
gg0 = ToDAG[gg] // ToAdjList
gg0 // VertexSet\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Definite Automata", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:22"],

Cell[TextData[{
  "A word ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is said to be ",
  StyleBox["synchronizing",
    FontColor->RGBColor[0, 0, 1]],
  " for a machine ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " if all computations with label ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " have the same target, regardless of the starting point of the \
computation:   ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](Q, x)\  = {p}\)]],
  ". \nHere is an example of a deterministic semiautomaton that has a \
synchronizing word. Except for one state the machine is also complete. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(m\  = \ 
        SA[15, \(-2\), {{1, 1, 2}, {2, 1, 2}, {3, 1, 4}, {4, 1, 6}, {5, 1, 
              8}, {6, 1, 8}, {7, 1, 9}, {8, 1, 4}, {9, 1, 12}, {10, 1, 
              12}, {11, 1, 13}, {12, 1, 13}, {13, 1, 9}, {14, 1, 6}, {1, 2, 
              1}, {2, 2, 3}, {3, 2, 5}, {4, 2, 7}, {5, 2, 1}, {6, 2, 8}, {7, 
              2, 10}, {8, 2, 11}, {9, 2, 13}, {10, 2, 14}, {11, 2, 5}, {12, 
              2, 12}, {13, 2, 15}, {14, 2, 14}, {15, 2, 
              10}}, {}, {}];\)\)], "Input"],

Cell[BoxData[
    \(DegreesFA[m]\)], "Input"],

Cell["\<\
The transitionfunction demonstrates that \"01010\" synchronizes \
this machine. \
\>", "Text"],

Cell[BoxData[{
    \(TransitionFunctionFA[m, delta]\), "\n", 
    \(delta[\ Range[15], \ "\<01010\>"\ ]\)}], "Input"],

Cell[TextData[{
  "A DFA is ",
  StyleBox["definite",
    FontColor->RGBColor[0, 0, 1]],
  " iff there is some number ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " such that all words ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(x\)\(|\)\(\ \)\(\(\[GreaterEqual]\)\(\ \
\)\(n\)\)\)\)]],
  ", are synchronizing. Thus, for all states ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  ",  we have:  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](p, x)\  = \ \[Delta](q, x)\)]],
  "  provided ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is sufficiently long. \nA moments thought shows that a DFA is definite \
iff its product automaton has only one nontrivial strongly connected \
component. Since initial and final states play no role in this, we may use \
the product construction for semiautomata. The machines generated by ",
  StyleBox["IthSymbolDFA", "SmallText"],
  " are definite: the state is determined entirely be the last three input \
symbols. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m = IthSymbolDFA[a,-3,{a,b}]
DefiniteQFA[m]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can determine the critical length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " in the definition of definiteness using the same command ",
  StyleBox["DefiniteQFA", "SmallText"],
  "."
}], "Text"],

Cell[BoxData[
    \(DefiniteQFA[m, Full \[Rule] True]\)], "Input"],

Cell[TextData[{
  "The method employed in the algorithm is to compute the product of the \
finite state machine with itself, and convert the product machine into a \
directed graph. The strongly connected components of this graph determine \
definiteness, and an analysis of the path length between the components \
determines the critical length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". More precisely, all sufficiently long paths must lead to a SCC that is \
part of the diagonal ",
  Cell[BoxData[
      \(TraditionalForm\`{\ \((p, p)\)\  | \ 
            p\  \[Element] \ Q\ }\ \  \[SubsetEqual] \ 
        M\^\(\(\ \)\(2\)\)\)]],
  ". \nTo speed up the computation a bit, one can compute the product \
automaton based on unordered pairs of states rather than the usual ordered \
pairs. For the remaining analysis of the diagram, unordered pairs suffice."
}], "Text"],

Cell["\<\
m2 = SquareSA[ToSA[m]];
g  = ToGraphFA[m2];
StronglyConnectedComponents[g,NonTrivial\[Rule]True]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
There is only one non-trivial SCC, so the machine is definite. \
Similarly, the corresponding star automaton is definite. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m3 = ToSA@StarFA[m];\)\), "\n", 
    \(\(m4 = SquareSA[m3];\)\), "\n", 
    \(\(g = ToGraphFA[m4];\)\), "\n", 
    \(StronglyConnectedComponents[g, NonTrivial \[Rule] True]\)}], "Input"],

Cell[TextData[{
  "But machines for the language ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\(a(
              b\[VeryThinSpace]b)\)\^*\)\  + \ \(\(b(
              a\[VeryThinSpace]a)\)\^*\)\)\)\)]],
  " should not be definite. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(RegularExpressionToFA[a ** RES[bb] + b ** RES[aa], {a, b}]\), "\n", 
    \(\(m5 = SquareSA[ToSA[%], Normalize \[Rule] 1];\)\), "\n", 
    \(\(g = ToGraphFA[m5];\)\), "\n", 
    \(StronglyConnectedComponents[g, NonTrivial \[Rule] True]\)}], "Input"],

Cell["\<\
There are several components, so we have to take a closer look. Not \
all the SCCs are part of the diagonal, so the machine in question is not \
definite.\
\>", "Text"],

Cell[BoxData[{
    \(Q\  = \ m5\  // \ States\), "\n", 
    \(PositionList[\ Q, Cases[Q, {x_, x_}]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Ambiguous Automata", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:23"],

Cell[TextData[{
  "A FSM is ",
  StyleBox["ambiguous",
    FontColor->RGBColor[0, 0, 1]],
  " iff there is some  word ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "  and states ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  "  such that there are at least two computations from ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " labelled ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  \nClearly, a deterministic machine is always unambiguous. But \
nondeterministic machines may also be unambiguous. The following example will \
be analyzed more carefully in the section on cellular automata. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(m = 
        SA[8, \(-2\), {{1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 1, 
              5}, {3, 1, 6}, {4, 2, 7}, {4, 1, 8}, {5, 2, 1}, {5, 2, 2}, {6, 
              2, 3}, {6, 2, 4}, {7, 1, 5}, {7, 1, 6}, {8, 1, 7}, {8, 1, 
              8}}];\)\)], "Input"],

Cell[BoxData[
    \(DegreesFA[m] // \ TableForm\)], "Input"],

Cell[TextData[{
  "In terms of the unfolding of the automaton ambiguity would translate into \
the existence of a diamond. More precisely, the automaton ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is ambiguous iff there is some word ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " such that the unfolding ",
  Cell[BoxData[
      \(TraditionalForm\`TD(M, x)\)]],
  " has two paths from some intial vertex to a terminal vertex. The following \
picture shows that ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ 001100\)]],
  " fails to produce a diamond."
}], "Text"],

Cell[BoxData[
    \(\(PlotComputationFA[m, "\<001100\>", PlotStyle \[Rule] { .015,  .02}, 
        LineStyle \[Rule] { .005,  .01}];\)\)], "Input"],

Cell["\<\
The method employed to determine definiteness can easily be adopted \
to ambiguity testing. This time, we have to verify that the SCC containing \
the diagonal (in the diagram of the square of the automaton) consists only of \
the diagonal itself.\
\>", "Text"],

Cell[BoxData[
    \(AmbiguousQFA[m]\)], "Input"],

Cell[TextData[{
  "The canonical nondeterministic automata that recognize all words with a \
certain symbol in position ",
  Cell[BoxData[
      \(TraditionalForm\`\(-i\)\)]],
  " provide another example of unambiguous machines. "
}], "Text"],

Cell[BoxData[{
    \(IthSymbolFA[a, \(-3\)]\  // \ DeterministicQFA\), "\n", 
    \(IthSymbolFA[a, \(-3\)]\  // \ AmbiguousQFA\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frontier Automata", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:24"],

Cell[TextData[{
  "Let M be some accessible DFA over a k-symbol alphabet. We can unfold ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " into a k-ary tree whose nodes are sequences in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([\)\(k\)\(]\)\)\)]],
  ". The nodes can be labeled by the states of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ": node ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is labeled  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](q\_0, x)\)]],
  "  (we identify ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " with the corresponding sequence of symbols in the underlying alphabet). \
By truncating the tree at all nodes that are labeled by a state that already \
occurs at a previous node (with respect to the tree ordering defined above) \
we obtain a finite tree, the transition tree of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ". \n\n",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " can now be represented as follows:  Let  fr be the frontier of the \
transition tree and ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " its interior nodes (all prefixes of frontier nodes). Define a function  \
",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\  : \ fr\ \[LongRightArrow]\ I\)]],
  "  from the frontier to the interior of the tree that maps node ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to the predecessor node ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " such that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](q\_0, x) = \[Delta](q\_0, y)\)]],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\)]],
  " together with the nodes ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " corresponding to final states in ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " completely determine ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ". We refer to the pair ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[CapitalGamma], F)\)\)]],
  " as the ",
  StyleBox["frontier automaton",
    FontColor->RGBColor[0, 0, 1]],
  " associated to ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ". \nHere is an example. The command ",
  StyleBox["ToFrontierDFA ",
    FontFamily->"Courier"],
  "returns the frontier automaton. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m = IthSymbolDFA[b,-2,{a,b}];
{\[CapitalGamma],F} = ToFrontierDFA[m];
\[CapitalGamma] // PrintEquations
F\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The frontier of the unfolding of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " consists of all words of length 3: "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["front = First /@ \[CapitalGamma]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "One can also construct a frontier automaton where  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma](x)\)]],
  "  is always a prefix of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", so that the next state is either a node immediately above the current \
one or lies somewhere on the branch below the current node. Needless to say, \
this machine will in general be larger than the canonical frontier automaton. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
{\[CapitalGamma],F} = ToPeriodicFrontierDFA[m];
\[CapitalGamma] // PrintEquations
F\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Conversely we can convert a frontier automaton into a DFA. It is a good \
idea to verify first that the domain of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\)]],
  " is in fact a frontier.  Below we concoct \[CapitalGamma] for a machine \
recognizing all strings with an even number of a's and b's. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
\[CapitalGamma] =     { 
\t\t\t{ aa, Eps }, 
\t\t\t{ bb, Eps }, 
\t\t\t{ baa, b },
\t\t\t{ bab, a },
\t\t\t{ aba, b },
\t\t\t{ abb, a }
 \t\t};
FrontierQ[First /@ \[CapitalGamma],{a,b}]\
\>", "Input",
  AspectRatioFixed->True],

Cell["m1 = FrontierToDFA[\[CapitalGamma],{Eps}]", "Input",
  AspectRatioFixed->True],

Cell["LanguageFA[m1,-4] // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell["\<\
Seems to work. Our frontier automaton is somewhat clumsy. Here is a \
more elegant solution.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m2  = MinimizeFA[m1];
{G,F} = ToFrontierDFA[m2];
\[CapitalGamma] // PrintEquations
F\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Compare this to the defining equations of the syntactic \
monoid.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
eq = SimplifyEquations@@SyntacticSG[m2,Equations->True];
PrintEquations[eq]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Some Sample Machines", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Sample machines", "c:25"}],

Cell[CellGroupData[{

Cell["  Ranking DFAs", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:26"],

Cell[TextData[{
  "There are several natural enumerations of all DFAs on ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " states and an alphabet of size ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "; or ",
  Cell[BoxData[
      \(TraditionalForm\`\((n, k)\)\)]],
  "-DFAs for short. This package contains a ranking and unranking function ",
  StyleBox["RankToDFA",
    FontFamily->"Courier"],
  " and ",
  StyleBox["RankOfDFA",
    FontFamily->"Courier"],
  " based on one such enumeration. ",
  StyleBox["NumberOfDFA",
    FontFamily->"Courier"],
  " counts the number of ",
  Cell[BoxData[
      \(TraditionalForm\`\((n, k)\)\)]],
  "-DFAs.\nFor one and two symbol alphabets the number of DFAs on ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " states, ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ 1, \(\(..\)\(,\)\(10\)\)\)]],
  ", is as follows:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Transpose[ { NumberOfDFA[#,1]& /@ Range[10],
\t         NumberOfDFA[#,2]& /@ Range[10] } ] // TableForm\
\>", "Input",
  AspectRatioFixed->True],

Cell["m = RankToDFA[12345,3,2]", "Input",
  AspectRatioFixed->True],

Cell["RankOfDFA[m]", "Input",
  AspectRatioFixed->True],

Cell["PrintFA[ m ]", "Input",
  AspectRatioFixed->True],

Cell["LanguageFA[ m, -4 ]  // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell["\<\
We can use the ranking machinery to generate random automata. This \
is occasionally useful to test new functions on these machines. \
\>", "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell["RankToDFA[ Random[Integer,NumberOfDFA[#1,#2]],#1,#2]&[8,3]", "Input",
  AspectRatioFixed->True],

Cell["LanguageFA[%,-4] // ColumnForm", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  One-symbol Alphabets", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:27"],

Cell[TextData[{
  "In this section we consider the special case of a one-symbol alphabet, \
say, the alphabet {a}.  A moments thought reveals that in this case all DFAs \
have the structure of a one-generated monoid: there is a linear transient \
part followed by a loop. Less formally: they look like a lasso. \n\nAs an \
example, suppose we wish to construct the minimal DFA for the following \
language:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`L = {\ 
          a\^i | i \[GreaterEqual] \ 4\ \  \[And] \ i = 0, 3  mod\ 4}\)]],
  ".\nSince ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " can be decomposed as\n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ {aaaa} \((\[Epsilon] + aaa)\) {\ 
            a\^i | \ i = 0  mod  4}\)]],
  "\nwe can build an automaton for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(L\)\(\ \ \)\)\)]],
  "as follows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = ConcatenateFA[ 
\t\tBuildDFA[{aaaaaaa,aaaa},{a}], 
\t\tModCounterDFA[a,0,4,{a}] 
\t]
m2 = MinimizeFA[ m1 ]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Thus, the transient part has length 5 and the loop has length 4. \
Consequently, the acceptance language is ultimately periodic with period 4:\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["LanguageFA[ m2, -40, SizeOnly->True ]", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["  (3,1)-DFAs", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"41-minimal DFAs", "c:28"}],

Cell["\<\
NumberOfDFA[3,1]
cand = Select[Range[NumberOfDFA[3,1]], 
\t\t(Mod[Floor[#/8],3]==0)& ];
Length[cand]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
We can now generate the machines, minimize them and eliminate \
duplicates. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
auto31 = RankToDFA[#,3,1]& /@ cand;
min31  = Union[ MinimizeFA /@ auto31 ];//Timing
min31 // Length\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The next step is to eliminate isomorphic machines. This can be done using \
the procedure ",
  StyleBox["MakeIndex",
    FontFamily->"Courier"],
  "  (defined in dimath.m). ",
  StyleBox["MakeIndex",
    FontFamily->"Courier"],
  " takes as input a list and an equivalence relation and returns an index \
vector describing the equivalence classes of the list elements. As it turns \
out, if you use the external function to mininize, only nonisomorphic \
machines survive and the next step is superfluous. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
{ind,r} = MakeIndex[min31,IsomorphicQDFA];//Timing
r
min31 = FromBitVector[ Witnesses[ind], min31 ];
min31 // ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
The acceptance languages (or rather: the first few words) of these \
machines can be nicely displayed as a matrix.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
lang = LanguageFA[#,-Length[min31],SizeOnly->True]& /@ min31;\
\>", \
"Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotMatrix[lang];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["  (4,1)-DFAs", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:29"],

Cell[TextData[{
  "For more than 3 states the method we just used becomes quite unwieldy. To \
speed things up, we make two changes. \nFirst, to generate the list of \
candidate machines we should not really use ",
  StyleBox["RankToDFA",
    FontFamily->"Courier"],
  ". Remember that on a one-symbol alphabet the accessible part of any DFA \
has the form of a lasso: there is a transient part of length ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " leading to a cycle of length ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ". Clearly, the machine is determined completely by ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and the list of final states (we assume the initial state is 1). So we \
can build the machines directly. \nSecond, we won't test for isomorphism. \
Instead, we will transform the machines into a normal form and then simply \
eliminate identical copies of the same machine. The command ",
  StyleBox["AccessibleFA",
    FontFamily->"Courier"],
  " produces the desired normal form and we can use ",
  StyleBox["Union",
    FontFamily->"Courier"],
  " to eliminate isomorphic machines. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
lassoDFA[ q_, p_ ] := 
Module[ {todfa,tr},
\ttodfa[LL_] := DFA[ p+q, 1, tr, 1, LL, {}, {} ];
\ttr = { Join[ Range[2,p+q], {q+1} ] };
\ttodfa /@ PowerSet[Range[q+p]]
];
lassoDFA[n_] := Join@@( lassoDFA[#,n-#]& /@ Range[0,n-1] );\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
cand = lassoDFA[4];
cand // Length\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
min41 = Union[ AccessibleFA[MinimizeFA[#]]& /@ cand ];//Timing
min41 // Length\
\>", "Input",
  AspectRatioFixed->True],

Cell["min41 // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell["\<\
min4 = Cases[ min41, DFA[4,__] ];
min4 // Length\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
lang  = LanguageFA[#,-Length[min41],SizeOnly->True]& /@ min41;
PlotMatrix[lang];\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the lower part of the picture is a copy of the previous image.\n\
\nBeyond ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ 4\)]],
  " this procedure becomes rather unbearably slow unless one uses the \
external procedures. Using optimized code on an SGI (R4000 CPU) it takes \
about 5 minutes to determine all minimal ",
  Cell[BoxData[
      \(TraditionalForm\`\((10, 1)\)\)]],
  "-DFAs. There are 4926 such machines. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  (n,1)-DFAs", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:30"],

Cell[TextData[{
  "A moment's thought reveals that one can construct minimal DFAs for \
one-symbol alphabets directly without having to resort to a minimization \
algorithm. A lasso automaton is minimal iff \n-  the bitvector for the final \
states on the loop is a primitive word over ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1}\)]],
  ",\n-  either the last state on the loop is final or the last transient \
state is final.\n\nThe following procedure ",
  StyleBox["minimallassoDFA[q,p]",
    FontFamily->"Courier"],
  " generates all minimal DFAs with ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " transient states and ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " states on the cycle. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
minimallassoDFA[ q_Integer, p_Integer ] := 
Module[ {todfa,tofinal,prim,tobv,tr,fin,fin0,fin1,Fin0,Fin1,tran,
\t\ttran0,tran1},
\ttobv[w_] := 
\t\tFromBitVector[ToExpression /@ ToCharacters[w], Range[p]];
\ttofinal[ {A_,B_} ] := Join[ A, q + B ];
\ttodfa[LL_List] := DFA[p+q,1,tr,1,LL,{},{}];
\t
\ttr = { Join[ Range[2,p+q], {q+1} ] };
\tprim = Select[ Words[p,-2], PrimitiveQ ];
\tfin  = tobv /@ prim;
\tfin0 = Select[ fin, !MemberQ[#,p]& ];
\tfin1 = Select[ fin,  MemberQ[#,p]& ];
\ttran = PowerSet[Range[q]];
\ttran0 = Select[ tran, !MemberQ[#,q]& ];
\ttran1 = Select[ tran,  MemberQ[#,q]& ];
\tIf[ q==0, tran1 = tran0 ];
\tFin0 = tofinal /@ CartesianProduct[ tran0, fin1 ];
\tFin1 = tofinal /@ CartesianProduct[ tran1, fin0 ];
\tFin  = Complement[ Union[ Fin0, Fin1 ], {{}} ];
\ttodfa /@ Fin 
];
minimallassoDFA[n_] := 
\tJoin@@( minimallassoDFA[#,n-#]& /@ Range[0,n-1] );\
\>", "Input",
  AspectRatioFixed->True],

Cell["minimallassoDFA[2,4]", "Input",
  AspectRatioFixed->True],

Cell["minimallassoDFA[4] // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since we know how to count primitive words we can also determine the \
number of minimal ",
  Cell[BoxData[
      \(TraditionalForm\`\((n, 1)\)\)]],
  "-DFAs. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[count];
count[0,p_]  := PrimitiveCount[p,2];
count[q_,p_] := 2^(q-1) PrimitiveCount[p,2];
count[n_]    := Plus@@(count[#,n-#]& /@ Range[0,n-1]);\
\>", "Input",
  AspectRatioFixed->True],

Cell["count /@ Range[10]", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["  I-th Symbol from the End", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:31"],

Cell[TextData[{
  "There is a natural nondeterministic machine for languages of the form \n\t\
",
  Cell[BoxData[
      \(TraditionalForm\`L(b, \(-r\)) = \(\[CapitalSigma]\^*\) 
          b\ \[CapitalSigma]\^\(r - 1\)\)]],
  ". \nThus every word in the language has a symbol '",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "' in position ",
  Cell[BoxData[
      \(TraditionalForm\`\(-r\)\)]],
  ". The machine has  ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "  states and all the nondeterministic transitions occur only at state 1. \
The command ",
  StyleBox["IthSymbolFA", "SmallText"],
  " generates the corresponding FA. We use alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\_\(\(3\)\(\ \)\) = \ {0, 1, 2}\)]],
  " throughout. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = IthSymbolFA[b,-3,3];
PrintFA[m1]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Almost all the states in ",
  StyleBox["m1", "SmallText"],
  " are deterministic, only state 1 has two transitions under input '",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "':"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["DegreesFA[m1] // TableForm", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "It may be desirable to number the states starting at 0 rather than 1. To \
this end there is the option ",
  StyleBox["Normalize", "SmallText"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["m1 = IthSymbolFA[b,-3,3,Normalize->1]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "There is also a natural DFA for the language ",
  Cell[BoxData[
      \(TraditionalForm\`L(b, \(-3\))\)]],
  " that uses as set of states all words over the alphabet of length at most \
",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["m2 = IthSymbolDFA[b,-3,3,Normalize->1]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus the automaton has  ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\^\(r + 1\) - \ 1\)\/\(k\  - \ 1\)\)]],
  " states where ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ \(\(|\)\(\(\[CapitalSigma]\)\(|\)\)\)\)]],
  ".  Minimization with option ",
  StyleBox["Normalize->1", "SmallText"],
  " shows the equivalent states. We sort and rearrange the words so that the \
structure of the equivalence classes becomes more clear. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
mm2 = MinimizeFA[m2,Normalize->2];
Q = Reverse /@ WordSort /@ States[mm2];
Q // ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "It is a good exercise to determine which words/states are equivalent and \
why. What does ",
  StyleBox["mm2", "SmallText"],
  " look like in general? What is the size of the minimal automaton?\nYet \
another way to construct a FSM for ",
  Cell[BoxData[
      \(TraditionalForm\`L(b, \(-3\))\)]],
  " uses the idea of a local-universal machine, see the discussion below. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
ini = (#===\"aaa\")&;
fin = (StringMatchQ[#,\"b*\"])&;
m3  = LocalUniversalFA[3,3,
\t\t\tIniLU->ini,FinLU->fin,Normalize->1]\
\>", "Input",
  AspectRatioFixed->True],

Cell["{ EquivalentQFA[m1,m2], EquivalentQFA[m1,m3] }", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that deterministic simulation of the original machine ",
  StyleBox["m1", "SmallText"],
  " causes an exponential blowup in size. The resulting machine turns out to \
be minimal. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m11 = ToDFA[m1]
MinimizeFA[m2] // Size\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  Factors", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:32"],

Cell[TextData[{
  "There is a natural nondeterministic machine for languages of the form \n\t\
",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ \ \(\[CapitalSigma]\^*\)\ w\ \ \(\
\[CapitalSigma]\^*\)\)]],
  ". \nThe machine has ",
  Cell[BoxData[
      \(TraditionalForm\`r + 1\)]],
  " states and all the nondeterministic transitions occur only at state 1. \
The automaton is generated by the command ",
  StyleBox["InfixFA",
    FontFamily->"Courier"],
  ". Note that the corresponding minimal DFA also has ",
  Cell[BoxData[
      \(TraditionalForm\`r + 1\)]],
  " states. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
r = 10;
m1 = InfixFA[ RandomWord[r,{a,b}],{a,b}]
m2 = MinimizeFA[ m1 ]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Similarly we can generate machines for all words that contain w as a \
prefix or suffix. Note that ",
  StyleBox["PrefixDFA",
    FontFamily->"Courier"],
  " produces a DFA on ",
  Cell[BoxData[
      \(TraditionalForm\`r + 2\)]],
  " states. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
r = 10;
PrefixDFA[ RandomWord[r,{a,b}],{a,b}]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
r = 10;
SuffixFA[ RandomWord[r,{a,b}],{a,b}] // MinimizeFA\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  String Searching and the KMP Algorithm", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:33"],

Cell[TextData[{
  "A task frequently encountered in many applications such as word processing \
is to determine all occurrences of a string w (the pattern) in another string \
t (the text). The pattern w is usually much shorter than the text.  The brute \
force approach to the problem takes ",
  Cell[BoxData[
      \(TraditionalForm\`O(nm)\)]],
  " steps where n is the length of the text and m is the length of the \
pattern. There are numerous algorithms that tackle the string searching \
problem and result in running times of ",
  Cell[BoxData[
      \(TraditionalForm\`O(n + m)\)]],
  " or better, at least on average.\nOne of these algorithms due to Knuth, \
Morris and Pratt can be described nicely in terms  of finite state machines \
and is axplained below. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[" The Morris-Pratt Algorithm", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:34"],

Cell[TextData[{
  "A simplified version of the string searching problem is to determine \
whether some prefix of the text t belongs to the language\n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ \(\[CapitalSigma]\^*\)\ w\)]],
  "\nwhere w is the pattern. There are many ways to generate a \
nondeterministic finite state machine for all words ending in a fixed suffix \
",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ". For example, we can tinker with the BEFA for ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ":"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
w  = ababbaab
m0 = BuildBEFA[w]
PrependTo[ m0[[2]], {1,1,1} ];
PrependTo[ m0[[2]], {1,2,1} ];
m0 = ToFA[ m0, {a,b} ]
LanguageFA[m0,-10] // ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Minimizing this machine does not cause exponential blow-up, in fact the \
minimal automaton has the same size as ",
  StyleBox["m0.", "SmallText"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["m1 = MinimizeFA[m0]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Why?  We can construe the |w|+1 states of the FA as the prefixes of w. \
Thus, the states of the deterministic simulation machine are sets of \
prefixes. To see which sets occur let us construct the power set machine with \
option ",
  StyleBox["Normalize->2",
    FontFamily->"Courier"],
  ". First, we have to insert the structured state set into m0. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
P  = WordPrefixes[w];
P0 = Drop[P,1];
m0 = ReplacePart[ m0, P, -1 ];
mm = ToDFA[ m0, Normalize->2 ]
mm // States // ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
We can now trace a computation of mm on some input to see how the \
machine works.  The right coumn in the table below is the sequence of input \
symbols and the left column shows the corresponding sequence of states (each \
pair should be read as (current state,next input)).\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["AcceptQFA[mm,w,DoTrace->True] // MatrixForm", "Input",
  AspectRatioFixed->True],

Cell["Here is a better example. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
u = Concatenate[ aabbababba,w]
AcceptQFA[mm,u,DoTrace->True] // MatrixForm\
\>", "Input",
  AspectRatioFixed->True],

Cell["PlotComputationFA[mm,u];", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "With a little meditation one can see that these sets ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " consist of maximal suffixes of the input that are prefixes of ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ". More precisely, they all have the form\n",
  StyleBox["\t",
    FontFamily->"Courier"],
  Cell[BoxData[
      \(TraditionalForm\`S = {\ \ \(f\^i\)(p)\ \  | \ i = 0, \[Ellipsis], 
          s}\)]],
  StyleBox[".",
    FontFamily->"Courier"],
  "\nHere ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is the longest word in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " and the failure function ",
  Cell[BoxData[
      \(TraditionalForm\`f\  : \ \(\(P\ \[LongRightArrow]\ P\)\(\ \)\)\)]],
  "is defined as follows: \n\t",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Epsilon])\ \  = \ \ \[Epsilon]\)]],
  ",\n\t",
  Cell[BoxData[
      \(TraditionalForm\`f(
          x)\ \  = \ \ longest\ proper\ suffix\ u\ of\ x\ such\ that\ u\  \
\[Element] \ P\)]],
  "\t\t\t\nIt is straightforward to compute this failure function. Note, \
though, that the definition of fail given below hinges on the fact that the \
command ",
  StyleBox["Suffixes", "SmallText"],
  " orders its output in increasing length. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[assign,fail];
assign[x_] :=
\tScan[ If[ MemberQ[P,#], fail[x]=#]&, Drop[ WordSuffixes[x],-1] ];
Scan[ assign, P ];
fail[Eps|\"Eps\"] = \"Eps\";
Information[fail]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We need to iterate ",
  StyleBox["fail", "SmallText"],
  ". The following function traces repeated application of ",
  StyleBox["fail",
    FontFamily->"Courier"],
  ". Applying it to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P\)\(\ \)\)\)]],
  " we obtain the set of states of the power set machine."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
iterfail[x_] := 
\tReverse[ Drop[ FixedPointList[fail,x], -1 ] ];
Q = iterfail /@ P;
Q // TableForm
Q===States[mm]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can now define the transition function of the minimal automaton in \
terms of the failure function. It is convenient to use the following function \
",
  StyleBox["next",
    FontFamily->"Courier"],
  ":\n\t",
  Cell[BoxData[
      \(TraditionalForm\`next[\(w\_1\) \[Ellipsis]w\_i] = w\_\(i + 1\)\)]],
  "\n(think of ",
  Cell[BoxData[
      \(TraditionalForm\`next[w]\)]],
  " as some symbol not in ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ")."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[next,delta];
next[p_] := next[p] = 
If[ WordLength[p]==WordLength[w],
\t-1,
\t{a,b}[[ ToIndex[w][[WordLength[p]+1]] ]]
];
delta[ p_, s_ ] := delta[ p, s ] =
\t\tIf[ s===next[p],
\t\t\tConcatenate[p,s],
\t\t(*else*)
\t\t\tIf[ p===\"Eps\", \"Eps\", delta[fail[p],s] ]
\t\t];\
\>", "Input",
  AspectRatioFixed->True],

Cell["next /@ P", "Input",
  AspectRatioFixed->True],

Cell["\<\
Applying this function to all state-symbol combinations we obtain \
the transition matrix of the deterministic machine. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
grid = CartesianProduct[ P, {a,b} ];
B  = Partition[ Map[ delta[#[[1]],#[[2]]]&, grid ], 2 ]
BB = B /. RenumberRules[P];
mm = DFA[ 9, 2,Transpose[BB],1,{9}, {}, {} ]\
\>", "Input",
  AspectRatioFixed->True],

Cell["IsomorphicQDFA[mm,m1]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[" Knuth's Improvement", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:35"],

Cell[TextData[{
  "Note that for applications of the string matching algorithm the crucial \
point is to implement the finite state machine rapidly.  There is no need to \
actually construct the minimal automaton (i.e., compute the transition table \
as we have just done), it is enough to be able to compute the next state on \
the fly using the ",
  StyleBox["fail",
    FontFamily->"Courier"],
  " function. Note that the table size of the full transition function is ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(w\)\(|\)\(+1\))\) | \[CapitalSigma] | \
\)]],
  ", whereas the table for the failure function only has size ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\(+1\)\)\)]],
  ". \nAn improved version of the algorithm that speeds up this computation \
is due to Knuth. It uses a slightly modified failure function defined as \
follows: \n\t\n\t",
  Cell[BoxData[
      \(TraditionalForm\`newfail[p]\  = \ 
        longest\ proper\ suffix\ q\ of\ p\ in\ P\ such\ that\ \ next[
              p]\  \[NotEqual] \ next[q]\)]],
  ".\n\nIf no such q exists set ",
  Cell[BoxData[
      \(TraditionalForm\`newfail[p]\  = \ \[Epsilon]\)]],
  "  (reset to initial state). We compare the two failure functions.\n        \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
newfail[\"Eps\"] = \"Eps\";
newfail[p_] := newfail[p] =
\t\tIf[ next[p]===next[ fail[p] ],
\t\t\tnewfail[ fail[p] ],
\t\t\tfail[p]
\t\t];
{ Range[0,8], P, fail /@ P, newfail /@ P } // Thread // TableForm\
\>", \
"Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the modified failure function resets immediately from state 7 \
under input a to state 0. The old function would first go to state 1, find \
another missmatch there and then reset to 0 in the second step. \nBoth \
failure functions can be computed efficently (in a suitable programming \
language like C) in ",
  Cell[BoxData[
      \(TraditionalForm\`O(m)\)]],
  " steps. Note, though, that there are some subtle problems in getting a \
correct implementation, see e.g. [Stephen92]."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["  Locally Testable Languages", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:36"],

Cell[TextData[{
  "A language L is ",
  StyleBox["locally testable",
    FontSlant->"Italic"],
  " if it is a finite boolean combination of languages of the form  \n\t",
  Cell[BoxData[
      \(TraditionalForm\`F\ \(\[CapitalSigma]\^*\), \ \(\[CapitalSigma]\^*\) 
        F\)]],
  "  or  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^*\)\ \
F\ \ \[CapitalSigma]\^\(\(*\)\(\ \)\)\)]],
  "\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " is finite. Thus, every locally testable language is star-free (but not \
conversely, the language  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((ab + ba)\)\^*\)\)]],
  " from above is a counterexample). The most typical example for a locally \
testable languages are finite complement languages: languages of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\^\(\(*\)\(\ \)\) - \ \(\
\[CapitalSigma]\^*\)\ F\ \ \[CapitalSigma]\^\(\(*\)\(\ \)\)\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " is finite. Thus, a word belongs to a finite complement language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " iff it contains no factor in ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ", the set of forbidden factors. \nClearly one can construct a FSM for a \
locally testable language using the commands ",
  StyleBox["PrefixFA",
    FontFamily->"Courier"],
  ", ",
  StyleBox["SuffixFA",
    FontFamily->"Courier"],
  " and ",
  StyleBox["InfixFA",
    FontFamily->"Courier"],
  " as well as the boolean operations. A more interesting method is described \
in the next section. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Let us consider \n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ \(all\ strings\ over\ K\  = \ {0, 
              1}\ \ containing\ \ neither\ \ 000\ \ nor\ \ 111\ \ but\ \ 00\)\
\)]],
  ".\nThus\n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ \((\ \(\[CapitalSigma]\^*\)\ \  - \ \ \(\
\[CapitalSigma]\^*\) {000, 
                  111}\ \(\[CapitalSigma]\^*\)\ )\)\ \  \[Intersection] \ \ \
\(\[CapitalSigma]\^*\) 00\ \[CapitalSigma]\^\(\(*\)\(\ \)\)\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = InfixFA[\"000\",-2] ~UnionFA~ InfixFA[\"111\",-2] // \
ComplementFA;
m  = InfixFA[\"00\",-2] ~IntersectionFA~ m1  // MinimizeFA;
LanguageFA[m,-6]//ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
S = SyntacticSG[m];
S // Length
AperiodicQSG[S]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is locally testable iff  for some number ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)]],
  ",  membership of a word ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  "  is determined completely by the prefix and suffix of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " of length ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  " and all its infixes of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". Hence one can test membership by sliding a window of width ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " accross the input string and remembering only all the blocks of length \
(at most) w that occur during the scan of the string (without remembering the \
order in which the blocks occur). \nOne can show that the syntatctic \
semigroups (see Guide5) of such languages are characterized by two \
properties:\n- local idempotence (for all idempotents ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`e\ S\ e\)]],
  " is idempotent), and \n- local commutativity (for all idempotents ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`e\ S\ e\)]],
  " is commutative). \nWe verify these properties for the last language:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["idem = IdemSG[S]", "Input",
  AspectRatioFixed->True],

Cell["e = idem[[-1]]", "Input",
  AspectRatioFixed->True],

Cell["eSe = Union[ e**ToList[S]**e ]", "Input",
  AspectRatioFixed->True],

Cell["eSe ** eSe === eSe", "Input",
  AspectRatioFixed->True],

Cell["\<\
In general we can test local idempotence and commutativity with the \
following commands:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
LocallyIdemQSG[S]
LocallyCommQSG[S]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  n-Local Universal Automata", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Local universal", "c:37"}],

Cell[TextData[{
  "The ",
  StyleBox["n-local universal automaton",
    FontSlant->"Italic"],
  " over alphabet  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\)]],
  "  has states tuples  ",
  Cell[BoxData[
      \(TraditionalForm\`\((a\_1, \[Ellipsis], 
          a\_n)\)\  \[Element] \ \[CapitalSigma]\^n\)]],
  "  and transitions\n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\((a\_1, \[Ellipsis], a\_n)\)\[CenterDot]\ 
          b\  = \ \((a\_2, \[Ellipsis], a\_\(n - 1\), b)\)\)]],
  ".\n\nThus, the machine remembers the last ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " symbols of the input string. One may think of these machines as sliding a \
window of length ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " across the input word. At every position the visible string is checked \
against some list of permissible patterns. A word is accepted if it passes \
all these local tests. \nOn the other hand, one can think of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-local universal automaton as a labeled de Bruijn graph over the alphabet  \
\[CapitalSigma]. De Bruijn graphs (or rather, their edge-lists) can be \
generated by the command ",
  StyleBox["DeBruijnEdges",
    FontFamily->"Courier"],
  ". Option ",
  StyleBox["Normalize",
    FontFamily->"Courier"],
  " has default ",
  StyleBox["False",
    FontFamily->"Courier"],
  ", which causes the vertex structure to be preserved. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["DeBruijnEdges[3,2] // ColumnForm", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Locally testable languages are closely related to local universal \
machines: by tracing a computation of an input word on such a machine we can \
solve the recognition problem for the language.  For an algebraic \
characterization in terms of the corresponding variety of syntactic \
semigroups see the previous section. \n\nThe command ",
  StyleBox["LocalUniversalFA[n,K]",
    FontFamily->"Courier"],
  " constructs a n-local universal machine over alphabet K. It has options  \
",
  StyleBox["IniLU",
    FontFamily->"Courier"],
  ",  ",
  StyleBox["FinLU",
    FontFamily->"Courier"],
  "  and ",
  StyleBox["EdgeLU ",
    FontFamily->"Courier"],
  "that determine the initial and final states and the permissible \
transitions. You can replace ",
  StyleBox["EdgeLU",
    FontFamily->"Courier"],
  ", ",
  StyleBox["IniLU",
    FontFamily->"Courier"],
  " and ",
  StyleBox["FinLU",
    FontFamily->"Courier"],
  " by functions on words of length ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", respectively that return a Boolean result."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["LocalUniversalFA // Options // TableForm", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:38"],

Cell[TextData[{
  "As an example, we construct an automaton based on a 3-local universal \
machine that accepts: \n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ \(all\ strings\ over\ \[CapitalSigma]\  = \ \
{a, b}\ \ containing\ neither\ \ aaa\ \ nor\ \ bbb\)\)]],
  ".\nSince  ",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ \(\[CapitalSigma]\^*\)\ \  - \ \ \(\(\
\[CapitalSigma]\^*\)\(\ \)\({aaa, bbb}\) \(\[CapitalSigma]\^*\)\(\ \)\)\)]],
  " ,  this language must be locally testable. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
infix = (#=!=\"aaa\" && #=!=\"bbb\")&;
m = LocalUniversalFA[ 2, {a,b}, EdgeLU\[Rule]infix, Normalize\[Rule]1 ];
PrintFA[m,LongForm\[Rule]True]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Machine ",
  StyleBox["m", "SmallText"],
  " is deterministic but not complete:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["DegreesFA[m] // TableForm", "Input",
  AspectRatioFixed->True],

Cell["m1 = MinimizeFA[m]", "Input",
  AspectRatioFixed->True],

Cell["\<\
L = LanguageFA[ m1, -5 ];
L // ColumnForm\
\>", "Input",
  AspectRatioFixed->True],

Cell["Complement[ Words[4], L[[5]] ]", "Input",
  AspectRatioFixed->True],

Cell["\<\
The syntactic homorphism shows that 'aaa' and 'bbb' lead to the \
null element in the syntactic semigroup. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(?SyntacticHomomorphism\)\)], "Input"],

Cell[BoxData[
    \(m1\)], "Input"],

Cell["SyntacticHomomorphism[f,m1]", "Input",
  AspectRatioFixed->True],

Cell["f[a]^Range[0,3] // TableForm", "Input",
  AspectRatioFixed->True],

Cell["f[b]^Range[0,3] // TableForm", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We compute the syntactic semigroup ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and verify that ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is aperiodic. Since ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is locally testable, ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " must be locally idempotent and locally commutative. We verify these \
properties using simple test routines defined above. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["S = SyntacticSG[m1]", "Input",
  AspectRatioFixed->True],

Cell["\<\
S contains 11 idempotents and is duly locally idempotent, locally \
commutative and aperiodic:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
IdemSG[S] // Length
LocallyIdemQSG[S]
LocallyCommQSG[S]
AperiodicQSG[S]\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:39"],

Cell[TextData[{
  "Here is a slightly more complicated example. Consider the language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of all strings over ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1}\)]],
  " \n\t- containing no block of length 5 with more than three 1's, and\n\t- \
containing a block 111. \nAgain, ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is locally testable. We first build a 4-local universal automaton that \
checks blocks of length 5. To test for the existence of a block '111' we make \
a second copy of the machine and perform a little surgery. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
goodblock = (Plus@@(ToExpression/@ToCharacters[#])<4)&;
m0 = LocalUniversalFA[ 4, -2, 
\tEdgeLU->goodblock, Normalize->1 ];
PrintFA[m0,Full->True,TransOnly->True]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Now for the surgery:\n\[Bullet]  Let ",
  Cell[BoxData[
      \(TraditionalForm\`m\_1\)]],
  " be the disjoint sum of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)]],
  " with itself, say, with states of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{i, p}\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is a state in ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)]],
  ". \n\[Bullet] Add a transition  ",
  Cell[BoxData[
      \(TraditionalForm\`\((\ {1, 0011}, \ 1, \ {2, 0111}\ )\)\)]],
  ".  Make sure you understand why no other transitions are needed. \n\
\[Bullet] Lastly, set the initial state to ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 0000}\)]],
  " and select as final states all states of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{2, _}\)]],
  ". \n"
}], "Text"],

Cell["m1 = SumFA[ m0, m0, Normalize->1 ]", "Input",
  AspectRatioFixed->True],

Cell["\<\
Q = States[m1];
s0 = Position[Q,{1,\"0000\"}][[1,1]]
s1 = Position[Q,{1,\"0011\"}][[1,1]]
t  = Position[Q,{2,\"0111\"}][[1,1]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["m2 = AddTransitionFA[ m1, s1, 2, t ]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(PositionList[Q, Cases[Q, {2, _}]]\)], "Input"],

Cell["m = SetInitialFinalFA[ m2, {s0}, % ]", "Input",
  AspectRatioFixed->True],

Cell["We minimize the automataton and check that it works:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
mm = MinimizeFA[m];
mm // Size
L = LanguageFA[ mm, 10 ];
L // Length
L\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
The syntactic semigroup has size 173 and has all the right \
properties (local commutativity will take a few minutes to verify, since \
there are lots of idempotents and the algorithm used is rather \
primitive).\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
S = SyntacticSG[mm];
S // Length
IdemSG[S] // Length
AperiodicQSG[S]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
LocallyIdemQSG[S]
LocallyCommQSG[S]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Of course, we could also build a suitable automaton using some \
standard constructors and boolean operations. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["mgood  = InfixFA[\"111\",-2] // MinimizeFA", "Input",
  AspectRatioFixed->True],

Cell["\<\
weight[w_] := Plus@@(ToIndex[w,{0,1}]-1)
W = Select[ Words[5,-2], (weight[#]>3)& ]
mbad = ConcatenateFA[AllDFA[-2],BuildDFA[W,-2],AllDFA[-2]] // MinimizeFA // \
ComplementFA\
\>", "Input",
  AspectRatioFixed->True],

Cell["mmm = IntersectionFA[mgood,mbad]  // MinimizeFA", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(IsomorphicQDFA[mm, mmm]\)], "Input"],

Cell[TextData[{
  "Trouble! Something went wrong: machines ",
  StyleBox["mm", "SmallText"],
  " and ",
  StyleBox["mmm", "SmallText"],
  " should be isomorphic. Let's take a look at the languages to see which \
machine is correct (if any)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
L1 = LanguageFA[mm,-10] // Flatten;
L1 // Length
L2 = LanguageFA[mmm,-10] // Flatten; 
L2 // Length\
\>", "Input",
  AspectRatioFixed->True],

Cell["It seems that the languages differ in only one word. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Complement[ L2, L1 ]", "Input",
  AspectRatioFixed->True],

Cell["\<\
We forgot word 1111 in the first machine! Let's add it on \
now.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["mmnew = UnionFA[ mm, BuildDFA[\"1111\",-2] ] // MinimizeFA", "Input",
  AspectRatioFixed->True],

Cell["Now the machines should be isomorphic:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["IsomorphicQDFA[mmnew,mmm]", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["  Ideals and their Bases", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:40"],

Cell[TextData[{
  "A language ",
  Cell[BoxData[
      \(TraditionalForm\`L\  \[SubsetEqual] \ \(\[CapitalSigma]\^*\)\)]],
  " is an ",
  StyleBox["ideal",
    FontColor->RGBColor[0, 0, 1]],
  " if   ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^*\) 
          L\ \ \(\[CapitalSigma]\^*\) \[SubsetEqual] L\)]],
  ".  If ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is given by a finite state machine we can easily test whether ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is an ideal (see the sections on closure properties and decision \
algorithms). "
}], "Text"],

Cell[BoxData[{
    \(\(m = 
        DFA[11, 2, {{2, 4, 5, 4, 4, 5, 9, 10, 9, 11, 4}, {3, 3, 3, 6, 7, 8, 
              3, 3, 9, 7, 9}}, 1, {9}];\)\), "\n", 
    \(\(all\  = \ AllDFA[2];\)\), "\n", 
    \(id\  = \ ConcatenateFA[all, m, all]\), "\n", 
    \(SubsetQFA[\ id, \ m]\)}], "Input"],

Cell[TextData[{
  "More interesting is the question of identifying a ",
  StyleBox["base",
    FontColor->RGBColor[0, 0, 1]],
  " for the ideal.  By base we mean a subset ",
  Cell[BoxData[
      \(TraditionalForm\`L\_0 \[SubsetEqual] \ L\)]],
  "  such that  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^*\) 
          L\_0\ \ \(\[CapitalSigma]\^*\) = L\)]],
  "  but no word in ",
  Cell[BoxData[
      \(TraditionalForm\`L\_0\)]],
  " is a factor of any other words in ",
  Cell[BoxData[
      \(TraditionalForm\`L\_0\)]],
  ".  Note that a base always exists and is uniquely determined by ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". Moreover, the base is regular whenever ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is. \n\nHere is an attempt to construct the base by hand. "
}], "Text"],

Cell[BoxData[
    \(LanguageFA[m, \(-6\)]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Perhaps  ",
  Cell[BoxData[
      \(TraditionalForm\`L\_0 = \ {baba}\)]],
  " will do."
}], "Text"],

Cell[BoxData[
    \(m1\  = \ 
      ComplementFA[m, InfixFA[\ baba, 2]]\  // \ MinimizeFA\)], "Input"],

Cell["Unfortunately, not. We need to add another word.", "Text"],

Cell[BoxData[
    \(LanguageFA[m1, \(-8\)]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Try  ",
  Cell[BoxData[
      \(TraditionalForm\`L\_0 = \ {baba, aabbaab}\)]],
  " ."
}], "Text"],

Cell[BoxData[
    \(m2\  = \ 
      ComplementFA[m1, InfixFA[\ aabbaab, 2]]\  // \ MinimizeFA\)], "Input"],

Cell["\<\
This time we have a complete base. Note, though, that in general \
the base may well fail to be finite, and the process of adding yet another \
word will go on indefinitely.  The language accepted by following machine \
(which is almost identical to our first example) is an ideal, but its base is \
infinite. \
\>", "Text"],

Cell[BoxData[{
    \(\(m\  = \ 
        DFA[11, 2, {{2, 4, 5, 4, 4, 5, 9, 10, 9, 11, 4}, {3, 3, 3, 6, 7, 8, 
              6, 6, 9, 7, 9}}, 1, {9}];\)\), "\n", 
    \(TestIdealFA[m]\)}], "Input"],

Cell["\<\
Nonetheless, we can construct a machine for it directly, without \
going to our approximation process.\
\>", "Text"],

Cell[BoxData[
    \(mm = IdealBaseFA[m]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We verify that the machine produced by ",
  StyleBox["IdealBaseFA", "SmallText"],
  " works as advertised."
}], "Text"],

Cell[BoxData[
    \(mmm\  = \ 
      MinimizeFA@ConcatenateFA[\ AllDFA[2], \ mm, \ AllDFA[2]\ ]\)], "Input"],

Cell[BoxData[
    \(IsomorphicQDFA[mmm, m]\)], "Input"],

Cell[BoxData[
    \(m === mmm\)], "Input"],

Cell[CellGroupData[{

Cell["Width 4 binary", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:41"],

Cell[BoxData[
    \(code = Random[Integer, 2\^15]\)], "Input"],

Cell[BoxData[
    \(CA[code, 4, \(-2\)]\  // \ PrintCA\)], "Input"],

Cell[BoxData[{
    \(\(n = ToFA[CA[code, 4, \(-2\)]];\)\), "\n", 
    \(\(m = MinimizeFA[n];\)\), "\n", 
    \(scc = StronglyConnectedComponents[ToGraphFA[m]]\)}], "Input"],

Cell["\<\
The following only works if the component corresponding to the \
minimal Fischer automaton is also the largest one. \
\>", "Text"],

Cell["pos = PositionOne[ Length/@scc, Max[Length/@scc] ]", "Input"],

Cell[BoxData[{
    \(mm = 
      ToSA@SelectFA[m, 
          scc\[LeftDoubleBracket]pos\[RightDoubleBracket]]\), "\n", 
    \(mm = MinimizeFA[mm]\)}], "Input"],

Cell[BoxData[
    \(IsomorphicQDFA[mm, m]\)], "Input"],

Cell[BoxData[{
    \(cnt = 
      LanguageFA[m, \(-20\), 
        SizeOnly \[Rule] True]\), "\[IndentingNewLine]", 
    \(2^Range[0, 20]\  - \ cnt\)}], "Input"],

Cell[BoxData[{
    \(LanguageFA[ComplementFA[m], 5]\), "\[IndentingNewLine]", 
    \(LanguageFA[ComplementFA[m], 6]\)}], "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{874, 992},
WindowMargins->{{Automatic, 91}, {Automatic, 0}},
PrintingStartingPageNumber->16,
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
CellLabelAutoDelete->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->Automatic,
Magnification->1.5,
StyleDefinitions -> "Demo.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1762, 52, 150, 4, 88, "Title",
      Evaluatable->False,
      CellTags->"c:1"]},
  "c:2"->{
    Cell[1937, 60, 113, 3, 124, "Section",
      Evaluatable->False,
      CellTags->"c:2"]},
  "Acceptance"->{
    Cell[2075, 67, 160, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->{"Acceptance", "c:3"}]},
  "c:3"->{
    Cell[2075, 67, 160, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->{"Acceptance", "c:3"}]},
  "LanguageFA"->{
    Cell[10426, 338, 148, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->{"LanguageFA", "c:4"}]},
  "c:4"->{
    Cell[10426, 338, 148, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->{"LanguageFA", "c:4"}]},
  "c:5"->{
    Cell[13839, 434, 161, 5, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:5"]},
  "c:6"->{
    Cell[18908, 613, 153, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:6"]},
  "Multiplicity"->{
    Cell[23812, 783, 152, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->{"Multiplicity", "c:7"}]},
  "c:7"->{
    Cell[23812, 783, 152, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->{"Multiplicity", "c:7"}]},
  "c:8"->{
    Cell[32726, 1122, 116, 3, 75, "Section",
      Evaluatable->False,
      CellTags->"c:8"]},
  "c:9"->{
    Cell[32867, 1129, 133, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:9"]},
  "c:10"->{
    Cell[34446, 1180, 132, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:10"]},
  "Boolean Operations"->{
    Cell[37777, 1280, 134, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Boolean Operations", "c:11"}]},
  "c:11"->{
    Cell[37777, 1280, 134, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Boolean Operations", "c:11"}]},
  "Concatenation Star"->{
    Cell[42702, 1461, 145, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Concatenation Star", "c:12"}]},
  "c:12"->{
    Cell[42702, 1461, 145, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Concatenation Star", "c:12"}]},
  "Shuffle"->{
    Cell[44690, 1539, 120, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Shuffle", "c:13"}]},
  "c:13"->{
    Cell[44690, 1539, 120, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Shuffle", "c:13"}]},
  "c:14"->{
    Cell[49197, 1709, 108, 3, 75, "Section",
      Evaluatable->False,
      CellTags->"c:14"]},
  "Conversion"->{
    Cell[50255, 1741, 126, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Conversion", "c:15"}],
    Cell[54550, 1905, 132, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Conversion", "c:17"}]},
  "c:15"->{
    Cell[50255, 1741, 126, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Conversion", "c:15"}]},
  "Epsilon Elimination"->{
    Cell[51220, 1790, 136, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Epsilon Elimination", "c:16"}]},
  "c:16"->{
    Cell[51220, 1790, 136, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Epsilon Elimination", "c:16"}]},
  "c:17"->{
    Cell[54550, 1905, 132, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Conversion", "c:17"}]},
  "c:18"->{
    Cell[57982, 2024, 96, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:18"]},
  "Graphs"->{
    Cell[58731, 2054, 121, 3, 75, "Section",
      Evaluatable->False,
      CellTags->{"Graphs", "c:19"}]},
  "c:19"->{
    Cell[58731, 2054, 121, 3, 75, "Section",
      Evaluatable->False,
      CellTags->{"Graphs", "c:19"}]},
  "c:20"->{
    Cell[59520, 2076, 122, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:20"]},
  "c:21"->{
    Cell[60948, 2125, 117, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:21"]},
  "c:22"->{
    Cell[64347, 2253, 107, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:22"]},
  "c:23"->{
    Cell[69847, 2427, 108, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:23"]},
  "c:24"->{
    Cell[72613, 2519, 104, 3, 75, "Section",
      Evaluatable->False,
      CellTags->"c:24"]},
  "Sample machines"->{
    Cell[77586, 2701, 128, 3, 75, "Section",
      Evaluatable->False,
      CellTags->{"Sample machines", "c:25"}]},
  "c:25"->{
    Cell[77586, 2701, 128, 3, 75, "Section",
      Evaluatable->False,
      CellTags->{"Sample machines", "c:25"}]},
  "c:26"->{
    Cell[77739, 2708, 104, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:26"]},
  "c:27"->{
    Cell[79635, 2781, 112, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:27"]},
  "41-minimal DFAs"->{
    Cell[81180, 2833, 126, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->{"41-minimal DFAs", "c:28"}]},
  "c:28"->{
    Cell[81180, 2833, 126, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->{"41-minimal DFAs", "c:28"}]},
  "c:29"->{
    Cell[82927, 2903, 105, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:29"]},
  "c:30"->{
    Cell[85641, 2997, 105, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:30"]},
  "c:31"->{
    Cell[88158, 3083, 116, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:31"]},
  "c:32"->{
    Cell[92043, 3226, 99, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:32"]},
  "c:33"->{
    Cell[93483, 3287, 130, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:33"]},
  "c:34"->{
    Cell[94472, 3313, 120, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:34"]},
  "c:35"->{
    Cell[100581, 3537, 113, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:35"]},
  "c:36"->{
    Cell[102887, 3603, 118, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:36"]},
  "Local universal"->{
    Cell[107566, 3762, 139, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Local universal", "c:37"}]},
  "c:37"->{
    Cell[107566, 3762, 139, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->{"Local universal", "c:37"}]},
  "c:38"->{
    Cell[110674, 3860, 102, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:38"]},
  "c:39"->{
    Cell[113480, 3975, 102, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:39"]},
  "c:40"->{
    Cell[118378, 4165, 114, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:40"]},
  "c:41"->{
    Cell[122038, 4298, 107, 3, 66, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:41"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 124180, 4371},
  {"c:2", 124282, 4375},
  {"Acceptance", 124394, 4379},
  {"c:3", 124517, 4383},
  {"LanguageFA", 124647, 4387},
  {"c:4", 124772, 4391},
  {"c:5", 124897, 4395},
  {"c:6", 125006, 4399},
  {"Multiplicity", 125124, 4403},
  {"c:7", 125251, 4407},
  {"c:8", 125378, 4411},
  {"c:9", 125485, 4415},
  {"c:10", 125596, 4419},
  {"Boolean Operations", 125722, 4423},
  {"c:11", 125858, 4427},
  {"Concatenation Star", 126008, 4431},
  {"c:12", 126144, 4435},
  {"Shuffle", 126283, 4439},
  {"c:13", 126408, 4443},
  {"c:14", 126533, 4447},
  {"Conversion", 126648, 4451},
  {"c:15", 126891, 4458},
  {"Epsilon Elimination", 127034, 4462},
  {"c:16", 127171, 4466},
  {"c:17", 127308, 4470},
  {"c:18", 127436, 4474},
  {"Graphs", 127549, 4478},
  {"c:19", 127670, 4482},
  {"c:20", 127791, 4486},
  {"c:21", 127903, 4490},
  {"c:22", 128015, 4494},
  {"c:23", 128127, 4498},
  {"c:24", 128239, 4502},
  {"Sample machines", 128359, 4506},
  {"c:25", 128489, 4510},
  {"c:26", 128619, 4514},
  {"c:27", 128731, 4518},
  {"41-minimal DFAs", 128854, 4522},
  {"c:28", 128990, 4526},
  {"c:29", 129126, 4530},
  {"c:30", 129241, 4534},
  {"c:31", 129356, 4538},
  {"c:32", 129468, 4542},
  {"c:33", 129579, 4546},
  {"c:34", 129691, 4550},
  {"c:35", 129806, 4554},
  {"c:36", 129922, 4558},
  {"Local universal", 130046, 4562},
  {"c:37", 130180, 4566},
  {"c:38", 130314, 4570},
  {"c:39", 130430, 4574},
  {"c:40", 130546, 4578},
  {"c:41", 130659, 4582}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 54, 0, 40, "SmallText"],
Cell[1762, 52, 150, 4, 88, "Title",
  Evaluatable->False,
  CellTags->"c:1"],

Cell[CellGroupData[{
Cell[1937, 60, 113, 3, 124, "Section",
  Evaluatable->False,
  CellTags->"c:2"],

Cell[CellGroupData[{
Cell[2075, 67, 160, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->{"Acceptance", "c:3"}],
Cell[2238, 73, 1535, 38, 298, "Text",
  Evaluatable->False],
Cell[3776, 113, 88, 2, 45, "Input"],
Cell[3867, 117, 70, 2, 45, "Input"],
Cell[3940, 121, 172, 6, 44, "Text",
  Evaluatable->False],
Cell[4115, 129, 121, 3, 68, "Input"],
Cell[4239, 134, 168, 5, 41, "Text",
  Evaluatable->False],
Cell[4410, 141, 84, 2, 45, "Input"],
Cell[4497, 145, 120, 2, 41, "Text",
  Evaluatable->False],
Cell[4620, 149, 102, 2, 45, "Input"],
Cell[4725, 153, 342, 10, 63, "Text",
  Evaluatable->False],
Cell[5070, 165, 457, 16, 63, "Text",
  Evaluatable->False],
Cell[5530, 183, 131, 3, 68, "Input"],
Cell[5664, 188, 173, 6, 44, "Text",
  Evaluatable->False],
Cell[5840, 196, 123, 3, 68, "Input"],
Cell[5966, 201, 332, 9, 79, "Text",
  Evaluatable->False],
Cell[6301, 212, 116, 2, 45, "Input"],
Cell[6420, 216, 203, 7, 41, "Text",
  Evaluatable->False],
Cell[6626, 225, 100, 2, 45, "Input"],
Cell[6729, 229, 933, 23, 217, "Text",
  Evaluatable->False],
Cell[7665, 254, 59, 1, 45, "Input"],
Cell[7727, 257, 138, 2, 68, "Input"],
Cell[7868, 261, 103, 2, 41, "Text",
  Evaluatable->False],
Cell[7974, 265, 715, 19, 117, "Text",
  Evaluatable->False],
Cell[8692, 286, 86, 1, 45, "Input"],
Cell[8781, 289, 231, 5, 114, "Input"],
Cell[9015, 296, 784, 19, 117, "Text",
  Evaluatable->False],
Cell[9802, 317, 87, 1, 45, "Input"],
Cell[9892, 320, 210, 4, 68, "Input"],
Cell[10105, 326, 108, 2, 41, "Text",
  Evaluatable->False],
Cell[10216, 330, 173, 3, 68, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10426, 338, 148, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->{"LanguageFA", "c:4"}],
Cell[10577, 344, 1743, 43, 425, "Text",
  Evaluatable->False],
Cell[12323, 389, 1052, 27, 219, "Text",
  Evaluatable->False],
Cell[13378, 418, 94, 2, 45, "Input"],
Cell[13475, 422, 327, 7, 137, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13839, 434, 161, 5, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:5"],
Cell[14003, 441, 1197, 33, 253, "Text",
  Evaluatable->False],
Cell[15203, 476, 542, 16, 104, "Text",
  Evaluatable->False],
Cell[15748, 494, 1171, 39, 182, "Text",
  Evaluatable->False],
Cell[16922, 535, 130, 3, 45, "Input"],
Cell[17055, 540, 354, 11, 72, "Text",
  Evaluatable->False],
Cell[17412, 553, 193, 4, 91, "Input"],
Cell[17608, 559, 213, 7, 41, "Text",
  Evaluatable->False],
Cell[17824, 568, 84, 2, 45, "Input"],
Cell[17911, 572, 244, 8, 60, "Text",
  Evaluatable->False],
Cell[18158, 582, 119, 2, 68, "Input"],
Cell[18280, 586, 118, 2, 41, "Text",
  Evaluatable->False],
Cell[18401, 590, 81, 2, 45, "Input"],
Cell[18485, 594, 97, 2, 41, "Text",
  Evaluatable->False],
Cell[18585, 598, 123, 2, 68, "Input"],
Cell[18711, 602, 76, 2, 45, "Input"],
Cell[18790, 606, 81, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18908, 613, 153, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:6"],
Cell[19064, 619, 1594, 45, 245, "Text",
  Evaluatable->False],
Cell[20661, 666, 931, 30, 145, "Text",
  Evaluatable->False],
Cell[21595, 698, 144, 2, 68, "Input"],
Cell[21742, 702, 78, 2, 45, "Input"],
Cell[21823, 706, 219, 9, 44, "Text",
  Evaluatable->False],
Cell[22045, 717, 119, 3, 68, "Input"],
Cell[22167, 722, 332, 13, 60, "Text",
  Evaluatable->False],
Cell[22502, 737, 240, 5, 114, "Input"],
Cell[22745, 744, 474, 12, 79, "Text",
  Evaluatable->False],
Cell[23222, 758, 111, 2, 68, "Input"],
Cell[23336, 762, 88, 1, 45, "Input"],
Cell[23427, 765, 142, 5, 41, "Text",
  Evaluatable->False],
Cell[23572, 772, 123, 2, 45, "Input"],
Cell[23698, 776, 77, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23812, 783, 152, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->{"Multiplicity", "c:7"}],
Cell[23967, 789, 811, 27, 143, "Text",
  Evaluatable->False],
Cell[24781, 818, 446, 9, 137, "Input"],
Cell[25230, 829, 95, 3, 68, "Input"],
Cell[25328, 834, 368, 8, 98, "Text",
  Evaluatable->False],
Cell[25699, 844, 107, 2, 45, "Input"],
Cell[25809, 848, 769, 22, 98, "Text",
  Evaluatable->False],
Cell[26581, 872, 164, 4, 68, "Input"],
Cell[26748, 878, 95, 2, 45, "Input"],
Cell[26846, 882, 264, 10, 41, "Text",
  Evaluatable->False],
Cell[27113, 894, 69, 2, 45, "Input"],
Cell[27185, 898, 174, 7, 41, "Text",
  Evaluatable->False],
Cell[27362, 907, 73, 2, 45, "Input"],
Cell[27438, 911, 515, 22, 60, "Text",
  Evaluatable->False],
Cell[27956, 935, 326, 7, 114, "Input"],
Cell[28285, 944, 1101, 39, 172, "Text",
  Evaluatable->False],
Cell[29389, 985, 360, 13, 60, "Text",
  Evaluatable->False],
Cell[29752, 1000, 128, 3, 68, "Input"],
Cell[29883, 1005, 93, 2, 45, "Input"],
Cell[29979, 1009, 402, 15, 68, "Text",
  Evaluatable->False],
Cell[30384, 1026, 102, 2, 45, "Input"],
Cell[30489, 1030, 264, 9, 63, "Text",
  Evaluatable->False],
Cell[30756, 1041, 131, 3, 68, "Input"],
Cell[30890, 1046, 199, 7, 41, "Text",
  Evaluatable->False],
Cell[31092, 1055, 92, 2, 45, "Input"],
Cell[31187, 1059, 171, 5, 41, "Text",
  Evaluatable->False],
Cell[31361, 1066, 189, 4, 91, "Input"],
Cell[31553, 1072, 170, 6, 44, "Text",
  Evaluatable->False],
Cell[31726, 1080, 39, 1, 45, "Input"],
Cell[31768, 1083, 176, 4, 91, "Input"],
Cell[31947, 1089, 561, 22, 79, "Text",
  Evaluatable->False],
Cell[32511, 1113, 166, 3, 68, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32726, 1122, 116, 3, 75, "Section",
  Evaluatable->False,
  CellTags->"c:8"],

Cell[CellGroupData[{
Cell[32867, 1129, 133, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:9"],
Cell[33003, 1134, 1069, 22, 236, "Text",
  Evaluatable->False],
Cell[34075, 1158, 72, 1, 44, "Input"],
Cell[34150, 1161, 94, 5, 84, "Input"],
Cell[34247, 1168, 102, 4, 64, "Input"],
Cell[34352, 1174, 57, 1, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[34446, 1180, 132, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:10"],
Cell[34581, 1185, 383, 8, 98, "Text",
  Evaluatable->False],
Cell[34967, 1195, 130, 4, 64, "Input"],
Cell[35100, 1201, 72, 1, 44, "Input"],
Cell[35175, 1204, 980, 28, 215, "Text",
  Evaluatable->False],
Cell[36158, 1234, 99, 4, 64, "Input"],
Cell[36260, 1240, 968, 16, 267, "Text",
  Evaluatable->False],
Cell[37231, 1258, 253, 7, 124, "Input"],
Cell[37487, 1267, 175, 5, 60, "Text",
  Evaluatable->False],
Cell[37665, 1274, 75, 1, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[37777, 1280, 134, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->{"Boolean Operations", "c:11"}],
Cell[37914, 1285, 1107, 24, 255, "Text",
  Evaluatable->False],
Cell[39024, 1311, 142, 6, 104, "Input"],
Cell[39169, 1319, 178, 6, 44, "Text",
  Evaluatable->False],
Cell[39350, 1327, 105, 4, 64, "Input"],
Cell[39458, 1333, 64, 1, 44, "Input"],
Cell[39525, 1336, 451, 14, 79, "Text",
  Evaluatable->False],
Cell[39979, 1352, 73, 1, 44, "Input"],
Cell[40055, 1355, 477, 12, 79, "Text",
  Evaluatable->False],
Cell[40535, 1369, 231, 6, 104, "Input"],
Cell[40769, 1377, 286, 7, 79, "Text",
  Evaluatable->False],
Cell[41058, 1386, 91, 4, 64, "Input"],
Cell[41152, 1392, 215, 7, 41, "Text",
  Evaluatable->False],
Cell[41370, 1401, 74, 1, 44, "Input"],
Cell[41447, 1404, 59, 1, 45, "Input"],
Cell[41509, 1407, 271, 6, 79, "Text",
  Evaluatable->False],
Cell[41783, 1415, 110, 5, 84, "Input"],
Cell[41896, 1422, 164, 6, 72, "Text",
  Evaluatable->False],
Cell[42063, 1430, 66, 1, 44, "Input"],
Cell[42132, 1433, 95, 4, 64, "Input"],
Cell[42230, 1439, 73, 1, 44, "Input"],
Cell[42306, 1442, 61, 1, 45, "Input"],
Cell[42370, 1445, 117, 2, 41, "Text",
  Evaluatable->False],
Cell[42490, 1449, 175, 7, 124, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42702, 1461, 145, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->{"Concatenation Star", "c:12"}],
Cell[42850, 1466, 202, 6, 41, "Text",
  Evaluatable->False],
Cell[43055, 1474, 179, 6, 104, "Input"],
Cell[43237, 1482, 375, 11, 79, "Text",
  Evaluatable->False],
Cell[43615, 1495, 96, 1, 44, "Input"],
Cell[43714, 1498, 74, 1, 44, "Input"],
Cell[43791, 1501, 94, 2, 41, "Text",
  Evaluatable->False],
Cell[43888, 1505, 78, 1, 44, "Input"],
Cell[43969, 1508, 292, 10, 60, "Text",
  Evaluatable->False],
Cell[44264, 1520, 85, 1, 44, "Input"],
Cell[44352, 1523, 212, 8, 41, "Text",
  Evaluatable->False],
Cell[44567, 1533, 86, 1, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44690, 1539, 120, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->{"Shuffle", "c:13"}],
Cell[44813, 1544, 218, 7, 60, "Text",
  Evaluatable->False],
Cell[45034, 1553, 65, 1, 44, "Input"],
Cell[45102, 1556, 74, 1, 44, "Input"],
Cell[45179, 1559, 539, 14, 110, "Text",
  Evaluatable->False],
Cell[45721, 1575, 123, 4, 64, "Input"],
Cell[45847, 1581, 104, 2, 41, "Text",
  Evaluatable->False],
Cell[45954, 1585, 104, 4, 64, "Input"],
Cell[46061, 1591, 386, 11, 79, "Text",
  Evaluatable->False],
Cell[46450, 1604, 143, 5, 84, "Input"],
Cell[46596, 1611, 76, 1, 44, "Input"],
Cell[46675, 1614, 36, 1, 45, "Input"],
Cell[46714, 1617, 134, 2, 68, "Input"],
Cell[46851, 1621, 776, 21, 141, "Text",
  Evaluatable->False],
Cell[47630, 1644, 72, 1, 44, "Input"],
Cell[47705, 1647, 87, 1, 44, "Input"],
Cell[47795, 1650, 64, 1, 44, "Input"],
Cell[47862, 1653, 594, 18, 82, "Text",
  Evaluatable->False],
Cell[48459, 1673, 56, 1, 44, "Input"],
Cell[48518, 1676, 237, 7, 122, "Text",
  Evaluatable->False],
Cell[48758, 1685, 86, 4, 64, "Input"],
Cell[48847, 1691, 104, 4, 64, "Input"],
Cell[48954, 1697, 135, 3, 45, "Input"],
Cell[49092, 1702, 56, 1, 44, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49197, 1709, 108, 3, 75, "Section",
  Evaluatable->False,
  CellTags->"c:14"],
Cell[49308, 1714, 922, 23, 186, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[50255, 1741, 126, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->{"Conversion", "c:15"}],
Cell[50384, 1746, 239, 10, 41, "Text",
  Evaluatable->False],
Cell[50626, 1758, 96, 4, 64, "Input"],
Cell[50725, 1764, 168, 5, 41, "Text",
  Evaluatable->False],
Cell[50896, 1771, 81, 4, 64, "Input"],
Cell[50980, 1777, 107, 2, 41, "Text",
  Evaluatable->False],
Cell[51090, 1781, 93, 4, 64, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51220, 1790, 136, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->{"Epsilon Elimination", "c:16"}],
Cell[51359, 1795, 1103, 30, 186, "Text",
  Evaluatable->False],
Cell[52465, 1827, 299, 7, 114, "Input"],
Cell[52767, 1836, 74, 1, 44, "Input"],
Cell[52844, 1839, 200, 5, 60, "Text",
  Evaluatable->False],
Cell[53047, 1846, 92, 4, 64, "Input"],
Cell[53142, 1852, 1113, 36, 162, "Text",
  Evaluatable->False],
Cell[54258, 1890, 150, 3, 91, "Input"],
Cell[54411, 1895, 102, 5, 84, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[54550, 1905, 132, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->{"Conversion", "c:17"}],
Cell[54685, 1910, 810, 14, 217, "Text",
  Evaluatable->False],
Cell[55498, 1926, 94, 4, 64, "Input"],
Cell[55595, 1932, 446, 10, 98, "Text",
  Evaluatable->False],
Cell[56044, 1944, 214, 4, 68, "Input"],
Cell[56261, 1950, 347, 12, 66, "Text",
  Evaluatable->False],
Cell[56611, 1964, 62, 1, 44, "Input"],
Cell[56676, 1967, 305, 11, 63, "Text",
  Evaluatable->False],
Cell[56984, 1980, 83, 1, 44, "Input"],
Cell[57070, 1983, 177, 5, 60, "Text",
  Evaluatable->False],
Cell[57250, 1990, 71, 1, 44, "Input"],
Cell[57324, 1993, 252, 10, 41, "Text",
  Evaluatable->False],
Cell[57579, 2005, 91, 1, 44, "Input"],
Cell[57673, 2008, 200, 8, 44, "Text",
  Evaluatable->False],
Cell[57876, 2018, 69, 1, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[57982, 2024, 96, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:18"],
Cell[58081, 2029, 329, 7, 79, "Text",
  Evaluatable->False],
Cell[58413, 2038, 76, 1, 44, "Input"],
Cell[58492, 2041, 57, 1, 44, "Input"],
Cell[58552, 2044, 74, 1, 44, "Input"],
Cell[58629, 2047, 53, 1, 44, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58731, 2054, 121, 3, 75, "Section",
  Evaluatable->False,
  CellTags->{"Graphs", "c:19"}],
Cell[58855, 2059, 640, 13, 136, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[59520, 2076, 122, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:20"],
Cell[59645, 2081, 508, 11, 129, "Text",
  Evaluatable->False],
Cell[60156, 2094, 276, 6, 137, "Input"],
Cell[60435, 2102, 208, 6, 104, "Input"],
Cell[60646, 2110, 62, 1, 44, "Input"],
Cell[60711, 2113, 58, 1, 44, "Input"],
Cell[60772, 2116, 63, 1, 44, "Input"],
Cell[60838, 2119, 73, 1, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[60948, 2125, 117, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:21"],
Cell[61068, 2130, 456, 9, 98, "Text",
  Evaluatable->False],
Cell[61527, 2141, 83, 1, 44, "Input"],
Cell[61613, 2144, 97, 4, 64, "Input"],
Cell[61713, 2150, 141, 5, 41, "Text",
  Evaluatable->False],
Cell[61857, 2157, 73, 1, 44, "Input"],
Cell[61933, 2160, 115, 2, 41, "Text",
  Evaluatable->False],
Cell[62051, 2164, 112, 4, 64, "Input"],
Cell[62166, 2170, 104, 2, 41, "Text",
  Evaluatable->False],
Cell[62273, 2174, 57, 1, 44, "Input"],
Cell[62333, 2177, 440, 10, 79, "Text",
  Evaluatable->False],
Cell[62776, 2189, 134, 4, 84, "Input"],
Cell[62913, 2195, 61, 1, 44, "Input"],
Cell[62977, 2198, 207, 6, 44, "Text",
  Evaluatable->False],
Cell[63187, 2206, 91, 1, 44, "Input"],
Cell[63281, 2209, 57, 1, 44, "Input"],
Cell[63341, 2212, 58, 1, 44, "Input"],
Cell[63402, 2215, 490, 13, 85, "Text",
  Evaluatable->False],
Cell[63895, 2230, 106, 4, 64, "Input"],
Cell[64004, 2236, 207, 6, 60, "Text",
  Evaluatable->False],
Cell[64214, 2244, 96, 4, 64, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[64347, 2253, 107, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:22"],
Cell[64457, 2258, 675, 21, 110, "Text",
  Evaluatable->False],
Cell[65135, 2281, 511, 8, 183, "Input"],
Cell[65649, 2291, 45, 1, 45, "Input"],
Cell[65697, 2294, 104, 3, 41, "Text"],
Cell[65804, 2299, 117, 2, 68, "Input"],
Cell[65924, 2303, 1166, 35, 151, "Text",
  Evaluatable->False],
Cell[67093, 2340, 94, 4, 64, "Input"],
Cell[67190, 2346, 228, 7, 63, "Text"],
Cell[67421, 2355, 66, 1, 45, "Input"],
Cell[67490, 2358, 886, 17, 189, "Text"],
Cell[68379, 2377, 147, 5, 84, "Input"],
Cell[68529, 2384, 194, 5, 60, "Text",
  Evaluatable->False],
Cell[68726, 2391, 209, 4, 114, "Input"],
Cell[68938, 2397, 303, 9, 41, "Text",
  Evaluatable->False],
Cell[69244, 2408, 269, 4, 114, "Input"],
Cell[69516, 2414, 178, 4, 60, "Text"],
Cell[69697, 2420, 113, 2, 68, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[69847, 2427, 108, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:23"],
Cell[69958, 2432, 799, 27, 129, "Text",
  Evaluatable->False],
Cell[70760, 2461, 287, 5, 114, "Input"],
Cell[71050, 2468, 60, 1, 45, "Input"],
Cell[71113, 2471, 588, 16, 98, "Text"],
Cell[71704, 2489, 147, 2, 68, "Input"],
Cell[71854, 2493, 271, 5, 79, "Text"],
Cell[72128, 2500, 48, 1, 45, "Input"],
Cell[72179, 2503, 242, 6, 60, "Text"],
Cell[72424, 2511, 140, 2, 68, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[72613, 2519, 104, 3, 75, "Section",
  Evaluatable->False,
  CellTags->"c:24"],
Cell[72720, 2524, 2344, 72, 305, "Text",
  Evaluatable->False],
Cell[75067, 2598, 156, 6, 104, "Input"],
Cell[75226, 2606, 203, 7, 41, "Text",
  Evaluatable->False],
Cell[75432, 2615, 75, 1, 44, "Input"],
Cell[75510, 2618, 513, 13, 98, "Text",
  Evaluatable->False],
Cell[76026, 2633, 134, 5, 84, "Input"],
Cell[76163, 2640, 409, 9, 79, "Text",
  Evaluatable->False],
Cell[76575, 2651, 236, 11, 204, "Input"],
Cell[76814, 2664, 84, 1, 44, "Input"],
Cell[76901, 2667, 74, 1, 44, "Input"],
Cell[76978, 2670, 164, 5, 41, "Text",
  Evaluatable->False],
Cell[77145, 2677, 135, 6, 104, "Input"],
Cell[77283, 2685, 137, 5, 41, "Text",
  Evaluatable->False],
Cell[77423, 2692, 126, 4, 64, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[77586, 2701, 128, 3, 75, "Section",
  Evaluatable->False,
  CellTags->{"Sample machines", "c:25"}],

Cell[CellGroupData[{
Cell[77739, 2708, 104, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:26"],
Cell[77846, 2713, 939, 31, 129, "Text",
  Evaluatable->False],
Cell[78788, 2746, 154, 4, 64, "Input"],
Cell[78945, 2752, 67, 1, 44, "Input"],
Cell[79015, 2755, 55, 1, 44, "Input"],
Cell[79073, 2758, 55, 1, 44, "Input"],
Cell[79131, 2761, 77, 1, 44, "Input"],
Cell[79211, 2764, 207, 6, 60, "Text",
  Evaluatable->False],
Cell[79421, 2772, 101, 1, 44, "Input"],
Cell[79525, 2775, 73, 1, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[79635, 2781, 112, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:27"],
Cell[79750, 2786, 938, 23, 265, "Text",
  Evaluatable->False],
Cell[80691, 2811, 162, 7, 124, "Input"],
Cell[80856, 2820, 216, 6, 60, "Text",
  Evaluatable->False],
Cell[81075, 2828, 80, 1, 44, "Input"],

Cell[CellGroupData[{
Cell[81180, 2833, 126, 3, 66, "Subsubsection",
  Evaluatable->False,
  CellTags->{"41-minimal DFAs", "c:28"}],
Cell[81309, 2838, 151, 6, 104, "Input"],
Cell[81463, 2846, 148, 5, 41, "Text",
  Evaluatable->False],
Cell[81614, 2853, 150, 5, 84, "Input"],
Cell[81767, 2860, 586, 14, 117, "Text",
  Evaluatable->False],
Cell[82356, 2876, 171, 6, 104, "Input"],
Cell[82530, 2884, 186, 5, 60, "Text",
  Evaluatable->False],
Cell[82719, 2891, 114, 4, 44, "Input"],
Cell[82836, 2897, 54, 1, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[82927, 2903, 105, 3, 66, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:29"],
Cell[83035, 2908, 1251, 31, 255, "Text",
  Evaluatable->False],
Cell[84289, 2941, 278, 9, 164, "Input"],
Cell[84570, 2952, 85, 4, 64, "Input"],
Cell[84658, 2958, 129, 4, 84, "Input"],
Cell[84790, 2964, 62, 1, 44, "Input"],
Cell[84855, 2967, 99, 4, 64, "Input"],
Cell[84957, 2973, 131, 4, 84, "Input"],
Cell[85091, 2979, 513, 13, 141, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[85641, 2997, 105, 3, 66, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:30"],
Cell[85749, 3002, 776, 20, 222, "Text",
  Evaluatable->False],
Cell[86528, 3024, 927, 26, 544, "Input"],
Cell[87458, 3052, 63, 1, 44, "Input"],
Cell[87524, 3055, 75, 1, 44, "Input"],
Cell[87602, 3058, 239, 8, 60, "Text",
  Evaluatable->False],
Cell[87844, 3068, 201, 6, 104, "Input"],
Cell[88048, 3076, 61, 1, 44, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[88158, 3083, 116, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:31"],
Cell[88277, 3088, 831, 24, 144, "Text",
  Evaluatable->False],
Cell[89111, 3114, 88, 4, 64, "Input"],
Cell[89202, 3120, 264, 9, 44, "Text",
  Evaluatable->False],
Cell[89469, 3131, 69, 1, 44, "Input"],
Cell[89541, 3134, 229, 7, 63, "Text",
  Evaluatable->False],
Cell[89773, 3143, 80, 1, 44, "Input"],
Cell[89856, 3146, 321, 11, 60, "Text",
  Evaluatable->False],
Cell[90180, 3159, 81, 1, 44, "Input"],
Cell[90264, 3162, 514, 13, 99, "Text",
  Evaluatable->False],
Cell[90781, 3177, 141, 5, 84, "Input"],
Cell[90925, 3184, 452, 11, 113, "Text",
  Evaluatable->False],
Cell[91380, 3197, 175, 6, 104, "Input"],
Cell[91558, 3205, 89, 1, 44, "Input"],
Cell[91650, 3208, 264, 7, 63, "Text",
  Evaluatable->False],
Cell[91917, 3217, 89, 4, 64, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[92043, 3226, 99, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:32"],
Cell[92145, 3231, 640, 19, 141, "Text",
  Evaluatable->False],
Cell[92788, 3252, 121, 5, 84, "Input"],
Cell[92912, 3259, 323, 11, 60, "Text",
  Evaluatable->False],
Cell[93238, 3272, 96, 4, 64, "Input"],
Cell[93337, 3278, 109, 4, 64, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[93483, 3287, 130, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:33"],
Cell[93616, 3292, 831, 17, 186, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[94472, 3313, 120, 3, 66, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:34"],
Cell[94595, 3318, 595, 16, 160, "Text",
  Evaluatable->False],
Cell[95193, 3336, 200, 8, 144, "Input"],
Cell[95396, 3346, 225, 6, 63, "Text",
  Evaluatable->False],
Cell[95624, 3354, 62, 1, 44, "Input"],
Cell[95689, 3357, 433, 10, 98, "Text",
  Evaluatable->False],
Cell[96125, 3369, 177, 7, 124, "Input"],
Cell[96305, 3378, 348, 7, 79, "Text",
  Evaluatable->False],
Cell[96656, 3387, 86, 1, 44, "Input"],
Cell[96745, 3390, 90, 2, 41, "Text",
  Evaluatable->False],
Cell[96838, 3394, 125, 4, 64, "Input"],
Cell[96966, 3400, 67, 1, 44, "Input"],
Cell[97036, 3403, 1320, 39, 236, "Text",
  Evaluatable->False],
Cell[98359, 3444, 218, 8, 164, "Input"],
Cell[98580, 3454, 386, 12, 63, "Text",
  Evaluatable->False],
Cell[98969, 3468, 165, 7, 124, "Input"],
Cell[99137, 3477, 539, 18, 122, "Text",
  Evaluatable->False],
Cell[99679, 3497, 329, 14, 264, "Input"],
Cell[100011, 3513, 52, 1, 44, "Input"],
Cell[100066, 3516, 192, 5, 60, "Text",
  Evaluatable->False],
Cell[100261, 3523, 216, 6, 104, "Input"],
Cell[100480, 3531, 64, 1, 44, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[100581, 3537, 113, 3, 66, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:35"],
Cell[100697, 3542, 1306, 29, 341, "Text",
  Evaluatable->False],
Cell[102006, 3573, 256, 10, 184, "Input"],
Cell[102265, 3585, 573, 12, 148, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[102887, 3603, 118, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:36"],
Cell[103008, 3608, 1661, 47, 248, "Text",
  Evaluatable->False],
Cell[104672, 3657, 548, 14, 134, "Text",
  Evaluatable->False],
Cell[105223, 3673, 213, 6, 104, "Input"],
Cell[105439, 3681, 98, 5, 84, "Input"],
Cell[105540, 3688, 1474, 44, 260, "Text",
  Evaluatable->False],
Cell[107017, 3734, 59, 1, 44, "Input"],
Cell[107079, 3737, 57, 1, 44, "Input"],
Cell[107139, 3740, 73, 1, 44, "Input"],
Cell[107215, 3743, 61, 1, 44, "Input"],
Cell[107279, 3746, 161, 5, 41, "Text",
  Evaluatable->False],
Cell[107443, 3753, 86, 4, 64, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[107566, 3762, 139, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->{"Local universal", "c:37"}],
Cell[107708, 3767, 1510, 41, 329, "Text",
  Evaluatable->False],
Cell[109221, 3810, 75, 1, 44, "Input"],
Cell[109299, 3813, 1264, 40, 217, "Text",
  Evaluatable->False],
Cell[110566, 3855, 83, 1, 44, "Input"],

Cell[CellGroupData[{
Cell[110674, 3860, 102, 3, 66, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:38"],
Cell[110779, 3865, 562, 13, 103, "Text",
  Evaluatable->False],
Cell[111344, 3880, 193, 5, 84, "Input"],
Cell[111540, 3887, 159, 6, 44, "Text",
  Evaluatable->False],
Cell[111702, 3895, 68, 1, 44, "Input"],
Cell[111773, 3898, 61, 1, 44, "Input"],
Cell[111837, 3901, 92, 4, 64, "Input"],
Cell[111932, 3907, 73, 1, 44, "Input"],
Cell[112008, 3910, 179, 5, 60, "Text",
  Evaluatable->False],
Cell[112190, 3917, 59, 1, 45, "Input"],
Cell[112252, 3920, 35, 1, 45, "Input"],
Cell[112290, 3923, 70, 1, 44, "Input"],
Cell[112363, 3926, 71, 1, 44, "Input"],
Cell[112437, 3929, 71, 1, 44, "Input"],
Cell[112511, 3932, 573, 20, 79, "Text",
  Evaluatable->False],
Cell[113087, 3954, 62, 1, 44, "Input"],
Cell[113152, 3957, 166, 5, 41, "Text",
  Evaluatable->False],
Cell[113321, 3964, 122, 6, 104, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[113480, 3975, 102, 3, 66, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:39"],
Cell[113585, 3980, 657, 16, 172, "Text",
  Evaluatable->False],
Cell[114245, 3998, 213, 6, 104, "Input"],
Cell[114461, 4006, 919, 30, 203, "Text"],
Cell[115383, 4038, 77, 1, 44, "Input"],
Cell[115463, 4041, 177, 6, 104, "Input"],
Cell[115643, 4049, 79, 1, 44, "Input"],
Cell[115725, 4052, 66, 1, 45, "Input"],
Cell[115794, 4055, 79, 1, 44, "Input"],
Cell[115876, 4058, 116, 2, 41, "Text",
  Evaluatable->False],
Cell[115995, 4062, 121, 7, 124, "Input"],
Cell[116119, 4071, 284, 7, 79, "Text",
  Evaluatable->False],
Cell[116406, 4080, 119, 6, 104, "Input"],
Cell[116528, 4088, 86, 4, 64, "Input"],
Cell[116617, 4094, 183, 5, 60, "Text",
  Evaluatable->False],
Cell[116803, 4101, 85, 1, 44, "Input"],
Cell[116891, 4104, 224, 6, 104, "Input"],
Cell[117118, 4112, 90, 1, 44, "Input"],
Cell[117211, 4115, 56, 1, 45, "Input"],
Cell[117270, 4118, 301, 9, 63, "Text",
  Evaluatable->False],
Cell[117574, 4129, 150, 6, 104, "Input"],
Cell[117727, 4137, 117, 2, 41, "Text",
  Evaluatable->False],
Cell[117847, 4141, 63, 1, 44, "Input"],
Cell[117913, 4144, 136, 5, 41, "Text",
  Evaluatable->False],
Cell[118052, 4151, 101, 1, 44, "Input"],
Cell[118156, 4154, 102, 2, 41, "Text",
  Evaluatable->False],
Cell[118261, 4158, 68, 1, 44, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[118378, 4165, 114, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:40"],
Cell[118495, 4170, 602, 19, 79, "Text"],
Cell[119100, 4191, 290, 6, 137, "Input"],
Cell[119393, 4199, 832, 24, 160, "Text"],
Cell[120228, 4225, 80, 2, 45, "Input"],
Cell[120311, 4229, 118, 5, 41, "Text"],
Cell[120432, 4236, 102, 2, 45, "Input"],
Cell[120537, 4240, 64, 0, 41, "Text"],
Cell[120604, 4242, 81, 2, 45, "Input"],
Cell[120688, 4246, 116, 5, 41, "Text"],
Cell[120807, 4253, 106, 2, 45, "Input"],
Cell[120916, 4257, 334, 6, 98, "Text"],
Cell[121253, 4265, 195, 4, 91, "Input"],
Cell[121451, 4271, 126, 3, 60, "Text"],
Cell[121580, 4276, 78, 2, 45, "Input"],
Cell[121661, 4280, 138, 4, 44, "Text"],
Cell[121802, 4286, 108, 2, 45, "Input"],
Cell[121913, 4290, 55, 1, 45, "Input"],
Cell[121971, 4293, 42, 1, 45, "Input"],

Cell[CellGroupData[{
Cell[122038, 4298, 107, 3, 66, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:41"],
Cell[122148, 4303, 62, 1, 53, "Input"],
Cell[122213, 4306, 67, 1, 45, "Input"],
Cell[122283, 4309, 172, 3, 91, "Input"],
Cell[122458, 4314, 140, 3, 60, "Text"],
Cell[122601, 4319, 67, 0, 44, "Input"],
Cell[122671, 4321, 159, 4, 68, "Input"],
Cell[122833, 4327, 54, 1, 45, "Input"],
Cell[122890, 4330, 160, 4, 68, "Input"],
Cell[123053, 4336, 129, 2, 68, "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

