(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     41957,       1387]*)
(*NotebookOutlinePosition[     45462,       1512]*)
(*  CellTagsIndexPosition[     44977,       1490]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\[Copyright] 1997-2002 K. Sutner ", "SmallText"],

Cell["The Minimal Automaton", "Title",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Charter",
  CellTags->"c:1"],

Cell[CellGroupData[{

Cell["The Minimal Automaton ", "Section",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True,
  CellTags->{"Minimization", "c:2"}],

Cell[TextData[{
  "For every regular language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " there is a unique (up to isomorphism) DFA which is minimal with respect \
to the number of states. There are several different chararcterizations of \
this minimal automaton. We begin with a fairly abstract one based on \
quotients and then show how this characterization can be used to find \
algorithms that compute the minimal automaton. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`The\ Quotient\ Automaton\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:3"],

Cell[TextData[{
  "The number of states in the minimal DFA for any regular language is equal \
to the number of left quotients of L and there is a natural construction of \
the minimal automaton from the quotients. (Left) Quotients of a language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " are obtained by deleting a prefix from all words in the language\n\t",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(-1\)\ L\  = \ {\ \ \ x\  | \ 
            x\ y\  \[Element] \ L\ }\)]],
  "\nA standard theorem says that:\n\ta language",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(L\)\)\)]],
  " is regular iff the set of all quotients of ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is finite. \nThe minimal DFA of a regular language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " can be obtained by computing all quotients ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and defining the automaton as follows. \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(Q\)\(\ \)\(=\)\(\ \)\({\ \(x\^\(-1\)\) L\  | \ 
            x\  \[Element] \ \(\[CapitalSigma]\^*\)}\)\(\ \ \)\)\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](\ K, \ a\ )\  = \ \(a\^\(-1\)\) K\)]],
  ",\n\t",
  Cell[BoxData[
      \(TraditionalForm\`q\_0 = \ L\)]],
  ",\n\t",
  Cell[BoxData[
      \(TraditionalForm\`F\  = \ {\ 
          K\  \[Element] \ Q\  | \ \[Epsilon]\  \[Element] \ K\ }\)]],
  ".\nIn general, this construction has no direct algorithmic consequences, \
since the quotients of a language are infinitary objects, even if there are \
only finitely many of them. We do not yet have a way to represent the \
quotients as data structures. However, there is one notable exception to this \
rule: for finite languages ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " the quotients are also finite, and we can simply represent them by lists \
of words. \nIn this package, the quotient automaton for finite languages can \
be constructed directly using ",
  StyleBox["QuotientDFA",
    FontFamily->"Courier"],
  ". For arbitrary languages we can obtain the minimal automaton by \
minimizing any given DFA for L (for a description of the minimization \
procedure see below) using MinimizeFA. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(L = {Eps, a, ba, aba, bbb}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(LeftQuotient[a, L]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(LeftQuotient[bb, L]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(m1 = QuotientDFA[L, {a, b}, Normalize \[Rule] 1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(States[m1]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Of course, we can also obtain the minimal automaton by minimizing any \
given DFA for ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". For example, we can convert a regular expression for ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " into an FA and then on into a DFA. After minimization the resulting \
automaton is isomorphic to ",
  Cell[BoxData[
      \(TraditionalForm\`m\_1\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(m = RegularExpressionToFA[Eps + a + ba + aba + bbb, {a, b}]\)], "Input"],

Cell[BoxData[
    \(IsomorphicQDFA[m1, MinimizeFA[m]]\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Suffix\ Machines\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:4"],

Cell[TextData[{
  "An interesting application of the quotient machine construction is the \
so-called suffix automaton: a DFA that accepts all suffixes of a given word. \
Note that a priori such a machine might have ",
  Cell[BoxData[
      \(TraditionalForm\`O(\(|\)\(w\)\( | \^2\))\)]],
  "  many states. However, one can show that the number of quotients of ",
  StyleBox["WordSuffixes[w]", "SmallText"],
  "  is actually at most ",
  Cell[BoxData[
      \(TraditionalForm\`2 | w | \)]],
  ". \nAs an example, we generate the suffixes of a few random words of \
length 8 on ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c}\)]],
  " and compute the quotients."
}], "Text"],

Cell[BoxData[{
    \(\(w = RandomWord[8, 3];\)\), "\n", 
    \(L = Reverse[WordSuffixes[w]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The DFA generated by ",
  StyleBox["QuotientDFA",
    FontFamily->"Courier"],
  " has the quotients as state set:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Msuff = QuotientDFA[L, 3, Normalize \[Rule] 1];\)\), "\n", 
    \(ColumnForm[States[Msuff]]\)}], "Input",
  AspectRatioFixed->True],

Cell["Here is an accepting computation of the quotient machine. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(tr = AcceptQFA[Msuff, w, DoTrace \[Rule] True];\)\), "\n", 
    \(ColumnForm[tr]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The sequence of states is obtained by taking quotients repeatedly: \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((LeftQuotient[StringTake[w, {#1}], 
              tr\[LeftDoubleBracket]#1\[RightDoubleBracket]] === 
            tr\[LeftDoubleBracket]#1 + 1\[RightDoubleBracket] &)\) /@ 
      Range[WordLength[w]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
The final states of Msuff are precisely the quotients containing \
Eps. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(States[Msuff]\)\[LeftDoubleBracket]Final[Msuff]\[RightDoubleBracket] === 
      Select[States[Msuff], MemberQ[#1, "\<Eps\>"] &]\)], "Input",
  AspectRatioFixed->True],

Cell["Test the acceptance language of Msuff:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Flatten[LanguageFA[Msuff, \(-10\)]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Note that we can also construct DFAs for suffixes by starting with \
the natural non-deterministic machine and applying deterministic simulation. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(w\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(fa = SuffixesFA[w, 3]\), "\n", 
    \(m1 = ToDFA[fa]\), "\n", 
    \(m2 = BuildDFA[WordSuffixes[w], 3]\), "\n", 
    \(m1 === m2\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Why are the machines identical? Let's preserve the structure of the \
state sets.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(fa = SuffixesFA[w, 3, Normalize \[Rule] 1]\), "\n", 
    \(m1 = \(\(Curry[ToDFA]\)[Normalize \[Rule] 1]\)[fa]\), "\n", 
    \(m2 = BuildDFA[WordSuffixes[w], 3, Normalize \[Rule] 1]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To make things clearer, we have to sort and reverse the states of \
the automata.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Q1 = Sort /@ States[m1];\)\), "\n", 
    \(\(Q2 = Reverse /@ States[m2];\)\), "\n", 
    \(\(\(Curry[TableForm]\)[TableDepth \[Rule] 2]\)[
      Pairs[Q1, Q2]]\)}], "Input",
  AspectRatioFixed->True],

Cell["Voila.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

The alternative construction is quite a bit faster, so we will use it to \
determine if the small size of Msuff is just a coincidence. Here is some more \
evidence for the claim that the suffix automaton does not blow up.
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((Size[ToDFA[SuffixesFA[RandomWord[8, 3], 3]]] &)\) /@ 
      Range[30]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ListPlot[%, PlotRange \[Rule] {{0, 21}, {8, 16}}, 
        PlotStyle \[Rule] {PointSize[0.015], Blue}];\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Homomorphisms\ and\ Behavior\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:5"],

Cell[TextData[{
  "To understand the relationship between the quotient automaton from the \
last section and an arbitrary DFA for the same language we need some general \
method to compare finite state machines. Here is a useful way to express that \
a smaller machine (M2 below) simulates another.\nLet M1 and M2 two DFAs over \
the same alphabet. M1 covers M2 if there is a partial, surjective \
homomorphism from M1 to M2 that preserves initial and final states. This \
homomorphism is called a covering map. If we insisted that all our machines \
are accessible, we could drop the annoying stipulation that the map may by \
partial.  Similarly, an injective homomorphism is called an embedding.  Note \
that if M1 and M2 have the same size then any covering map as well as any \
embedding must be an isomorphism. \nThe minimal automaton has the following \
property: \n\tEvery DFA for a language L covers the minimal automaton for L. \
\n\nWe can test for the existence of covering maps, embeddings and \
isomorphism using ",
  StyleBox["CoverQDFA",
    FontFamily->"Courier"],
  ", ",
  StyleBox["ImbedQDFA",
    FontFamily->"Courier"],
  " and ",
  StyleBox["IsomorphicQDFA",
    FontFamily->"Courier"],
  ". \nAs an example, let us compute the minimal automaton for the FA ",
  StyleBox["Mb3",
    FontFamily->"Courier"],
  " from above  (accepts all words whose third symbol from the end is an \
'b').  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Mb3 = IthSymbolFA[b, \(-3\), {a, b}];\)\), "\n", 
    \(\(m1 = ToDFA[Mb3];\)\), "\n", 
    \(\(m2 = MinimizeFA[m1];\)\), "\n", 
    \(Size[{m1, m2}]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
There is no reduction in size. Hence m1 and m2 should be \
isomorphic.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(IsomorphicQDFA[m1, m2]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The isomorphism can be displayed by setting option ",
  StyleBox["DoTrace->True",
    FontFamily->"Courier"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(IsomorphicQDFA[m1, m2, DoTrace \[Rule] True]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\

Here is a more interesting example:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m1 = BuildDFA[aa, {a, b}];\)\), "\n", 
    \(\(m2 = BuildDFA[ab, {a, b}];\)\), "\n", 
    \(\(m3 = BuildDFA[bb, {a, b}];\)\), "\n", 
    \(m4 = 
      UnionFA[m1, m2, m3, Normalize \[Rule] 2, Full \[Rule] True]\)}], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(States[m4]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Note that the states of m4 are now lists of type {{x,y},z}. To make \
things less confusing we will flatten them to triples. Then we compute the \
accessible part, minimize and display equivalent states.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m4 = ReplacePart[m4, Flatten /@ States[m4], \(-1\)];\)\), "\n", 
    \(m5 = AccessibleFA[m4, Normalize \[Rule] 2]\), "\n", 
    \(\(m6 = MinimizeFA[m5, Normalize \[Rule] 2];\)\), "\n", 
    \(ColumnForm[States[m6]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Curry[TableForm]\)[TableDepth \[Rule] 2]\)[
      CoverQDFA[m4, m6, DoTrace \[Rule] True]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Another way to obtain the minimal DFA is via regular expressions. \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m7 = ToDFA[RegularExpressionToFA[aa + ab + bb, {a, b}]];\)\), "\n", 
    \(m8 = MinimizeFA[m7]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Size[{m4, m5, m6, m7, m8}]\)], "Input",
  AspectRatioFixed->True],

Cell["m5 imbeds into m4:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ImbedQDFA[m5, m4]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Here is the covering map from m4 to m6 and the isomorphism between \
m6 and m8.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Curry[TableForm]\)[TableDepth \[Rule] 2]\)[
      CoverQDFA[m4, m6, DoTrace \[Rule] True]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(iso = IsomorphicQDFA[m8, m6, DoTrace \[Rule] True];\)\), "\n", 
    \(\(\(Curry[TableForm]\)[TableDepth \[Rule] 2]\)[iso]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Using ",
  StyleBox["AssignFunction",
    FontFamily->"Courier"],
  " one can assign the output of ",
  StyleBox["IsomorphicQDFA",
    FontFamily->"Courier"],
  " and the other commands to a function symbol:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(AssignFunction[ff, iso];\)\), "\n", 
    \(ff[4]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To see that the theorem about covers is true in general we need the notion \
of the behavior of a state. The behavior of a state p in a machine M is the \
acceptance language of the machine obtained by making p the sole initial \
state in M. One can show that in an accessible DFA every state has as \
behavior one of the quotients of the language. The map the associates a state \
with its behavior is the required covering map. Hence, if we could somehow \
compute the behavior of a state, we could construct the minimal automaton \
from a given DFA: identify all states with the same behavior. \n\nHere is an \
example. Let us compute the behaviors of all states in the natural DFA for ",
  Cell[BoxData[
      \(TraditionalForm\`L(a, \(-3\))\)]],
  "  (of course, we can only compute a few words in the behavior). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(m = IthSymbolDFA[a, \(-3\), 2]\), "\n", 
    \(Clear[beh]\), "\n", 
    \(\(beh[p_] := \(beh[p] = 
          Flatten[BehaviorFA[m, p, \(-5\)]]\);\)\), "\n", 
    \(Scan[beh, Range[15]]\), "\n", 
    \(beh[10]\), "\n", 
    \(beh[5]\)}], "Input"],

Cell["Next we classify the states according to their behavior.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Q0 = ToClasses[Range[15], beh, Type \[Rule] Function];\)\), "\n", 
    \(Sort[Q0]\)}], "Input"],

Cell["\<\
We can also determine an index for the equivalence relation that \
can then be used to compute the corresponding quotient automaton (which is \
the minimal automaton since the equivalence relation here is none other than \
behavioral equivalence).\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({ind, r} = MakeIndex[beh /@ Range[15]];\)\), "\n", 
    \(MatrixForm[{Range[15], ind}]\), "\n", 
    \(m1 = StateMergeDFA[m, ind]\)}], "Input"],

Cell["\<\
This is done automatically in the minimization algorithm explained \
in the next section.  Of course, the equivalence relation is computed in a \
more efficient manner there. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m2 = 
        MinimizeFA[m, Normalize \[Rule] 2, 
          External \[Rule] False];\)\), "\n", 
    \(Sort[Sort /@ States[m2]]\)}], "Input"],

Cell[BoxData[
    \(IsomorphicQDFA[m1, m2]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Computing\ the\ Minimal\ Automaton\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:6"],

Cell["\<\
Note that we cannot directly implement the method from the last \
section. We have no way of testing whether two states have the same behavior \
or not. However, there is a way check equality of behaviors without actually \
having to compute the corresponding languages. The idea is to approximate the \
behavior, first by considering only words of length 0 (i.e., the empty word), \
and then systematically refining this relation by considering longer and \
longer words. When nothing now happens in this process we have distinguished \
all states with different behavior. It is then quite easy to merge states \
with the same behavior into one `superstate' and the DFA obtained from these \
superstates is the minimal DFA. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Simple\ Minimization\)], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:7"],

Cell[TextData[{
  "The internal command ",
  StyleBox["MinimizeFA",
    FontFamily->"Courier"],
  " uses a quadratic time  algorithm (whatever that may mean for programs \
written in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "). First, the behavioral equivalence is computed in a procedure  ",
  StyleBox["MinimizeDFA",
    FontFamily->"Courier"],
  ".  Then, the actual minimal automaton is computed via a procedure ",
  StyleBox["StateMergeDFA",
    FontFamily->"Courier"],
  ". The approach taken in ",
  StyleBox["MinimizeDFA",
    FontFamily->"Courier"],
  " is to partition the states first into final and non-final states and then \
refining the partition (using the transition function) until no improvement \
can be made. Indeed, ",
  StyleBox["MinimizeDFA",
    FontFamily->"Courier"],
  " uses the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " command ",
  StyleBox["FixedPoint",
    FontFamily->"Courier"],
  " for this purpose. \nAs an example, we construct a nonminimal DFA m1 of \
size 13 for the even-even language using a regular expression (see below for \
more information on the implementation of regular expressions in this \
package). The corresponding minimal automaton has only 4 states. The merging \
process can be made visible using option ",
  StyleBox["DoTrace->True",
    FontFamily->"Courier"],
  ". ",
  StyleBox["MinimizeDFA",
    FontFamily->"Courier"],
  " then returns the minimal automaton as well as a list of the refinement \
matrices that occur during the computation. \nSince minimization always \
starts with a call to ",
  StyleBox["AccessibleFA",
    FontFamily->"Courier"],
  " (which may rearrange the states of the machine), we apply ",
  StyleBox["AccessibleFA",
    FontFamily->"Courier"],
  " by hand first so that the steps of the algorithm are better visible."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
e0 = aa + bb;
e1 = ab + ba;
exp = RES[ e0 + e1**RES[e0]**e1 ]\
\>", "Input"],

Cell[BoxData[
    \(RegularExpressionToFA[exp, {a, b}, Thompson \[Rule] True]\)], "Input"],

Cell[BoxData[
    \(m1 = ToDFA[%]\)], "Input"],

Cell[BoxData[{
    \(\({m2, t2} = 
        MinimizeDFA[m1, DoTrace \[Rule] True, 
          Normalize \[Rule] 1];\)\), "\n", 
    \(m2\), "\n", 
    \(States[m2]\), "\n", 
    \(TableForm[t2]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{
        SuperscriptBox["Hopcroft", "\[Prime]",
          MultilineFunction->None], " ", "s", " ", "Algorithm"}], 
      TraditionalForm]], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:8"],

Cell[TextData[{
  "There is a more efficient state merging algorithm due to Hopcroft that has \
asymptotic running time O(n lg n). It is used in the external code. Since the \
external programs are hard to trace (you can try to use your debugger), we \
have also implemented Hopcroft's algorithm internally. The trace shows the \
choice of pivot and the resulting partition. Note, though, that the internal \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementation of this algorithm is actually slower than the standard \
algorithm (whose time complexity is ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\^2)\)]],
  ", at least in theory). \n\nHere is the trace of Hopcroft's algorithm for \
the machine m1 from above. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({m3, t3} = 
        MinimizeDFA[m1, Hopcroft \[Rule] True, 
          DoTrace \[Rule] True];\)\), "\n", 
    \(m3\)}], "Input"],

Cell[BoxData[{
    \(Final[m1]\), "\n", 
    \(PrintFA[m1, TransOnly \[Rule] True]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The pivot (symbol, partition number) is on the left and the \
resulting partition on the right. 
Note that nothing changes in the last four steps. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintFA[ToNFA[ReverseFA[m1]], TransOnly \[Rule] True]\)], "Input"],

Cell[BoxData[
    \(TableForm[t3, TableDepth \[Rule] 2]\)], "Input"],

Cell["The two machines are of course isomorphic.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(IsomorphicQDFA[m2, m3]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Subword\ Modular\ Counters\)], "Subsubsection"],

Cell[BoxData[
    \(m = SubwordModCounterDFA[ba, 0, 7, 2]\)], "Input"],

Cell[BoxData[{
    \(\({mm, tr} = 
        MinimizeDFA[m, DoTrace \[Rule] True, 
          Normalize \[Rule] 1];\)\), "\n", 
    \(mm\), "\n", 
    \(TableForm[tr]\)}], "Input"],

Cell[BoxData[{
    \(\({mm, tr} = 
        MinimizeDFA[m, Hopcroft \[Rule] True, 
          DoTrace \[Rule] True];\)\), "\n", 
    \(mm\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Final[mm]\), "\n", 
    \(PrintFA[mm, TransOnly \[Rule] True]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[tr, TableDepth \[Rule] 2]\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Minimization\ by\ Reversal\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:9"],

Cell[TextData[{
  "There is a somewhat surprising method to compute the minimal automaton \
based solely on reversal and the power automaton construction. \n\nMore \
precisely, let ",
  StyleBox["pow(m)",
    FontFamily->"Courier"],
  " denote the operation of constructing the accessible part of the power set \
machine of a nondeterministic machine m. Let ",
  StyleBox["rev(m)",
    FontFamily->"Courier"],
  " denote the reversal machine of m. Then one can compute the minimal \
automaton as follows: compute the reversal, perform deterministic simulation, \
then compute the reversal again, lastly perform deterministic simulation one \
more time. The resulting automaton is (isomorphic to) the minimal automaton: \
\n\n\tminimal DFA =",
  StyleBox[" pow(rev(pow(rev(m))))",
    FontFamily->"Courier"],
  ".\n\nNeedless to say, this method is computationally inefficient. Here is \
an example. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mb3 = IthSymbolFA[b, \(-3\)]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(LanguageFA[%, \(-4\)]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(m1 = ToDFA[ReverseFA[ToDFA[ReverseFA[Mb3]]]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Here is the minimal DFA, computed in the traditional way. The \
machines are isomorphic. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(m2 = MinimizeFA[Mb3]\), "\n", 
    \(IsomorphicQDFA[m1, m2]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Equivalence\ of\ Finite\ State\ Machines\)], \
"Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:10"],

Cell[CellGroupData[{

Cell["Minimal Automata", "Subsubsection"],

Cell[TextData[{
  "Minimal automata afford a normal form for regular languages. As a \
consequence,  equality of regular languages is decidable. Since regular \
languages are closed under union the subset relation is also decidable. \nTo \
check whether two machines accept the same language, we first compute the \
corresponding minimal automata, say ",
  Cell[BoxData[
      \(TraditionalForm\`M\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  " We now have to test if ",
  Cell[BoxData[
      \(TraditionalForm\`M\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  " are isomorphic. There are basically two ways to do this. One is to use a \
modified version of depth-first-search to try to construct an isomorphism \
between the two machines. If the construction succeeds the machines are \
isomorphic, and conversely. Another possibility is to use the function that \
computes the accessible part. It is not hard to see that for ",
  Cell[BoxData[
      \(TraditionalForm\`M\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  " accessible we have\n\n\t",
  Cell[BoxData[
      \(TraditionalForm\`M\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  "  isomorphic  \[DoubleLongLeftRightArrow]  ",
  Cell[BoxData[
      \(TraditionalForm\`acc(M\_1)\  = \ acc(M\_2)\)]],
  "\n\nOf course, AccessibleFA also uses depth-first-search. However, since \
only one machine is dealt with at a time, this approach is a little easier to \
implement than the other method. \nThe commands ",
  StyleBox["EquivalenceQFA",
    FontFamily->"Courier"],
  " and ",
  StyleBox["SubsetQFA",
    FontFamily->"Courier"],
  " are currently based on method one. Both functions use ",
  StyleBox["ToDFA",
    FontFamily->"Courier"],
  " if the input is nondeterministic and therefore have potentially \
exponential space and time requirement. To test the two functions let us \
first define two different DFAs that accept the same language. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m1 = IthSymbolDFA[a,-4];
m2 = ToDFA@IthSymbolFA[a,-4];
mm1 = MinimizeFA[m1];
mm2 = MinimizeFA[m2];
IsomorphicQDFA[mm1,mm2]\
\>", "Input"],

Cell[TextData[{
  "The Kleene star of ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " always is a superset of ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ".  In the following example it is a proper superset. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m2 = IthSymbolFA[b, 8, {a, b, c}];\)\), "\n", 
    \(\(m3 = StarFA[m2];\)\), "\[IndentingNewLine]", 
    \(SubsetQFA[m2, m3]\), "\[IndentingNewLine]", 
    \(\(mm2 = MinimizeFA[m2];\)\), "\n", 
    \(\(mm3 = MinimizeFA[m3];\)\), "\n", 
    \(IsomorphicQDFA[mm2, mm3]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Union-Find", "Subsubsection"],

Cell[TextData[{
  "If the given finite state machines are DFAs one can test equivalence more \
directly, without computing the minimal automaton.  First off, suppose we \
have two DFA ",
  Cell[BoxData[
      \(TraditionalForm\`M\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  "  over the same alphabet.  To test equivalence, we could compute the \
product automaton ",
  Cell[BoxData[
      \(TraditionalForm\`M\  = \ M\_1\[Cross]\ M\_2\)]],
  " and then check that the accessible part only contains only states of the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, q)\)\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "  and  ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  "  are either both final or both non-final. "
}], "Text"],

Cell["\<\
m1 = IthSymbolDFA[a,-4];
m2 = ToDFA@IthSymbolFA[a,-4];
m = AccessibleFA[ ProductFA[m1,m2,Normalize->1], Normalize->2 ]\
\>", "Input"],

Cell["\<\
Select[ States[m], \
Xor[MemberQ[Final[m1],#[[1]]],MemberQ[Final[m2],#[[2]]]]& ]\
\>", "Input"],

Cell[TextData[{
  "The problem with this approach is that it is potentially quadratic. \
Instead, consider the sum automaton ",
  Cell[BoxData[
      \(TraditionalForm\`M\  = \ M\_1 + \ M\_2\)]],
  " whose state set ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " is the disjoint union of ",
  Cell[BoxData[
      \(TraditionalForm\`Q\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Q\_2\)]],
  ".  The transition functions induce an equivalence relation on ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  ".  More precisely, define an equivalence relation \[Rho]  on ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " by \n-  ",
  Cell[BoxData[
      \(TraditionalForm\`q\_01\ \[Rho]\ \ q\_02\)]],
  " , and \n-  ",
  Cell[BoxData[
      \(TraditionalForm\`p\ \[Rho]\ q\)]],
  "  implies  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Delta]\_1\)(p, 
          a)\)\(\ \ \)\(\[Rho]\)\(\ \ \)\(\(\[Delta]\_2\)(q, 
          a)\)\(\ \)\)\)]],
  "  for all ",
  Cell[BoxData[
      \(TraditionalForm\`a\  \[Element] \ \[CapitalSigma]\)]],
  ". \nThen the two machines are equivalent if, and only if,  \[Rho] \
saturates  ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\  \[Union] \ F\_2\)]],
  ".   \n\nThe equivalence relation can be generated in nearly linear time \
using the classical union/find datastructure. Note, though, that the \
implemenation in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses neither path-compression nor ranked union, so it might be somewhat \
slower. "
}], "Text"],

Cell["EquivalentQFA[m1,m2]", "Input"],

Cell["{n1,n2,F,R} = EquivalentQFA[m1,m2,DoTrace->True]", "Input"],

Cell[TextData[{
  "The disjointness condition is simply implemented by shifting the states in \
",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  ".  Thus, the last block indicates that states 1, 3, 7, 15, 31 in ",
  Cell[BoxData[
      \(TraditionalForm\`M\_1\)]],
  " are equivalent to state 1 in ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  ". \n"
}], "Text"],

Cell["\<\
BehaviorFA[m1,15,-5]
BehaviorFA[m2,1,-5]\
\>", "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`u \[NotEqual] v\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:11"],

Cell[TextData[{
  "Lastly, an example of a familiy of finite languages whose associated \
minimal automata are surprisingly complicated.\nConsider the languages \n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(\(\ \)\(n\)\)\  = \ \ {\ 
            u\[VeryThinSpace]v\  | \ \  | u |  = \(\(\(|\)\(v\)\(|\)\)\  = \ 
                n\ \  \[And] \ \ u \[NotEqual] v\)\ \ }\  \[Subset] \ \({a, 
                b}\^*\)\)]],
  ".\n",
  StyleBox["Claim",
    FontWeight->"Bold"],
  ":  The minimal DFA for  ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(\(\ \)\(n\)\)\)]],
  "  has  ",
  Cell[BoxData[
      \(TraditionalForm\`3\[CenterDot]2\^n + \ n\  - \ 2\)]],
  "  states. "
}], "Text"],

Cell[TextData[{
  "To prove this assertion, on can show that the first ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " layers in the minimal automaton for ",
  Cell[BoxData[
      \(TraditionalForm\`L\_n\)]],
  " form full binary tree; the corresponding quotients are of the form ",
  Cell[BoxData[
      \(TraditionalForm\`P\  \[SubsetEqual] \ {a, b}\^k\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n\  \[LessEqual] \ k\  \[LessEqual] \ 2  n\)]],
  ".  For the remainder of the machine, the quotients are of the form  ",
  Cell[BoxData[
      \(TraditionalForm\`P\  = {a, b}\^k\)]],
  " or   ",
  Cell[BoxData[
      \(TraditionalForm\`P\  = {a, b}\^k - \ {w}\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " is some word of length ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0\  \[LessEqual] \ k\  < \ n\)]],
  ", and all such sets arise.\nNote that the cardinality of  ",
  Cell[BoxData[
      \(TraditionalForm\`L\_\(\(\ \)\(n\)\)\)]],
  "  is ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(\(\ \)\(2  n\)\)\  - \ 2\^\(\(\ \)\(n\)\)\)]],
  ", so we have to constrain our experiments to reasonably small values of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". \n"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(L = Words[3];\)\), "\n", 
    \(\(LL = 
        StringJoin /@ 
          Select[CartesianProduct[L, 
              L], #1\[LeftDoubleBracket]1\[RightDoubleBracket] =!= #1\
\[LeftDoubleBracket]2\[RightDoubleBracket] &];\)\), "\n", 
    \(Length[LL]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(m = QuotientDFA[LL, {a, b}, Normalize \[Rule] 1];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Size[m]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(LL = LanguageSort[Complement[States[m], {{}}]];\)\), "\n", 
    \(Length /@ LL\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[LL]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({S, W, eq} = SyntacticSG[m, Equations \[Rule] True];\)\), "\n", 
    \(Length[S]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eqs = SimplifyEquations[S, W, eq];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintEquations[eqs]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReduce[bbbbbb, eq, DoTrace \[Rule] True]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReduce[abbbbb, eq, DoTrace \[Rule] True]\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exponential Blowup", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Exponential blow-up", "c:12"}],

Cell[TextData[{
  "The conversion process from a nondeterministic machine to the \
corresponding minimal automaton has a potentially exponential component: the \
size of a machine produced by deterministic simulation can be as large as ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(\(\ \)\(n\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the size of the original nondeteriministic machine. Here are a few \
examples."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Reset\ Counters\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:13"],

Cell[TextData[{
  "Consider the following family of count/reset machines CR[n].  Machine \
CR[n] counts symbols ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " modulo n, and ignores symbols ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", or nondeterministically resets to the initial state.  CR[n] has ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " states but will produce a power automaton of  ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n - 1\)]],
  "  states. The deterministic machine turns out to be already minimal. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(CR[n_Integer] := 
        FA[n, 2, 
          Join[\(({#1, 1, #1 + 1} &)\) /@ 
              Range[n - 1], {{n, 1, 1}}, \(({#1, 2, #1} &)\) /@ 
              Range[n], \(({#1, 2, 1} &)\) /@ 
              Range[2, n]], {1}, {1}];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(m = CR[4]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m1 = ToDFA[m, Normalize \[Rule] 1];\)\), "\n", 
    \(PrintFA[m1, Full \[Rule] True, TransOnly \[Rule] True]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[LanguageFA[m1, \(-5\)]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotComputationFA[m, "\<aabab\>"];\)\)], "Input"],

Cell[BoxData[
    \(Final[m1]\)], "Input"],

Cell[BoxData[
    \(\(PlotComputationFA[m1, "\<aabab\>"];\)\)], "Input"],

Cell[BoxData[
    \(Size[MinimizeFA[m1]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
To see the exponential blowup more clearly we compute a whole \
sequence of these machines, say, up to CR[10] (if you do not have the \
external code installed use a smaller range instead) :\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((Size[MinimizeFA[CR[#1]]] &)\) /@ Range[10]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
If you do have the external code, you can speed-up things a little \
by sending only the size back over the link:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((SendProgram[CR[#1], "\<todfa min size\>"] &)\) /@ 
      Range[10]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Much faster is to compute only the sizes of the power automata: \
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((SendProgram[CR[#1], "\<todfasize\>"] &)\) /@ Range[10]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Circulant\ Machines\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:14"],

Cell[TextData[{
  "Here is another example for exponential blow-up during deterministic \
simulation. The underlying transition diagram is a circulant ",
  Cell[BoxData[
      \(TraditionalForm\`C(n; 1, \(-1\))\)]],
  ", i.e., a bi-cycle. The labels are all ",
  StyleBox["a",
    FontSlant->"Italic"],
  " for clockwise edges and the first counterclockwise edge, and ",
  StyleBox["b",
    FontSlant->"Italic"],
  " for the remaining edges. All states are initial and final. Note that the \
machine is almost a permutation automaton: we only need to flip the one \
counterclockwise transition from ",
  StyleBox["a",
    FontSlant->"Italic"],
  " to ",
  StyleBox["b",
    FontSlant->"Italic"],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(circ[n_Integer] := 
      CirculantSA[n, {1, \(-1\)}, 
        Join[Table[0, {n + 1}], Table[1, {n - 1}]], \(-2\)]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(circ[4]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((Size[MinimizeFA[circ[#1]]] &)\) /@ Range[10]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Again, a smaller range is appropriate if you have to use the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " minimization procedure instead.\nThe same blow-up occurs for odd-sized \
machines when we restrict the initial states to ",
  Cell[BoxData[
      \(TraditionalForm\`{1}\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(m = SetInitialFA[circ[9], {1}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Size[MinimizeFA[m]]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`DeBruijn\ Automata\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:15"],

Cell[TextData[{
  "Yet another way to produce exponential blow-up is by flipping a transition \
in a permutation automaton arising from a one-dimensional cellular automaton, \
see Guide6. Here is one example: ",
  Cell[BoxData[
      \(TraditionalForm\`CA[38250, 4, 2]\)]],
  "  is a permutation automaton whose corresponding minimal automaton is \
trivial, but if we change the label at the self-loop at state 1 we obtain \
full exponential blow-up. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(sa = ToSA[CA[38251, 4, 2]]\), "\n", 
    \(\(dfa = ToDFA[%];\)\), "\n", 
    \(Size[dfa]\), "\n", 
    \(Size[MinimizeFA[dfa]]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1207, 985},
WindowMargins->{{Automatic, 18}, {4, Automatic}},
PrintingStartingPageNumber->52,
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowSelection->True,
ShowCellLabel->True,
CellLabelAutoDelete->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->Automatic,
Magnification->1.5,
StyleDefinitions -> "Demo.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1762, 52, 130, 4, 88, "Title",
      Evaluatable->False,
      CellTags->"c:1"]},
  "Minimization"->{
    Cell[1917, 60, 151, 4, 124, "Section",
      Evaluatable->False,
      PageBreakAbove->False,
      CellTags->{"Minimization", "c:2"}]},
  "c:2"->{
    Cell[1917, 60, 151, 4, 124, "Section",
      Evaluatable->False,
      PageBreakAbove->False,
      CellTags->{"Minimization", "c:2"}]},
  "c:3"->{
    Cell[2599, 81, 146, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:3"]},
  "c:4"->{
    Cell[6175, 188, 141, 4, 56, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:4"]},
  "c:5"->{
    Cell[10685, 348, 150, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:5"]},
  "c:6"->{
    Cell[18131, 584, 156, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:6"]},
  "c:7"->{
    Cell[19112, 607, 145, 4, 56, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:7"]},
  "c:8"->{
    Cell[21636, 687, 264, 8, 62, "Subsubsection",
      Evaluatable->False,
      CellTags->"c:8"]},
  "c:9"->{
    Cell[24378, 785, 148, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:9"]},
  "c:10"->{
    Cell[26092, 841, 165, 5, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:10"]},
  "c:11"->{
    Cell[32434, 1051, 138, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:11"]},
  "Exponential blow-up"->{
    Cell[35911, 1171, 130, 3, 75, "Section",
      Evaluatable->False,
      CellTags->{"Exponential blow-up", "c:12"}]},
  "c:12"->{
    Cell[35911, 1171, 130, 3, 75, "Section",
      Evaluatable->False,
      CellTags->{"Exponential blow-up", "c:12"}]},
  "c:13"->{
    Cell[36580, 1193, 138, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:13"]},
  "c:14"->{
    Cell[39230, 1291, 142, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:14"]},
  "c:15"->{
    Cell[41083, 1359, 141, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:15"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 42937, 1416},
  {"Minimization", 43048, 1420},
  {"c:2", 43200, 1425},
  {"c:3", 43352, 1430},
  {"c:4", 43459, 1434},
  {"c:5", 43570, 1438},
  {"c:6", 43679, 1442},
  {"c:7", 43788, 1446},
  {"c:8", 43900, 1450},
  {"c:9", 44012, 1454},
  {"c:10", 44122, 1458},
  {"c:11", 44233, 1462},
  {"Exponential blow-up", 44360, 1466},
  {"c:12", 44494, 1470},
  {"c:13", 44628, 1474},
  {"c:14", 44740, 1478},
  {"c:15", 44852, 1482}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 54, 0, 40, "SmallText"],
Cell[1762, 52, 130, 4, 88, "Title",
  Evaluatable->False,
  CellTags->"c:1"],

Cell[CellGroupData[{
Cell[1917, 60, 151, 4, 124, "Section",
  Evaluatable->False,
  PageBreakAbove->False,
  CellTags->{"Minimization", "c:2"}],
Cell[2071, 66, 503, 11, 79, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2599, 81, 146, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:3"],
Cell[2748, 87, 2293, 53, 503, "Text",
  Evaluatable->False],
Cell[5044, 142, 85, 2, 45, "Input"],
Cell[5132, 146, 77, 2, 45, "Input"],
Cell[5212, 150, 78, 2, 45, "Input"],
Cell[5293, 154, 107, 2, 45, "Input"],
Cell[5403, 158, 69, 2, 45, "Input"],
Cell[5475, 162, 485, 15, 79, "Text",
  Evaluatable->False],
Cell[5963, 179, 92, 1, 45, "Input"],
Cell[6058, 182, 92, 2, 45, "Input"],

Cell[CellGroupData[{
Cell[6175, 188, 141, 4, 56, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:4"],
Cell[6319, 194, 679, 16, 116, "Text"],
Cell[7001, 212, 131, 3, 68, "Input"],
Cell[7135, 217, 193, 7, 41, "Text",
  Evaluatable->False],
Cell[7331, 226, 154, 3, 68, "Input"],
Cell[7488, 231, 122, 2, 41, "Text",
  Evaluatable->False],
Cell[7613, 235, 143, 3, 68, "Input"],
Cell[7759, 240, 141, 5, 41, "Text",
  Evaluatable->False],
Cell[7903, 247, 260, 5, 68, "Input"],
Cell[8166, 254, 144, 5, 41, "Text",
  Evaluatable->False],
Cell[8313, 261, 188, 3, 45, "Input"],
Cell[8504, 266, 102, 2, 41, "Text",
  Evaluatable->False],
Cell[8609, 270, 94, 2, 45, "Input"],
Cell[8706, 274, 220, 6, 60, "Text",
  Evaluatable->False],
Cell[8929, 282, 60, 2, 45, "Input"],
Cell[8992, 286, 189, 5, 114, "Input"],
Cell[9184, 293, 153, 5, 41, "Text",
  Evaluatable->False],
Cell[9340, 300, 241, 4, 91, "Input"],
Cell[9584, 306, 153, 5, 41, "Text",
  Evaluatable->False],
Cell[9740, 313, 222, 5, 91, "Input"],
Cell[9965, 320, 70, 2, 41, "Text",
  Evaluatable->False],
Cell[10038, 324, 295, 8, 122, "Text",
  Evaluatable->False],
Cell[10336, 334, 131, 3, 45, "Input"],
Cell[10470, 339, 166, 3, 68, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10685, 348, 150, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:5"],
Cell[10838, 354, 1472, 30, 379, "Text",
  Evaluatable->False],
Cell[12313, 386, 211, 5, 114, "Input"],
Cell[12527, 393, 142, 5, 41, "Text",
  Evaluatable->False],
Cell[12672, 400, 81, 2, 45, "Input"],
Cell[12756, 404, 195, 7, 41, "Text",
  Evaluatable->False],
Cell[12954, 413, 103, 2, 45, "Input"],
Cell[13060, 417, 108, 5, 72, "Text",
  Evaluatable->False],
Cell[13171, 424, 275, 7, 114, "Input"],
Cell[13449, 433, 69, 2, 45, "Input"],
Cell[13521, 437, 275, 6, 60, "Text",
  Evaluatable->False],
Cell[13799, 445, 277, 5, 114, "Input"],
Cell[14079, 452, 153, 3, 45, "Input"],
Cell[14235, 457, 140, 5, 41, "Text",
  Evaluatable->False],
Cell[14378, 464, 157, 3, 68, "Input"],
Cell[14538, 469, 85, 2, 45, "Input"],
Cell[14626, 473, 82, 2, 41, "Text",
  Evaluatable->False],
Cell[14711, 477, 76, 2, 45, "Input"],
Cell[14790, 481, 151, 5, 41, "Text",
  Evaluatable->False],
Cell[14944, 488, 153, 3, 45, "Input"],
Cell[15100, 493, 184, 3, 68, "Input"],
Cell[15287, 498, 287, 10, 60, "Text",
  Evaluatable->False],
Cell[15577, 510, 111, 3, 68, "Input"],
Cell[15691, 515, 898, 15, 217, "Text",
  Evaluatable->False],
Cell[16592, 532, 266, 7, 160, "Input"],
Cell[16861, 541, 120, 2, 41, "Text",
  Evaluatable->False],
Cell[16984, 545, 118, 2, 68, "Input"],
Cell[17105, 549, 319, 7, 79, "Text",
  Evaluatable->False],
Cell[17427, 558, 166, 3, 91, "Input"],
Cell[17596, 563, 247, 6, 60, "Text",
  Evaluatable->False],
Cell[17846, 571, 164, 4, 68, "Input"],
Cell[18013, 577, 81, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18131, 584, 156, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:6"],
Cell[18290, 590, 797, 13, 155, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19112, 607, 145, 4, 56, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:7"],
Cell[19260, 613, 1900, 49, 293, "Text",
  Evaluatable->False],
Cell[21163, 664, 86, 4, 84, "Input"],
Cell[21252, 670, 90, 1, 45, "Input"],
Cell[21345, 673, 46, 1, 45, "Input"],
Cell[21394, 676, 205, 6, 114, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21636, 687, 264, 8, 62, "Subsubsection",
  Evaluatable->False,
  CellTags->"c:8"],
Cell[21903, 697, 799, 17, 182, "Text",
  Evaluatable->False],
Cell[22705, 716, 150, 4, 68, "Input"],
Cell[22858, 722, 122, 3, 68, "Input"],
Cell[22983, 727, 219, 6, 72, "Text",
  Evaluatable->False],
Cell[23205, 735, 86, 1, 45, "Input"],
Cell[23294, 738, 68, 1, 45, "Input"],
Cell[23365, 741, 106, 2, 41, "Text",
  Evaluatable->False],
Cell[23474, 745, 81, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[23592, 752, 84, 1, 56, "Subsubsection"],
Cell[23679, 755, 70, 1, 45, "Input"],
Cell[23752, 758, 177, 5, 91, "Input"],
Cell[23932, 765, 175, 5, 68, "Input"],
Cell[24110, 772, 122, 3, 68, "Input"],
Cell[24235, 777, 94, 2, 45, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24378, 785, 148, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:9"],
Cell[24529, 791, 960, 21, 322, "Text",
  Evaluatable->False],
Cell[25492, 814, 87, 2, 45, "Input"],
Cell[25582, 818, 80, 2, 45, "Input"],
Cell[25665, 822, 103, 2, 45, "Input"],
Cell[25771, 826, 161, 5, 41, "Text",
  Evaluatable->False],
Cell[25935, 833, 120, 3, 68, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26092, 841, 165, 5, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:10"],

Cell[CellGroupData[{
Cell[26282, 850, 41, 0, 64, "Subsubsection"],
Cell[26326, 852, 2061, 52, 360, "Text",
  Evaluatable->False],
Cell[28390, 906, 147, 6, 124, "Input"],
Cell[28540, 914, 285, 10, 41, "Text",
  Evaluatable->False],
Cell[28828, 926, 329, 7, 160, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[29194, 938, 35, 0, 64, "Subsubsection"],
Cell[29232, 940, 794, 24, 98, "Text"],
Cell[30029, 966, 143, 4, 84, "Input"],
Cell[30175, 972, 105, 3, 44, "Input"],
Cell[30283, 977, 1544, 45, 253, "Text"],
Cell[31830, 1024, 37, 0, 44, "Input"],
Cell[31870, 1026, 65, 0, 44, "Input"],
Cell[31938, 1028, 379, 12, 91, "Text"],
Cell[32320, 1042, 65, 3, 64, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32434, 1051, 138, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:11"],
Cell[32575, 1057, 690, 18, 134, "Text"],
Cell[33268, 1077, 1338, 40, 147, "Text",
  Evaluatable->False],
Cell[34609, 1119, 310, 8, 91, "Input"],
Cell[34922, 1129, 112, 2, 45, "Input"],
Cell[35037, 1133, 66, 2, 45, "Input"],
Cell[35106, 1137, 141, 3, 68, "Input"],
Cell[35250, 1142, 73, 2, 45, "Input"],
Cell[35326, 1146, 143, 3, 68, "Input"],
Cell[35472, 1151, 97, 2, 45, "Input"],
Cell[35572, 1155, 78, 2, 45, "Input"],
Cell[35653, 1159, 103, 2, 45, "Input"],
Cell[35759, 1163, 103, 2, 45, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[35911, 1171, 130, 3, 75, "Section",
  Evaluatable->False,
  CellTags->{"Exponential blow-up", "c:12"}],
Cell[36044, 1176, 511, 13, 79, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[36580, 1193, 138, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:13"],
Cell[36721, 1199, 609, 17, 79, "Text",
  Evaluatable->False],
Cell[37333, 1218, 292, 7, 91, "Input"],
Cell[37628, 1227, 68, 2, 45, "Input"],
Cell[37699, 1231, 171, 3, 68, "Input"],
Cell[37873, 1236, 93, 2, 45, "Input"],
Cell[37969, 1240, 71, 1, 45, "Input"],
Cell[38043, 1243, 42, 1, 45, "Input"],
Cell[38088, 1246, 72, 1, 45, "Input"],
Cell[38163, 1249, 79, 2, 45, "Input"],
Cell[38245, 1253, 262, 6, 60, "Text",
  Evaluatable->False],
Cell[38510, 1261, 104, 2, 45, "Input"],
Cell[38617, 1265, 185, 5, 41, "Text",
  Evaluatable->False],
Cell[38805, 1272, 128, 3, 45, "Input"],
Cell[38936, 1277, 138, 5, 38, "Text",
  Evaluatable->False],
Cell[39077, 1284, 116, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39230, 1291, 142, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:14"],
Cell[39375, 1297, 763, 22, 98, "Text",
  Evaluatable->False],
Cell[40141, 1321, 173, 4, 68, "Input"],
Cell[40317, 1327, 66, 2, 45, "Input"],
Cell[40386, 1331, 106, 2, 45, "Input"],
Cell[40495, 1335, 378, 11, 72, "Text",
  Evaluatable->False],
Cell[40876, 1348, 89, 2, 45, "Input"],
Cell[40968, 1352, 78, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41083, 1359, 141, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:15"],
Cell[41227, 1365, 512, 11, 98, "Text",
  Evaluatable->False],
Cell[41742, 1378, 187, 5, 114, "Input"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

