(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     61472,       2149]*)
(*NotebookOutlinePosition[     64151,       2242]*)
(*  CellTagsIndexPosition[     63809,       2226]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\[Copyright] 1997-2002 K. Sutner ", "SmallText"],

Cell[BoxData[
    FormBox[
      StyleBox[\(Syntactic\ Semigroups\),
        FontFamily->"Charter"], TraditionalForm]], "Title"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Transformation\ Semigroups\)], "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`The\ Basics\)], "Subsection"],

Cell[TextData[{
  "A ",
  StyleBox["semigroup",
    FontColor->RGBColor[0, 0, 1]],
  " is a set together with an associative operation. If there is an identity \
element we have a ",
  StyleBox["monoid",
    FontColor->RGBColor[0, 0, 1]],
  ". A group is a monoid where every element has an inverse. One can show \
that every semigroup can already be represented as a set of maps   ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\  \[RightArrow] \ \([n]\)\)]],
  "   where the operation is composition of functions.  This corresponds to \
the well-known result that every group can be represented as a group of \
permutations. We will refer to such semigroups as ",
  StyleBox["transformation semigroups",
    FontColor->RGBColor[0, 0, 1]],
  ". The elements are transformations and are represented by terms of the \
form \n\t",
  Cell[BoxData[
      \(TraditionalForm\`T[\ a\_1, \ a\_2, \ \[Ellipsis], \ a\_n\ ]\)]],
  ".\nThus, 1 is mapped to ",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  ", 2 to ",
  Cell[BoxData[
      \(TraditionalForm\`a\_2\)]],
  " and so forth. Composition is implemented using ",
  StyleBox["NonCommutativeMultiply",
    FontFamily->"Courier"],
  ".  Note that  ",
  StyleBox["x**y",
    FontFamily->"Courier"],
  "  means: apply map ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " first, then apply map ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ".   "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(x = T[2, 3, 4, 5, 6, 1]\), "\n", 
    \(y = T[2, 2, 5, 6, 5, 6]\), "\n", 
    \(x ** y\), "\n", 
    \(y ** x\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Poducts of the same transformation can be expressed as powers. Note that \
in the example  ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ x\^7\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ColumnForm[x\^Range[0, 8]]\), "\n", 
    \(x === x\^7\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since transformations are maps  ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\  \[RightArrow] \ \([n]\)\)]],
  " we can associate a range and a kernel to each transformation. The \
cardinality of the range is the ",
  StyleBox["rank",
    FontColor->RGBColor[0, 0, 1]],
  " of the transformation. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(TableForm2 = \(Curry[TableForm]\)[TableDepth \[Rule] 2];\)\)], "Input"],

Cell[BoxData[{
    \(y\), "\n", 
    \(\(ker = KernelT[y];\)\), "\n", 
    \(\(im = ImageT[y];\)\), "\n", 
    \(TableForm2[Thread[{ker, im}]]\)}], "Input"],

Cell[TextData[{
  "Since lists are automatically ordered in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " we can reconstruct a transformation from its kernel and range."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KernelImageToT[ker, im]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A transformation ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " induces a map from the kernel classes to the kernel classes, or, by \
renumbering, a new transformation ",
  Cell[BoxData[
      \(TraditionalForm\`\([r]\)\  \[RightArrow] \ \([r]\)\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is the rank of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". This map is the collapse of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". In the next example, the collapse is a permutation. As a result, there \
is some exponent ",
  Cell[BoxData[
      \(TraditionalForm\`p > 1\)]],
  " such that  ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ x\^p\)]],
  " and the powers of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " form a group. The identity of this group is idempotent (i.e., ",
  Cell[BoxData[
      \(TraditionalForm\`e ** e == e\)]],
  ") and we can compute inverses."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(x = T[2, 3, 1, 8, 8, 5, 5, 5];\)\), "\n", 
    \(TableForm2[Thread[{ImageT[x], KernelT[x]}]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(kx = CollapseT[x]\), "\n", 
    \(OrderT[kx]\), "\n", 
    \(xx = InverseT[x]\), "\n", 
    \(e = x ** xx\), "\n", 
    \(e ** e\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Of course, in general the collapse fails to be a permutation. \
However, a sufficiently high power of any transformation always has a \
permutation as collapse. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(y = T[2, 3, 4, 5, 6, 7, 7]\), "\n", 
    \(ColumnForm[CollapseT /@ \(y\^Range[6]\)]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A semigroup ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is ",
  StyleBox["generated",
    FontColor->RGBColor[0, 0, 1]],
  " by some of its elements iff every element in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " can be written as a product of these elements (but not necessarily in a \
unique way). \n\nThe semigroup generated by any single element thus has the \
form of a lasso: there is a transient part that leads to a cycle. If the \
transient part has length 0 the transformation generates a group. In the \
other extreme, if the cycle has length 1, the transformation is said to be \
aperiodic. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(TransientPeriodicT[x]\), "\n", 
    \(TransientPeriodicT[y]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Graphically we can display the powers of transformations using the command \
",
  StyleBox["PlotT", "Commentary"],
  ". It is clear from the pictures that ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " is ",
  StyleBox["aperiodic: ",
    FontColor->RGBColor[0, 0, 1]],
  "for some exponent ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ":  ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(k + 1\) = \ x\^\(\(\ \)\(k\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotT[x];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotT[y];\)\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
The same analysis for a random transformation. Execute the next \
cell several times to see the various patterns. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(z = RandomT[12]\), "\n", 
    \(TableForm2[Thread[{KernelT[z], ImageT[z]}]]\), "\n", 
    \(TransientPeriodicT[z]\), "\n", 
    \(\(PlotT[z];\)\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Witnesses\ and\ Equations\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:4"],

Cell[TextData[{
  "The semigroup of all maps  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([\)\(n\)\(]\)\)\  \[RightArrow] \ \
\(\([\)\(n\)\(]\)\)\)]],
  "  is generated by the three transformations produced by commands ",
  StyleBox["RShiftT[n]", "SmallText"],
  ", ",
  StyleBox["TranspositionT[n]", "SmallText"],
  " and ",
  StyleBox["Merge12T[n]", "SmallText"],
  ". For example, for ",
  Cell[BoxData[
      \(TraditionalForm\`n\  = \ 8\)]],
  " these transformations are as follows:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[{RShiftT[8], TranspositionT[8], Merge12T[8]}]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`T\_n\)]],
  " has ",
  Cell[BoxData[
      \(TraditionalForm\`n\^n\)]],
  " elements we have to confine ourselves to a smaller example."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(T3 = TransformationSG[3]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since T3 contains the identity map ",
  Cell[BoxData[
      \(TraditionalForm\`T[1, 2, 3]\)]],
  " we have a monoid. There are 16 aperiodic elements in T3, 10 of which are \
idempotents. Three of them are right nulls (the constant functions ",
  Cell[BoxData[
      \(TraditionalForm\`T[i, i, i]\)]],
  "). 21 elements belong to a group in T3. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(aper = AperiodicSG[T3]\), "\n", 
    \(Length[aper]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(idem = IdemSG[T3]\), "\n", 
    \(Length[idem]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(null = RightNullSG[T3]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Length[IngroupSG[T3]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
We can verify that these transformations are indeed aperiodic and \
idempotent.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(aper\^3 === aper\^2\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(idem\ idem === idem\)], "Input",
  AspectRatioFixed->True],

Cell["The pictures for the aperiodic elements.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(gr = \(PlotT[#, 5, \ PlotStyle \[Rule] {0.04, 0.04}, 
              DisplayFunction \[Rule] Identity] &\) /@ aper;\)\)], "Input"],

Cell[BoxData[
    \(\(ShowArray[gr];\)\)], "Input",
  AspectRatioFixed->True],

Cell["Display[\"T3perm.gif\", %, \"GIF\", ImageSize->500 ]", "Input"],

Cell["Directory[]", "Input"],

Cell["\<\
The elements of rank 3 form a group, the symmetric group on three \
points. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(S3 = Select[T3, RankT[#1] == 3 &]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gr = \((PlotT[#1, PlotStyle \[Rule] {0.05, 0.05}, 
                DisplayFunction \[Rule] Identity] &)\) /@ 
          ToList[S3];\)\), "\n", 
    \(\(ShowArray[gr];\)\)}], "Input"],

Cell[TextData[{
  "If we associate the three generators with symbols ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", we can write each element in Tn as a word over ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c}\)]],
  ". The minimal such word (in the hierarchical order) is the witness for the \
transformation. As we will see later, it may be preferable to replace the \
semigroup elements by their witnesses. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({T3, W, eq} = 
        TransformationSG[3, Equations \[Rule] True];\)\), "\n", 
    \(TableForm[PrintWitnesses[T3, W]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The relations between these words are captured in the list of \
\"equations\" produced by the command ",
  StyleBox["GenerateSG", "SmallText"],
  ". For example, ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " corresponds to the idempotent element ",
  Cell[BoxData[
      \(TraditionalForm\`T[1, 1, 3]\)]],
  ", so there is an equation",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(c\ c\  = \ c\)\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintEquations[eq]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
By repeated application of these equations we can simplify any word \
to the corresponding witness. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReduce[caacbcaaca, eq, DoTrace \[Rule] True]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "One can also try to construct a semigroup from a set of equations. For \
example, over the alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{a}\)]],
  " the equation ",
  Cell[BoxData[
      \(TraditionalForm\`a\ a\ a\ a\  = \ a\)]],
  "  defines the semigroup  ",
  Cell[BoxData[
      \(TraditionalForm\`{a, a\ a, a\ a\ a}\)]],
  "  where the operation is concatenation and subsequent reduction according \
to the equation. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquationsToWitnesses[{{aaaa, a}}, {a}]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Command ",
  StyleBox["EquationsToWitnesses", "SmallText"],
  " has a default bound of 500 for the number of witnesses generated since \
there is no way of telling whether the corresponding semigroup is finite for \
larger alphabets. The bound can be changed by setting, say,  ",
  StyleBox["BoundETW->1000", "SmallText"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq = {{aaaaa, a}, {bbb, bb}, {ba, ab}};\)\), "\n", 
    \(S = EquationsToWitnesses[eq, {a, b}]\)}], "Input"],

Cell[BoxData[
    \(WordReduce[aaabbbaaabbb, eq]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We can translate ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " into a transformation semigroup by converting the the right translations  \
",
  Cell[BoxData[
      \(TraditionalForm\`x\  \[Rule] \ x\[VeryThinSpace]a\)]],
  "  and  ",
  Cell[BoxData[
      \(TraditionalForm\`x\  \[Rule] \ x\[VeryThinSpace]b\)]],
  "  into transformations:  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Ta = 
      T @@ PositionList[
          S, \((WordReduce[Concatenate[#1, a], eq] &)\) /@ S]\), "\n", 
    \(Tb = 
      T @@ PositionList[
          S, \((WordReduce[Concatenate[#1, b], eq] &)\) /@ S]\)}], "Input"],

Cell[BoxData[{
    \(\({SS, W, eq} = 
        GenerateSG[GEN[14, 2, {Ta, Tb}], Equations \[Rule] True];\)\), "\n", 
    \(Length[SS]\), "\n", 
    \(S === W\), "\n", 
    \(TableForm[PrintWitnesses[SS, W]]\)}], "Input"],

Cell[BoxData[
    \(PrintEquations[eq]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Voila, the same equations that we started out from.

Here is an example of a set of equations that do not produce a finite \
semigroup. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq = {{aaaa, 1}, {bbb, bb}, {bbaa, 1}}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquationsToWitnesses[eq, {a, b}, BoundETW \[Rule] 100]\)], "Input",
  AspectRatioFixed->True],

Cell["Add some more equations:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquationsToWitnesses[
      Join[eq, {{baab, a}, {baba, bb}, {bbabb, bb}}], {a, b}, 
      BoundETW \[Rule] 100]\)], "Input"],

Cell[TextData[{
  "Still no good, all words in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((baaa)\)\^*\)\)]],
  " are still irreducible.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquationsToWitnesses[
      Join[eq, {{baab, a}, {baba, bb}, {bbabb, bb}, {baaa, a}}], {a, b}, 
      BoundETW \[Rule] 100]\)], "Input"],

Cell["That looks more promising. Let's increase the bound. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquationsToWitnesses[
      Join[eq, {{baab, a}, {baba, bb}, {bbabb, bb}, {baaa, a}}], {a, b}, 
      BoundETW \[Rule] 500]\)], "Input"],

Cell["\<\
Same as before. Hence our equations really define a finite \
semigroup. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Syntactic\ Semigroups\)], "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Syntactic semigroups", "c:5"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Transformation\ Semigroups\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:6"],

Cell[TextData[{
  "A deterministic finite automaton over state set ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " and alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " essentially consists of a collection of transition functions\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_s\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(\(:\)\(\ \)\(Q\ \[LongRightArrow]
          Q\)\)\)\)]],
  "\nfor ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " any symbol in alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ". These functions generate a finite semigroup. In particular for  ",
  Cell[BoxData[
      \(TraditionalForm\`Q\  = \ \([n]\)\)]],
  "  we can express a transition function  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_s\)]],
  StyleBox["  ",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  "as a transformation \n      ",
  Cell[BoxData[
      \(TraditionalForm\`T\_s = 
        T[\[Tau]\_s[1], \[Tau]\_s[2],  .. , \[Tau]\_s[n]]\)]],
  ".\nThe semigroup generated by the transformations ",
  Cell[BoxData[
      \(TraditionalForm\`T\_s\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`s\  \[Element] \ K\)]],
  ", is the transition semigroup of the automaton. If we start from the \
minimal automaton, we obtain the syntactic semigroup of the corresponding \
language. There is a natural homomorphism\n\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`f\  : \ 
        K\^\(\(\ \)\(*\)\)\[LongRightArrow]\ \ S\)]],
  StyleBox["\n",
    FontFamily->"Symbol"],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is the syntactic semigroup of the machine. ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " induces a congruence relation on the monoid of all words under \
concatentation, the syntactic congruence of the corresponding language. Since \
",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is epi, ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is isomorphic to ",
  Cell[BoxData[
      \(TraditionalForm\`K\^\(\(\ \)\(*\)\)\)]],
  " modulo this congruence. \nWe now give a few examples that show how to \
compute (the and in the) syntactic semigroup. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Finite\ Cofinite\ Languages\)], "Subsection"],

Cell[TextData[{
  "Consider the following cofinite language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ":\n       ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\)\(\ \)\(=\)\(\ \)\)\)]],
  "all words over ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " of length different from 3.\nWe construct a DFA for ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " by taking the complement of a machine recognizing all words of length \
exactly 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(m = ComplementFA[BuildDFA[Words[3, {a, b}], {a, b}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(L = LanguageFA[m, \(-5\)];\)\), "\n", 
    \(EnumForm0[L]\)}], "Input"],

Cell["The DFA  m is already minimal:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Size[MinimizeFA[m]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Hence we can compute the syntactic semigroup of L as follows.\
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(gen = ToGeneratorsFA[m]\), "\n", 
    \(S = GenerateSG[gen]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is a finite complement language, S must contain a null (state 5 is a trap \
in m):"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(NullSG[S]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Indeed, ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is ",
  StyleBox["nilpotent",
    FontColor->RGBColor[0, 0, 1]],
  ": there are no idempotents other than the null (which is no surprise since \
Nil is the variety corresponding exactly to finite-cofinite languages)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(NilpotentQSG[S]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We recompute ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " together with a list of witnesses and equations. Since the acceptance \
language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is defined solely in terms of the lengths of words we get an equation ",
  Cell[BoxData[
      \(TraditionalForm\`a\  = \ b\)]],
  "  (both symbols induce the same transition behavior) and",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(a\^\(\(\ \)\(5\)\)\  = \ 
        a\^\(\(\ \)\(4\)\)\)\)\)]],
  ",  since all words of length at least 4 are indistinguishable in m. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({S, W, eq} = GenerateSG[gen, Equations \[Rule] True];\)\), "\n", 
    \(TableForm[PrintWitnesses[S, W]]\)}], "Input"],

Cell[BoxData[
    \(PrintEquations[eq]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReduce[RandomWord[10, {a, b}], eq]\)], "Input",
  AspectRatioFixed->True],

Cell["Here are the reductions for all words up to length 4.", "Text"],

Cell[BoxData[
    \(Union[\((WordReduce[#1, eq] &)\) /@ Words[\(-4\), {a, b}]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Next we procuce the syntactic homomorphismfor ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SyntacticHomomorphism[f, m]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(f[aba]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is now defined on all words over ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " and has attribute ",
  StyleBox["Listable", "Commentary"],
  ". To get all values ",
  Cell[BoxData[
      \(TraditionalForm\`f[w]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " up to length 4 we compute:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Union[f[Words[\(-5\), {a, b}]]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the identity map is not in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " since ",
  StyleBox["GenerateSG", "SmallText"],
  " produces the syntactic semigroup rather than the syntactic monoid (unless \
option ",
  StyleBox["Full->True", "SmallText"],
  " is set). \nIn our example, any two words of length 3 should be equivalent \
with respect to the synctactic congruence induced by ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(theta[x_, y_] := f[x] === f[y];\)\), "\n", 
    \(\((theta[RandomWord[3, {a, b}], RandomWord[3, {a, b}]] &)\) /@ 
      Range[10]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The equivalence classes of theta on words up to some length can be \
generated with the command  SyntacticCongruence. To classify all words up to \
length 5 type:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cong = SyntacticCongruence[m, \(-5\)];\)\), "\n", 
    \(ColumnForm[cong]\)}], "Input",
  AspectRatioFixed->True],

Cell["f is constant on each class.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Union[f[cong\[LeftDoubleBracket]4\[RightDoubleBracket]]]\), "\n", 
    \(Union[f[cong\[LeftDoubleBracket]5\[RightDoubleBracket]]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Another way to obtain witnesses is to pick one word (say, the \
length-lex first) in each equivalence class of theta. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(W\), "\n", 
    \(First /@ cong\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since theta saturates ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " we can write ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " as a union of some of the classes of theta: "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(congL = Select[cong, MemberQ[Flatten[L], First[#]] &]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Union[Flatten[L]] === Union[Flatten[congL]]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Mod - Counters\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:8"],

Cell["\<\
Below we define m5 to be the minimal automaton for words over \
alphabet {a,b,c} containing a number of b's that is congruent 0 modulo 5. As \
in the last section, we compute the syntactic semigroup (which turns out to \
be a group in this case) and  the syntactic congruence.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m5 = ModCounterDFA[b, 0, 5, {a, b, c}];\)\), "\n", 
    \(\({S5, wit, eqn} = SyntacticSG[m5, Equations \[Rule] True];\)\), "\n", 
    \(ColumnForm[S5]\)}], "Input"],

Cell[BoxData[
    \(InGroupSG[S5]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
There is exactly one idempotent element in S5, namely the unit \
element.  Its H-class is the whole group. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(IdemSG[S5]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(HClassT[OneT[5], S5]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[PrintWitnesses[S5, wit]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
From the equations we see that inputs a and c are ignored and b's \
are counted modulo 5, as expected. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[PrintEquations[eqn, Algebraic \[Rule] True]]\)], "Input",
  AspectRatioFixed->True],

Cell["This becomes clear when the equations are simplified.", "Text"],

Cell[BoxData[
    \(PrintEquations[SimplifyEquations[S5, wit, eqn]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`i - th\ Symbol\ from\ the\ end\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:9"],

Cell[TextData[{
  "For the next example let us again consider all words that have a symbol ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " in position ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\)\)]],
  ". "
}], "Text"],

Cell[BoxData[{
    \(\(Mb3 = ToDFA[IthSymbolFA[b, \(-3\), {a, b}]];\)\), "\n", 
    \(\({S, wit, eqn} = SyntacticSG[Mb3, Equations \[Rule] True];\)\), "\n", 
    \(Length[S]\), "\n", 
    \(ColumnForm[S]\)}], "Input"],

Cell[TextData[{
  "Thus, the syntactic monoid has size 14 and contains all the constant \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`T[i, i,  ... , i]\)]],
  ". The constants are exactly the idempotents in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", or, equivalently, the right nulls in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(idem = IdemSG[S]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(RightNullSG[S] == idem\)], "Input"],

Cell["\<\
To see where these constant functions come from let us generate the \
corresponding witnesses.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[PrintWitnesses[S, wit]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus, for all words ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " of length at least 3 the syntactic homomorphism ",
  Cell[BoxData[
      \(TraditionalForm\`f[w]\)]],
  " is a constant function. More precisely, ",
  Cell[BoxData[
      \(TraditionalForm\`f[w]\  = \ f[u]\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is the suffix of ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " of length 3. Hence the transition function ",
  Cell[BoxData[
      \(TraditionalForm\`delta\)]],
  " of Mb3 has the property that, say,  ",
  Cell[BoxData[
      \(TraditionalForm\`delta[p, aaa]\  = \ 1\)]],
  "  for all states ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ". Indeed, the machine can be reset into any state ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " by a suitable input ",
  Cell[BoxData[
      \(TraditionalForm\`w\  = \ w \((q)\)\)]],
  " of length 3, regardless of the current state. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(TransitionFunctionFA[Mb3, del, Full \[Rule] True];\)\), "\n", 
    \(ColumnForm[\((del[#1, aaa] &)\) /@ Range[8]]\)}], "Input"],

Cell["\<\
If you have the experimental code package loaded, you can check \
this property directly. \
\>", "Text"],

Cell[BoxData[
    \(DefiniteQFA[Mb3]\)], "Input"],

Cell["\<\
This effect is also visible in the defining equations for the \
syntactic monoid. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintEquations[eqn]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Plainly, ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " must be aperiodic."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(AperiodicQSG[S]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "More convincing is perhaps a plot of the transformations in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ". The following pictures show the first 5 powers of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " for each ",
  Cell[BoxData[
      \(TraditionalForm\`t\  \[Element] \ S\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(pt\  = \(PlotT[#, 5, 
              PlotStyle \[Rule] {0.04, 
                  0.04}, \[IndentingNewLine]DisplayFunction \[Rule] 
                Identity] &\) /@ ToList[S];\)\), "\n", 
    \(\(ShowArray[pt];\)\)}], "Input"],

Cell[TextData[{
  "The only regular D-class in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " consists of the right nulls in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(dc = DClassDecomposition[S];\)\), "\n", 
    \(ColumnForm[DClassDimensions[dc]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(DClassToBlocks[dc\[LeftDoubleBracket]1\[RightDoubleBracket]]\)], "Input",\

  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Counting\ Subwords\ mod\ p\ and\ p - 
      Groups\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"Subword counter", "c:10"}],

Cell[TextData[{
  "The command ",
  StyleBox["SubwordCounterDFA[w,p,K]", "Commentary"],
  " constructs a DFA for the language \t\n\t",
  Cell[BoxData[
      \(TraditionalForm\`L(w, 
          p)\ \  = \ \ {\ \ \ x\ \  | \ \ WordBinomial[x, 
                w]\ \  = \ \ p\ }\)]],
  ".\nSimilarly, command SubwordModCounterDFA[w,r,p,K] builds a DFA for \n\t\
",
  Cell[BoxData[
      \(TraditionalForm\`L(w, r, 
          p)\ \  = \ \ {\ \ \ x\ \  | \ \ WordBinomial[x, 
                w]\ \  = \ \ r\ mod\ p\ }\)]],
  ".\nNote that the number of states in the DFA for ",
  Cell[BoxData[
      \(TraditionalForm\`L(w, p)\)]],
  " is bounded by ",
  Cell[BoxData[
      \(TraditionalForm\`\((p + 2)\)\^\(\(|\)\(w\)\(|\)\)\)]],
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  " and in the machine for ",
  Cell[BoxData[
      \(TraditionalForm\`L(w, r, p)\)]],
  " by  ",
  Cell[BoxData[
      \(TraditionalForm\`p\^\(\(|\)\(w\)\(|\)\)\)]],
  ". Option ",
  StyleBox["Normalize->1", "Commentary"],
  " preserves the states as length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\)\)]],
  " vectors over ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1,  .. , p, p + 1}\)]],
  "  (",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1,  .. , p - 1}\)]],
  ", respectively). Generating a trace of a computation shows how the \
components of the state vector are updated. \n"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m = 
        SubwordCounterDFA[abab, 3, {a, b}, Normalize \[Rule] 1];\)\), "\n", 
    \(Size[m]\), "\n", 
    \(States[m]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(w = bbaababbbb;\)\), "\n", 
    \(TableForm[AcceptQFA[m, w, DoTrace \[Rule] True]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nLet us take a closer look at the language  ",
  Cell[BoxData[
      \(TraditionalForm\`L(a\[VeryThinSpace]b, 2)\)]],
  ":"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(m0 = SubwordCounterDFA[ab, 2, {a, b}, Normalize \[Rule] 1]\)], "Input",
  AspectRatioFixed->True],

Cell["We minimize and generate a few words in the language. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m1 = MinimizeFA[m0, Normalize \[Rule] 2];\)\), "\n", 
    \(\(L = LanguageFA[m1, \(-6\)];\)\), "\n", 
    \(ColumnForm[L]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "It looks like   ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\^*\)\ {\ a\[VeryThinSpace]a\[VeryThinSpace]b, \ 
            a\[VeryThinSpace]b\[VeryThinSpace]b\ }\ \(a\^*\)\ \  = \ \ L(
          a\[VeryThinSpace]b, 2)\)]],
  ". We can verify this guess as follows:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(mm = 
        BuildDFA[
          L\[LeftDoubleBracket]4\[RightDoubleBracket], {a, b}];\)\), "\n", 
    \(\(ma = BuildStarDFA[a, {a, b}];\)\), "\n", 
    \(\(mb = BuildStarDFA[b, {a, b}];\)\), "\n", 
    \(\(mmm = ToDFA[ConcatenateFA[mb, mm, ma]];\)\), "\n", 
    \(EquivalentQFA[m1, mmm]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
It is interesting to take a closer look at the state set of \
m1.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[States[m1]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the only input words that leave machine ",
  Cell[BoxData[
      \(TraditionalForm\`m0\)]],
  " in state ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 1}\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{2, 0}\)]],
  ", respectively, are 'ab' and 'aa'. Both lead to state 3 in ",
  Cell[BoxData[
      \(TraditionalForm\`m1\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[\((WordBinomial[#1, ab, DoTrace \[Rule] True] &)\) /@ {ab, 
          aa}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[\((AcceptQFA[m1, #1, DoTrace \[Rule] True] &)\) /@ {ab, 
          aa}]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
We can use the frontier construction to check that 'ab' and 'aa' \
indeed lead to the same state in m1. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({fr, F} = ToFrontierDFA[m1];\)\), "\n", 
    \(TableForm[{fr, F}]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
All the four letter inputs in the frontier except the third lead to \
the trap state in m2.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(W = Drop[First /@ fr, 2];\)\), "\n", 
    \(ColumnForm[
      Last /@ \(\((AcceptQFA[m1, #1, DoTrace \[Rule] True] &)\) /@ 
          W\)]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "One can show that languages of the form ",
  Cell[BoxData[
      \(TraditionalForm\`L(w, k)\)]],
  " are piecewise testable. To see this note that  ",
  Cell[BoxData[
      \(TraditionalForm\`L(w, k)\  = \ 
        L(w, \(\(\[GreaterEqual]\)\(k\)\))\ \  - \ \ L(
            w, \(\(>\)\(k\)\))\)]],
  ".  Any language of the form ",
  Cell[BoxData[
      \(TraditionalForm\`L(w, \(\(>\)\(i\)\))\)]],
  " is upward closed with respect to subwords. Since any set of pairwise \
incomparable words must be finite, the language ",
  Cell[BoxData[
      \(TraditionalForm\`L(w, i)\)]],
  " can be written as a finite union of languages ",
  Cell[BoxData[
      \(TraditionalForm\`L(u, 1)\)]],
  " (all words ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " containing at least one subword ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  "). Hence ",
  Cell[BoxData[
      \(TraditionalForm\`L(w, k)\)]],
  " is in the boolean algebra generated by these languages. As a consequence, \
the syntactic semigroup of ",
  Cell[BoxData[
      \(TraditionalForm\`L(w, k)\)]],
  " must be ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  "-trivial. \n"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({S, wit, eq} = SyntacticSG[m1, Equations \[Rule] True];\)\), "\n", 
    \(\(eq = SimplifyEquations[S, wit, eq];\)\), "\n", 
    \(PrintEquations[eq]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReduce[bbbbabbaaaa, eq, DoTrace \[Rule] True]\)], "Input",
  AspectRatioFixed->True],

Cell["The three regular D-classes consist of one idempotent each.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(dc = DClassDecomposition[S];\)\), "\n", 
    \(ColumnForm[DClassDimensions[dc]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[DClassToBlocks[dc]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nHere is an example for a machine counting subwords modulo ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ". We construct  m5 to be the minimal automaton for ",
  Cell[BoxData[
      \(TraditionalForm\`L(a\[VeryThinSpace]b, 0, 5)\)]],
  " over alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m5 = MinimizeFA[SubwordModCounterDFA[ab, 0, 5, {a, b}]];\)\), "\n", 
    \(Size[m5]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(L7 = LanguageFA[m5, 7]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((WordBinomial[#1, ab] &)\) /@ L7\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({S5, wit, eqn} = SyntacticSG[m5, Equations \[Rule] True];\)\), "\n", 
    \(Length[S5]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "By a theorem by Eilenberg and Sh\[UDoubleDot]tzenberger the boolean \
algebra generated by the languages ",
  Cell[BoxData[
      \(TraditionalForm\`L \((w, r, p)\)\)]],
  " corresponds to the variety of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "-groups. \nThus, ",
  Cell[BoxData[
      \(TraditionalForm\`S5\)]],
  " should be a group. Indeed, ",
  Cell[BoxData[
      \(TraditionalForm\`S5\)]],
  " is a subgroup of ",
  Cell[BoxData[
      \(TraditionalForm\`S \((25)\)\)]],
  ", the full symmetric group on 25 elements. The most efficient way to \
establish this is to check that the generators of ",
  Cell[BoxData[
      \(TraditionalForm\`S5\)]],
  " are bijections. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Alternatively we can generate the ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  "-class of any element in S5 and verify that it is the whole semigroup. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(hc = 
        HClassT[S5\[LeftDoubleBracket]17\[RightDoubleBracket], 
          S5];\)\), "\n", 
    \(Length[hc]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the defining equations for S5 have the following property. \nLet \
  \n\t",
  Cell[BoxData[
      \(TraditionalForm\`t(
          w)\ \  := \ \ \(\(|\)\(w\)\(|\)\(\ \ \)\(\(+\ \ WordBinomial[w, 
                ab]\)\ \ \ mod\ 5\)\)\)]],
  ". \nThen  for any equation  ",
  Cell[BoxData[
      \(TraditionalForm\`u\  = \ v\)]],
  "   we have  ",
  Cell[BoxData[
      \(TraditionalForm\`t(u)\  = \ t(v)\)]],
  ".  Other than the trivial equations ",
  Cell[BoxData[
      \(TraditionalForm\`aaaaa\  = \ 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`bbbbb\  = \ 1\)]],
  "  it is rather tedious to find such relations by hand. Here are the \
defining relations for S5: "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintEquations[eqn]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "If you have access to the external automata code, all these computations \
can be done quickly in one call. The ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  "-class decomposition show that there is only on ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  "-class, namely the whole (semi-)group."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({S, wit, eq, dc} = 
        SyntacticSG[m5, DClasses \[Rule] True];\)\), "\n", 
    \(Length[S]\), "\n", 
    \(DClassDimensions[dc]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Star - free\ Languages\)], "Subsection"],

Cell[TextData[{
  "By a theorem of Schutzenberger the syntactic monoid of a regular language \
is aperiodic iff the language is star-free. The former condition can be \
tested using the command ",
  StyleBox["AperiodicQSG", "SmallText"],
  ".\n\naperiodic:  ",
  Cell[BoxData[
      \(TraditionalForm\`x\^n = x\^\(n + 1\)\)]],
  "\nstar-free:  closure of finite under concatenation and boolean \
operations. \nextended star height:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`h(0)\  = \ \(h(a)\ \  = \ 0\)\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`h(X + Y)\  = \ \(h(X\[VeryThinSpace]Y)\  = \ 
          max[\ h(X), \ h(Y)\ ]\)\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`h(\(A\^*\) - X)\  = \ h(X)\)]],
  "\n \t",
  Cell[BoxData[
      \(TraditionalForm\`h(\(X\^*\))\  = \ \(\(h(
            X)\)\(\ \)\(+\)\(\ \)\(1\)\(\ \ \)\)\)]],
  "  \n",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " star-free  iff  ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " has extended star height 0.\nWe will see that the following language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is star-free, though this fact is less than obvious from the rational \
expression that defines it:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\ \  = \ \ \(\((\ ab\  + \ ba\ )\)\^*\)\)]],
  ".\nWe compute the minimal automaton for L, the syntactic semigroup and the \
defining relations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m=MinimizeFA[RegularExpressionToFA[RES[ab+ba],{a,b}]];
{S,wit,eqn}=SyntacticSG[m,Equations\[Rule]True];
Length[S]
TableForm[PrintWitnesses[S,wit]]\
\>", "Input"],

Cell[BoxData[
    \(idem = IdemSG[S]\)], "Input",
  AspectRatioFixed->True],

Cell["The constant function with witness 'aaa' is a null in S. ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(NullSG[S]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(dc = DClassDecomposition[S];\)\), "\n", 
    \(ColumnForm[DClassDimensions[dc]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To display the ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  "-classes as a set of words rather than their images in the syntactic \
semigroup we can use the list of witnesses produced by command ",
  StyleBox["SyntacticSG", "SmallText"],
  ". \nNote that the order of ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  "-classes as well as their internal order depends on the algorithm used to \
generate them.  The following commands a appropriate for the output generated \
by the external code, you may have to adjust them slightly for the internal \
code. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(AssignFunction[h, ToList[S], wit];\)\), "\n", 
    \(\(SetAttributes[h, Listable];\)\)}], "Input"],

Cell[TextData[{
  "Pick the ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  "-class with dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`3\[Cross]3\[Cross]1\)]],
  " and display it in witness form. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(D2 = 
      ToList[DClassToBlocks[
          dc\[LeftDoubleBracket]2\[RightDoubleBracket]]]\), "\n", 
    \(MatrixForm[h[D2]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To transform the first row into the third we can use the following \
left multipliers:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(h[SolveLeft[T[1, 3, 3, 3], T[3, 1, 3, 3], S]]\), "\n", 
    \(h[SolveLeft[T[2, 3, 3, 3], T[3, 2, 3, 3], S]]\), "\n", 
    \(h[SolveLeft[T[4, 3, 3, 3], T[3, 4, 3, 3], S]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To see that both `b' and `bba' work properly we have to consider \
the defining relations for S.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintEquations[eqn]\)], "Input",
  AspectRatioFixed->True],

Cell["Thus, for example,  ", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReduce[babba, eqn]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
For the opposite direction, multiply by `a' or `baa' on the left:\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(h[SolveLeft[T[3, 1, 3, 3], T[1, 3, 3, 3], S]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReduce[baabba, eqn]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Similarly, multiplication by 'a' on the right transforms column \
three into column one and so on. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The command ",
  StyleBox["AperiodicQSG", "SmallText"],
  " tests whether a given semigroup is aperiodic. It  also accepts a list of \
generators for the semigroup as input. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(gen = ToGeneratorsFA[m];\)\), "\n", 
    \(AperiodicQSG[GenerateSG[gen]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nAs an example for a language that fails to be aperiodic let us return to \
the even-even language over alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " from above.  As we have seen, the product machine of two mod-counters is \
the minimal automaton. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(M = 
        IntersectionFA[ModCounterDFA[a, 0, 2, {a, b}], 
          ModCounterDFA[b, 0, 2, {a, b}]];\)\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Let us compute an initial segment of the syntactic congruence \
relation. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cong = LanguageSort[SyntacticCongruence[M, \(-5\)]];\)\), "\n", 
    \(ColumnForm[cong]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\({\[Epsilon], "aa", "bb", "aaaa", "aabb", "abab", "abba", "baab", 
              "baba", "bbaa", "bbbb"}\)},
          {\({"a", "aaa", "abb", "bab", "bba", "aaaaa", "aaabb", "aabab", 
              "aabba", "abaab", "ababa", "abbaa", "abbbb", "baaab", "baaba", 
              "babaa", "babbb", "bbaaa", "bbabb", "bbbab", "bbbba"}\)},
          {\({"b", "aab", "aba", "baa", "bbb", "aaaab", "aaaba", "aabaa", 
              "aabbb", "abaaa", "ababb", "abbab", "abbba", "baaaa", "baabb", 
              "babab", "babba", "bbaab", "bbaba", "bbbaa", "bbbbb"}\)},
          {\({"ab", "ba", "aaab", "aaba", "abaa", "abbb", "baaa", "babb", 
              "bbab", "bbba"}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{\[Epsilon], "aa", "bb", "aaaa", "aabb", "abab", "abba", 
        "baab", "baba", "bbaa", "bbbb"}, {"a", "aaa", "abb", "bab", "bba", 
        "aaaaa", "aaabb", "aabab", "aabba", "abaab", "ababa", "abbaa", 
        "abbbb", "baaab", "baaba", "babaa", "babbb", "bbaaa", "bbabb", 
        "bbbab", "bbbba"}, {"b", "aab", "aba", "baa", "bbb", "aaaab", "aaaba",
         "aabaa", "aabbb", "abaaa", "ababb", "abbab", "abbba", "baaaa", 
        "baabb", "babab", "babba", "bbaab", "bbaba", "bbbaa", "bbbbb"}, {"ab",
         "ba", "aaab", "aaba", "abaa", "abbb", "baaa", "babb", "bbab", 
        "bbba"}}],
      Editable->False]], "Output"]
}, Closed]],

Cell["\<\

The congruence classes are determined by the parity of the words.\
\>", "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(parikh[w_] := \((Mod[#1, 2] &)\) /@ 
          ParikhVector[w, {a, b}];\)\), "\n", 
    \(ColumnForm[Union /@ Map[parikh, cong, {2}]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Correspondingly, the syntactic monoid has exactly four \
elements.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({S, wit, eqn} = SyntacticSG[M, Equations \[Rule] True];\)\), "\n", 
    \(ColumnForm[S]\)}], "Input"],

Cell[TextData[{
  "Semigroup ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " really is a group. Proof by pictures:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ShowArray[\((PlotT[#1, 6, PlotStyle \[Rule] {0.04, 0.04}, 
                DisplayFunction \[Rule] Identity] &)\) /@ 
          ToList[S]];\)\)], "Input"],

Cell[TextData[{
  "Or we might compute the ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  "-class of some element in ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(HClassT[S\[LeftDoubleBracket]1\[RightDoubleBracket], S]\)], "Input",
  AspectRatioFixed->True],

Cell["Here are the witnesses:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[PrintWitnesses[S, wit]]\)], "Input",
  AspectRatioFixed->True],

Cell["And the defining equations.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintEquations[eqn]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Hence the syntactic semigroup S is a nontrivial abelian group and \
therefore fails to be aperiodic. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(AperiodicQSG[S]\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`The\ Tropical\ Semiring\ and\ FPP\)], "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->{"FPP", "c:12"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Starheight\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:13"],

Cell[TextData[{
  "The star height of a regular expression is inductively defined by:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`h(0) = \ \(h(a)\ \  = \ 0\)\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`h(X + Y) = \ \(h(X\ Y)\  = \ 
          max[\ h(X), \ h(Y)\ ]\)\)]],
  "\n\t",
  Cell[BoxData[
      \(TraditionalForm\`h(X\^\(\(\ \)\(*\)\)) = \ h(X)\  + \ 1\)]],
  ".\nThe star height of a regular language is the minimal starheight of any \
regular expression denoting it.  By a theorem of Hashiguchi the star-height \
of a regular language is computable. \nConsider again the language \n\t",
  Cell[BoxData[
      \(TraditionalForm\`L\ \  = \ \ \(\((\ 
              aa\  + \ bb\  + \ \((ab\  + \ 
                      ba)\) \(\((aa\  + \ bb)\)\^*\) \((ab\  + \ 
                      ba)\)\ )\)\^*\)\)]],
  "\nof all words containing an even number of a's and b's.   Intuitively it \
is clear that ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " has star height 2.           \nClosely related to star height is the \
finite power property (fpp): X has the fpp iff\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(X\^*\)\ \  = \ \ \(1\  + \ X\  + \ 
              X\^2\  + \  .. \)\  + \ X\^n\)]],
  "    \nfor some ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ".  To test whether a language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " has fpp one first constructs the minimal automaton ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is converted into an automaton ",
  Cell[BoxData[
      \(TraditionalForm\`M\^\(\(\ \)\(*\)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`L\^\(\(\ \)\(*\)\)\)]],
  ", called the loop automaton of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ".  The automaton ",
  Cell[BoxData[
      \(TraditionalForm\`M\^\(\(\ \)\(*\)\)\)]],
  " is then translated into a collection of transition matrices ",
  Cell[BoxData[
      \(TraditionalForm\`T\_s\)]],
  " over the tropical semiring, ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " a symbol . By a theorem of I. Simon, ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " has fpp iff the monoid generated by these matrices is finite. The latter \
property is decidable. \nThe loop automaton for is constructed from an FA for \
",
  Cell[BoxData[
      \(TraditionalForm\`L\  - \ {\[Epsilon]}\)]],
  " with single initial and final state by merging these two states.\n\
Tropical semiring:\n\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalN]\  \[Union] \ \
{\[Infinity]}\)]],
  "\n\t+:    Min\n\t",
  Cell[BoxData[
      \(TraditionalForm\`*\)]],
  ":    Plus\n    \nUnfortunately, both algorithms are as yet not implemented \
in our package. \nHowever, we can give a little example of a regular language \
with fpp at least to the point of generating the monoid ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]T\_a, \ 
        T\_\(\(b\)\(\ \ \)\)\[RightAngleBracket]\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"Example", ":", " ", Cell[TextData[{
          "L = ",
          Cell[BoxData[
              \(TraditionalForm\`a\^\(\(\ \)\(*\)\)\  + \ \(\((a + 
                          b)\)\^*\)\ b\)]]
        }]], " "}], TraditionalForm]], "Subsubsection"],

Cell["\<\
First we construct the minimal automaton m for L and the \
corresponding loop automaton mloop. We add an additional state q to m1 and \
add transitions to the initial state and from the final states. This machine \
is the loop automaton of m and accepts L*.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m = MinimizeFA[RegularExpressionToFA[RES[a]+RES[a+b]**b,{a,b}]];
PrintFA[m]\
\>", "Input"],

Cell[BoxData[{
    \(\(mloop = LoopAutomatonFA[ToFA[m]];\)\), "\n", 
    \(PrintFA[mloop]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquivalentQFA[StarFA[m], mloop]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
We are interested in paths from the intial state 1 to a final \
state, i.e., to state 1 or 2, that use the new state q=4 as infrequently as \
possible. For input bbaabaa for example we have to enter state 4 at least \
twice (corresponding to factorization (bbaab,aa)). \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PlotComputationFA[mloop, bbaabaa];\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Next we generate the natural homomorphism\n\t",
  Cell[BoxData[
      \(TraditionalForm\`f\  : \ \ \(A\^*\)\ \[LongRightArrow]\ Q\[Cross]
          Q\ \[LongRightArrow]\ \[DoubleStruckCapitalN]\_\[Infinity]\)]],
  "\nof matrices over the tropical semiring induced by the loop automaton  \
mloop. The homomorphism f is induced by the two matrices f[a] and f[b]. \
Matrix f[s] assigns cost 0 to all transitions with label s not involving the \
new state q, cost 1 to transitions leading into q and cost Infinity to any \
pair of states without a transition labeled s between them.   The matrices \
are generated using option Tropical->True in command TransitionMatrix.     "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(TransitionMatrixFA[mloop, f, Type \[Rule] Tropical];\)\), "\n", 
    \(\(gen = {f[a], f[b]};\)\), "\n", 
    \(MatrixForm /@ gen\)}], "Input"],

Cell["\<\
Thus all transitions ending at state 4 carry a penalty of 1 unit. \
We compute all products of these matrices up to length 3 .\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(p3 = Union[f /@ Words[\(-3\), {a, b}]];\)\), "\n", 
    \(Length[p3]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(MatrixForm /@ p3\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
It seems that <gen> is indeed a finite semigroup. As we will see, \
<gen> has exactly three elements (one of the matrices in p3 is f[Eps] = \
Id[4]). Note that the next command would crash the system if <gen> were \
infinite --- this is not a decision algorithm. (Actually, the computation \
would stop once BoundGSG elements have been generated in which case the \
result would be inconclusive.) Command GenerateSG applies to all matrices \
over semirings as long as the semiring operations are defined in terms of  \
Plus and Times. 
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({MS, wit, eq} = 
        GenerateSG[GEN[4, 2, gen], Equations \[Rule] True];\)\), "\n", 
    \(Length[MS]\), "\n", 
    \(Union[Flatten[ToList[MS]]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Thus, all matrices have non-infinity entries at most 2. By printing \
a list of witnesses we can see that these entries only occur in computations \
ending in the special state 4. Hence we must have L* = L2 . We verify this by \
computing a machine for L2 and showing that it is equivalent to mloop. \
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[PrintWitnesses[MS, wit]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(EquivalentQFA[mloop, ConcatenateFA[m, m]]\)], "Input",
  AspectRatioFixed->True],

Cell["The defining equations for the matrix semigroup MS are:", "Text"],

Cell[BoxData[
    \(PrintEquations[SimplifyEquations[MS, wit, eq]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReduce[RandomWord[20, {a, b}], eq, DoTrace \[Rule] True]\)], "Input",\

  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Example:  ",
  Cell[BoxData[
      \(TraditionalForm\`L\ \  = \ \ \[Epsilon]\  + \ \(aa(aaa)\)\^\(\(\ \
\)\(*\)\)\)]]
}], "Subsubsection"],

Cell[TextData[{
  "Here is another example without comments for a one-symbol alphabet. This \
time ",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ L\^\(\(\ \)\(3\)\)\)]],
  ". It is not too hard to see that every  infinite language  in a* has fpp."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
m = MinimizeFA[RegularExpressionToFA[Eps+RES[aaa]**aa,{a}]];
mloop = LoopAutomatonFA[m]\
\>", "Input"],

Cell[BoxData[
    \(\(PlotComputationFA[mloop, aaaaaaaaa];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(TransitionMatrixFA[mloop, f, Type \[Rule] Tropical];\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\({MS, wit, eq} = 
        GenerateSG[GEN[5, 1, {f[a]}], Equations \[Rule] True];\)\), "\n", 
    \(Length[MS]\), "\n", 
    \(Union[Flatten[ToList[MS]]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[PrintWitnesses[MS, wit]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(EquivalentQFA[mloop, ConcatenateFA[m, m]]\), "\n", 
    \(EquivalentQFA[mloop, ConcatenateFA[m, m, m]]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{963, 992},
WindowMargins->{{113, Automatic}, {-35, Automatic}},
PrintingStartingPageNumber->73,
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowSelection->True,
ShowCellLabel->True,
CellLabelAutoDelete->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->Automatic,
Magnification->1.5,
StyleDefinitions -> "Demo.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:4"->{
    Cell[8750, 300, 147, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:4"]},
  "Syntactic semigroups"->{
    Cell[17347, 619, 166, 4, 66, "Section",
      Evaluatable->False,
      CellTags->{"Syntactic semigroups", "c:5"}]},
  "c:5"->{
    Cell[17347, 619, 166, 4, 66, "Section",
      Evaluatable->False,
      CellTags->{"Syntactic semigroups", "c:5"}]},
  "c:6"->{
    Cell[17538, 627, 148, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:6"]},
  "c:8"->{
    Cell[26244, 944, 136, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:8"]},
  "c:9"->{
    Cell[27914, 1006, 152, 4, 46, "Subsection",
      Evaluatable->False,
      CellTags->"c:9"]},
  "Subword counter"->{
    Cell[32379, 1181, 194, 5, 46, "Subsection",
      Evaluatable->False,
      CellTags->{"Subword counter", "c:10"}]},
  "c:10"->{
    Cell[32379, 1181, 194, 5, 46, "Subsection",
      Evaluatable->False,
      CellTags->{"Subword counter", "c:10"}]},
  "FPP"->{
    Cell[52235, 1865, 162, 4, 66, "Section",
      Evaluatable->False,
      CellTags->{"FPP", "c:12"}]},
  "c:12"->{
    Cell[52235, 1865, 162, 4, 66, "Section",
      Evaluatable->False,
      CellTags->{"FPP", "c:12"}]},
  "c:13"->{
    Cell[52422, 1873, 133, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:13"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:4", 62454, 2178},
  {"Syntactic semigroups", 62579, 2182},
  {"c:5", 62711, 2186},
  {"c:6", 62843, 2190},
  {"c:8", 62952, 2194},
  {"c:9", 63061, 2198},
  {"Subword counter", 63183, 2202},
  {"c:10", 63316, 2206},
  {"FPP", 63448, 2210},
  {"c:12", 63566, 2214},
  {"c:13", 63684, 2218}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 54, 0, 40, "SmallText"],
Cell[1762, 52, 128, 3, 77, "Title"],

Cell[CellGroupData[{
Cell[1915, 59, 78, 1, 115, "Section"],

Cell[CellGroupData[{
Cell[2018, 64, 66, 1, 57, "Subsection"],
Cell[2087, 67, 1471, 42, 217, "Text",
  Evaluatable->False],
Cell[3561, 111, 170, 5, 114, "Input"],
Cell[3734, 118, 235, 8, 44, "Text",
  Evaluatable->False],
Cell[3972, 128, 114, 3, 81, "Input"],
Cell[4089, 133, 383, 11, 60, "Text",
  Evaluatable->False],
Cell[4475, 146, 93, 1, 45, "Input"],
Cell[4571, 149, 156, 4, 114, "Input"],
Cell[4730, 155, 242, 7, 60, "Text",
  Evaluatable->False],
Cell[4975, 164, 82, 2, 45, "Input"],
Cell[5060, 168, 1015, 33, 98, "Text",
  Evaluatable->False],
Cell[6078, 203, 155, 3, 68, "Input"],
Cell[6236, 208, 189, 6, 137, "Input"],
Cell[6428, 216, 233, 6, 60, "Text",
  Evaluatable->False],
Cell[6664, 224, 144, 3, 75, "Input"],
Cell[6811, 229, 706, 18, 160, "Text",
  Evaluatable->False],
Cell[7520, 249, 120, 3, 68, "Input"],
Cell[7643, 254, 524, 19, 67, "Text",
  Evaluatable->False],
Cell[8170, 275, 72, 2, 45, "Input"],
Cell[8245, 279, 72, 2, 45, "Input"],
Cell[8320, 283, 186, 5, 60, "Text",
  Evaluatable->False],
Cell[8509, 290, 204, 5, 114, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8750, 300, 147, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:4"],
Cell[8900, 306, 553, 17, 63, "Text",
  Evaluatable->False],
Cell[9456, 325, 115, 2, 45, "Input"],
Cell[9574, 329, 265, 10, 41, "Text",
  Evaluatable->False],
Cell[9842, 341, 83, 2, 45, "Input"],
Cell[9928, 345, 424, 11, 79, "Text",
  Evaluatable->False],
Cell[10355, 358, 112, 3, 68, "Input"],
Cell[10470, 363, 107, 3, 68, "Input"],
Cell[10580, 368, 81, 2, 45, "Input"],
Cell[10664, 372, 80, 2, 45, "Input"],
Cell[10747, 376, 151, 5, 41, "Text",
  Evaluatable->False],
Cell[10901, 383, 78, 2, 50, "Input"],
Cell[10982, 387, 78, 2, 45, "Input"],
Cell[11063, 391, 104, 2, 41, "Text",
  Evaluatable->False],
Cell[11170, 395, 151, 2, 68, "Input"],
Cell[11324, 399, 77, 2, 45, "Input"],
Cell[11404, 403, 69, 0, 44, "Input"],
Cell[11476, 405, 28, 0, 44, "Input"],
Cell[11507, 407, 148, 5, 41, "Text",
  Evaluatable->False],
Cell[11658, 414, 92, 2, 45, "Input"],
Cell[11753, 418, 205, 4, 91, "Input"],
Cell[11961, 424, 602, 18, 79, "Text",
  Evaluatable->False],
Cell[12566, 444, 181, 4, 68, "Input"],
Cell[12750, 450, 504, 16, 66, "Text",
  Evaluatable->False],
Cell[13257, 468, 77, 2, 45, "Input"],
Cell[13337, 472, 172, 5, 41, "Text",
  Evaluatable->False],
Cell[13512, 479, 107, 2, 45, "Input"],
Cell[13622, 483, 510, 15, 79, "Text",
  Evaluatable->False],
Cell[14135, 500, 97, 2, 45, "Input"],
Cell[14235, 504, 408, 10, 85, "Text",
  Evaluatable->False],
Cell[14646, 516, 131, 2, 68, "Input"],
Cell[14780, 520, 87, 2, 45, "Input"],
Cell[14870, 524, 430, 14, 60, "Text",
  Evaluatable->False],
Cell[15303, 540, 236, 6, 68, "Input"],
Cell[15542, 548, 219, 5, 114, "Input"],
Cell[15764, 555, 77, 2, 45, "Input"],
Cell[15844, 559, 208, 7, 103, "Text",
  Evaluatable->False],
Cell[16055, 568, 97, 2, 45, "Input"],
Cell[16155, 572, 113, 2, 45, "Input"],
Cell[16271, 576, 88, 2, 41, "Text",
  Evaluatable->False],
Cell[16362, 580, 145, 3, 68, "Input"],
Cell[16510, 585, 203, 7, 41, "Text",
  Evaluatable->False],
Cell[16716, 594, 156, 3, 91, "Input"],
Cell[16875, 599, 117, 2, 41, "Text",
  Evaluatable->False],
Cell[16995, 603, 156, 3, 91, "Input"],
Cell[17154, 608, 144, 5, 41, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17347, 619, 166, 4, 66, "Section",
  Evaluatable->False,
  CellTags->{"Syntactic semigroups", "c:5"}],

Cell[CellGroupData[{
Cell[17538, 627, 148, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:6"],
Cell[17689, 633, 2241, 66, 384, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[19967, 704, 82, 1, 46, "Subsection"],
Cell[20052, 707, 528, 17, 122, "Text",
  Evaluatable->False],
Cell[20583, 726, 111, 2, 45, "Input"],
Cell[20697, 730, 94, 2, 68, "Input"],
Cell[20794, 734, 94, 2, 41, "Text",
  Evaluatable->False],
Cell[20891, 738, 78, 2, 45, "Input"],
Cell[20972, 742, 135, 5, 41, "Text",
  Evaluatable->False],
Cell[21110, 749, 120, 3, 68, "Input"],
Cell[21233, 754, 223, 8, 41, "Text",
  Evaluatable->False],
Cell[21459, 764, 68, 2, 45, "Input"],
Cell[21530, 768, 359, 11, 60, "Text",
  Evaluatable->False],
Cell[21892, 781, 74, 2, 45, "Input"],
Cell[21969, 785, 659, 18, 82, "Text",
  Evaluatable->False],
Cell[22631, 805, 140, 2, 68, "Input"],
Cell[22774, 809, 77, 2, 45, "Input"],
Cell[22854, 813, 97, 2, 45, "Input"],
Cell[22954, 817, 69, 0, 41, "Text"],
Cell[23026, 819, 117, 2, 45, "Input"],
Cell[23146, 823, 181, 7, 41, "Text",
  Evaluatable->False],
Cell[23330, 832, 86, 2, 45, "Input"],
Cell[23419, 836, 65, 2, 45, "Input"],
Cell[23487, 840, 447, 17, 64, "Text",
  Evaluatable->False],
Cell[23937, 859, 90, 2, 45, "Input"],
Cell[24030, 863, 538, 16, 116, "Text",
  Evaluatable->False],
Cell[24571, 881, 192, 4, 91, "Input"],
Cell[24766, 887, 234, 6, 60, "Text",
  Evaluatable->False],
Cell[25003, 895, 136, 3, 68, "Input"],
Cell[25142, 900, 92, 2, 41, "Text",
  Evaluatable->False],
Cell[25237, 904, 190, 3, 68, "Input"],
Cell[25430, 909, 190, 5, 60, "Text",
  Evaluatable->False],
Cell[25623, 916, 92, 3, 68, "Input"],
Cell[25718, 921, 269, 10, 41, "Text",
  Evaluatable->False],
Cell[25990, 933, 112, 2, 45, "Input"],
Cell[26105, 937, 102, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26244, 944, 136, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:8"],
Cell[26383, 950, 348, 7, 79, "Text",
  Evaluatable->False],
Cell[26734, 959, 187, 3, 91, "Input"],
Cell[26924, 964, 72, 2, 45, "Input"],
Cell[26999, 968, 179, 5, 41, "Text",
  Evaluatable->False],
Cell[27181, 975, 69, 2, 45, "Input"],
Cell[27253, 979, 79, 2, 45, "Input"],
Cell[27335, 983, 93, 2, 45, "Input"],
Cell[27431, 987, 175, 5, 41, "Text",
  Evaluatable->False],
Cell[27609, 994, 113, 2, 45, "Input"],
Cell[27725, 998, 69, 0, 41, "Text"],
Cell[27797, 1000, 80, 1, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[27914, 1006, 152, 4, 46, "Subsection",
  Evaluatable->False,
  CellTags->"c:9"],
Cell[28069, 1012, 232, 8, 41, "Text"],
Cell[28304, 1022, 217, 4, 114, "Input"],
Cell[28524, 1028, 426, 14, 60, "Text",
  Evaluatable->False],
Cell[28953, 1044, 75, 2, 45, "Input"],
Cell[29031, 1048, 55, 1, 45, "Input"],
Cell[29089, 1051, 166, 5, 41, "Text",
  Evaluatable->False],
Cell[29258, 1058, 92, 2, 45, "Input"],
Cell[29353, 1062, 1029, 34, 98, "Text",
  Evaluatable->False],
Cell[30385, 1098, 150, 2, 68, "Input"],
Cell[30538, 1102, 114, 3, 41, "Text"],
Cell[30655, 1107, 49, 1, 45, "Input"],
Cell[30707, 1110, 154, 5, 41, "Text",
  Evaluatable->False],
Cell[30864, 1117, 78, 2, 45, "Input"],
Cell[30945, 1121, 162, 7, 41, "Text",
  Evaluatable->False],
Cell[31110, 1130, 74, 2, 45, "Input"],
Cell[31187, 1134, 383, 13, 60, "Text",
  Evaluatable->False],
Cell[31573, 1149, 248, 5, 91, "Input"],
Cell[31824, 1156, 249, 10, 41, "Text",
  Evaluatable->False],
Cell[32076, 1168, 142, 3, 68, "Input"],
Cell[32221, 1173, 121, 3, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[32379, 1181, 194, 5, 46, "Subsection",
  Evaluatable->False,
  CellTags->{"Subword counter", "c:10"}],
Cell[32576, 1188, 1472, 43, 268, "Text",
  Evaluatable->False],
Cell[34051, 1233, 184, 5, 91, "Input"],
Cell[34238, 1240, 145, 3, 68, "Input"],
Cell[34386, 1245, 203, 7, 72, "Text",
  Evaluatable->False],
Cell[34592, 1254, 117, 2, 45, "Input"],
Cell[34712, 1258, 118, 2, 41, "Text",
  Evaluatable->False],
Cell[34833, 1262, 184, 4, 91, "Input"],
Cell[35020, 1268, 346, 9, 41, "Text",
  Evaluatable->False],
Cell[35369, 1279, 351, 8, 137, "Input"],
Cell[35723, 1289, 137, 5, 41, "Text",
  Evaluatable->False],
Cell[35863, 1296, 81, 2, 45, "Input"],
Cell[35947, 1300, 434, 16, 60, "Text",
  Evaluatable->False],
Cell[36384, 1318, 144, 3, 45, "Input"],
Cell[36531, 1323, 141, 3, 45, "Input"],
Cell[36675, 1328, 176, 5, 41, "Text",
  Evaluatable->False],
Cell[36854, 1335, 128, 3, 68, "Input"],
Cell[36985, 1340, 163, 5, 41, "Text",
  Evaluatable->False],
Cell[37151, 1347, 201, 5, 68, "Input"],
Cell[37355, 1354, 1231, 38, 167, "Text",
  Evaluatable->False],
Cell[38589, 1394, 211, 4, 91, "Input"],
Cell[38803, 1400, 108, 2, 45, "Input"],
Cell[38914, 1404, 123, 2, 41, "Text",
  Evaluatable->False],
Cell[39040, 1408, 142, 3, 68, "Input"],
Cell[39185, 1413, 89, 2, 45, "Input"],
Cell[39277, 1417, 401, 13, 91, "Text",
  Evaluatable->False],
Cell[39681, 1432, 146, 3, 68, "Input"],
Cell[39830, 1437, 81, 2, 45, "Input"],
Cell[39914, 1441, 93, 2, 45, "Input"],
Cell[40010, 1445, 149, 3, 68, "Input"],
Cell[40162, 1450, 767, 24, 110, "Text",
  Evaluatable->False],
Cell[40932, 1476, 239, 7, 41, "Text",
  Evaluatable->False],
Cell[41174, 1485, 176, 5, 68, "Input"],
Cell[41353, 1492, 771, 23, 153, "Text",
  Evaluatable->False],
Cell[42127, 1517, 78, 2, 45, "Input"],
Cell[42208, 1521, 386, 11, 60, "Text",
  Evaluatable->False],
Cell[42597, 1534, 169, 4, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42803, 1543, 77, 1, 46, "Subsection"],
Cell[42883, 1546, 1474, 40, 454, "Text",
  Evaluatable->False],
Cell[44360, 1588, 171, 5, 104, "Input"],
Cell[44534, 1595, 75, 2, 45, "Input"],
Cell[44612, 1599, 121, 2, 41, "Text",
  Evaluatable->False],
Cell[44736, 1603, 68, 2, 45, "Input"],
Cell[44807, 1607, 142, 3, 68, "Input"],
Cell[44952, 1612, 650, 16, 132, "Text",
  Evaluatable->False],
Cell[45605, 1630, 121, 2, 68, "Input"],
Cell[45729, 1634, 271, 10, 41, "Text",
  Evaluatable->False],
Cell[46003, 1646, 186, 5, 68, "Input"],
Cell[46192, 1653, 158, 5, 41, "Text",
  Evaluatable->False],
Cell[46353, 1660, 230, 4, 91, "Input"],
Cell[46586, 1666, 168, 5, 41, "Text",
  Evaluatable->False],
Cell[46757, 1673, 78, 2, 45, "Input"],
Cell[46838, 1677, 84, 2, 41, "Text",
  Evaluatable->False],
Cell[46925, 1681, 81, 2, 45, "Input"],
Cell[47009, 1685, 139, 5, 41, "Text",
  Evaluatable->False],
Cell[47151, 1692, 104, 2, 45, "Input"],
Cell[47258, 1696, 82, 2, 45, "Input"],
Cell[47343, 1700, 171, 5, 41, "Text",
  Evaluatable->False],
Cell[47517, 1707, 254, 7, 63, "Text",
  Evaluatable->False],
Cell[47774, 1716, 135, 3, 68, "Input"],
Cell[47912, 1721, 352, 9, 110, "Text",
  Evaluatable->False],
Cell[48267, 1732, 166, 4, 68, "Input"],
Cell[48436, 1738, 146, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[48607, 1747, 150, 3, 68, "Input"],
Cell[48760, 1752, 1468, 24, 139, "Output"]
}, Closed]],
Cell[50243, 1779, 140, 6, 72, "Text",
  Evaluatable->False],
Cell[50386, 1787, 196, 4, 68, "Input"],
Cell[50585, 1793, 138, 5, 41, "Text",
  Evaluatable->False],
Cell[50726, 1800, 124, 2, 68, "Input"],
Cell[50853, 1804, 182, 7, 41, "Text",
  Evaluatable->False],
Cell[51038, 1813, 176, 3, 91, "Input"],
Cell[51217, 1818, 239, 10, 41, "Text",
  Evaluatable->False],
Cell[51459, 1830, 114, 2, 45, "Input"],
Cell[51576, 1834, 87, 2, 41, "Text",
  Evaluatable->False],
Cell[51666, 1838, 92, 2, 45, "Input"],
Cell[51761, 1842, 91, 2, 41, "Text",
  Evaluatable->False],
Cell[51855, 1846, 78, 2, 45, "Input"],
Cell[51936, 1850, 173, 5, 41, "Text",
  Evaluatable->False],
Cell[52112, 1857, 74, 2, 45, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[52235, 1865, 162, 4, 66, "Section",
  Evaluatable->False,
  CellTags->{"FPP", "c:12"}],

Cell[CellGroupData[{
Cell[52422, 1873, 133, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:13"],
Cell[52558, 1879, 3094, 83, 713, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[55677, 1966, 286, 7, 61, "Subsubsection"],
Cell[55966, 1975, 329, 7, 79, "Text",
  Evaluatable->False],
Cell[56298, 1984, 100, 3, 64, "Input"],
Cell[56401, 1989, 129, 3, 68, "Input"],
Cell[56533, 1994, 90, 2, 45, "Input"],
Cell[56626, 1998, 341, 7, 79, "Text",
  Evaluatable->False],
Cell[56970, 2007, 97, 2, 45, "Input"],
Cell[57070, 2011, 751, 13, 179, "Text",
  Evaluatable->False],
Cell[57824, 2026, 165, 3, 91, "Input"],
Cell[57992, 2031, 198, 5, 60, "Text",
  Evaluatable->False],
Cell[58193, 2038, 131, 3, 68, "Input"],
Cell[58327, 2043, 75, 2, 45, "Input"],
Cell[58405, 2047, 608, 12, 167, "Text",
  Evaluatable->False],
Cell[59016, 2061, 211, 5, 91, "Input"],
Cell[59230, 2068, 374, 8, 79, "Text",
  Evaluatable->False],
Cell[59607, 2078, 93, 2, 45, "Input"],
Cell[59703, 2082, 100, 2, 45, "Input"],
Cell[59806, 2086, 71, 0, 41, "Text"],
Cell[59880, 2088, 105, 2, 45, "Input"],
Cell[59988, 2092, 121, 3, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[60146, 2100, 157, 5, 64, "Subsubsection"],
Cell[60306, 2107, 312, 8, 63, "Text",
  Evaluatable->False],
Cell[60621, 2117, 112, 3, 64, "Input"],
Cell[60736, 2122, 99, 2, 45, "Input"],
Cell[60838, 2126, 115, 2, 45, "Input"],
Cell[60956, 2130, 214, 5, 91, "Input"],
Cell[61173, 2137, 93, 2, 45, "Input"],
Cell[61269, 2141, 163, 3, 68, "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

