(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     58112,       1924]*)
(*NotebookOutlinePosition[     61298,       2042]*)
(*  CellTagsIndexPosition[     60836,       2020]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\[Copyright] 1997-2002 K. Sutner ", "SmallText"],

Cell[TextData[StyleBox["Words and Machines",
  FontFamily->"Charter"]], "Title",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:1"],

Cell[CellGroupData[{

Cell["About The Guides", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:2"],

Cell[CellGroupData[{

Cell["The Guides", "Subsection",
  CellTags->"c:3"],

Cell[TextData[{
  "The Guide1 through Guide7 notebooks accompany ",
  StyleBox["automata", "SmallText"],
  ", a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package that contains algorithms that generate and manipulate finite \
state machines and their syntactic semigroups, and linear cellular automata. \
The notebooks replace a printed manual -- at least for the time being. \
Briefly, their contents are as follows: \n\n\tGuide1:\tIntroduction\n\t\
Guide2:\tFinite State Machines\n\tGuide3:\tThe Minimal Automaton\n\tGuide4:\t\
Rational Expressions\n\tGuide5:\tSyntactic Semigroups\n\tGuide6:\tLinear \
Cellular Automata\n\tGuide7:\tProgramming in `automata' \n\nThe notebook ",
  StyleBox["AutomataIndex.nb",
    FontColor->RGBColor[0, 0, 1]],
  " contains a more detailed index of the Guides. \nThe Guides are meant to \
be used interactively in a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. It is less helpful to generate a printout; not to mention that \
printing all the Guide notebooks wastes a tree. A person reasonably familiar \
with both ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and finite state machines should have no problems using the basic \
commands in automata after going through this notebook once--or maybe twice. \
\n\nNeedless to say, ALL the sample computations in these notebooks should \
work flawlessly, a claim I would not care to make for the whole package. At \
any rate, if you encounter difficulties with any of the computations here, \
you should make sure that your files are not corrupted and that ",
  StyleBox["automata.m", "SmallText"],
  " and ",
  StyleBox["dimath.m", "SmallText"],
  " are loaded properly. You may have to customize the 'Startup' section \
above a little. If the problem persists, please let me know about it. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["On-Line Help", "Subsection",
  CellTags->"c:4"],

Cell[TextData[{
  "The commands in ",
  StyleBox["automata", "SmallText"],
  " all have usage messages associated with them, though some of these \
messages are unreasonably terse."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Words and Languages", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:5"],

Cell[CellGroupData[{

Cell["  Words", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:6"],

Cell[TextData[{
  "Words are naturally implemented in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as strings. However, strings must be typed with quotes, a process that \
becomes quite cumbersome after a while. Also, there is the problem that the \
empty word is invisible as a string. From an algebraic point of view, the \
empty word is particularly important and therefore we have reserved a special \
sybol for it: ",
  StyleBox["Eps", "SmallText"],
  ". Within this package, a word may be either a string or a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " symbol (whose atoms should be chosen from some reasonable alphabet like \
",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  "). Thus one can type\n\t",
  Cell[BoxData[
      FormBox[
        StyleBox[\(L\  = \ \ {\ Eps, \ aa, \ bb\ }\),
          FontFamily->"Courier"], TraditionalForm]]],
  "     \nrather than \n\t",
  Cell[BoxData[
      FormBox[
        StyleBox[\(L\  = \ \ {\ \*"\<\"\"\>", \ "aa", \ "bb"\ }\),
          FontFamily->"Courier"], TraditionalForm]]],
  " \nTo avoid clutter in the Global context, though, all procedures that \
generate words as output will use strings to represent them. This feature \
makes is slightly more tedious to define functions that can cope with direct \
input from the user as well as output from other functions in automata. \
Typically, you will have to write definitions like \n",
  StyleBox["\t",
    FontFamily->"Courier"],
  Cell[BoxData[
      \(TraditionalForm\`f[\ Eps | "Eps"\ ]\  := \ \(\(...\)\(.\)\)\)],
    FontFamily->"Courier"],
  StyleBox["\n\t",
    FontFamily->"Courier"],
  Cell[BoxData[
      \(TraditionalForm\`f[
          x_]\  := \ \(\(...\)\(\ \ \)\(ToString[x]\)\)\  ... \)],
    FontFamily->"Courier"],
  "\nto get the desired flexibility. Of course, if one uses digit based \
alphabets like ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1}\)]],
  ",  strings must be used at any rate: otherwise ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  evaluates the expression 001 to 1. \n\nNote that automata modifies the \
built-in function ",
  StyleBox["ToString", "SmallText"],
  " so that it treats ",
  StyleBox["Eps", "SmallText"],
  " properly. Also, there is a funcion ",
  StyleBox["ToCharacters", "SmallText"],
  " that behaves like the built-in ",
  StyleBox["Characters", "SmallText"],
  " except that it also treats ",
  StyleBox["Eps", "SmallText"],
  " properly and takes symbols as input. With those two function it should be \
easy to write your own procedures. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ToString[Eps]\), "\n", 
    \(FullForm[%]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ToCharacters /@ {Eps, abab, "\<abcdef\>"}\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The predicate ",
  StyleBox["WordQ", "SmallText"],
  " tests if a Mathematica expression is a word:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordQ /@ {Eps, "\<Eps\>", aaaaaaaaaaa, "\<ababababa\>", 
        5555}\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The length of a word is computed by ",
  StyleBox["WordLength", "SmallText"],
  ":"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordLength /@ {Eps, "\<Eps\>", aaaaaaaaaaa, "\<ababababa\>"}\)], "Input",\

  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["WordReverse", "SmallText"],
  " flips a word around:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordReverse /@ {Eps, "\<Eps\>", 
        aaaaaaaaaab, "\<aaaaaaaaaab\>"}\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To concatenate two or more words use the command ",
  StyleBox["Concatenate", "SmallText"],
  ". (",
  StyleBox["StringJoin", "SmallText"],
  " will not work on symbols). ",
  StyleBox["Concatenate", "SmallText"],
  " is polyadic, takes symbols as input and treats ",
  StyleBox["Eps", "SmallText"],
  " properly. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Concatenate[bbb, Eps, aaa]\), "\n", 
    \(Concatenate[aba, bbb, aaa]\), "\n", 
    \(Concatenate["\<aba\>", bbb, "\<aaa\>"]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Concatenate", "SmallText"],
  " also behaves properly on lists of words."
}], "Text"],

Cell[BoxData[
    \(Concatenate[{a, b}, {a, b}]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The command ",
  StyleBox["Words[r,K]", "SmallText"],
  " produces a list of words of length ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " over alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ". If the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is negative, ",
  StyleBox["Words", "SmallText"],
  " generates a (flat) list of all words up to length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(r\)\(|\)\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Words[3, {a, b}]\), "\n", 
    \(Words[\(-3\), {a, b}]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
No new symbols are introduced into the Global context by this call:\
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Head /@ %\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Words\ is\ one\ of\ the\ commands\ where\ the\ alphabet\ defaults\ to\ \
$alphabet . Thus\)], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Words[3]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Words", "SmallText"],
  " can be abused in various ways:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[x, y, ab]\), "\n", 
    \(Words[\(-3\), {x, 8}]\), "\n", 
    \(Words[\(-8\), {ab}]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To generate standard digit and letter alphabets without having to type all \
the symbols you can use the command ",
  StyleBox["MakeAlphabet", "SmallText"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(MakeAlphabet[5]\), "\n", 
    \(MakeAlphabet[\(-5\)]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Command ",
  StyleBox["RandomWord[r,K]", "SmallText"],
  " generates one random word of length ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " over alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " (with uniformly distributed symbols). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(RandomWord[10, 2]\)], "Input"],

Cell[TextData[{
  "The commands ",
  StyleBox["WordPrefixes", "SmallText"],
  " and ",
  StyleBox["WordSuffixes", "SmallText"],
  " generate a list of all prefixes and suffixes of a given word, \
respectively. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordPrefixes[RandomWord[8, {x, y}]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["WordFactorizations", "SmallText"],
  " produces all factorizations  w = uv  of a word w. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TableForm[WordFactorizations[abbb]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
On occasion it is more convenient to think of words as elements in \
the free monoid over the corrsponding alphabet and write them in the standard \
power notation:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(w = WordPower[aaaab, 3]\), "\n", 
    \(AlgebraicForm[w]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A word is ",
  StyleBox["primitive",
    FontColor->RGBColor[0, 0, 1]],
  " iff it cannot be written as a power of a shorter word. The root of a word \
",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " is the shortest word ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " such that  ",
  Cell[BoxData[
      \(TraditionalForm\`w = u\^\(\(\ \)\(i\)\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Select[Words[6, {a, b}], PrimitiveQ]\), "\n", 
    \(Length[%]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(w = WordPower[abc, 10]\), "\n", 
    \(WordRoot[w]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordLength[WordRoot[RandomWord[20, 2]]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To compute ",
  Cell[BoxData[
      \(TraditionalForm\`p[n, k]\)]],
  ", the number of primitive words of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " over an alphabet of size ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", one can use recursion: \n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(p[n, k]\), "  ", "=", "  ", 
          
          FormBox[\(k\^n - \ \ \[Sum]\_\(\(d\  | \ n\  &\)\ d < n\)\ 
                p[d, k]\),
            "TraditionalForm"]}], TraditionalForm]]],
  "\nwhere the sum is over all proper divisors ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[p]\), "\n", 
    \(p[1, k_] := k; \), "\n", 
    \(p[n_, k_] := \(p[n, k] = 
        k\^n - Plus @@ \(\((p[#1, k] &)\) /@ 
              Drop[Divisors[n], \(-1\)]\)\)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(p[10, 2]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A better approach is to realize that \n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          
          FormBox[\(k\^n = \ \ \[Sum]\_\(\(d\)\(\ \)\(|\)\(\ \)\(n\)\(\ \)\)\ 
                p[d, k]\),
            "TraditionalForm"]}], TraditionalForm]]],
  "\nand then to use M\[ODoubleDot]bius inversion to compute the number of \
primitive words. This approach is taken in ",
  StyleBox["PrimitiveCount", "SmallText"],
  ". Note that there are lots of primitive words."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((PrimitiveCount[#1, 2] &)\) /@ Range[12]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(N[\((PrimitiveCount[#1, 2] &)\) /@ Range[20]\/2\^Range[20]]\)], "Input",\

  AspectRatioFixed->True],

Cell[TextData[{
  "Command ",
  StyleBox["WordShuffle", "SmallText"],
  " produces all possible interleavings of given words:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordShuffle[aabb, ccaa]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
In general it is quite difficult to count the number of words that \
arise from a shuffle operation. There is one special case, though, where the \
computation is simple:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordShuffle[aaaa, bbb]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Length[%] === Binomial[7, 4]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ToIndex[w,K]", "SmallText"],
  " converts a word ",
  Cell[BoxData[
      \(TraditionalForm\`w = \(\(w\_1\) w\_2.  .. \) w\_l\)]],
  " into a corresponding list of numbers ",
  Cell[BoxData[
      \(TraditionalForm\`{i\_1, i\_2, \(\(..\)\(,\)\(i\_l\)\)}\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`i\_j\)]],
  " is the position of symbol ",
  Cell[BoxData[
      \(TraditionalForm\`w\_j\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " (which we may safely assume to be ordered since we use lists to represent \
sets). If no second input field is specified, the default ",
  StyleBox["$alphabet", "SmallText"],
  " is substituted. ",
  StyleBox["ToWord", "SmallText"],
  " performs the inverse operation. The two commands can be combined to \
perform substitutions. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((ToIndex[#1, {x, y}] &)\) /@ 
      WordPrefixes[RandomWord[8, {x, y}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((ToWord[#1, {a, b}] &)\) /@ %\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Here is a simple one-dimensional Lindenmayer system based on ",
  StyleBox["ToIndex", "SmallText"],
  " and ",
  StyleBox["ToWords", "SmallText"],
  ". Note that strings and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " symbols can be mixed in an alphabet."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Lindenmayer[x_] := 
      ToWord[ToIndex[x, {0, 1}], {"\<1\>", "\<10\>"}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(LS = NestList[Lindenmayer, "\<0\>", 9]; \), "\n", 
    \(ColumnForm[LS]\)}], "Input",
  AspectRatioFixed->True],

Cell["The lengths of these strings are the Fibonacci numbers:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordLength[LS]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The same effect can be obtained using the command ",
  StyleBox["MakeHomomorphism", "SmallText"],
  " (which uses the built-in ",
  StyleBox["StringReplace", "SmallText"],
  " internally and is therefore faster). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(MakeHomomorphism[lind, {0, 1}, {1, 10}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[NestList[lind, "\<0\>", 9]]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["  Order relations on words", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:7"],

Cell["\<\
There are various ways to introduce an order relation on words.The \
most standard one is lexicographic order and is used in the built-in command \
Sort.The standard lexicographic ordering of words can be expressed by a rank \
function using ToIndex as follows.Let\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(rank[Eps | "\<Eps\>"] = 0; \), "\n", 
    \(rank[w_] := 
      ToIndex[w, {a, 
            b}] . \((1\/3)\)\^Range[0, WordLength[w] - 1]; \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(rank[a]\), "\n", 
    \(rank[aaaaaaaaaaa]\), "\n", 
    \(rank[b]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(TableForm[{W = Words[2, {a, b}], rank /@ W}]\), "\n", 
    \(TableForm[{W = Words[3, {a, b}], rank /@ W}]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Lexicographic order will occasionally produce undesired results \
when applied to languages. For example, \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(L = WordSuffixes[aababbababa]; \), "\n", 
    \(Sort[L]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(but\)], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordSort[L]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(WordSort[\((RandomWord[\(-6\), {a, b}] &)\) /@ Range[10]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Command  ",
  StyleBox["WordSort", "SmallText"],
  "  uses the length-lex order on words, a product order of length and \
lexicographic order: \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`u\  < \ v\)]],
  "   iff   \t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(|\)\(u\)\(|\)\(<\)\)\(\ \)\(|\)\(v\)\(|\)\(\ \
\)\)\)]],
  "  or \n\t\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\(\(\(\(|\)\(u\)\(|\)\)\(\ \)\(=\)\)\(\ \
\)\(|\)\) v\)\(|\)\)\(\ \)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  "  precedes  ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  "  lexicographically.\t\t\t\n",
  StyleBox["WordSort", "SmallText"],
  " is used automatically in commands like ",
  StyleBox["WordPrefixes", "SmallText"],
  " and ",
  StyleBox["WordSuffixes", "SmallText"],
  ". This is essential in some applications (see the section on the KMP \
string searching algorithm). ",
  StyleBox["WordSort", "SmallText"],
  " uses the built in sorting procedure ",
  StyleBox["Sort", "SmallText"],
  " and has comparable speed. \nThere is another sorting command ",
  StyleBox["LanguageSort", "SmallText"],
  " that applies to lists of languages. It is useful primarily to display \
syntactic congruence classes, see below.  \nNeedless to say, there is a \
natural ranking function for the ",
  StyleBox["WordSort", "SmallText"],
  " order."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[rank]; \), "\n", 
    \(rank[Eps | "\<Eps\>", _] = 0; \), "\n", 
    \(rank[w_, alph_] := 
      Block[{k, l}, k = Length[alph]; 
        l = WordLength[
            w]; \(k\^l - 1\)\/\(k - 1\) + \((ToIndex[w, alph] - 1)\) . 
            Reverse[k\^Range[0, l - 1]]]; \)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Define W3 to be all words over {a,b} of length at most 3. Their \
ranks over alphabets {a,b} and {a,b,c} are\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(W3 = Words[\(-3\), {a, b}]\), "\n", 
    \(r0 = \((rank[#1, {a, b}] &)\) /@ W3\), "\n", 
    \(r1 = \((rank[#1, {a, b, c}] &)\) /@ W3\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Structure of a Finite State Machine", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:8"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Types\ of\ Finite\ State\ Machines\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:9"],

Cell[TextData[{
  "The most basic type of finite state machine is a semiautomaton, or SA for \
short. A semiautomaton consists of a \n\t-  a finite set of states ",
  StyleBox["Q",
    FontSlant->"Italic"],
  ",\n\t-  an alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\)]],
  ",\n\t-  a transition relation  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\  \[SubsetEqual] \ 
        Q\ \[Cross]\ \((\[CapitalSigma] \[Union] {\[Epsilon]})\)\ \[Cross]\ 
          Q\)]],
  ".  \nA triple  ",
  StyleBox["(p,s,q)",
    FontSlant->"Italic"],
  "  in ",
  StyleBox["\[Tau]",
    FontFamily->"Symbol"],
  " is a transition of the automaton, and ",
  StyleBox["s",
    FontSlant->"Italic"],
  " is its label. As we will see, it is convenient to allow the empty word as \
a label. If we think of an SA as simple system that responds to an external \
stimulus (some symbol ",
  StyleBox["s",
    FontSlant->"Italic"],
  " from the alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\)]],
  ") by performing a transition from state ",
  StyleBox["p",
    FontSlant->"Italic"],
  " into a new state ",
  StyleBox["q",
    FontSlant->"Italic"],
  " according to the transition relation, then transition labeled  correspond \
to autonomous transitions: the system changes its state without an external \
stimulus. If no transitions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, \[Epsilon], q)\)\)]],
  " occur the machine is  ",
  StyleBox["\[Epsilon]",
    FontFamily->"Symbol"],
  "-free. \n\nA semiautomaton can perfom simple computations as follows: it \
receives a sequence of symbols as input, and for every input symbol it \
performs a state transition according to the transition relation. Hence, a \
computation is a sequence \n\t",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_0\) \(s\_1\) \(p\_1\) \(s\_2\) 
        p\_3. \ \[Ellipsis]\ \(p\_\(n - 1\)\) \(s\_n\) p\_n\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "\nwhere the ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  " are states and s",
  StyleBox["i",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  " is in ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma] \[Union] {\[Epsilon]}\)]],
  ". The label of the computation is  ",
  Cell[BoxData[
      \(TraditionalForm\`s = \(s\_1.  .. \) 
            s\_n \[Element] \ \(\[CapitalSigma]\^*\)\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`p\_0, p\_1, \(\(...\)\(,\)\(p\_n\)\)\)]],
  " its trace. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In order to use SAs as acceptors, we have to limit admissible computations \
by insisting that the source state ",
  Cell[BoxData[
      \(TraditionalForm\`p\_0\)]],
  " is from a special set of states ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  ", the set of initial states, and similarly the target state pn is from a \
designated set of states ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  ", the set of final states. A finite automaton, or FA, correspondingly \
consists of a semiautomaton together with a set of initial and final states. \
A finite automaton ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " accepts a word ",
  StyleBox["x",
    FontSlant->"Italic"],
  " if there is a computation in M from an initial to a final state whose \
label is ",
  StyleBox["x",
    FontSlant->"Italic"],
  ". The set of all words accepted by ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is the acceptance language of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "There are some special types of machines that are of particular interest. \
Suppose M is some semiautomaton. We can think of its transition relation ",
  StyleBox["\[Tau] ",
    FontFamily->"Symbol"],
  "as defining, for each symbol ",
  StyleBox["a",
    FontSlant->"Italic"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma] \[Union] {\[Epsilon]}\)]],
  ", a binary relation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_a\)]],
  " on ",
  StyleBox["Q",
    FontSlant->"Italic"],
  ". We have already introduced the notion of epsilon-freeness: ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is epsilon-free iff ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_\[Epsilon]\)]],
  " is empty. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is deterministic if it is epsilon-free and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_a\)]],
  " is a partial function for each symbol ",
  StyleBox["a",
    FontSlant->"Italic"],
  ". \n",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is complete if it is epsilon-free and the domain of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_a\)]],
  " is all of ",
  StyleBox["Q",
    FontSlant->"Italic"],
  " for each symbol ",
  StyleBox["a",
    FontSlant->"Italic"],
  ".\nA deterministic finite automaton (DFA) is deterministic and complete \
(i.e., the relations ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_a\)]],
  " are functions from Q to Q), and there is exactly one initial state.  \
Hence ",
  StyleBox["\[Tau]",
    FontFamily->"Symbol"],
  " can be written conveniently as an ",
  Cell[BoxData[
      \(TraditionalForm\`K\ \[Cross]\ Q\)]],
  " matrix over ",
  StyleBox["Q",
    FontSlant->"Italic"],
  ".  \n\nIn a nondeterministic finite automaton (NFA) the relations ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_a\)]],
  " can be construed as  partial multi valued functions, which can be \
represented by a ",
  Cell[BoxData[
      \(TraditionalForm\`K\ \[Cross]\ Q\)]],
  " matrix over ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP](Q)\)]],
  ". \t\nIn this package, a FSM is represented by a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expression of the form\n\n\t",
  StyleBox["SA[  Q,  K,  T ],",
    FontWeight->"Bold"],
  "\n\t",
  StyleBox["FA[  Q,  K,  T,  I,  F ],",
    FontWeight->"Bold"],
  "\n\t",
  StyleBox["NFA[ Q,  K,  T,  I,  F ]",
    FontWeight->"Bold"],
  "\t,\n\t",
  StyleBox["DFA[ Q,  K,  T, q0,  F ].\n",
    FontWeight->"Bold"],
  "\nThe first type of expression stands for a semiautomaton, the second for \
an arbitrary finite automaton, the third for an epsilon-free automaton, and \
the fourth for a DFA, a deterministic complete machine with exactly one \
initial state. The headers FA, NFA and DFA are protected. For the sake of \
consistency, a DFA can also take the form ",
  StyleBox["DFA[Q, K, T, {q0}, F]", "SmallText"],
  ", i.e., the initial state may also be given as a list just as in all the \
other machines. \nAs indicated above, for the last two types of machines, the \
transition relation T is represented by a matrix. For SAs and FAs, however, \
the transitions are given as a list of triples.\nHere are some typical \
examples. The commands used in these examples will be explained in more \
detail later. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(AllDFA[{a, b}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(m = IthSymbolFA[a, \(-3\), {a, b}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ToNFA[m]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(MatrixForm[Transitions[%]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ToSA[m]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
The various fields of a machine can be extracted by the following \
commands. Note that States and Alphabet also return the cardinality of the \
respective sets. The size of a machine is returned by Size.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Size[m]\), "\n", 
    \(States[m]\), "\n", 
    \(Alphabet[m]\), "\n", 
    \(Transitions[m]\), "\n", 
    \(Initial[m]\), "\n", 
    \(Final[m]\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`The\ Truth\)], "Subsubsection",
  CellTags->"c:10"],

Cell["\<\
Actually, the structure of a FSM in this package is slightly more \
complicated than the explanation above suggest.  In reality, there are two \
more fields in a FSM that are simply not shown in the ordinary print form of \
a machine.  Replacing the header FA by List makes the hidden fields \
visible:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[ToList[m]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The entry in the second position from the end is the alphabet of the \
machine in explicit form: a list of characters.  See also the discussion \
about short-cuts below. \nThe last field shows the structured state set of \
the machine. The empty list here simply indicates that the states are  ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \(\(..\)\(,\)\(n\)\)}\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the number of states.  See the following sections for more \
information."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
However, to facilitate typing or other constructions of machines by \
hand, the package will automatically supply the missing fields. For \
example:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SA[2, 2, {{1, 1, 2}, {2, 1, 1}, {2, 2, 2}}]\), "\n", 
    \(FullForm[%]\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["States and Structured States, Normalization ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:11"],

Cell[TextData[{
  "For most purposes it is convenient to use ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([\)\(n\)\(]\)\)\  = \ {1, 
          2, \(\(...\)\(,\)\(n\)\)}\)]],
  " as set of states. Machines of this form will be referred to as \
normalized.  On occasion, however, it is preferable to use a state set Q of a \
different form. For example, if one computes the product machine of two given \
machines, the state set naturally is a set of pairs ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, q)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is a state of the first and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " a state of the second machine. To allow the user to preserve such special \
state sets, many of the commands in this  package have an option ",
  StyleBox["Normalize", "SmallText"],
  " associated with them. The default value for ",
  StyleBox["Normalize", "SmallText"],
  " is 0; therefore the states of the output machines are automatically \
normalized to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([\)\(n\)\(]\)\)\)]],
  ". If non-normalized output is desired use the option  ",
  Cell[BoxData[
      \(Normalize -> 1\)], "SmallText"],
  ". Note that normalization affects only the state set of an automaton. \
Transitions, initial and final states always use positional notation to \
represent states.\nAlso note that nonnormalized machines can be significantly \
bigger than their normalized counterparts. \n\nHere is a typical example. \
First, we construct two DFAs and their corresponding semiautomata:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(m1 = BuildDFA[aaa, {a, b}];\)\), "\n", 
    \(\(m2 = BuildDFA[bb, {a, b}];\)\), "\n", 
    \(s1 = ToSA[m1]\), "\n", 
    \(s2 = ToSA[m2]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The product of ",
  StyleBox["s1", "SmallText"],
  " and ",
  StyleBox["s2", "SmallText"],
  " has 20 states:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ProductFA[s1, s2]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To preserve the structure of the states we can use the option ",
  StyleBox["Normalize->1", "SmallText"],
  ". In our case, we obtain the Cartesian product of [5] and [4]."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ProductFA[s1, s2, Normalize \[Rule] 1]\), "\n", 
    \(States[%]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Things become a little more interesting if we compute the product \
of the two DFAs. The algorithm constructs only the accessible part, hence a \
few pairs are missing from the full Cartesian product.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(m = UnionFA[m1, m2, Normalize \[Rule] 1]\), "\n", 
    \(States[%]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Thus, option  ",
  StyleBox["Normalize->1", "SmallText"],
  "  preserves the structured state set during the constructions, whereas  ",
  StyleBox["Normalize->0", "SmallText"],
  ", the default, renormalizes to ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\)]],
  ".  The structure of the resulting state set depends on the operation under \
consideration:  \n\t",
  StyleBox["AccessibleFA", "SmallText"],
  ":\t\t\tsubset of ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\)]],
  "\n\t",
  StyleBox["ToDFA", "SmallText"],
  ":\t\t\t\tsubset of  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalP](\([n]\))\)]],
  "\n\t",
  StyleBox["MinimizeFA", "SmallText"],
  ":\t\t\tpartition of ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\)]],
  "\n\t",
  StyleBox["ProductFA", "SmallText"],
  ":\t\t\tsubset of  ",
  Cell[BoxData[
      \(TraditionalForm\`\([n\_1]\)\[Cross]\([n\_2]\)\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Note that in the last table the state set of the input machine(s) \
was assumed to be normalized.  If it is not, the result will be the same as \
if normalization were performed before the actual operation. 
We can push things a little further and preserve the state set of the input \
machine. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(fa = InfixFA[aabb, 2, Normalize \[Rule] 1];\)\), "\n", 
    \(States[fa]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(States[ToDFA[fa, Normalize \[Rule] 1]]\), "\n", 
    \(States[ToDFA[fa, Normalize \[Rule] 2]]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
If we minimize the last FA, we get a state set consisting of sets \
of sets of words:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Curry[TableForm]\)[TableDepth \[Rule] 2]\)[
      States[MinimizeFA[fa, Normalize \[Rule] 2]]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
How much information about the state is necessary depends very much \
on what one is trying to accomplish.  With a little experience it wil be \
quite obvious which level of normalization is appropriate. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Alphabets\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:12"],

Cell[TextData[{
  "The standard way to specify an alphabet is to provide a List of atomic \
symbols or strings of length 1.  However, it is absolutely necessary to ",
  StyleBox["Clear", "SmallText"],
  " any symbols that might already be in use. Otherwise, strange things are \
bound to happen. \nIt is a good idea to define a few frequently used \
alphabets such as \n",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}, \ {a, b, c}\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1}\)]],
  " beforehand, see also the section on shortcuts below. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[a, b, x, y, z]\), "\n", 
    \(al2 = {a, b}\), "\n", 
    \(alx = {x, y, z}\), "\n", 
    \(Words[3, al2]\), "\n", 
    \(Words[3, alx]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Alphabets can also be produced with the command ",
  StyleBox["MakeAlphabet", "SmallText"],
  ". The variant ",
  StyleBox["MakeFullAlphabet", "SmallText"],
  " returns a pair cardinality/alphabet."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(MakeAlphabet[\(-10\)]\), "\n", 
    \(MakeAlphabet[4]\), "\n", 
    \(MakeFullAlphabet[4]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Since alphabets whose symbols are digits like ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1}\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1, 2}\)]],
  " are used frequently, there is a shortcut for them: integer ",
  Cell[BoxData[
      \(TraditionalForm\`\(-k\)\)]],
  " represents alphabet  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalSigma]\_k = {0, 1, \[Ellipsis], k - 1}\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Words[2, \(-5\)]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that leading zeros are surpressed by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", so it will often be necessary to quote strings over these alphabets.\n\n\
Command ",
  StyleBox["Alphabet", "SmallText"],
  " produces the underlying alphabet of a finite state machine :"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Alphabet[m]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Transition\ Relation\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:13"],

Cell[TextData[{
  "The transition relation tau depends on the type of automaton under \
consideration. In automata we have adopted the following conventions.\n\n\
\[EmptyCircle]  In an SA, ",
  StyleBox["\[Tau]",
    FontFamily->"Symbol"],
  "  is list of triples ",
  Cell[BoxData[
      \(TraditionalForm\`{p, s, q}\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(s\)\(\ \ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " are integers, ",
  Cell[BoxData[
      \(TraditionalForm\`1\  \[LessEqual] \ p, q\  \[LessEqual] \ n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1\  \[LessEqual] \ s\  \[LessEqual] \ 
          k\  = \ \(\(|\)\(\(\[CapitalSigma]\)\(|\)\)\)\)]],
  ". Epsilon transitions are indicated by  ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  ".  Intuitively, the triple  ",
  Cell[BoxData[
      \(TraditionalForm\`{p, s, q}\)]],
  " indicates that the automaton can move from state ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " to state ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " under input ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ". The same convention applies to FAs. \n\[EmptyCircle]  In a NFA, the \
transition relation ",
  StyleBox["\[Tau]",
    FontFamily->"Symbol"],
  "  is implemented as a ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\ \[Cross]\ n\)\(\ \)\)\)]],
  "matrix of lists representing subsets of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([\)\(n\)\(]\)\)\)]],
  "  (where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the number of states and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " the size of the underlying alphabet). The list ",
  Cell[BoxData[
      \(TraditionalForm\`{q\_1, \[Ellipsis], q\_i}\)]],
  " in position ",
  Cell[BoxData[
      \(TraditionalForm\`\((s, p)\)\)]],
  " indicates that the automaton can move from state ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " under input ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " to one of the states ",
  Cell[BoxData[
      \(TraditionalForm\`q\_1, \[Ellipsis], q\_i\)]],
  ". \n\[EmptyCircle]  Lastly, in a DFA, the transitions are best viewed as a \
map   ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\  : \ \[CapitalSigma]\ \[Cross]Q\  \
\[RightArrow] \ Q\)]],
  ". ",
  StyleBox["\n",
    FontFamily->"Symbol"],
  "Thus we represent ",
  StyleBox["\[Tau]",
    FontFamily->"Symbol"],
  " by an ",
  Cell[BoxData[
      \(TraditionalForm\`k\ \[Cross]\ n\)]],
  " matrix with entries from ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([\)\(n\)\(]\)\)\)]],
  ". Entry ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " in position ",
  Cell[BoxData[
      \(TraditionalForm\`\((s, p)\)\)]],
  " indicates that the automaton moves from state ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " to state ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " under input ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ". \n\nCommand ",
  Cell[BoxData[
      \(TraditionalForm\`Transitions\)]],
  " extracts the transition relation of a finite state machine. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Transitions[m]\), "\n", 
    \(Transitions[ToNFA[m]]\), "\n", 
    \(Transitions[ToFA[m]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Again, note that the entries in the expressions representing transitions \
are all non-negative integers. Thus, integer ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " stands for the state ",
  Cell[BoxData[
      \(TraditionalForm\`Q[\([\)\(p\)\(]\)]\)]],
  " (which may be an integer but could also be more complicated Mathematica \
object such as, say, a list of pairs of integers or a list of words). \nWhen \
one constructs FSMs by hand it is on occasion more convenient to initially \
define transitions in terms of the real states of the machine. The command ",
  StyleBox["ConvertToFA", "SmallText"],
  " effects translation into standard form. It can be used when: \n(1)   \
Transitions are given with reference to states.\n(2)   For a DFA or NFA \
transitions are given as a list, rather than in matrix form.\n(3)   Initial \
and final states are given with reference to states.\nSee below for some \
applications. \n"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If it is necessary to display the symbols in a list of transitions \
directly rather than their positions in the alphabet one can use the command \
",
  StyleBox["FullTransitions", "SmallText"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(FullTransitions[ToFA[m]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Sometimes it is considerably more convenient to specify a list of \
transitions by making reference to the real states and/or the real symbols in \
the transitions.\nSince the entries in the expressions representing \
transitions in a FSM are all required to be non-negative integers, we need to \
apply a conversion routine to obtain a properly formed machine. Thus, integer \
",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " stands for the state ",
  Cell[BoxData[
      \(TraditionalForm\`Q[\([\)\(p\)\(]\)]\)]],
  ", which could be any Mathematica object, but typically will be a pair of \
integers, a word, or a list of words). \nThe command ",
  StyleBox["ConvertToFA", "SmallText"],
  " effects this translation into standard form. It can be used when: \n(1)   \
Transitions are given with reference to states and/or symbols.\n(2)   For a \
DFA or NFA transitions are given as a list, rather than in matrix form.\n(3)  \
 Initial and final states are given with reference to states.\nHere is a \
typical application: a machine that accepts any string of a's of length at \
least 2. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ConvertToFA[
      FA, {Eps, a, aa}, {a, 
        b}, {{Eps, a, a}, {a, a, aa}, {aa, a, aa}}, {Eps}, {aa}]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Conversions\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:14"],

Cell[TextData[{
  "Conversions between the different types of machines can be effected by the \
commands ",
  StyleBox["ToSA", "SmallText"],
  ", ",
  StyleBox["ToDFA", "SmallText"],
  ", ",
  StyleBox["ToNFA", "SmallText"],
  " and ",
  StyleBox["ToFA", "SmallText"],
  ". All four commands are polymorphic:  they accept as input all four types \
of machines. ",
  StyleBox["ToDFA", "SmallText"],
  " uses deterministic simulation and has therefore potentially exponential \
time and space requirements. By default, only the accessible part of the \
deterministic machine is constructed. If the full power set machine is \
required use the option ",
  StyleBox["Full->True", "SmallText"],
  ". Furthermore, the deterministic machine is automatically normalized. \
Normalization can be avoided with option  ",
  StyleBox["Normalize->1", "SmallText"],
  ". The last option is also available for ",
  StyleBox["ToNFA", "SmallText"],
  " and ",
  StyleBox["ToFA", "SmallText"],
  ".\n\nOf course, stripping off the initial and final states to obtain the \
underlying semiautomaton destroys the acceptance language of the machine. All \
the other commands preserve the language of the automaton. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(m = IthSymbolFA[a, \(-3\), {a, b}]\), "\n", 
    \(ToNFA[m]\), "\n", 
    \(ToSA[m]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Special\ Automata\)], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:15"],

Cell["\<\
Other than SAs, FAs, NFAs and DFAs,  the package also uses several \
normal forms for FSMs. Currently there are McNaughton-Yamada style machines, \
begin/exit automata and frontier automata; see below for a discussion.
No attempt has been made to extend all operations to all types of machines. \
The special machines can be converted to FAs and are used mostly for \
efficiency reasons, for example in the algorithm that translates regular \
expressions to finite automata. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating Machines", "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:16"],

Cell[TextData[{
  "The automata package contains several creator functions that generate FSMs \
from various  parameters. Their usage should be fairly obvious from the \
examples given below and their usage messages. To display a FSM, we provide a \
function ",
  StyleBox["PrintFA", "SmallText"],
  " (which works reasonably well for machines of up to about 20 states). For \
non-normalized FAs (as well as for large normalized machines) one can use \
option ",
  StyleBox["Full->True", "SmallText"],
  " to obtain a list of transitions in table form. Option ",
  StyleBox["TransOnly->True", "SmallText"],
  " will display only the transitions of the automaton (as a matrix for DFAs \
and NFAs, and as a table for FAs). \n\nThe procedure ",
  StyleBox["BuildDFA", "SmallText"],
  " constructs a DFA that accepts a given word or list of words. The input \
may be given as a sequence or a list of words. The underlying alphabet is \
specified as the last input field. ",
  StyleBox["BuildDFA", "SmallText"],
  " automatically constructs the minimal automaton for the specified finite \
language."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(m1 = BuildDFA[aaa, {a, b}, Normalize \[Rule] 1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintFA[m1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(PrintFA[m1, Full \[Rule] True, TransOnly \[Rule] True]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(m2 = Size[MinimizeFA[m1]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(LanguageFA[m1, \(-5\)]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["BuildDFA", "SmallText"],
  " also accomodates finite sets of words. For example: "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(L = {Eps, aa, bb, aba}\), "\n", 
    \(BuildDFA[L, {a, b, c}]\), "\n", 
    \(LL = Flatten[LanguageFA[%, \(-4\)]]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The command  ",
  StyleBox["BuildDFA", "SmallText"],
  " also accepts sequences of words as input. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((LanguageFA[#1, \(-3\)] &)\)[
      BuildDFA[Eps, aa, bb, {a, b, c, d}]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "As pointed out above, words output by any of the procedures in automata \
are ",
  StyleBox["Mathematica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  " strings.  This avoids the accumulation of huge numbers of symbols during \
a session.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Head /@ L\), "\n", 
    \(Head /@ LL\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To obtain an automaton for all words of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(ww ... \) w\)]],
  " one can use the command ",
  StyleBox["BuildStarDFA", "SmallText"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(BuildStarDFA[aaab, {a, b}]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "There are special constructors for DFAs accepting the empty set, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\^*\)\)]],
  " and \[CapitalSigma]",
  StyleBox["+",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  " (the machines are chosen so that they remain invariant under application \
of ",
  StyleBox["MinimizeFA", "SmallText"],
  "):"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(EmptyDFA[{a, b, c}]\), "\n", 
    \(AllDFA[{a, b, c}]\), "\n", 
    \(AllPlusDFA[{a, b, c}]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A DFA that accepts all words over the alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c}\)]],
  " that contain a fixed number of occurrences of a certain symbol is \
generated by the command ",
  StyleBox["CounterDFA", "SmallText"],
  ". All strings over ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1}\)]],
  "  with exactly 3 1's are produced by:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(DIG = {0, 1};\)\), "\n", 
    \(CounterDFA["\<1\>", 3, DIG]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Alternatively, we can use the shortcut to specify the alphabet DIG \
by the integer -2:\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(CounterDFA["\<1\>", 3, \(-2\)]\), "\n", 
    \(Alphabet[%]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the second field in the DFA is now -2. \n\nDFAs generated by \
command ",
  StyleBox["ModCounterDFA", "SmallText"],
  " count the occurrences of a symbol modulo some parameter.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ModCounterDFA[b, 1, 3, {a, b, c}]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The commands ",
  StyleBox["PrefixDFA", "SmallText"],
  ", ",
  StyleBox["InfixFA", "SmallText"],
  " and ",
  StyleBox["SuffixFA", "SmallText"],
  " produce machines that accept words with a given prefix, infix and suffix, \
respectively. They all have the  option ",
  StyleBox["Normalize->0", "SmallText"],
  " which sets the state set to the prefixes of the given word. \n(To avoid \
the standard confusion, we use the terminology infix or factor versus \
subword.)"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(PrefixDFA[abbb, {a, b}]\), "\n", 
    \(InfixFA[abbb, {a, b}]\), "\n", 
    \(m = SuffixFA[abbb, {a, b}, Normalize \[Rule] 1]\), "\n", 
    \(States[%]\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The structured state set becomes visible in other operations:\
\>", \
"Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(MatrixForm[AcceptQFA[m, abbabbb, DoTrace \[Rule] True]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "A DFA that tests its input for the occurrence of some given word w as a \
subword is generated by the command SubwordDFA. Similarly, a DFA that counts \
the number of  occurrences of some given word w as a subword of its input \
modulo p is produced by ",
  StyleBox["SubwordModCounterDFA[w,i,p,K]", "SmallText"],
  ". Option ",
  StyleBox["Normalize->1", "SmallText"],
  " produces a state set of the form  ",
  Cell[BoxData[
      \(TraditionalForm\`Q \[SubsetEqual] {0, 1, \[Ellipsis], p - 1}\^\(\(|\)\
\(w\)\(|\)\)\)]],
  ", which is natural if one considers the algorithm used in the construction \
of the automaton."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SubwordDFA[abb, {a, b}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Maab = 
        SubwordModCounterDFA[aab, 1, 5, {a, b}, 
          Normalize \[Rule] 1];\)\), "\n", 
    \(Size[Maab]\), "\n", 
    \(States[Maab]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Here are all words of length 6 with exactly 1 mod 5 subwords ",
  Cell[BoxData[
      \(TraditionalForm\`aab\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ColumnForm[LanguageFA[Maab, \(-7\)]]\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
Lastly, the next commands construct deterministic and \
nondeterministic machines for languages of all strings whose i-th symbol is \
fixed. Here i is an integer different from 0.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(IthSymbolFA[b, 3, {a, b, c}]\), "\n", 
    \(IthSymbolFA[b, \(-3\), {a, b, c}]\), "\n", 
    \(IthSymbolDFA[b, 3, {a, b, c}]\), "\n", 
    \(IthSymbolDFA[b, \(-2\), {a, b, c}, Normalize \[Rule] 0]\)}], "Input"],

Cell[CellGroupData[{

Cell["  Shortcuts", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"c:17"],

Cell[TextData[{
  "There are numerous commands in this package that require the user to type \
in an alphabet. To make this process a little less time consuming there is a \
global variable ",
  StyleBox["$alphabet", "SmallText"],
  " that provides a default for the alphabet in many commands. ",
  StyleBox["$alphabet", "SmallText"],
  " is initialized to ",
  StyleBox["{a,b}", "SmallText"],
  " in this notebook and can be changed by the user (the change won't take \
effect until you reload the package, though). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \($alphabet\), "\n", 
    \(Words[3]\), "\n", 
    \(AllDFA[]\), "\n", 
    \(LanguageFA[%, 3]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "In case of doubt, it is always a good idea to write the alphabet the \
standard way. For digit alphabets of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1, \(\(...\)\(,\)\(k\)\) - 1}\)]],
  " one can simply specify ",
  Cell[BoxData[
      \(TraditionalForm\`\(-k\)\)]],
  " rather than typing in the corresponding list of integers. For letter \
alphabets like ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c}\)]],
  " positive integers serve as abbreviations (e.g., ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c}\)]],
  " is represented by 3)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Words[3, 3]\), "\n", 
    \(AllDFA[\(-3\)]\), "\n", 
    \(LanguageFA[%, 3]\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To make life easy for the casual reader, we will not use any abbreviations \
in this notebook. Other strange commands that might occur on occasion can all \
be found in ",
  StyleBox["dimath.m", "SmallText"],
  ", together with explanations how they work. Typical examples are ",
  StyleBox["Zwei", "SmallText"],
  " and ",
  StyleBox["Drei", "SmallText"],
  ". \n\nExercise:  Determine what commands Zwei and Drei do. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1003, 992},
WindowMargins->{{85, Automatic}, {Automatic, 0}},
PrintingStartingPageNumber->1,
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
CellLabelAutoDelete->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->Automatic,
Magnification->1.5,
StyleDefinitions -> "Demo.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1762, 52, 147, 4, 88, "Title",
      Evaluatable->False,
      CellTags->"c:1"]},
  "c:2"->{
    Cell[1934, 60, 102, 3, 124, "Section",
      Evaluatable->False,
      CellTags->"c:2"]},
  "c:3"->{
    Cell[2061, 67, 51, 1, 66, "Subsection",
      CellTags->"c:3"]},
  "c:4"->{
    Cell[4040, 112, 53, 1, 55, "Subsection",
      CellTags->"c:4"]},
  "c:5"->{
    Cell[4338, 126, 105, 3, 75, "Section",
      Evaluatable->False,
      CellTags->"c:5"]},
  "c:6"->{
    Cell[4468, 133, 96, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:6"]},
  "c:7"->{
    Cell[18078, 629, 115, 3, 55, "Subsection",
      Evaluatable->False,
      CellTags->"c:7"]},
  "c:8"->{
    Cell[21831, 756, 121, 3, 75, "Section",
      Evaluatable->False,
      CellTags->"c:8"]},
  "c:9"->{
    Cell[21977, 763, 156, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:9"]},
  "c:10"->{
    Cell[30173, 1021, 88, 2, 56, "Subsubsection",
      CellTags->"c:10"]},
  "c:11"->{
    Cell[31698, 1071, 134, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:11"]},
  "c:12"->{
    Cell[37027, 1237, 132, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:12"]},
  "c:13"->{
    Cell[39476, 1325, 143, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:13"]},
  "c:14"->{
    Cell[45788, 1518, 134, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:14"]},
  "c:15"->{
    Cell[47362, 1565, 140, 4, 57, "Subsection",
      Evaluatable->False,
      CellTags->"c:15"]},
  "c:16"->{
    Cell[48101, 1587, 106, 3, 75, "Section",
      Evaluatable->False,
      CellTags->"c:16"]},
  "c:17"->{
    Cell[55954, 1855, 101, 3, 66, "Subsection",
      Evaluatable->False,
      CellTags->"c:17"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 59049, 1951},
  {"c:2", 59151, 1955},
  {"c:3", 59256, 1959},
  {"c:4", 59336, 1962},
  {"c:5", 59417, 1965},
  {"c:6", 59522, 1969},
  {"c:7", 59629, 1973},
  {"c:8", 59738, 1977},
  {"c:9", 59844, 1981},
  {"c:10", 59954, 1985},
  {"c:11", 60042, 1988},
  {"c:12", 60154, 1992},
  {"c:13", 60266, 1996},
  {"c:14", 60378, 2000},
  {"c:15", 60490, 2004},
  {"c:16", 60602, 2008},
  {"c:17", 60711, 2012}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 54, 0, 40, "SmallText"],
Cell[1762, 52, 147, 4, 88, "Title",
  Evaluatable->False,
  CellTags->"c:1"],

Cell[CellGroupData[{
Cell[1934, 60, 102, 3, 124, "Section",
  Evaluatable->False,
  CellTags->"c:2"],

Cell[CellGroupData[{
Cell[2061, 67, 51, 1, 66, "Subsection",
  CellTags->"c:3"],
Cell[2115, 70, 1888, 37, 602, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[4040, 112, 53, 1, 55, "Subsection",
  CellTags->"c:4"],
Cell[4096, 115, 193, 5, 63, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4338, 126, 105, 3, 75, "Section",
  Evaluatable->False,
  CellTags->"c:5"],

Cell[CellGroupData[{
Cell[4468, 133, 96, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:6"],
Cell[4567, 138, 2622, 65, 516, "Text",
  Evaluatable->False],
Cell[7192, 205, 102, 3, 68, "Input"],
Cell[7297, 210, 100, 2, 45, "Input"],
Cell[7400, 214, 179, 6, 44, "Text",
  Evaluatable->False],
Cell[7582, 222, 129, 3, 45, "Input"],
Cell[7714, 227, 162, 6, 44, "Text",
  Evaluatable->False],
Cell[7879, 235, 121, 3, 45, "Input"],
Cell[8003, 240, 141, 5, 44, "Text",
  Evaluatable->False],
Cell[8147, 247, 131, 3, 45, "Input"],
Cell[8281, 252, 394, 12, 66, "Text",
  Evaluatable->False],
Cell[8678, 266, 185, 4, 91, "Input"],
Cell[8866, 272, 113, 3, 44, "Text"],
Cell[8982, 277, 86, 2, 45, "Input"],
Cell[9071, 281, 548, 20, 66, "Text",
  Evaluatable->False],
Cell[9622, 303, 115, 3, 68, "Input"],
Cell[9740, 308, 141, 5, 41, "Text",
  Evaluatable->False],
Cell[9884, 315, 68, 2, 45, "Input"],
Cell[9955, 319, 169, 4, 43, "Text",
  Evaluatable->False],
Cell[10127, 325, 67, 2, 45, "Input"],
Cell[10197, 329, 145, 5, 44, "Text",
  Evaluatable->False],
Cell[10345, 336, 150, 4, 91, "Input"],
Cell[10498, 342, 241, 7, 63, "Text",
  Evaluatable->False],
Cell[10742, 351, 113, 3, 68, "Input"],
Cell[10858, 356, 337, 12, 63, "Text",
  Evaluatable->False],
Cell[11198, 370, 50, 1, 45, "Input"],
Cell[11251, 373, 271, 9, 63, "Text",
  Evaluatable->False],
Cell[11525, 384, 94, 2, 45, "Input"],
Cell[11622, 388, 178, 5, 44, "Text",
  Evaluatable->False],
Cell[11803, 395, 94, 2, 45, "Input"],
Cell[11900, 399, 236, 6, 60, "Text",
  Evaluatable->False],
Cell[12139, 407, 117, 3, 68, "Input"],
Cell[12259, 412, 451, 17, 63, "Text",
  Evaluatable->False],
Cell[12713, 431, 123, 3, 68, "Input"],
Cell[12839, 436, 111, 3, 68, "Input"],
Cell[12953, 441, 98, 2, 45, "Input"],
Cell[13054, 445, 759, 27, 106, "Text",
  Evaluatable->False],
Cell[13816, 474, 233, 6, 92, "Input"],
Cell[14052, 482, 67, 2, 45, "Input"],
Cell[14122, 486, 563, 15, 130, "Text",
  Evaluatable->False],
Cell[14688, 503, 101, 2, 45, "Input"],
Cell[14792, 507, 120, 3, 75, "Input"],
Cell[14915, 512, 186, 6, 44, "Text",
  Evaluatable->False],
Cell[15104, 520, 82, 2, 45, "Input"],
Cell[15189, 524, 242, 6, 60, "Text",
  Evaluatable->False],
Cell[15434, 532, 81, 2, 45, "Input"],
Cell[15518, 536, 87, 2, 45, "Input"],
Cell[15608, 540, 888, 26, 108, "Text",
  Evaluatable->False],
Cell[16499, 568, 132, 3, 45, "Input"],
Cell[16634, 573, 90, 2, 45, "Input"],
Cell[16727, 577, 349, 11, 63, "Text",
  Evaluatable->False],
Cell[17079, 590, 132, 3, 45, "Input"],
Cell[17214, 595, 132, 3, 68, "Input"],
Cell[17349, 600, 119, 2, 41, "Text",
  Evaluatable->False],
Cell[17471, 604, 73, 2, 45, "Input"],
Cell[17547, 608, 293, 8, 63, "Text",
  Evaluatable->False],
Cell[17843, 618, 98, 2, 45, "Input"],
Cell[17944, 622, 97, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18078, 629, 115, 3, 55, "Subsection",
  Evaluatable->False,
  CellTags->"c:7"],
Cell[18196, 634, 336, 7, 79, "Text",
  Evaluatable->False],
Cell[18535, 643, 199, 5, 101, "Input"],
Cell[18737, 650, 126, 4, 91, "Input"],
Cell[18866, 656, 166, 3, 68, "Input"],
Cell[19035, 661, 178, 5, 41, "Text",
  Evaluatable->False],
Cell[19216, 668, 116, 3, 68, "Input"],
Cell[19335, 673, 83, 3, 43, "Text",
  Evaluatable->False],
Cell[19421, 678, 70, 2, 45, "Input"],
Cell[19494, 682, 116, 2, 45, "Input"],
Cell[19613, 686, 1451, 41, 266, "Text",
  Evaluatable->False],
Cell[21067, 729, 335, 8, 156, "Input"],
Cell[21405, 739, 180, 5, 41, "Text",
  Evaluatable->False],
Cell[21588, 746, 194, 4, 91, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[21831, 756, 121, 3, 75, "Section",
  Evaluatable->False,
  CellTags->"c:8"],

Cell[CellGroupData[{
Cell[21977, 763, 156, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:9"],
Cell[22136, 769, 2565, 72, 429, "Text",
  Evaluatable->False],
Cell[24704, 843, 1084, 33, 117, "Text",
  Evaluatable->False],
Cell[25791, 878, 807, 26, 80, "Text",
  Evaluatable->False],
Cell[26601, 906, 2661, 74, 593, "Text",
  Evaluatable->False],
Cell[29265, 982, 73, 2, 45, "Input"],
Cell[29341, 986, 93, 2, 45, "Input"],
Cell[29437, 990, 67, 2, 45, "Input"],
Cell[29507, 994, 85, 2, 45, "Input"],
Cell[29595, 998, 66, 2, 45, "Input"],
Cell[29664, 1002, 276, 6, 60, "Text",
  Evaluatable->False],
Cell[29943, 1010, 205, 7, 160, "Input"],

Cell[CellGroupData[{
Cell[30173, 1021, 88, 2, 56, "Subsubsection",
  CellTags->"c:10"],
Cell[30264, 1025, 374, 8, 79, "Text",
  Evaluatable->False],
Cell[30641, 1035, 80, 2, 45, "Input"],
Cell[30724, 1039, 593, 14, 110, "Text",
  Evaluatable->False],
Cell[31320, 1055, 220, 6, 60, "Text",
  Evaluatable->False],
Cell[31543, 1063, 106, 2, 68, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31698, 1071, 134, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:11"],
Cell[31835, 1076, 1643, 36, 273, "Text",
  Evaluatable->False],
Cell[33481, 1114, 199, 5, 114, "Input"],
Cell[33683, 1121, 189, 8, 44, "Text",
  Evaluatable->False],
Cell[33875, 1131, 76, 2, 45, "Input"],
Cell[33954, 1135, 251, 6, 63, "Text",
  Evaluatable->False],
Cell[34208, 1143, 125, 3, 68, "Input"],
Cell[34336, 1148, 272, 6, 60, "Text",
  Evaluatable->False],
Cell[34611, 1156, 127, 3, 68, "Input"],
Cell[34741, 1161, 985, 31, 214, "Text",
  Evaluatable->False],
Cell[35729, 1194, 367, 8, 91, "Text",
  Evaluatable->False],
Cell[36099, 1204, 135, 3, 68, "Input"],
Cell[36237, 1209, 154, 3, 68, "Input"],
Cell[36394, 1214, 157, 5, 41, "Text",
  Evaluatable->False],
Cell[36554, 1221, 157, 3, 45, "Input"],
Cell[36714, 1226, 276, 6, 60, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[37027, 1237, 132, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:12"],
Cell[37162, 1243, 620, 15, 144, "Text",
  Evaluatable->False],
Cell[37785, 1260, 202, 6, 137, "Input"],
Cell[37990, 1268, 277, 8, 63, "Text",
  Evaluatable->False],
Cell[38270, 1278, 150, 4, 91, "Input"],
Cell[38423, 1284, 494, 16, 60, "Text",
  Evaluatable->False],
Cell[38920, 1302, 75, 2, 45, "Input"],
Cell[38998, 1306, 368, 10, 124, "Text",
  Evaluatable->False],
Cell[39369, 1318, 70, 2, 45, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[39476, 1325, 143, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:13"],
Cell[39622, 1331, 3244, 109, 372, "Text",
  Evaluatable->False],
Cell[42869, 1442, 150, 4, 91, "Input"],
Cell[43022, 1448, 1014, 20, 306, "Text",
  Evaluatable->False],
Cell[44039, 1470, 280, 8, 63, "Text",
  Evaluatable->False],
Cell[44322, 1480, 83, 2, 45, "Input"],
Cell[44408, 1484, 1175, 23, 305, "Text",
  Evaluatable->False],
Cell[45586, 1509, 165, 4, 68, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[45788, 1518, 134, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:14"],
Cell[45925, 1524, 1253, 30, 229, "Text",
  Evaluatable->False],
Cell[47181, 1556, 144, 4, 91, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47362, 1565, 140, 4, 57, "Subsection",
  Evaluatable->False,
  CellTags->"c:15"],
Cell[47505, 1571, 547, 10, 129, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[48101, 1587, 106, 3, 75, "Section",
  Evaluatable->False,
  CellTags->"c:16"],
Cell[48210, 1592, 1155, 23, 250, "Text",
  Evaluatable->False],
Cell[49368, 1617, 106, 2, 45, "Input"],
Cell[49477, 1621, 70, 2, 45, "Input"],
Cell[49550, 1625, 113, 2, 45, "Input"],
Cell[49666, 1629, 84, 2, 45, "Input"],
Cell[49753, 1633, 81, 2, 45, "Input"],
Cell[49837, 1637, 170, 5, 44, "Text",
  Evaluatable->False],
Cell[50010, 1644, 174, 4, 91, "Input"],
Cell[50187, 1650, 179, 6, 44, "Text",
  Evaluatable->False],
Cell[50369, 1658, 133, 3, 45, "Input"],
Cell[50505, 1663, 329, 10, 60, "Text",
  Evaluatable->False],
Cell[50837, 1675, 97, 3, 68, "Input"],
Cell[50937, 1680, 268, 9, 44, "Text",
  Evaluatable->False],
Cell[51208, 1691, 85, 2, 45, "Input"],
Cell[51296, 1695, 447, 13, 75, "Text",
  Evaluatable->False],
Cell[51746, 1710, 152, 4, 91, "Input"],
Cell[51901, 1716, 443, 13, 63, "Text",
  Evaluatable->False],
Cell[52347, 1731, 122, 3, 68, "Input"],
Cell[52472, 1736, 159, 5, 41, "Text",
  Evaluatable->False],
Cell[52634, 1743, 119, 3, 68, "Input"],
Cell[52756, 1748, 268, 7, 105, "Text",
  Evaluatable->False],
Cell[53027, 1757, 92, 2, 45, "Input"],
Cell[53122, 1761, 549, 15, 116, "Text",
  Evaluatable->False],
Cell[53674, 1778, 212, 5, 114, "Input"],
Cell[53889, 1785, 135, 5, 41, "Text",
  Evaluatable->False],
Cell[54027, 1792, 114, 2, 45, "Input"],
Cell[54144, 1796, 701, 16, 104, "Text",
  Evaluatable->False],
Cell[54848, 1814, 82, 2, 45, "Input"],
Cell[54933, 1818, 209, 6, 91, "Input"],
Cell[55145, 1826, 198, 7, 41, "Text",
  Evaluatable->False],
Cell[55346, 1835, 95, 2, 45, "Input"],
Cell[55444, 1839, 251, 6, 60, "Text",
  Evaluatable->False],
Cell[55698, 1847, 231, 4, 114, "Input"],

Cell[CellGroupData[{
Cell[55954, 1855, 101, 3, 66, "Subsection",
  Evaluatable->False,
  CellTags->"c:17"],
Cell[56058, 1860, 578, 13, 104, "Text",
  Evaluatable->False],
Cell[56639, 1875, 153, 5, 114, "Input"],
Cell[56795, 1882, 648, 18, 79, "Text",
  Evaluatable->False],
Cell[57446, 1902, 136, 4, 91, "Input"],
Cell[57585, 1908, 499, 12, 147, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

