(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    694640,      27374]*)
(*NotebookOutlinePosition[    975748,      34728]*)
(*  CellTagsIndexPosition[    966847,      34461]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["AcceptQFA", "ObjectName",
  CellTags->"AcceptQFA"],

Cell["Type: function", "Highlight",
  CellTags->"AcceptQFA"],

Cell[TextData[{
  StyleBox["AcceptQFA[M,w]", "MR"],
  "  tests whether machine M accepts input w. "
}], "Usage",
  CellTags->"AcceptQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"},
          {"Multiplicity", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"AcceptQFA"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True", "MR"],
  " produces a trace of the computation. "
}], "Notes",
  CellTags->"AcceptQFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Multiplicity->True", "MR"],
  " computes the multiplicity of w with respect to M."
}], "Notes",
  CellTags->"AcceptQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AcceptQFA"],

Cell[TextData[{
  "A machine for all words containting exactly two ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s."
}], "ExampleText",
  CellTags->"AcceptQFA"],

Cell[CellGroupData[{

Cell["M = CounterDFA[a,2]", "Input",
  CellLabel->"In[146]:=",
  CellTags->"AcceptQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 4}, {1, 2, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[146]=",
  CellTags->"AcceptQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AcceptQFA[M, babab]\)], "Input",
  CellLabel->"In[147]:=",
  CellTags->"AcceptQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[147]=",
  CellTags->"AcceptQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AcceptQFA[M, babab, DoTrace \[Rule] True]\)], "Input",
  CellLabel->"In[149]:=",
  CellTags->"AcceptQFA"],

Cell[BoxData[
    \({1, 1, 2, 2, 3, 3}\)], "Output",
  CellLabel->"Out[149]=",
  CellTags->"AcceptQFA"]
}, Open  ]],

Cell["All accepted words of length 4.", "ExampleText",
  CellTags->"AcceptQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[\ Words[4], AcceptQFA[M, #] &\ ]\)], "Input",
  CellLabel->"In[148]:=",
  CellTags->"AcceptQFA"],

Cell[BoxData[
    \({"aabb", "abab", "abba", "baab", "baba", "bbaa"}\)], "Output",
  CellLabel->"Out[148]=",
  CellTags->"AcceptQFA"]
}, Open  ]]
}, Closed]],

Cell["AccessibleFA", "ObjectName",
  CellTags->"AccessibleFA"],

Cell["Type: function", "Highlight",
  CellTags->"AccessibleFA"],

Cell[TextData[{
  StyleBox["AccessibleFA[M]", "MR"],
  "  constructs the accessible part of a FSM ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"AccessibleFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"AccessibleFA"],

Cell["The initial state of a DFA is renumbered to 1. ", "Notes",
  CellTags->"AccessibleFA"],

Cell["\<\
The operation is idempotent and can be used to check equivalence of \
DFAs. \
\>", "Notes",
  CellTags->"AccessibleFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["CoAccessibleFA",
    ButtonData:>"CoAccessibleFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["TrimFA",
    ButtonData:>"TrimFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AccessibleFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AccessibleFA"],

Cell["\<\
 A machine on 5 states, two of which fail to be accessible.  The \
accessible part is equivalent to the original machine.\
\>", "MathCaption",
  CellTags->"AccessibleFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ 
      FA[\ 5, \ 2, \ {{1, 1, 3}, {3, 2, 4}, {2, 1, 1}, {2, 2, 
            5}}, {1}, {4}, {}, {a, b, c, d, e}]\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"AccessibleFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{1, 1, 3}, {3, 2, 4}, {2, 1, 1}, {2, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[9]=",
  CellTags->"AccessibleFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ma\  = \ AccessibleFA[m]\), "\n", 
    \(EquivalentQFA[m, ma]\)}], "Input",
  CellLabel->"In[10]:=",
  CellTags->"AccessibleFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {2, 2, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[10]=",
  CellTags->"AccessibleFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[11]=",
  CellTags->"AccessibleFA"]
}, Open  ]],

Cell[" We can preserve the state set of the original machine.", "MathCaption",
  CellTags->"AccessibleFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AccessibleFA[m, Normalize \[Rule] 1]\  // \ States\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"AccessibleFA"],

Cell[BoxData[
    \({1, 3, 4}\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->"AccessibleFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AccessibleFA[m, Normalize \[Rule] 2]\  // \ States\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->"AccessibleFA"],

Cell[BoxData[
    \({a, c, d}\)], "Output",
  CellLabel->"Out[14]=",
  CellTags->"AccessibleFA"]
}, Open  ]]
}, Closed]],

Cell["AddTransitionFA", "ObjectName",
  CellTags->"AddTransitionFA"],

Cell["Type: function", "Highlight",
  CellTags->"AddTransitionFA"],

Cell[TextData[{
  StyleBox["AddTransitionFA[M,p,w,q]", "MR"],
  "  adds the transition ",
  StyleBox["{p,w,q}", "MR"],
  " to ",
  StyleBox["M", "MR"],
  ". Can also be used in the form ",
  StyleBox["AddTransitionFA[M,{p,w,q}]", "MR"],
  " or ",
  StyleBox["AddTransitionFA[M,L]", "MR"],
  " where ",
  StyleBox["L", "MR"],
  " is a list of transitions."
}], "Usage",
  CellTags->"AddTransitionFA"],

Cell["\<\
Here w may be a word in which case a sequence of transitions is \
inserted.\
\>", "Notes",
  CellTags->"AddTransitionFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["RemoveTransitionFA",
    ButtonData:>"RemoveTransitionFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AddTransitionFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AddTransitionFA"],

Cell["A machine recognizing only the word aaa.", "ExampleText",
  CellTags->"AddTransitionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m\  = \ 
      FA[\ 4, \ 3, \ {{1, 1, 2}, {2, 1, 3}, {3, 1, 4}}, {1}, {4}]\), "\n", 
    \(LanguageFA[m, \(-5\)]\)}], "Input",
  CellLabel->"In[534]:=",
  CellTags->"AddTransitionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "3", ",", 
          TagBox[\({{1, 1, 2}, {2, 1, 3}, {3, 1, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[534]=",
  CellTags->"AddTransitionFA"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa"}, {}, {}}\)], "Output",
  CellLabel->"Out[535]=",
  CellTags->"AddTransitionFA"]
}, Open  ]],

Cell[TextData[{
  "We add a back-transition labeled ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "."
}], "ExampleText",
  CellTags->"AddTransitionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m1 = AddTransitionFA[m, \ 4, b, 2\ \ ]\), "\n", 
    \(LanguageFA[m1, \(-15\)\ ]\)}], "Input",
  CellLabel->"In[546]:=",
  CellTags->"AddTransitionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "3", ",", 
          TagBox[\({{1, 1, 2}, {2, 1, 3}, {3, 1, 4}, {4, 2, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[546]=",
  CellTags->"AddTransitionFA"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa"}, {}, {}, {"aaabaa"}, {}, {}, {"aaabaabaa"}, {}, \
{}, {"aaabaabaabaa"}, {}, {}, {"aaabaabaabaabaa"}}\)], "Output",
  CellLabel->"Out[547]=",
  CellTags->"AddTransitionFA"]
}, Open  ]],

Cell[TextData[{
  "And another back-transition labeled ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "."
}], "ExampleText",
  CellTags->"AddTransitionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m2 = AddTransitionFA[m1, \ 4, c, 2\ \ ];\)\), "\n", 
    \(LanguageFA[m2, \(-15\)\ ]\)}], "Input",
  CellLabel->"In[550]:=",
  CellTags->"AddTransitionFA"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa"}, {}, {}, {"aaabaa", 
        "aaacaa"}, {}, {}, {"aaabaabaa", "aaabaacaa", "aaacaabaa", 
        "aaacaacaa"}, {}, {}, {"aaabaabaabaa", "aaabaabaacaa", 
        "aaabaacaabaa", "aaabaacaacaa", "aaacaabaabaa", "aaacaabaacaa", 
        "aaacaacaabaa", "aaacaacaacaa"}, {}, {}, {"aaabaabaabaabaa", 
        "aaabaabaabaacaa", "aaabaabaacaabaa", "aaabaabaacaacaa", 
        "aaabaacaabaabaa", "aaabaacaabaacaa", "aaabaacaacaabaa", 
        "aaabaacaacaacaa", "aaacaabaabaabaa", "aaacaabaabaacaa", 
        "aaacaabaacaabaa", "aaacaabaacaacaa", "aaacaacaabaabaa", 
        "aaacaacaabaacaa", "aaacaacaacaabaa", "aaacaacaacaacaa"}}\)], "Output",\

  CellLabel->"Out[551]=",
  CellTags->"AddTransitionFA"]
}, Open  ]]
}, Closed]],

Cell["AllDFA", "ObjectName",
  CellTags->"AllDFA"],

Cell["Type: function", "Highlight",
  CellTags->"AllDFA"],

Cell[TextData[{
  StyleBox["AllDFA[K]", "MR"],
  "  constructs a DFA that accepts all words over alphabet ",
  StyleBox["K", "MR"],
  "."
}], "Usage",
  CellTags->"AllDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "True", "False"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"AllDFA"],

Cell[TextData[{
  "With option  ",
  StyleBox["Full\[Rule]False", "MR"],
  "  only non-empty words are accepted."
}], "Notes",
  CellTags->"AllDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AllDFA"],

Cell[TextData[{
  "A DFA accepting all non-empty words over the alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c}\)]],
  ". "
}], "ExampleText",
  CellTags->"AllDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AllDFA[{a, b, c}, Full \[Rule] False]\)], "Input",
  CellLabel->"In[120]:=",
  CellTags->"AllDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"2", ",", "3", ",", 
          TagBox[\({{2, 2}, {2, 2}, {2, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[120]=",
  CellTags->"AllDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[%, \(-3\)]\)], "Input",
  CellLabel->"In[121]:=",
  CellTags->"AllDFA"],

Cell[BoxData[
    \({{}, {"a", "b", "c"}, {"aa", "ab", "ac", "ba", "bb", "bc", "ca", "cb", 
        "cc"}, {"aaa", "aab", "aac", "aba", "abb", "abc", "aca", "acb", 
        "acc", "baa", "bab", "bac", "bba", "bbb", "bbc", "bca", "bcb", "bcc", 
        "caa", "cab", "cac", "cba", "cbb", "cbc", "cca", "ccb", 
        "ccc"}}\)], "Output",
  CellLabel->"Out[121]=",
  CellTags->"AllDFA"]
}, Open  ]]
}, Closed]],

Cell["AlphabetSize", "ObjectName",
  CellTags->"AlphabetSize"],

Cell["Type: function", "Highlight",
  CellTags->"AlphabetSize"],

Cell[TextData[{
  StyleBox["AlphabetSize[K]", "MR"],
  "  returns the size of the alphabet ",
  StyleBox["K", "MR"],
  ". "
}], "Usage",
  CellTags->"AlphabetSize"],

Cell["Also applicable to machines.", "Notes",
  CellTags->"AlphabetSize"],

Cell[TextData[{
  "See also ",
  ButtonBox["Alphabet",
    ButtonData:>"Alphabet",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["FullAlphabet",
    ButtonData:>"FullAlphabet",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AlphabetSize"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AlphabetSize"],

Cell["The size of the alphabet of a machine.", "ExampleText",
  CellTags->"AlphabetSize"],

Cell[CellGroupData[{

Cell[TextData[{
  "m = IthSymbolFA[a,-5,{a,b,c}];",
  "\n",
  Cell[BoxData[
      \(AlphabetSize[m]\)], "Input",
    CellLabel->"In[127]:="]
}], "Input",
  CellLabel->"In[130]:=",
  CellTags->"AlphabetSize"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[131]=",
  CellTags->"AlphabetSize"]
}, Open  ]],

Cell["Some canonical alphabets.", "ExampleText",
  CellTags->"AlphabetSize"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlphabetSize[{a, b, c}]\)], "Input",
  CellLabel->"In[132]:=",
  CellTags->"AlphabetSize"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[132]=",
  CellTags->"AlphabetSize"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlphabetSize[\(-5\)]\)], "Input",
  CellLabel->"In[133]:=",
  CellTags->"AlphabetSize"],

Cell[BoxData[
    \(5\)], "Output",
  CellLabel->"Out[133]=",
  CellTags->"AlphabetSize"]
}, Open  ]]
}, Closed]],

Cell["Alphabet", "ObjectName",
  CellTags->"Alphabet"],

Cell["Type: function", "Highlight",
  CellTags->"Alphabet"],

Cell[TextData[{
  StyleBox["Alphabet[M]", "MR"],
  "  returns the proper alphabet of machine ",
  StyleBox["M", "MR"],
  "."
}], "Usage",
  CellTags->"Alphabet"],

Cell[TextData[{
  StyleBox["M", "MR"],
  " is a finite state machine or a cellular automaton."
}], "Notes",
  CellTags->"Alphabet"],

Cell["Also applies to words and lists of words.", "Notes",
  CellTags->"Alphabet"],

Cell[TextData[{
  " See also ",
  ButtonBox["AlphabetSize",
    ButtonData:>"AlphabetSize",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["FullAlphabet",
    ButtonData:>"FullAlphabet",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Alphabet"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Alphabet"],

Cell["The underlying alphabet of a machine.", "ExampleText",
  CellTags->"Alphabet"],

Cell[CellGroupData[{

Cell[TextData[{
  "m = IthSymbolFA[a,-5,{a,b,c}];",
  "\n",
  Cell[BoxData[
      \(Alphabet[m]\)], "Input",
    CellLabel->"In[127]:="]
}], "Input",
  CellLabel->"In[136]:=",
  CellTags->"Alphabet"],

Cell[BoxData[
    \({"a", "b", "c"}\)], "Output",
  CellLabel->"Out[137]=",
  CellTags->"Alphabet"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "m = IthSymbolFA[a,-5,3];\n",
  Cell[BoxData[
      \(Alphabet[m]\)], "Input",
    CellLabel->"In[127]:="]
}], "Input",
  CellLabel->"In[138]:=",
  CellTags->"Alphabet"],

Cell[BoxData[
    \({"a", "b", "c"}\)], "Output",
  CellLabel->"Out[139]=",
  CellTags->"Alphabet"]
}, Open  ]],

Cell["The alphabet of a word.", "ExampleText",
  CellTags->"Alphabet"],

Cell[CellGroupData[{

Cell["Alphabet[\"hello\"]", "Input",
  CellLabel->"In[141]:=",
  CellTags->"Alphabet"],

Cell[BoxData[
    \({"e", "h", "l", "o"}\)], "Output",
  CellLabel->"Out[141]=",
  CellTags->"Alphabet"]
}, Open  ]]
}, Closed]],

Cell["AmbiguousQFA", "ObjectName",
  CellTags->"AmbiguousQFA"],

Cell["Type: function", "Highlight",
  CellTags->"AmbiguousQFA"],

Cell[TextData[{
  StyleBox["AmbiguousQFA[M,opts]", "MR"],
  "  tests whether FSM ",
  StyleBox["M", "MR"],
  " is ambiguous. "
}], "Usage",
  CellTags->"AmbiguousQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"AmbiguousQFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " causes the product automaton to be displayed (provided the input machine \
is not deterministic). "
}], "Notes",
  CellTags->"AmbiguousQFA"],

Cell["\<\
The algorithm uses a product automaton construction and is \
therefore quadratic.\
\>", "Notes",
  CellTags->"AmbiguousQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AmbiguousQFA"],

Cell["A trivially ambiguous machine.", "ExampleText",
  CellTags->"AmbiguousQFA"],

Cell[CellGroupData[{

Cell[TextData[{
  "s = SA[4,2,{{1,1,2},{2,2,4},{1,1,3},{3,2,4}}];",
  "\n",
  Cell[BoxData[
      \(AmbiguousQFA[s]\)], "Input",
    CellLabel->"In[4]:="]
}], "Input",
  CellLabel->"In[3]:=",
  CellTags->"AmbiguousQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[4]=",
  CellTags->"AmbiguousQFA"]
}, Open  ]],

Cell["An unambiguous machine based on a cellular automaton.", "ExampleText",
  CellTags->"AmbiguousQFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s\  = \ ToSA[CA[90]];\)\), "\n", 
    \(AmbiguousQFA[s]\)}], "Input",
  CellLabel->"In[11]:=",
  CellTags->"AmbiguousQFA"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->"AmbiguousQFA"]
}, Open  ]]
}, Closed]],

Cell["Arden", "ObjectName",
  CellTags->"Arden"],

Cell["Type: function", "Highlight",
  CellTags->"Arden"],

Cell[TextData[{
  StyleBox["Arden[eq]", "MR"],
  "  solves a linear equation ",
  StyleBox["eq", "MR"],
  " over the language semiring using Arden's lemma. The second component of \
the resulting equation is a rational expression, possibly containing \
additional variables. "
}], "Usage",
  CellTags->"Arden"],

Cell[TextData[{
  "Use in conjunction with ",
  StyleBox["Substitute", "MR"],
  "."
}], "Notes",
  CellTags->"Arden"],

Cell[TextData[{
  "Since the simplification methods for regular expressions used in ",
  StyleBox["Arden", "MR"],
  " are rather weak one can only tackle small systems."
}], "Notes",
  CellTags->"Arden"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Arden"],

Cell[TextData[{
  "A DFA for all words containing an even number of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s, converted into a system of equations. "
}], "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ DFA[4, 2, {{3, 4, 1, 2}, {2, 1, 4, 3}}, 1, {1}\ ]\)], "Input",
  CellLabel->"In[83]:=",
  CellTags->"Arden"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{3, 4, 1, 2}, {2, 1, 4, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[83]=",
  CellTags->"Arden"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({e1, e2, e3, e4} = ToEquationsDFA[m];\)\), "\n", 
    \(ColumnForm[{e1, e2, e3, e4}]\  //. \ {RET \[Rule] 
          NonCommutativeMultiply, REP \[Rule] Plus}\)}], "Input",
  CellLabel->"In[84]:=",
  AspectRatioFixed->True,
  CellTags->"Arden"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("X"\_1 == \[Epsilon] + "a" ** "X"\_3 + "b" ** "X"\_2\)},
          {\("X"\_2 == "a" ** "X"\_4 + "b" ** "X"\_1\)},
          {\("X"\_3 == "a" ** "X"\_1 + "b" ** "X"\_4\)},
          {\("X"\_4 == "a" ** "X"\_2 + "b" ** "X"\_3\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {
        Equal[ 
          Automata`automata`Private`X[ 1], 
          Plus[ \[Epsilon], 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 3]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 2]]]], 
        Equal[ 
          Automata`automata`Private`X[ 2], 
          Plus[ 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 4]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 1]]]], 
        Equal[ 
          Automata`automata`Private`X[ 3], 
          Plus[ 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 1]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 4]]]], 
        Equal[ 
          Automata`automata`Private`X[ 4], 
          Plus[ 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 2]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 3]]]]}],
      Editable->False]], "Output",
  CellLabel->"Out[85]=",
  CellTags->"Arden"]
}, Open  ]],

Cell[TextData[{
  "Substitute to express ",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`X\_4\)]],
  ". "
}], "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{

Cell[BoxData[
    \(e11 = Substitute[e1, e2, e3]\)], "Input",
  CellLabel->"In[86]:=",
  AspectRatioFixed->True,
  CellTags->"Arden"],

Cell[BoxData[
    \("X"\_1 == \[Epsilon] + "aa" ** "X"\_1 + "ab" ** "X"\_4 + 
        "ba" ** "X"\_4 + "bb" ** "X"\_1\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->"Arden"]
}, Open  ]],

Cell[TextData[{
  "Substitute to express ",
  Cell[BoxData[
      \(TraditionalForm\`X\_4\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`X\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`X\_4\)]],
  ", and solve the equation."
}], "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{

Cell[BoxData[
    \(e44 = Substitute[e4, e2, e3]\)], "Input",
  CellLabel->"In[87]:=",
  AspectRatioFixed->True,
  CellTags->"Arden"],

Cell[BoxData[
    \("X"\_4 == 
      "aa" ** "X"\_4 + "ab" ** "X"\_1 + "ba" ** "X"\_1 + 
        "bb" ** "X"\_4\)], "Output",
  CellLabel->"Out[87]=",
  CellTags->"Arden"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(e5 = Arden[e44]\)], "Input",
  CellLabel->"In[88]:=",
  AspectRatioFixed->True,
  CellTags->"Arden"],

Cell[BoxData[
    \("X"\_4 == 
      RES["aa" + "bb"] ** \(("ab" ** "X"\_1 + "ba" ** "X"\_1)\)\)], "Output",
  CellLabel->"Out[88]=",
  CellTags->"Arden"]
}, Open  ]],

Cell["\<\
Substitute back, and solve one more time for the final \
answer.\
\>", "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{

Cell[BoxData[
    \(e6 = Substitute[e11, e5]\)], "Input",
  CellLabel->"In[89]:=",
  AspectRatioFixed->True,
  CellTags->"Arden"],

Cell[BoxData[
    \("X"\_1 == \[Epsilon] + "aa" ** "X"\_1 + "bb" ** "X"\_1 + 
        "ab" ** RES["aa" + "bb"] ** "ab" ** "X"\_1 + 
        "ab" ** RES["aa" + "bb"] ** "ba" ** "X"\_1 + 
        "ba" ** RES["aa" + "bb"] ** "ab" ** "X"\_1 + 
        "ba" ** RES["aa" + "bb"] ** "ba" ** "X"\_1\)], "Output",
  CellLabel->"Out[89]=",
  CellTags->"Arden"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = Arden[e6]\)], "Input",
  CellLabel->"In[90]:=",
  AspectRatioFixed->True,
  CellTags->"Arden"],

Cell[BoxData[
    \("X"\_1 == 
      RES["aa" + "bb" + "ab" ** RES["aa" + "bb"] ** "ab" + 
          "ab" ** RES["aa" + "bb"] ** "ba" + 
          "ba" ** RES["aa" + "bb"] ** "ab" + 
          "ba" ** RES["aa" + "bb"] ** "ba"]\)], "Output",
  CellLabel->"Out[90]=",
  CellTags->"Arden"]
}, Open  ]],

Cell["\<\
Note that the last expression could be simplified as follows. Our \
simplification rules are not powerful enough to do this automatically.\
\>", \
"ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{

Cell[BoxData[
    \(re\  = \ 
      RES[\ REP[\ aa, \ bb, \ 
          RET[\ REP[ab, ba], RES[REP[aa, bb]], REP[ab, ba]]\ ]]\)], "Input",
  CellLabel->"In[91]:=",
  CellTags->"Arden"],

Cell[BoxData[
    \(RES[
      aa + bb + \((ab + ba)\) ** RES[aa + bb] ** \((ab + ba)\)]\)], "Output",
  CellLabel->"Out[91]=",
  CellTags->"Arden"]
}, Open  ]],

Cell["\<\
We can check that the two regular expressions are indeed \
equivalent.\
\>", "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m1\  = \ RegularExpressionToFA[sol[\([2]\)]];\)\), "\n", 
    \(\(m2\  = \ RegularExpressionToFA[re];\)\), "\n", 
    \(EquivalentQFA[m1, m2]\)}], "Input",
  CellLabel->"In[92]:=",
  CellTags->"Arden"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[94]=",
  CellTags->"Arden"]
}, Open  ]]
}, Closed]],

Cell["BehaviorFA", "ObjectName",
  CellTags->"BehaviorFA"],

Cell["Type: function", "Highlight",
  CellTags->"BehaviorFA"],

Cell[TextData[{
  StyleBox["BehaviorFA[M,p,r]", "MR"],
  "  constructs part of the behavior of state ",
  StyleBox["p", "MR"],
  " in automaton ",
  StyleBox["M", "MR"],
  " (the acceptance language of the machine ",
  StyleBox["M", "MR"],
  " with ",
  StyleBox["p", "MR"],
  " as only initial state). Only words of length ",
  StyleBox["r", "MR"],
  "  are generated."
}], "Usage",
  CellTags->"BehaviorFA"],

Cell[TextData[{
  " For negative values of ",
  StyleBox["r", "MR"],
  " all words up to length ",
  StyleBox["Abs[r]", "MR"],
  "  are generated."
}], "Notes",
  CellTags->"BehaviorFA"],

Cell[TextData[{
  " See also ",
  ButtonBox["LanguageFA",
    ButtonData:>"LanguageFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"BehaviorFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BehaviorFA"],

Cell[TextData[{
  "A machine accepting all words containing a number of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s congruent to 1 modulo 3."
}], "ExampleText",
  CellTags->"BehaviorFA"],

Cell[CellGroupData[{

Cell["m = ModCounterDFA[a,1,3]", "Input",
  CellLabel->"In[38]:=",
  CellTags->"BehaviorFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{2, 3, 1}, {1, 2, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[38]=",
  CellTags->"BehaviorFA"]
}, Open  ]],

Cell["\<\
The behavior of the initial state 1 is just the language of the \
machine. \
\>", "ExampleText",
  CellTags->"BehaviorFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BehaviorFA[m, 1, \(-4\)]\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->"BehaviorFA"],

Cell[BoxData[
    \({{}, {"a"}, {"ab", "ba"}, {"abb", "bab", "bba"}, {"aaaa", "abbb", 
        "babb", "bbab", "bbba"}}\)], "Output",
  CellLabel->"Out[40]=",
  CellTags->"BehaviorFA"]
}, Open  ]],

Cell[TextData[{
  "But state 2 has as behavior all words containing a multiple of 3 ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s."
}], "ExampleText",
  CellTags->"BehaviorFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BehaviorFA[m, 2, \(-4\)]\)], "Input",
  CellLabel->"In[41]:=",
  CellTags->"BehaviorFA"],

Cell[BoxData[
    \({{\[Epsilon]}, {"b"}, {"bb"}, {"aaa", "bbb"}, {"aaab", "aaba", "abaa", 
        "baaa", "bbbb"}}\)], "Output",
  CellLabel->"Out[41]=",
  CellTags->"BehaviorFA"]
}, Open  ]]
}, Closed]],

Cell["BFunctionToCA", "ObjectName",
  CellTags->"BFunctionToCA"],

Cell["Type: function", "Highlight",
  CellTags->"BFunctionToCA"],

Cell[TextData[{
  StyleBox["BFunctionToCA[f,w]", "MR"],
  "  constructs a CA of width ",
  StyleBox["w", "MR"],
  " over alphabet ",
  StyleBox["{0,1}", "MR"],
  " whose local map is given by ",
  StyleBox["f", "MR"],
  ", a Boolean expression in variables ",
  StyleBox["x1", "MR"],
  ", ",
  StyleBox["x2", "MR"],
  ", \[Ellipsis] Negated variables can be denoted by ",
  StyleBox["xx1", "MR"],
  " and so forth. "
}], "Usage",
  CellTags->"BFunctionToCA"],

Cell[TextData[{
  StyleBox["Plus", "MR"],
  " and ",
  StyleBox["Times", "MR"],
  " can be used instead of logical ",
  StyleBox["Or", "MR"],
  " and ",
  StyleBox["And", "MR"],
  ". "
}], "Notes",
  CellTags->"BFunctionToCA"],

Cell[TextData[{
  "See ",
  ButtonBox["PolynomialToCA",
    ButtonData:>"PolynomialToCA",
    ButtonStyle->"AddOnsLink"],
  " for conversion of polynomials modulo ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " to CAs. "
}], "Notes",
  CellTags->"BFunctionToCA"],

Cell[TextData[{
  " See ",
  StyleBox["FunctionToCA", "MR"],
  " and ",
  StyleBox["PolynomialToCA", "MR"],
  " ."
}], "Notes",
  CellTags->"BFunctionToCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BFunctionToCA"],

Cell["\<\
Exclusive or on the left right neighbors produces ECA with rule \
number 90.\
\>", "ExampleText",
  CellTags->"BFunctionToCA"],

Cell[CellGroupData[{

Cell["\<\
BFunctionToCA[ Xor[x1,x3],3]
PrintCA[%]\
\>", "Input",
  CellLabel->"In[48]:=",
  CellTags->"BFunctionToCA"],

Cell[BoxData[
    \(CA[90, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->"BFunctionToCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {\("000" \[Rule] "0"\), \("100" \[Rule] "1"\)},
          {\("001" \[Rule] "1"\), \("101" \[Rule] "0"\)},
          {\("010" \[Rule] "0"\), \("110" \[Rule] "1"\)},
          {\("011" \[Rule] "1"\), \("111" \[Rule] "0"\)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {1, 2}]]]], "Output",
  CellLabel->"Out[49]//TableForm=",
  CellTags->"BFunctionToCA"]
}, Open  ]],

Cell["Another elementary CA.", "ExampleText",
  CellTags->"BFunctionToCA"],

Cell[CellGroupData[{

Cell["\<\
BFunctionToCA[ x1 + xx2 x3,3]
PrintCA[%]\
\>", "Input",
  CellLabel->"In[52]:=",
  CellTags->"BFunctionToCA"],

Cell[BoxData[
    \(CA[242, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[52]=",
  CellTags->"BFunctionToCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {\("000" \[Rule] "0"\), \("100" \[Rule] "1"\)},
          {\("001" \[Rule] "1"\), \("101" \[Rule] "1"\)},
          {\("010" \[Rule] "0"\), \("110" \[Rule] "1"\)},
          {\("011" \[Rule] "0"\), \("111" \[Rule] "1"\)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {1, 2}]]]], "Output",
  CellLabel->"Out[53]//TableForm=",
  CellTags->"BFunctionToCA"]
}, Open  ]]
}, Closed]],

Cell["BuildBEFA", "ObjectName",
  CellTags->"BuildBEFA"],

Cell["Type: function", "Highlight",
  CellTags->"BuildBEFA"],

Cell[TextData[{
  StyleBox["BuildBEFA[w]", "MR"],
  "  constructs a BEFA (begin/exit automaton) that accepts exactly the word \
",
  StyleBox["w", "MR"],
  "."
}], "Usage",
  CellTags->"BuildBEFA"],

Cell[TextData[{
  "Returns a machine of type ",
  StyleBox["BEFA", "MR"],
  "."
}], "Notes",
  CellTags->"BuildBEFA"],

Cell["\<\
This is used in the Thompson style conversion of regular \
expressions to machines. \
\>", "Notes",
  CellTags->"BuildBEFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BuildBEFA"],

Cell[TextData[{
  "The initial state is implicitely assumed to be 1, and the final state ",
  StyleBox["n", "MR"],
  " where ",
  StyleBox["n", "MR"],
  " is the total number of states. "
}], "ExampleText",
  CellTags->"BuildBEFA"],

Cell[CellGroupData[{

Cell["BuildBEFA[ abab ]", "Input",
  CellLabel->"In[57]:=",
  CellTags->"BuildBEFA"],

Cell[BoxData[
    \(BEFA[
      5, {{1, "a", 2}, {2, "b", 3}, {3, "a", 4}, {4, "b", 5}}]\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->"BuildBEFA"]
}, Open  ]]
}, Closed]],

Cell["BuildDFA", "ObjectName",
  CellTags->"BuildDFA"],

Cell["Type: function", "Highlight",
  CellTags->"BuildDFA"],

Cell[TextData[{
  StyleBox["BuildDFA[w1,..,ws,K]", "MR"],
  "  constructs the minimal DFA for the finite language ",
  Cell[BoxData[
      \(TraditionalForm\`{w\_1, \[Ellipsis], w\_s}\)]],
  " ",
  StyleBox[" ", "Input"],
  " over alphabet ",
  StyleBox["K", "MR"],
  ". Also accepts a list of words as input."
}], "Usage",
  CellTags->"BuildDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"BuildDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->1", "MR"],
  " causes the state set to be preserved in structured form: a set of sets of \
words, more precisely, all left quotients of ",
  StyleBox["L", "MR"],
  ". "
}], "Notes",
  CellTags->"BuildDFA"],

Cell[TextData[{
  " See also ",
  ButtonBox["QuotientDFA",
    ButtonData:>"QuotientDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"BuildDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BuildDFA"],

Cell["A language of cardinality 3.", "ExampleText",
  CellTags->"BuildDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = BuildDFA[aa, bab, bbb, 2]\), "\n", 
    \(LanguageFA[m, \(-6\)]\)}], "Input",
  CellLabel->"In[69]:=",
  CellTags->"BuildDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"6", ",", "2", ",", 
          TagBox[\({{2, 4, 6, 5, 5, 5}, {3, 5, 6, 5, 5, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[69]=",
  CellTags->"BuildDFA"],

Cell[BoxData[
    \({{}, {}, {"aa"}, {"bab", "bbb"}, {}, {}, {}}\)], "Output",
  CellLabel->"Out[70]=",
  CellTags->"BuildDFA"]
}, Open  ]],

Cell["All words of length 4, except for aaaa.", "ExampleText",
  CellTags->"BuildDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(W = Rest[Words[4]]\), "\n", 
    \(m = \ BuildDFA[\ W, \ 2\ ]\), "\n", 
    \(LanguageFA[m, \(-6\)]\)}], "Input",
  CellLabel->"In[83]:=",
  CellTags->"BuildDFA"],

Cell[BoxData[
    \({"aaab", "aaba", "aabb", "abaa", "abab", "abba", "abbb", "baaa", 
      "baab", "baba", "babb", "bbaa", "bbab", "bbba", "bbbb"}\)], "Output",
  CellLabel->"Out[83]=",
  CellTags->"BuildDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"9", ",", "2", ",", 
          
          TagBox[\({{2, 4, 5, 6, 7, 8, 9, 8, 8}, {3, 5, 5, 7, 7, 9, 9, 8, 
                8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({9}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[84]=",
  CellTags->"BuildDFA"],

Cell[BoxData[
    \({{}, {}, {}, {}, {"aaab", "aaba", "aabb", "abaa", "abab", "abba", 
        "abbb", "baaa", "baab", "baba", "babb", "bbaa", "bbab", "bbba", 
        "bbbb"}, {}, {}}\)], "Output",
  CellLabel->"Out[85]=",
  CellTags->"BuildDFA"]
}, Open  ]]
}, Closed]],

Cell["BuildNNFA", "ObjectName",
  CellTags->"BuildNNFA"],

Cell["Type: function", "Highlight",
  CellTags->"BuildNNFA"],

Cell[TextData[{
  StyleBox["BuildNNFA[w]", "MR"],
  "  constructs a NNFA that accepts exactly the word ",
  StyleBox["w", "MR"],
  " (returns only the tail of the automaton)."
}], "Usage",
  CellTags->"BuildNNFA"],

Cell[TextData[{
  "Returns a machine of type ",
  StyleBox["NNFA", "MR"],
  "."
}], "Notes",
  CellTags->"BuildNNFA"],

Cell["\<\
Used only in the McNaugthon-Yamada conversion algorithm from \
regular expressions to machines.\
\>", "Notes",
  CellTags->"BuildNNFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BuildNNFA"],

Cell["An NNFA for the word aab.", "ExampleText",
  CellTags->"BuildNNFA"],

Cell[CellGroupData[{

Cell["BuildNNFA[aab]", "Input",
  CellLabel->"In[89]:=",
  CellTags->"BuildNNFA"],

Cell[BoxData[
    \(NNFA[3, {{1, 2}, {2, 3}}, {"a", "a", "b"}, {1}, {3}, 0]\)], "Output",
  CellLabel->"Out[89]=",
  CellTags->"BuildNNFA"]
}, Open  ]]
}, Closed]],

Cell["BuildStarDFA", "ObjectName",
  CellTags->"BuildStarDFA"],

Cell["Type: function", "Highlight",
  CellTags->"BuildStarDFA"],

Cell[TextData[{
  StyleBox["BuildStarDFA[w]", "MR"],
  "  builds a DFA for the language ",
  Cell[BoxData[
      \(TraditionalForm\`w\^\(\(\ \)\(*\)\)\)]],
  "."
}], "Usage",
  CellTags->"BuildStarDFA"],

Cell["The initial and unique final state are both 1.", "Notes",
  CellTags->"BuildStarDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BuildStarDFA"],

Cell[TextData[{
  "A DFA accepting all words of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((aabc)\)\(\ \)\)\^i\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`i\  \[GreaterEqual] \ 0\)]],
  "."
}], "ExampleText",
  CellTags->"BuildStarDFA"],

Cell[CellGroupData[{

Cell["BuildStarDFA[aabc,3]", "Input",
  CellLabel->"In[95]:=",
  CellTags->"BuildStarDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "3", ",", 
          TagBox[\({{2, 3, 5, 5, 5}, {5, 5, 4, 5, 5}, {5, 5, 5, 1, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[95]=",
  CellTags->"BuildStarDFA"]
}, Open  ]]
}, Closed]],

Cell["CirculantSA", "ObjectName",
  CellTags->"CirculantSA"],

Cell["Type: function", "Highlight",
  CellTags->"CirculantSA"],

Cell[TextData[{
  StyleBox["CirculantSA[n,d,lab,K]", "MR"],
  "  constructs a semiautomaton whose transition diagram is a circulant graph \
",
  Cell[BoxData[
      \(TraditionalForm\`C(n; d)\)]],
  " and whose transitions are given by the list ",
  StyleBox["lab", "MR"],
  "."
}], "Usage",
  CellTags->"CirculantSA"],

Cell[TextData[{
  "The strides are given by the integer list ",
  StyleBox["d", "MR"],
  "."
}], "Notes",
  CellTags->"CirculantSA"],

Cell[TextData[{
  "The length of label list ",
  StyleBox["lab", "MR"],
  " must be  ",
  StyleBox["n Length[d]", "MR"],
  ". "
}], "Notes",
  CellTags->"CirculantSA"],

Cell[TextData[{
  "See also ",
  ButtonBox["CirculantGraph",
    ButtonData:>"CirculantGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"CirculantSA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CirculantSA"],

Cell[TextData[{
  "A circulant SA with stride list ",
  Cell[BoxData[
      \(TraditionalForm\`\((1, 2)\)\)]],
  " and exactly one ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " transition. "
}], "ExampleText",
  CellTags->"CirculantSA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = CirculantSA[5, {1, 2}, Join[{a}, Table[b, {9}]]]\)], "Input",
  CellLabel->"In[107]:=",
  CellTags->"CirculantSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {2, 2, 3}, {3, 2, 4}, {4, 2, 5}, {5, 2, 
                1}, {1, 2, 3}, {2, 2, 4}, {3, 2, 5}, {4, 2, 1}, {5, 2, 2}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[107]=",
  CellTags->"CirculantSA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, 6]\)], "Input",
  CellLabel->"In[108]:=",
  CellTags->"CirculantSA"],

Cell[BoxData[
    \({"abbabb", "abbbab", "abbbba", "abbbbb", "babbab", "babbba", "babbbb", 
      "bbabba", "bbabbb", "bbbabb", "bbbbab", "bbbbba", "bbbbbb"}\)], "Output",\

  CellLabel->"Out[108]=",
  CellTags->"CirculantSA"]
}, Open  ]]
}, Closed]],

Cell["ClassifyCA", "ObjectName",
  CellTags->"ClassifyCA"],

Cell["Type: function", "Highlight",
  CellTags->"ClassifyCA"],

Cell[TextData[{
  StyleBox["ClassifyCA[C]", "MR"],
  " classifies a cellular automaton C according to the topological properties \
of the global map. The algorithm distinguishes between injective, open, and \
surjective global maps."
}], "Usage",
  CellTags->"ClassifyCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "True"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ClassifyCA"],

Cell[TextData[{
  "Return values are as follows: \n",
  Cell[BoxData[GridBox[{
          {"0", 
            StyleBox["nothing",
              "MathCaption"]},
          {"1", 
            StyleBox[\(\(\ \)\(surjective\)\),
              "MathCaption"]},
          {"2", 
            StyleBox["open",
              "MathCaption"]},
          {"3", 
            StyleBox["injective",
              "MathCaption"]}
          }]]]
}], "Notes",
  CellTags->"ClassifyCA"],

Cell[TextData[{
  "With option ",
  StyleBox["Full->True", "MR"],
  " returns the type, and the non-transient part of the collapse of the \
square de Bruijn graph of C."
}], "Notes",
  CellTags->"ClassifyCA"],

Cell["\<\
Note that injective implies open, which in turn implies surjective. \
\
\>", "Notes",
  CellTags->"ClassifyCA"],

Cell["\<\
The algorithm uses the product automaton of the corresponding de \
Bruijn automaton and is thus quadratic.\
\>", "Notes",
  CellTags->"ClassifyCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ClassifyCA"],

Cell["Some elementary cellular automata:", "ExampleText",
  CellTags->"ClassifyCA"],

Cell[CellGroupData[{

Cell["ClassifyCA[CA[110]]", "Input",
  CellLabel->"In[407]:=",
  CellTags->"ClassifyCA"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[407]=",
  CellTags->"ClassifyCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClassifyCA[CA[30]]", "Input",
  CellLabel->"In[408]:=",
  CellTags->"ClassifyCA"],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[408]=",
  CellTags->"ClassifyCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClassifyCA[CA[90]]", "Input",
  CellLabel->"In[409]:=",
  CellTags->"ClassifyCA"],

Cell[BoxData[
    \(2\)], "Output",
  CellLabel->"Out[409]=",
  CellTags->"ClassifyCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClassifyCA[CA[51]]", "Input",
  CellLabel->"In[410]:=",
  CellTags->"ClassifyCA"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[410]=",
  CellTags->"ClassifyCA"]
}, Open  ]],

Cell["A CA of width 2 over a 4-symbol alphabet", "ExampleText",
  CellTags->"ClassifyCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ClassifyCA[CA[508289460, 2, \(-4\)]]\)], "Input",
  CellLabel->"In[411]:=",
  CellTags->"ClassifyCA"],

Cell[BoxData[
    \(2\)], "Output",
  CellLabel->"Out[411]=",
  CellTags->"ClassifyCA"]
}, Open  ]],

Cell["All elementary CAs.", "ExampleText",
  CellTags->"ClassifyCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[\ ClassifyCA[CA[r]], \ {r, 0, 255}\ ]\  // \ 
        Frequencies\)\  // \ TableForm\)], "Input",
  CellLabel->"In[4.1]:=",
  CellTags->"ClassifyCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "226"},
          {"1", "16"},
          {"2", "8"},
          {"3", "6"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[4.1]//TableForm=",
  CellTags->"ClassifyCA"]
}, Open  ]]
}, Closed]],

Cell["CoAccessibleFA", "ObjectName",
  CellTags->"CoAccessibleFA"],

Cell["Type: function", "Highlight",
  CellTags->"CoAccessibleFA"],

Cell[TextData[{
  StyleBox["CoAccessibleFA[M]", "MR"],
  "  returns the coaccessible part of a finite state machine ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"CoAccessibleFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"CoAccessibleFA"],

Cell[TextData[{
  "Result will be an FA even if ",
  StyleBox["M", "MR"],
  " is a DFA and teh accessible part is complete."
}], "Notes",
  CellTags->"CoAccessibleFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["AccessibleFA",
    ButtonData:>"AccessibleFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["TrimFA",
    ButtonData:>"TrimFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"CoAccessibleFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CoAccessibleFA"],

Cell["\<\
 A machine on 5 states, two of which fail to be coaccessible. \
\
\>", "MathCaption",
  CellTags->"CoAccessibleFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ 
      FA[\ 5, \ 2, \ {{1, 1, 3}, {3, 2, 4}, {4, 1, 5}}, {1}, {4}, {}, {a, b, 
          c, d, e}]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"CoAccessibleFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{1, 1, 3}, {3, 2, 4}, {4, 1, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[3]=",
  CellTags->"CoAccessibleFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CoAccessibleFA[m]\), "\n", 
    \(EquivalentQFA[m, %%]\)}], "Input",
  CellLabel->"In[4]:=",
  CellTags->"CoAccessibleFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{3, 1, 2}, {2, 2, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[4]=",
  CellTags->"CoAccessibleFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[5]=",
  CellTags->"CoAccessibleFA"]
}, Open  ]],

Cell[" We can preserve the state set of the original machine.", "MathCaption",
  CellTags->"CoAccessibleFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoAccessibleFA[m, Normalize \[Rule] 1]\  // \ States\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"CoAccessibleFA"],

Cell[BoxData[
    \({1, 3, 4}\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"CoAccessibleFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoAccessibleFA[m, Normalize \[Rule] 2]\  // \ States\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"CoAccessibleFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {2, 2, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[7]=",
  CellTags->"CoAccessibleFA"],

Cell[BoxData[
    \({a, c, d}\)], "Output",
  CellLabel->"Out[8]=",
  CellTags->"CoAccessibleFA"]
}, Open  ]]
}, Closed]],

Cell["CodeterministicQFA", "ObjectName",
  CellTags->"CodeterministicQFA"],

Cell["Type: function", "Highlight",
  CellTags->"CodeterministicQFA"],

Cell[TextData[{
  StyleBox["CodeterministicQFA[M]", "MR"],
  "  tests whether  machine M is codeterministic (M can be an FA, NFA or \
SA)."
}], "Usage",
  CellTags->"CodeterministicQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "True"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"CodeterministicQFA"],

Cell[TextData[{
  "With option ",
  StyleBox["Full->True", "MR"],
  " the function tests whether ",
  Cell[BoxData[
      \(TraditionalForm\`M\^op\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  "-deterministic, and returns ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Infinity]\)]],
  " accordingly. "
}], "Notes",
  CellTags->"CodeterministicQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["DeterministicQFA",
    ButtonData:>"DeterministicQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"CodeterministicQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CodeterministicQFA"],

Cell["\<\
A codeterministic semiautomaton based on an elementary cellular \
automaton.\
\>", "ExampleText",
  CellTags->"CodeterministicQFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(s = ToSA[CA[90]]\), "\n", 
    \(CodeterministicQFA[s]\)}], "Input",
  CellLabel->"In[182]:=",
  CellTags->"CodeterministicQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 
                1}, {3, 1, 2}, {4, 2, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[182]=",
  CellTags->"CodeterministicQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[183]=",
  CellTags->"CodeterministicQFA"]
}, Open  ]]
}, Closed]],

Cell["ComplementFA", "ObjectName",
  CellTags->"ComplementFA"],

Cell["Type: function", "Highlight",
  CellTags->"ComplementFA"],

Cell[TextData[{
  StyleBox["ComplementFA[M]", "MR"],
  "  generates a DFA that accepts the complement of the acceptance language \
of machine M. "
}], "Usage",
  CellTags->"ComplementFA"],

Cell["\<\
  For a DFA M this is accomplished by interchanging final and \
non-final states, but a nondeterministic machine is converted to a DFA first. \
 Hence, time and space requirements may be exponential.\
\>", "Notes",
  CellTags->"ComplementFA"],

Cell[TextData[{
  StyleBox["ComplementFA[M1,M2]", "MR"],
  " constructs a DFA for the language L(M1) - L(M2)."
}], "Notes",
  CellTags->"ComplementFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ComplementFA"],

Cell["\<\
A DFA for all words of length other than 4 obtained from \
complementation.\
\>", "ExampleText",
  CellTags->"ComplementFA"],

Cell[CellGroupData[{

Cell["m = BuildDFA[ Words[4], 2 ]", "Input",
  CellLabel->"In[204]:=",
  CellTags->"ComplementFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"6", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 6, 6}, {2, 3, 4, 5, 6, 6}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[204]=",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ ComplementFA[m]\)], "Input",
  CellLabel->"In[205]:=",
  CellTags->"ComplementFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"6", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 6, 6}, {2, 3, 4, 5, 6, 6}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4, 6}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[205]=",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[mm, \(-8\), SizeOnly \[Rule] True\ ]\)], "Input",
  CellLabel->"In[207]:=",
  CellTags->"ComplementFA"],

Cell[BoxData[
    \({1, 2, 4, 8, 0, 32, 64, 128, 256}\)], "Output",
  CellLabel->"Out[207]=",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["m5 = BuildDFA[ Words[-5], 2 ]", "Input",
  CellLabel->"In[208]:=",
  CellTags->"ComplementFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 6, 7, 7}, {2, 3, 4, 5, 6, 7, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4, 5, 6}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[208]=",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell["A DFA for all words of length other than 4 and at most 5.", \
"ExampleText",
  CellTags->"ComplementFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ ComplementFA[\ m5, \ m\ ]\)], "Input",
  CellLabel->"In[211]:=",
  CellTags->"ComplementFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 6, 7, 7}, {2, 3, 4, 5, 6, 7, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4, 6}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[211]=",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[mm, \(-8\), SizeOnly \[Rule] True\ ]\)], "Input",
  CellLabel->"In[212]:=",
  CellTags->"ComplementFA"],

Cell[BoxData[
    \({1, 2, 4, 8, 0, 32, 0, 0, 0}\)], "Output",
  CellLabel->"Out[212]=",
  CellTags->"ComplementFA"]
}, Open  ]]
}, Closed]],

Cell["CompleteFA", "ObjectName",
  CellTags->"CompleteFA"],

Cell["Type: function", "Highlight",
  CellTags->"CompleteFA"],

Cell[TextData[{
  StyleBox["CompleteFA[M]", "MR"],
  "  adds a sink to M if necessary to produce a complete automaton."
}], "Usage",
  CellTags->"CompleteFA"],

Cell["\<\
Result is of type FA even if the machine is deterministic and thus \
a DFA.\
\>", "Notes",
  CellTags->"CompleteFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CompleteFA"],

Cell["An incomplete machine, and its complete counterpart. ", "ExampleText",
  CellTags->"CompleteFA"],

Cell[CellGroupData[{

Cell["m = FA[2,2,{{1,1,2}},{1},{2}]", "Input",
  CellLabel->"In[54]:=",
  CellTags->"CompleteFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"2", ",", "2", ",", 
          TagBox[\({{1, 1, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[54]=",
  CellTags->"CompleteFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompleteFA[m]\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"CompleteFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"3", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {2, 1, 3}, {1, 2, 3}, {2, 2, 3}, {3, 1, 
                3}, {3, 2, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[55]=",
  CellTags->"CompleteFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[%, %%]\)], "Input",
  CellLabel->"In[56]:=",
  CellTags->"CompleteFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[56]=",
  CellTags->"CompleteFA"]
}, Open  ]]
}, Closed]],

Cell["CompleteQFA", "ObjectName",
  CellTags->"CompleteQFA"],

Cell["Type: function", "Highlight",
  CellTags->"CompleteQFA"],

Cell[TextData[{
  StyleBox["CompleteQFA[M]", "MR"],
  "  tests whether the finite state machine ",
  StyleBox["M", "MR"],
  " is complete."
}], "Usage",
  CellTags->"CompleteQFA"],

Cell["\<\
 DFAs are trivially complete, for all other types a check is \
performed to see if all states are complete. \
\>", "Notes",
  CellTags->"CompleteQFA"],

Cell[" Note that the size of the alphabet is important here. ", "Notes",
  CellTags->"CompleteQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CompleteQFA"],

Cell["An  complete machine over a 1-symbol alphabet.", "ExampleText",
  CellTags->"CompleteQFA"],

Cell[CellGroupData[{

Cell["\<\
m = SA[2,1,{{1,1,2},{2,1,2}} ]
CompleteQFA[m]\
\>", "Input",
  CellLabel->"In[63]:=",
  CellTags->"CompleteQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"2", ",", "1", ",", 
          TagBox[\({{1, 1, 2}, {2, 1, 2}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[63]=",
  CellTags->"CompleteQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[64]=",
  CellTags->"CompleteQFA"]
}, Open  ]],

Cell["But over a 2-symbol alphabet the same machine is incomplete.", \
"ExampleText",
  CellTags->"CompleteQFA"],

Cell[CellGroupData[{

Cell["ReplacePart[m,2,2] // CompleteQFA", "Input",
  CellLabel->"In[72]:=",
  CellTags->"CompleteQFA"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[72]=",
  CellTags->"CompleteQFA"]
}, Open  ]]
}, Closed]],

Cell["ComposeCA", "ObjectName",
  CellTags->"ComposeCA"],

Cell["Type: function", "Highlight",
  CellTags->"ComposeCA"],

Cell[TextData[{
  StyleBox["ComposeCA[C1,C2]", "MR"],
  "  composes cellular automata ",
  StyleBox["C1", "MR"],
  " and ",
  StyleBox["C2", "MR"],
  " .  The cellular automata are assumed to be over the same alphabet."
}], "Usage",
  CellTags->"ComposeCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ComposeCA"],

Cell[TextData[{
  "Composition is in diagrammatic order, so that first the local rule of ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " is applied, and then the local rule of ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  ". "
}], "Notes",
  CellTags->"ComposeCA"],

Cell[TextData[{
  "The width of the resulting automaton is ",
  Cell[BoxData[
      \(TraditionalForm\`w\_1 + w\_2 - 1\)]],
  ". "
}], "Notes",
  CellTags->"ComposeCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ComposeCA"],

Cell["A hybrid automaton alternating between rules 90 and 30.", "ExampleText",
  CellTags->"ComposeCA"],

Cell[CellGroupData[{

Cell["cc = ComposeCA[ CA[90,3,-2], CA[30,3,-2] ]", "Input",
  CellLabel->"In[87]:=",
  CellTags->"ComposeCA"],

Cell[BoxData[
    \(CA[1959889710, 5, \(-2\)]\)], "Output",
  CellLabel->"Out[87]=",
  CellTags->"ComposeCA"]
}, Open  ]],

Cell[BoxData[
    \(\(EvolutionCA[\ cc, 60\ ];\)\)], "Input",
  CellLabel->"In[86]:=",
  CellTags->"ComposeCA"]
}, Closed]],

Cell["ComputationFA", "ObjectName",
  CellTags->"ComputationFA"],

Cell["Type: function", "Highlight",
  CellTags->"ComputationFA"],

Cell[TextData[{
  StyleBox["ComputationFA[M,w]", "MR"],
  "  determines all computations of machine ",
  StyleBox["M", "MR"],
  " on an input word ",
  StyleBox["w", "MR"],
  " (starting at an initial state)."
}], "Usage",
  CellTags->"ComputationFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"ShowAll", "\[Rule]", "True", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ComputationFA"],

Cell["\<\
A computation here is represented by a list whose entries alternate \
between states and symbols. The result is a collection of such lists.\
\>", \
"Notes",
  CellTags->"ComputationFA"],

Cell["\<\
Note that the number of computations may grow exponentially in the \
length of the input word.\
\>", "Notes",
  CellTags->"ComputationFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ComputationGraphFA",
    ButtonData:>"ComputationGraphFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["PlotComputationFA",
    ButtonData:>"PlotComputationFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ComputationFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ComputationFA"],

Cell[TextData[{
  "A machine for the language of all words whose 4th symbol from the end is \
an ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". "
}], "ExampleText",
  CellTags->"ComputationFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = IthSymbolFA[a, \(-4\)]\)], "Input",
  CellLabel->"In[90]:=",
  CellTags->"ComputationFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}, {4, 1, 5}, {4, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[90]=",
  CellTags->"ComputationFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputationFA[\ m, \ abbaaa\ ]\)], "Input",
  CellLabel->"In[93]:=",
  CellTags->"ComputationFA"],

Cell[BoxData[
    \({{1, "a", 1, "b", 1, "b", 1, "a", 1, "a", 1, "a", 1}, {1, "a", 1, "b", 
        1, "b", 1, "a", 1, "a", 1, "a", 2}, {1, "a", 1, "b", 1, "b", 1, "a", 
        1, "a", 2, "a", 3}, {1, "a", 1, "b", 1, "b", 1, "a", 2, "a", 3, "a", 
        4}}\)], "Output",
  CellLabel->"Out[93]=",
  CellTags->"ComputationFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputationFA[\ m, \ bbbbb\ ]\)], "Input",
  CellLabel->"In[94]:=",
  CellTags->"ComputationFA"],

Cell[BoxData[
    \({{1, "b", 1, "b", 1, "b", 1, "b", 1, "b", 1}}\)], "Output",
  CellLabel->"Out[94]=",
  CellTags->"ComputationFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Length[ComputationFA[m, #]] &\)\  /@ \ Words[5]\)], "Input",
  CellLabel->"In[95]:=",
  CellTags->"ComputationFA"],

Cell[BoxData[
    \({5, 4, 4, 3, 4, 3, 3, 2, 4, 3, 3, 2, 3, 2, 2, 1, 5, 4, 4, 3, 4, 3, 3, 
      2, 4, 3, 3, 2, 3, 2, 2, 1}\)], "Output",
  CellLabel->"Out[95]=",
  CellTags->"ComputationFA"]
}, Open  ]]
}, Closed]],

Cell["ComputationGraphFA", "ObjectName",
  CellTags->"ComputationGraphFA"],

Cell["Type: function", "Highlight",
  CellTags->"ComputationGraphFA"],

Cell[TextData[{
  StyleBox["ComputationGraphFA[M,w]", "MR"],
  "  produces the unfolding of the finite state machine ",
  StyleBox["M", "MR"],
  " with respect to input word ",
  StyleBox["w", "MR"],
  ". "
}], "Usage",
  CellTags->"ComputationGraphFA"],

Cell[TextData[{
  "Returns a ",
  StyleBox["Graph", "MR"],
  " object, is useful mostly for visulatizations.  The size of the graph is \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\(\[CenterDot]\)\)\  | w | \)]],
  ". "
}], "Notes",
  CellTags->"ComputationGraphFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ComputationFA",
    ButtonData:>"ComputationFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["PlotComputationFA",
    ButtonData:>"PlotComputationFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ComputationGraphFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ComputationGraphFA"],

Cell[TextData[{
  "A machine for the language of all words whose 4th symbol from the end is \
an ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". "
}], "ExampleText",
  CellTags->"ComputationGraphFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = IthSymbolFA[a, \(-4\)]\)], "Input",
  CellLabel->"In[90]:=",
  CellTags->"ComputationGraphFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}, {4, 1, 5}, {4, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[90]=",
  CellTags->"ComputationGraphFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComputationGraphFA[m, aba\ ]\)], "Input",
  CellLabel->"In[98]:=",
  CellTags->"ComputationGraphFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"20", ",", "14", ",", "1", ",", 
          
          TagBox[\({{1, 6}, {1, 7}, {2, 8}, {3, 9}, {4, 10}, {6, 
                11}, \[LeftSkeleton]2\[RightSkeleton], {9, 15}, {11, 
                16}, {11, 17}, {12, 18}, {13, 19}, {14, 20}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[98]=",
  CellTags->"ComputationGraphFA"]
}, Open  ]]
}, Closed]],

Cell["ConcatenateFA", "ObjectName",
  CellTags->"ConcatenateFA"],

Cell["Type: function", "Highlight",
  CellTags->"ConcatenateFA"],

Cell[TextData[{
  StyleBox["ConcatenateFA[M1,M2]", "MR"],
  "  generates an machine that accepts the concatenation of the acceptance \
languages of M1 and M2. "
}], "Usage",
  CellTags->"ConcatenateFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"EpsElim", "\[Rule]", "True", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ConcatenateFA"],

Cell[TextData[{
  "Option  ",
  StyleBox["EpsElim->False", "MR"],
  "  does not eliminate the \[Epsilon]-transitions introduced in the \
construction."
}], "Notes",
  CellTags->"ConcatenateFA"],

Cell[TextData[{
  "The algorithm introduces \[Epsilon]-transitions from all states in ",
  Cell[BoxData[
      \(TraditionalForm\`F\_1\)]],
  " to all states in ",
  Cell[BoxData[
      \(TraditionalForm\`I\_2\)]],
  " and is thus quadratic. "
}], "Notes",
  CellTags->"ConcatenateFA"],

Cell[TextData[{
  StyleBox["ConcatenateFA", "MR"],
  " is polyadic."
}], "Notes",
  CellTags->"ConcatenateFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ConcatenateFA"],

Cell["All words of length 2 concatenated with themselves.", "ExampleText",
  CellTags->"ConcatenateFA"],

Cell[CellGroupData[{

Cell[" m = BuildDFA[ Words[2], 2 ]", "Input",
  CellLabel->"In[118]:=",
  CellTags->"ConcatenateFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 4}, {2, 3, 4, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[118]=",
  CellTags->"ConcatenateFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ ConcatenateFA[\ m, m]\)], "Input",
  CellLabel->"In[119]:=",
  CellTags->"ConcatenateFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"8", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 2}, {2, 1, 3}, {2, 1, 5}, {2, 2, 
                3}, \[LeftSkeleton]8\[RightSkeleton], {6, 2, 7}, {7, 1, 
                8}, {7, 2, 8}, {8, 1, 8}, {8, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({7}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[119]=",
  CellTags->"ConcatenateFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ mm, \ \(-8\), \ SizeOnly \[Rule] True\ ]\)], "Input",
  CellLabel->"In[120]:=",
  CellTags->"ConcatenateFA"],

Cell[BoxData[
    \({0, 0, 0, 0, 16, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[120]=",
  CellTags->"ConcatenateFA"]
}, Open  ]]
}, Closed]],

Cell["ConvertToFA", "ObjectName",
  CellTags->"ConvertToFA"],

Cell["Type: function", "Highlight",
  CellTags->"ConvertToFA"],

Cell[TextData[{
  StyleBox["ConvertToFA[H,Q,K,A,I,F]", "MR"],
  "  generates a machine with head H, states Q, alphabet K, transitions A, \
initial/final states I/F. "
}], "Usage",
  CellTags->"ConvertToFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"ToMatrix", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ConvertToFA"],

Cell[TextData[{
  "Option  ",
  StyleBox["ToMatrix->True", "MR"],
  "  causes a flat list of transitions to be converted into a matrix, only \
applies to construcation of a DFA."
}], "Notes",
  CellTags->"ConvertToFA"],

Cell["noteworthy", "Notes",
  CellTags->"ConvertToFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ConvertToFA"],

Cell["\<\
On occasion it is more natural to write transitions in terms of \
actual states, not in positional notation.\
\>", "ExampleText",
  CellTags->"ConvertToFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvertToFA[
      FA, {\[Epsilon], a, aa}, {a, 
        b}, {{\[Epsilon], a, a}, {a, a, aa}, {aa, a, 
          aa}}, {\[Epsilon]}, {aa}\ ]\)], "Input",
  CellLabel->"In[135]:=",
  AspectRatioFixed->True,
  CellTags->"ConvertToFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {2, 1, 3}, {3, 1, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[135]=",
  CellTags->"ConvertToFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[%, \(-5\)]\)], "Input",
  CellLabel->"In[136]:=",
  CellTags->"ConvertToFA"],

Cell[BoxData[
    \({{}, {}, {"aa"}, {"aaa"}, {"aaaa"}, {"aaaaa"}}\)], "Output",
  CellLabel->"Out[136]=",
  CellTags->"ConvertToFA"]
}, Open  ]]
}, Closed]],

Cell["CounterDFA", "ObjectName",
  CellTags->"CounterDFA"],

Cell["Type: function", "Highlight",
  CellTags->"CounterDFA"],

Cell[TextData[{
  StyleBox["CounterDFA[a,r,K]", "MR"],
  "  constructs a DFA for the language of all words w over alphabet K that \
contain exactly r many a's. For negative r, all words with at most Abs[r] \
many a's are accepted."
}], "Usage",
  CellTags->"CounterDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"CounterDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ModCounterDFA",
    ButtonData:>"ModCounterDFA",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"CounterDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CounterDFA"],

Cell["All words containing exactly 3 b's.", "ExampleText",
  CellTags->"CounterDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = CounterDFA[b, 3]\)], "Input",
  CellLabel->"In[144]:=",
  CellTags->"CounterDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{1, 2, 3, 4, 5}, {2, 3, 4, 5, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[144]=",
  CellTags->"CounterDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[145]:=",
  CellTags->"CounterDFA"],

Cell[BoxData[
    \({{}, {}, {}, {"bbb"}, {"abbb", "babb", "bbab", "bbba"}, {"aabbb", 
        "ababb", "abbab", "abbba", "baabb", "babab", "babba", "bbaab", 
        "bbaba", "bbbaa"}}\)], "Output",
  CellLabel->"Out[145]=",
  CellTags->"CounterDFA"]
}, Open  ]]
}, Closed]],

Cell["CoverQDFA", "ObjectName",
  CellTags->"CoverQDFA"],

Cell["Type: function", "Highlight",
  CellTags->"CoverQDFA"],

Cell[TextData[{
  StyleBox["CoverQDFA[M1,M2,opts]", "MR"],
  "  tests whether DFA M1 covers DFA M2. "
}], "Usage",
  CellTags->"CoverQDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"CoverQDFA"],

Cell["The machines are assumed to be over the same alphabet. ", "Notes",
  CellTags->"CoverQDFA"],

Cell[TextData[{
  "The algorithm tries to construct a partial surjective homomorphism from \
DFA ",
  Cell[BoxData[
      \(TraditionalForm\`M\_1\)]],
  " to DFA ",
  Cell[BoxData[
      \(TraditionalForm\`M\_2\)]],
  "."
}], "Notes",
  CellTags->"CoverQDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True", "MR"],
  " causes the homomorphism to be displayed."
}], "Notes",
  CellTags->"CoverQDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CoverQDFA"],

Cell["\<\
Every DFA for a fixed language covers the minimal DFA for that \
language.  \
\>", "ExampleText",
  CellTags->"CoverQDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = IthSymbolDFA[a, \(-3\)]\), "\n", 
    \(mm = MinimizeFA[m]\)}], "Input",
  CellLabel->"In[156]:=",
  CellTags->"CoverQDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"15", ",", "2", ",", 
          
          TagBox[\({{2, 4, 6, 8, 10, 12, 14, 8, 10, 12, 14, 8, 10, 12, 
                14}, {3, 5, 7, 9, 11, 13, 15, 9, 11, 13, 15, 9, 11, 13, 
                15}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({8, 9, 10, 11}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[156]=",
  CellTags->"CoverQDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 4, 6, 3, 6, 2}, {1, 7, 5, 5, 8, 7, 8, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4, 5, 6, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[157]=",
  CellTags->"CoverQDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoverQDFA[m, mm]\)], "Input",
  CellLabel->"In[158]:=",
  CellTags->"CoverQDFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[158]=",
  CellTags->"CoverQDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoverQDFA[m, mm, DoTrace \[Rule] True]\)], "Input",
  CellLabel->"In[165]:=",
  CellTags->"CoverQDFA"],

Cell[BoxData[
    \({{1, 1}, {2, 2}, {3, 1}, {4, 3}, {5, 7}, {6, 2}, {7, 1}, {8, 4}, {9, 
        5}, {10, 6}, {11, 8}, {12, 3}, {13, 7}, {14, 2}, {15, 1}}\)], "Output",\

  CellLabel->"Out[165]=",
  CellTags->"CoverQDFA"]
}, Open  ]]
}, Closed]],

Cell["DeBruijnEdges", "ObjectName",
  CellTags->"DeBruijnEdges"],

Cell["Type: function", "Highlight",
  CellTags->"DeBruijnEdges"],

Cell[TextData[{
  StyleBox["DeBruijnEdges[w,K]", "MR"],
  "  generates an edge list for the de Bruijn graph of width w over alphabet \
K."
}], "Usage",
  CellTags->"DeBruijnEdges"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"DeBruijnEdges"],

Cell[TextData[{
  " The default alphabet is ",
  Cell[BoxData[
      \(TraditionalForm\`K\  = \ {0, 1}\)]],
  "."
}], "Notes",
  CellTags->"DeBruijnEdges"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->0", "MR"],
  " produces edge list in positional notation, suitable for a ",
  StyleBox["Graph", "MR"],
  " object."
}], "Notes",
  CellTags->"DeBruijnEdges"],

Cell[TextData[{
  "See also ",
  ButtonBox["DeBruijnGraph",
    ButtonData:>"DeBruijnGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DeBruijnEdges"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DeBruijnEdges"],

Cell[TextData[{
  "Edges for the de Bruijn graph of width 3 over ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1}\)]],
  ". "
}], "ExampleText",
  CellTags->"DeBruijnEdges"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeBruijnEdges[3, \(-2\)]\)], "Input",
  CellLabel->"In[203]:=",
  CellTags->"DeBruijnEdges"],

Cell[BoxData[
    \({{"000", "000"}, {"000", "001"}, {"001", "010"}, {"001", 
        "011"}, {"010", "100"}, {"010", "101"}, {"011", "110"}, {"011", 
        "111"}, {"100", "000"}, {"100", "001"}, {"101", "010"}, {"101", 
        "011"}, {"110", "100"}, {"110", "101"}, {"111", "110"}, {"111", 
        "111"}}\)], "Output",
  CellLabel->"Out[203]=",
  CellTags->"DeBruijnEdges"]
}, Open  ]],

Cell["The same in positional notation.", "ExampleText",
  CellTags->"DeBruijnEdges"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeBruijnEdges[3, \(-2\), Normalize \[Rule] 0]\)], "Input",
  CellLabel->"In[204]:=",
  CellTags->"DeBruijnEdges"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {2, 3}, {2, 4}, {3, 5}, {3, 6}, {4, 7}, {4, 8}, {5, 
        1}, {5, 2}, {6, 3}, {6, 4}, {7, 5}, {7, 6}, {8, 7}, {8, 
        8}}\)], "Output",
  CellLabel->"Out[204]=",
  CellTags->"DeBruijnEdges"]
}, Open  ]]
}, Closed]],

Cell["DeBruijnGraph", "ObjectName",
  CellTags->"DeBruijnGraph"],

Cell["Type: function", "Highlight",
  CellTags->"DeBruijnGraph"],

Cell[TextData[{
  StyleBox["DeBruijnGraph[w,K]", "MR"],
  "  generates the de Bruijn graph of width w over alphabet K."
}], "Usage",
  CellTags->"DeBruijnGraph"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "0", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"DeBruijnGraph"],

Cell[TextData[{
  " The default alphabet is ",
  Cell[BoxData[
      \(TraditionalForm\`K\  = \ {0, 1}\)]],
  "."
}], "Notes",
  CellTags->"DeBruijnGraph"],

Cell[TextData[{
  "The nodes in this graph are words of length ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ", and the edges are of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\((ax, xb)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is a word of length ",
  Cell[BoxData[
      \(TraditionalForm\`w - 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " are symbols. These graphs are ",
  Cell[BoxData[
      \(TraditionalForm\`\((k, k)\)\)]],
  "-regular: all nodes have indegree and outdegree ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ \(\(|\)\(K\)\(|\)\)\)]],
  ". They are also Eulerian and Hamiltonian. "
}], "Notes",
  CellTags->"DeBruijnGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["DeBruijnEdges",
    ButtonData:>"DeBruijnEdges",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DeBruijnGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DeBruijnGraph"],

Cell[TextData[{
  "The de Bruijn graph of width 3 over ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1}\)]],
  ". "
}], "ExampleText",
  CellTags->"DeBruijnGraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\  = \ DeBruijnGraph[3, \(-2\), Normalize \[Rule] 1]\)], "Input",
  CellLabel->"In[217]:=",
  CellTags->"DeBruijnGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"8", ",", "16", ",", "1", ",", 
          
          TagBox[\({{1, 1}, {1, 2}, {2, 3}, {2, 4}, {3, 5}, {3, 6}, {4, 
                7}, {4, 8}, {5, 1}, {5, 2}, {6, 3}, {6, 4}, {7, 5}, {7, 
                6}, {8, 7}, {8, 8}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[217]=",
  CellTags->"DeBruijnGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VertexSet[%]\)], "Input",
  CellLabel->"In[218]:=",
  CellTags->"DeBruijnGraph"],

Cell[BoxData[
    \({"000", "001", "010", "011", "100", "101", "110", "111"}\)], "Output",
  CellLabel->"Out[218]=",
  CellTags->"DeBruijnGraph"]
}, Open  ]],

Cell["\<\
This graph is strongly transitive: there is a path of length 3 \
between any two vertices.\
\>", "ExampleText",
  CellTags->"DeBruijnGraph"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(A\  = \ Edges[ToAdjMatrix[g]];\)\), "\n", 
    \(MatrixPower[A, 3]\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[219]:=",
  CellTags->"DeBruijnGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "1", "1"},
            {"1", "1", "1", "1", "1", "1", "1", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[220]//MatrixForm=",
  CellTags->"DeBruijnGraph"]
}, Open  ]]
}, Closed]],

Cell["DefiniteQFA", "ObjectName",
  CellTags->"DefiniteQFA"],

Cell["Type: function", "Highlight",
  CellTags->"DefiniteQFA"],

Cell[TextData[{
  StyleBox["DefiniteQFA[M]", "MR"],
  "  tests wetherM is definite, i.e., whether for all sufficiently long words \
w computations on w always end at the same state, regardless of the starting \
state. \n"
}], "Usage",
  CellTags->"DefiniteQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"DefiniteQFA"],

Cell[TextData[{
  "If option ",
  StyleBox["Full->True", "MR"],
  " is set, the definite-depth of the machine is computed. "
}], "Notes",
  CellTags->"DefiniteQFA"],

Cell["\<\
The algorithm computes the strongly connected components of the \
corresponding product machine and is thus quadratic.\
\>", "Notes",
  CellTags->"DefiniteQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ProductSA",
    ButtonData:>"ProductSA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DefiniteQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DefiniteQFA"],

Cell["A definite automaton.", "ExampleText",
  CellTags->"DefiniteQFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = IthSymbolDFA[a, \(-3\), {a, b}]\), "\n", 
    \(DefiniteQFA[m]\)}], "Input",
  CellLabel->"In[38]:=",
  AspectRatioFixed->True,
  CellTags->"DefiniteQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"15", ",", "2", ",", 
          
          TagBox[\({{2, 4, 6, 8, 10, 12, 14, 8, 10, 12, 14, 8, 10, 12, 
                14}, {3, 5, 7, 9, 11, 13, 15, 9, 11, 13, 15, 9, 11, 13, 
                15}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({8, 9, 10, 11}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[38]=",
  CellTags->"DefiniteQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[39]=",
  CellTags->"DefiniteQFA"]
}, Open  ]],

Cell["All words of length at least 3 lead to synchronization:", "ExampleText",
  CellTags->"DefiniteQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefiniteQFA[m, Full \[Rule] True]\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->"DefiniteQFA"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[40]=",
  CellTags->"DefiniteQFA"]
}, Open  ]],

Cell[BoxData[
    \(TransitionFunctionFA[m, \[Delta]]\)], "Input",
  CellLabel->"In[42]:=",
  CellTags->"DefiniteQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[Delta][#, aba] &\)\  /@ \ Range[15]\)], "Input",
  CellLabel->"In[49]:=",
  CellTags->"DefiniteQFA"],

Cell[BoxData[
    \({10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
      10}\)], "Output",
  CellLabel->"Out[49]=",
  CellTags->"DefiniteQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[Delta][#, aaa] &\)\  /@ \ Range[15]\)], "Input",
  CellLabel->"In[44]:=",
  CellTags->"DefiniteQFA"],

Cell[BoxData[
    \({8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 8}\)], "Output",
  CellLabel->"Out[44]=",
  CellTags->"DefiniteQFA"]
}, Open  ]]
}, Closed]],

Cell["DegreesFA", "ObjectName",
  CellTags->"DegreesFA"],

Cell["Type: function", "Highlight",
  CellTags->"DegreesFA"],

Cell[TextData[{
  StyleBox["DegreesFA[M]", "MR"],
  "  returns a ",
  StyleBox["K", "MR"],
  " by ",
  StyleBox["Q", "MR"],
  " matrix of integers where entry ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, a)\)\)]],
  " is the number of transitions with source ",
  StyleBox["p", "MR"],
  " and label ",
  StyleBox["a", "MR"],
  "."
}], "Usage",
  CellTags->"DegreesFA"],

Cell["\<\
A 0 entry indicates an incomplete state, and an entry larger than 1 \
indicates a nondeterministic state.\
\>", "Notes",
  CellTags->"DegreesFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DegreesFA"],

Cell["\<\
A machine that contains one nondeterministic state, and one \
incomplete state.\
\>", "ExampleText",
  CellTags->"DegreesFA"],

Cell[CellGroupData[{

Cell["m = IthSymbolFA[b,-3,{a,b,c}]", "Input",
  CellLabel->"In[57]:=",
  CellTags->"DegreesFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "3", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {1, 3, 1}, {2, 1, 
                3}, {2, 2, 3}, {2, 3, 3}, {3, 1, 4}, {3, 2, 4}, {3, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[57]=",
  CellTags->"DegreesFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DegreesFA[m]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->"DegreesFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "0"},
            {"2", "1", "1", "0"},
            {"1", "1", "1", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[58]//MatrixForm=",
  CellTags->"DegreesFA"]
}, Open  ]]
}, Closed]],

Cell["DeleteStateFA", "ObjectName",
  CellTags->"DeleteStateFA"],

Cell["Type: function", "Highlight",
  CellTags->"DeleteStateFA"],

Cell[TextData[{
  StyleBox["DeleteStateFA[M,p]", "MR"],
  "  removes state p from machine M"
}], "Usage",
  CellTags->"DeleteStateFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"DeleteStateFA"],

Cell[" Input p can also be a list of states.", "Notes",
  CellTags->"DeleteStateFA"],

Cell[" Machine M can be an FA, NFA or SA (but not a DFA).", "Notes",
  CellTags->"DeleteStateFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DeleteStateFA"],

Cell["\<\
A semiautomaton that accepts all words, and two mutilated versions.\
\
\>", "ExampleText",
  CellTags->"DeleteStateFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(s\  = \ 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 1}, {3, 
              1, 2}, {4, 2, 3}, {4, 1, 4}}];\)\), "\n", 
    \(s1\  = \ DeleteStateFA[s, 1]\), "\n", 
    \(s2\  = \ DeleteStateFA[s, 2]\)}], "Input",
  CellLabel->"In[86]:=",
  CellTags->"DeleteStateFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {1, 2, 3}, {2, 1, 1}, {3, 2, 2}, {3, 1, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[97]=",
  CellTags->"DeleteStateFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 1, 1}, {2, 2, 1}, {3, 2, 2}, {3, 1, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[98]=",
  CellTags->"DeleteStateFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(LanguageFA[\ s, \(-8\), SizeOnly \[Rule] True\ \ ]\), "\n", 
    \(LanguageFA[\ s1, \(-8\), SizeOnly \[Rule] True\ \ ]\), "\n", 
    \(LanguageFA[\ s2, \(-8\), SizeOnly \[Rule] True\ \ ]\)}], "Input",
  CellLabel->"In[101]:=",
  CellTags->"DeleteStateFA"],

Cell[BoxData[
    \({1, 2, 4, 8, 16, 32, 64, 128, 256}\)], "Output",
  CellLabel->"Out[101]=",
  CellTags->"DeleteStateFA"],

Cell[BoxData[
    \({1, 2, 4, 7, 13, 22, 39, 65, 112}\)], "Output",
  CellLabel->"Out[102]=",
  CellTags->"DeleteStateFA"],

Cell[BoxData[
    \({1, 2, 4, 5, 6, 7, 8, 9, 10}\)], "Output",
  CellLabel->"Out[103]=",
  CellTags->"DeleteStateFA"]
}, Open  ]]
}, Closed]],

Cell["DependencyCA", "ObjectName",
  CellTags->"DependencyCA"],

Cell["Type: function", "Highlight",
  CellTags->"DependencyCA"],

Cell[TextData[{
  StyleBox["DependencyCA[C]", "MR"],
  "  returns a list of the indices of the variables upon which the local map \
of cellular automaton C depends. "
}], "Usage",
  CellTags->"DependencyCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["Dependency",
    ButtonData:>"Dependency",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DependencyCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DependencyCA"],

Cell["\<\
The following cellular automaton has width 4, but the local map \
depends only on arguments 1 and 3. \
\>", "ExampleText",
  CellTags->"DependencyCA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(c = CA[13260, 4, \(-2\)]\), "\n", 
    \(DependencyCA[c]\)}], "Input",
  CellLabel->"In[76]:=",
  CellTags->"DependencyCA"],

Cell[BoxData[
    \(CA[13260, 4, \(-2\)]\)], "Output",
  CellLabel->"Out[76]=",
  CellTags->"DependencyCA"],

Cell[BoxData[
    \({1, 3}\)], "Output",
  CellLabel->"Out[77]=",
  CellTags->"DependencyCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintCA[c]\)], "Input",
  CellLabel->"In[78]:=",
  CellTags->"DependencyCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {\("0000" \[Rule] "0"\), \("0100" \[Rule] "0"\), \("1000" \[Rule] 
              "1"\), \("1100" \[Rule] "1"\)},
          {\("0001" \[Rule] "0"\), \("0101" \[Rule] "0"\), \("1001" \[Rule] 
              "1"\), \("1101" \[Rule] "1"\)},
          {\("0010" \[Rule] "1"\), \("0110" \[Rule] "1"\), \("1010" \[Rule] 
              "0"\), \("1110" \[Rule] "0"\)},
          {\("0011" \[Rule] "1"\), \("0111" \[Rule] "1"\), \("1011" \[Rule] 
              "0"\), \("1111" \[Rule] "0"\)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {1, 2}]]]], "Output",
  CellLabel->"Out[78]//TableForm=",
  CellTags->"DependencyCA"]
}, Open  ]]
}, Closed]],

Cell["DeterministicQFA", "ObjectName",
  CellTags->"DeterministicQFA"],

Cell["Type: function", "Highlight",
  CellTags->"DeterministicQFA"],

Cell[TextData[{
  StyleBox["DeterministicQFA[M]", "MR"],
  "  tests whether machine M is deterministic (M can be an FA, NFA or SA). "
}], "Usage",
  CellTags->"DeterministicQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "True"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"DeterministicQFA"],

Cell[TextData[{
  "With option ",
  StyleBox["Full->True", "MR"],
  " the function tests whether ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  "-deterministic, and returns ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Infinity]\)]],
  " accordingly. "
}], "Notes",
  CellTags->"DeterministicQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["CodeterministicQFA",
    ButtonData:>"CodeterministicQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DeterministicQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DeterministicQFA"],

Cell["\<\
A deterministic semiautomaton based on an elementary cellular \
automaton.\
\>", "ExampleText",
  CellTags->"DeterministicQFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(s = ToSA[CA[90]]\), "\n", 
    \(DeterministicQFA[s]\)}], "Input",
  CellLabel->"In[188]:=",
  CellTags->"DeterministicQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 
                1}, {3, 1, 2}, {4, 2, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[188]=",
  CellTags->"DeterministicQFA"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[189]=",
  CellTags->"DeterministicQFA"]
}, Open  ]],

Cell["\<\
Another such semiautomaton that fails to be deterministic but that \
is 1-deterministic.\
\>", "ExampleText",
  CellTags->"DeterministicQFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(s = ToSA[CA[51]]\), "\n", 
    \(DeterministicQFA[s, Full \[Rule] True]\)}], "Input",
  CellLabel->"In[199]:=",
  CellTags->"DeterministicQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", \(-2\), ",", 
          
          TagBox[\({{1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 1, 4}, {3, 2, 
                1}, {3, 2, 2}, {4, 1, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[199]=",
  CellTags->"DeterministicQFA"],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[200]=",
  CellTags->"DeterministicQFA"]
}, Open  ]]
}, Closed]],

Cell["EmptyDFA", "ObjectName",
  CellTags->"EmptyDFA"],

Cell["Type: function", "Highlight",
  CellTags->"EmptyDFA"],

Cell[TextData[{
  StyleBox["EmptyDFA[K]", "MR"],
  "  constructs a DFA that accepts the empty language over alphabet K."
}], "Usage",
  CellTags->"EmptyDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"EmptyDFA"],

Cell["A DFA accepting no words at all.", "ExampleText",
  CellTags->"EmptyDFA"],

Cell[CellGroupData[{

Cell["m = EmptyDFA[3]", "Input",
  CellLabel->"In[108]:=",
  CellTags->"EmptyDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"1", ",", "3", ",", 
          TagBox[\({{1}, {1}, {1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[108]=",
  CellTags->"EmptyDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-5\)]\)], "Input",
  CellLabel->"In[109]:=",
  CellTags->"EmptyDFA"],

Cell[BoxData[
    \({{}, {}, {}, {}, {}, {}}\)], "Output",
  CellLabel->"Out[109]=",
  CellTags->"EmptyDFA"]
}, Open  ]]
}, Closed]],

Cell["EmptyQFA", "ObjectName",
  CellTags->"EmptyQFA"],

Cell["Type: function", "Highlight",
  CellTags->"EmptyQFA"],

Cell[TextData[{
  StyleBox["EmptyQFA[M]", "MR"],
  "  tests whether the acceptance language of M is empty "
}], "Usage",
  CellTags->"EmptyQFA"],

Cell["\<\
The algorithm computes the accessible part of the automaton and is \
linear.\
\>", "Notes",
  CellTags->"EmptyQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"EmptyQFA"],

Cell["Two midly complicated machines with empty intersection.", "ExampleText",
  CellTags->"EmptyQFA"],

Cell[BoxData[
    \(\(m1 = \ 
        DFA[6, 2, {{2, 4, 3, 5, 6, 3}, {3, 3, 3, 3, 3, 3}}, 
          1, {6}];\)\)], "Input",
  CellLabel->"In[132]:=",
  CellTags->"EmptyQFA"],

Cell[BoxData[
    \(\(m2\  = \ 
        DFA[9, 2, {{2, 4, 5, 6, 7, 8, 9, 8, 8}, {3, 5, 5, 7, 7, 9, 9, 8, 8}}, 
          1, {9}];\)\)], "Input",
  CellLabel->"In[133]:=",
  CellTags->"EmptyQFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(EmptyQFA[m1]\), "\n", 
    \(EmptyQFA[m2]\), "\n", 
    \(EmptyQFA[IntersectionFA[m1, m2]]\)}], "Input",
  CellLabel->"In[134]:=",
  CellTags->"EmptyQFA"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[134]=",
  CellTags->"EmptyQFA"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[135]=",
  CellTags->"EmptyQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[136]=",
  CellTags->"EmptyQFA"]
}, Open  ]]
}, Closed]],

Cell["EpsFreeQ", "ObjectName",
  CellTags->"EpsFreeQ"],

Cell["Type: function", "Highlight",
  CellTags->"EpsFreeQ"],

Cell[TextData[{
  StyleBox["EpsFreeQ[M]", "MR"],
  "  tests whether a machine is epsilon-free."
}], "Usage",
  CellTags->"EpsFreeQ"],

Cell[TextData[{
  "Machine ",
  StyleBox["M", "MR"],
  " can be an FA, SA or BEFA."
}], "Notes",
  CellTags->"EpsFreeQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"EpsFreeQ"],

Cell["\<\
Conversion from regular expression usually produces epsilon \
transitions. \
\>", "ExampleText",
  CellTags->"EpsFreeQ"],

Cell[CellGroupData[{

Cell["RegularExpressionToBEFA[ RES[REP[aa,bb]] ]", "Input",
  CellLabel->"In[140]:=",
  CellTags->"EpsFreeQ"],

Cell[BoxData[
    \(BEFA[
      6, {{1, \[Epsilon], 2}, {2, "a", 3}, {2, "b", 4}, {2, \[Epsilon], 
          6}, {3, "a", 5}, {4, "b", 5}, {5, \[Epsilon], 2}}]\)], "Output",
  CellLabel->"Out[140]=",
  CellTags->"EpsFreeQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EpsFreeQ[%]\)], "Input",
  CellLabel->"In[141]:=",
  CellTags->"EpsFreeQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[141]=",
  CellTags->"EpsFreeQ"]
}, Open  ]]
}, Closed]],

Cell["EpsilonEliminationFA", "ObjectName",
  CellTags->"EpsilonEliminationFA"],

Cell["Type: function", "Highlight",
  CellTags->"EpsilonEliminationFA"],

Cell[TextData[{
  StyleBox["EpsilonEliminationFA[M]", "MR"],
  "  converts a machine M into an equivalent epsilon-free machine. "
}], "Usage",
  CellTags->"EpsilonEliminationFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"EpsilonEliminationFA"],

Cell[TextData[{
  "With option ",
  StyleBox["DoTrace->True", "MR"],
  " it returns ",
  Cell[BoxData[
      \(TraditionalForm\`{m, t\_\[Epsilon], t, t\_c}\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the epsilon-free FA, ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  " is a list of the epsilon transitions of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " is a list of the non-epsilon transitions, and ",
  Cell[BoxData[
      \(TraditionalForm\`t\_c\)]],
  "represents the transitive, reflexive closure of ",
  Cell[BoxData[
      \(TraditionalForm\`t\_\[Epsilon]\)]],
  ". All are given as binary relations on the state set of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "."
}], "Notes",
  CellTags->"EpsilonEliminationFA"],

Cell["\<\
Epsilon elimination is used automatically in the Thompson style \
conversion algorithms from regular expressions to machines.\
\>", "Notes",
  CellTags->"EpsilonEliminationFA"],

Cell["\<\
The algorithm preserves the number of states but is in general \
quadratic due to the number of newly introduced transitions. \
\>", "Notes",
  CellTags->"EpsilonEliminationFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"EpsilonEliminationFA"],

Cell["\<\
A machine produced by conversion from regular expression, and its \
epsilon-free counterpart.\
\>", "ExampleText",
  CellTags->"EpsilonEliminationFA"],

Cell[BoxData[
    \(\(m = 
        FA[17, 2, {{2, 1, 3}, {3, 1, 5}, {4, 1, 4}, {5, 1, 4}, {6, 1, 4}, {2, 
              2, 4}, {3, 2, 4}, {4, 2, 4}, {5, 2, 6}, {6, 2, 4}, {1, 0, 
              2}, {6, 0, 1}, {1, 0, 7}, {8, 1, 9}, {9, 1, 9}, {10, 1, 
              9}, {11, 1, 12}, {12, 1, 9}, {8, 2, 10}, {9, 2, 9}, {10, 2, 
              11}, {11, 2, 9}, {12, 2, 9}, {7, 0, 8}, {12, 0, 7}, {7, 0, 
              13}, {13, 1, 14}, {14, 1, 14}, {15, 1, 14}, {16, 1, 14}, {17, 
              1, 14}, {13, 2, 15}, {14, 2, 14}, {15, 2, 16}, {16, 2, 
              17}, {17, 2, 14}}, {1}, {17}];\)\)], "Input",
  CellLabel->"In[153]:=",
  CellTags->"EpsilonEliminationFA"],

Cell[BoxData[
    \(\(mm\  = \ EpsilonEliminationFA[m];\)\)], "Input",
  CellLabel->"In[159]:=",
  CellTags->"EpsilonEliminationFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[m, mm]\)], "Input",
  CellLabel->"In[156]:=",
  CellTags->"EpsilonEliminationFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[156]=",
  CellTags->"EpsilonEliminationFA"]
}, Open  ]],

Cell["The trace of the algorithm.", "ExampleText",
  CellTags->"EpsilonEliminationFA"],

Cell[BoxData[
    \(\({mm, te, t, tt}\  = \ 
        EpsilonEliminationFA[m, DoTrace \[Rule] True];\)\)], "Input",
  CellLabel->"In[160]:=",
  CellTags->"EpsilonEliminationFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(te\)], "Input",
  CellLabel->"In[161]:=",
  CellTags->"EpsilonEliminationFA"],

Cell[BoxData[
    \({{1, 2}, {6, 1}, {1, 7}, {7, 8}, {12, 7}, {7, 13}}\)], "Output",
  CellLabel->"Out[161]=",
  CellTags->"EpsilonEliminationFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(t\)], "Input",
  CellLabel->"In[162]:=",
  CellTags->"EpsilonEliminationFA"],

Cell[BoxData[
    \({{2, 1, 3}, {3, 1, 5}, {4, 1, 4}, {5, 1, 4}, {6, 1, 4}, {2, 2, 4}, {3, 
        2, 4}, {4, 2, 4}, {5, 2, 6}, {6, 2, 4}, {8, 1, 9}, {9, 1, 9}, {10, 1, 
        9}, {11, 1, 12}, {12, 1, 9}, {8, 2, 10}, {9, 2, 9}, {10, 2, 11}, {11, 
        2, 9}, {12, 2, 9}, {13, 1, 14}, {14, 1, 14}, {15, 1, 14}, {16, 1, 
        14}, {17, 1, 14}, {13, 2, 15}, {14, 2, 14}, {15, 2, 16}, {16, 2, 
        17}, {17, 2, 14}}\)], "Output",
  CellLabel->"Out[162]=",
  CellTags->"EpsilonEliminationFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tt\)], "Input",
  CellLabel->"In[163]:=",
  CellTags->"EpsilonEliminationFA"],

Cell[BoxData[
    \({{1, 2, 7, 8, 13}, {2}, {3}, {4}, {5}, {6, 1, 2, 7, 8, 13}, {7, 8, 
        13}, {8}, {9}, {10}, {11}, {12, 7, 8, 
        13}, {13}, {14}, {15}, {16}, {17}}\)], "Output",
  CellLabel->"Out[163]=",
  CellTags->"EpsilonEliminationFA"]
}, Open  ]]
}, Closed]],

Cell["EquivalentQFA", "ObjectName",
  CellTags->"EquivalentQFA"],

Cell["Type: function", "Highlight",
  CellTags->"EquivalentQFA"],

Cell[TextData[{
  StyleBox["EquivalentQFA[M1,M2]", "MR"],
  "  tests whether automata M1 and M2 are equivalent. "
}], "Usage",
  CellTags->"EquivalentQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"EquivalentQFA"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True", "MR"],
  " returns a list ",
  Cell[BoxData[
      \(TraditionalForm\`\((n\_1, n\_2, F, R)\)\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " is the size of the first DFA, ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " the size of the second DFA, ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " the disjoint union of the final states of both machines, and ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " the partition on the joint state set induced by the algorithm. "
}], "Notes",
  CellTags->"EquivalentQFA"],

Cell["\<\
For deterministic machines the union-find algorithm is used. Thus, \
the time complexity is nearly linear.
NOTE: only partially implemented.\
\>", "Notes",
  CellTags->"EquivalentQFA"],

Cell["\<\
If the input is nondeterministic a conversion to a deterministic \
machine is performed, so the algorithm has potentially exponential space and \
time complexity.\
\>", "Notes",
  CellTags->"EquivalentQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"EquivalentQFA"],

Cell["Several equivalent machines.", "ExampleText",
  CellTags->"EquivalentQFA"],

Cell[BoxData[
    \(\(m0\  = \ 
        FA[4, 2, {{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[174]:=",
  CellTags->"EquivalentQFA"],

Cell[BoxData[
    \(\(m1\  = \ 
        DFA[15, 2, {{2, 4, 6, 8, 10, 12, 14, 8, 10, 12, 14, 8, 10, 12, 
              14}, {3, 5, 7, 9, 11, 13, 15, 9, 11, 13, 15, 9, 11, 13, 15}}, 
          1, {8, 9, 10, 11}];\)\)], "Input",
  CellLabel->"In[175]:=",
  CellTags->"EquivalentQFA"],

Cell[BoxData[
    \(\(m2\  = \ 
        DFA[8, 2, {{2, 3, 4, 4, 6, 3, 6, 2}, {1, 7, 5, 5, 8, 7, 8, 1}}, 
          1, {4, 5, 6, 8}];\)\)], "Input",
  CellLabel->"In[176]:=",
  CellTags->"EquivalentQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[\ m1, \ m2\ ]\)], "Input",
  CellLabel->"In[177]:=",
  CellTags->"EquivalentQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[177]=",
  CellTags->"EquivalentQFA"]
}, Open  ]],

Cell["This call requires deterministic simulation.", "ExampleText",
  CellTags->"EquivalentQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[\ m0, \ m1\ ]\)], "Input",
  CellLabel->"In[180]:=",
  CellTags->"EquivalentQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[180]=",
  CellTags->"EquivalentQFA"]
}, Open  ]],

Cell["\<\
A trace of the partition constructed by the algorithm. All blocks \
intersect either both final state sets, or a disjoint with both.\
\>", \
"ExampleText",
  CellTags->"EquivalentQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \({n1, n2, F, R}\  = \ 
      EquivalentQFA[\ m1, \ m2, DoTrace \[Rule] True\ ]\)], "Input",
  CellLabel->"In[183]:=",
  CellTags->"EquivalentQFA"],

Cell[BoxData[
    \({15, 
      8, {8, 9, 10, 11, 19, 20, 21, 
        23}, {{8, 19}, {9, 20}, {10, 21}, {11, 23}, {4, 12, 18}, {5, 13, 
          22}, {2, 6, 14, 17}, {1, 3, 7, 15, 16}}}\)], "Output",
  CellLabel->"Out[183]=",
  CellTags->"EquivalentQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Intersection[F, #] &\)\  /@ \ R\)], "Input",
  CellLabel->"In[184]:=",
  CellTags->"EquivalentQFA"],

Cell[BoxData[
    \({{8, 19}, {9, 20}, {10, 21}, {11, 23}, {}, {}, {}, {}}\)], "Output",
  CellLabel->"Out[184]=",
  CellTags->"EquivalentQFA"]
}, Open  ]]
}, Closed]],

Cell["EvolutionCA", "ObjectName",
  CellTags->"EvolutionCA"],

Cell["Type: function", "Highlight",
  CellTags->"EvolutionCA"],

Cell[TextData[{
  StyleBox["EvolutionCA[C,X,t,opts]", "MR"],
  "  plots t steps in the evolution of pattern X under the global map of \
cellular automaton C. "
}], "Usage",
  CellTags->"EvolutionCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Boundary", "\[Rule]", "Cyclic", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"EvolutionCA"],

Cell[TextData[{
  "Option ",
  StyleBox["Boundary->Fixed", "MR"],
  " uses fixed boundary conditions."
}], "Notes",
  CellTags->"EvolutionCA"],

Cell[TextData[{
  "The default for ",
  StyleBox["X", "MR"],
  " is a one-point seed generated by ",
  ButtonBox["SeedConfiguration",
    ButtonData:>"SeedConfiguration",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"EvolutionCA"],

Cell[TextData[{
  "The default for ",
  StyleBox["t", "MR"],
  " is 40."
}], "Notes",
  CellTags->"EvolutionCA"],

Cell[TextData[{
  "Uses ",
  StyleBox["PlotMatrix", "MR"],
  "  to render the graphics."
}], "Notes",
  CellTags->"EvolutionCA"],

Cell[TextData[{
  "See also ",
  Cell[BoxData[
      FormBox[
        ButtonBox["GlobalMapCA",
          ButtonData:>"GlobalMapCA",
          ButtonStyle->"AddOnsLink"], TraditionalForm]]],
  " and ",
  ButtonBox["OrbitCA",
    ButtonData:>"OrbitCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"EvolutionCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"EvolutionCA"],

Cell["A classical example: additive rule 90.", "ExampleText",
  CellTags->"EvolutionCA"],

Cell[CellGroupData[{

Cell["EvolutionCA[CA[90]];", "Input",
  CellLabel->"In[187]:=",
  CellTags->"EvolutionCA"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .50617 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0117578 0.0120517 0.0117578 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .50617 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .50617 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .50617 L
s
0 .50617 m
1 .50617 L
s
1 0 m
1 .50617 L
s
0 0 m
1 0 L
1 .50617 L
0 .50617 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01205 translate
.95238 .48207 scale
243 string
81 41 8 [81 0 0 41 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[187]:=",
  ImageSize->{288, 145.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"EvolutionCA"]
}, Open  ]],

Cell["\<\
The same CA with different boundary conditions, and a different \
initial configuration. The orbit ends in the fixed point \"all-zeros\".\
\>", \
"ExampleText",
  CellTags->"EvolutionCA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X = SeedConfiguration[{1, 1, 1}, 15];\)\), "\n", 
    \(\(EvolutionCA[CA[90], X, 10, \ Boundary \[Rule] Fixed, 
        GridLines \[Rule] True];\)\)}], "Input",
  CellLabel->"In[202]:=",
  CellTags->"EvolutionCA"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .73333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.0174603 0.0634921 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .73333 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .73333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .73333 L
s
0 .73333 m
1 .73333 L
s
1 0 m
1 .73333 L
s
0 0 m
1 0 L
1 .73333 L
0 .73333 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01746 translate
.95238 .69841 scale
45 string
15 11 8 [15 0 0 11 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF
0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF
0000FFCCFFFF0000FF
0000FF0000FF0000FFCCFFFF0000FF0000FF0000FFCCFFFF0000FF0000FF0000FFCCFFFF
0000FF0000FF0000FF
CCFFFF0000FF0000FFCCFFFF0000FF0000FFCCFFFFCCFFFFCCFFFF0000FF0000FFCCFFFF
0000FF0000FFCCFFFF
CCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FF0000FFCCFFFF0000FFCCFFFF0000FFCCFFFF0000FF0000FF
CCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFF0000FF0000FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FFCCFFFF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF
pop
P
% End of image
.8 g
.003 w
.02381 .01746 m
.02381 .71587 L
s
.0873 .01746 m
.0873 .71587 L
s
.15079 .01746 m
.15079 .71587 L
s
.21429 .01746 m
.21429 .71587 L
s
.27778 .01746 m
.27778 .71587 L
s
.34127 .01746 m
.34127 .71587 L
s
.40476 .01746 m
.40476 .71587 L
s
.46825 .01746 m
.46825 .71587 L
s
.53175 .01746 m
.53175 .71587 L
s
.59524 .01746 m
.59524 .71587 L
s
.65873 .01746 m
.65873 .71587 L
s
.72222 .01746 m
.72222 .71587 L
s
.78571 .01746 m
.78571 .71587 L
s
.84921 .01746 m
.84921 .71587 L
s
.9127 .01746 m
.9127 .71587 L
s
.97619 .01746 m
.97619 .71587 L
s
.02381 .01746 m
.97619 .01746 L
s
.02381 .08095 m
.97619 .08095 L
s
.02381 .14444 m
.97619 .14444 L
s
.02381 .20794 m
.97619 .20794 L
s
.02381 .27143 m
.97619 .27143 L
s
.02381 .33492 m
.97619 .33492 L
s
.02381 .39841 m
.97619 .39841 L
s
.02381 .4619 m
.97619 .4619 L
s
.02381 .5254 m
.97619 .5254 L
s
.02381 .58889 m
.97619 .58889 L
s
.02381 .65238 m
.97619 .65238 L
s
.02381 .71587 m
.97619 .71587 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[202]:=",
  ImageSize->{288, 211.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"EvolutionCA"]
}, Open  ]]
}, Closed]],

Cell["FactorialQFA", "ObjectName",
  CellTags->"FactorialQFA"],

Cell["Type: function", "Highlight",
  CellTags->"FactorialQFA"],

Cell[TextData[{
  StyleBox["FactorialQFA[M,opts]", "MR"],
  "  tests whether the language accepted by FSM ",
  StyleBox["M", "MR"],
  " is factorial, i.e., closed under factors."
}], "Usage",
  CellTags->"FactorialQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"FactorialQFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  "  returns in addition the semiautomaton constructed by the algorithm: the \
minimal automaton minus its sink state."
}], "Notes",
  CellTags->"FactorialQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FactorialQFA"],

Cell["Here is a small factorial DFA.", "ExampleText",
  CellTags->"FactorialQFA"],

Cell[BoxData[
    \(\(m = 
        DFA[6, 2, {{2, 2, 4, 4, 6, 6}, {1, 3, 1, 5, 2, 6}}, 
          1, {1, 2, 3, 4, 5}];\)\)], "Input",
  CellLabel->"In[294]:=",
  CellTags->"FactorialQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialQFA[s]\)], "Input",
  CellLabel->"In[295]:=",
  CellTags->"FactorialQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[295]=",
  CellTags->"FactorialQFA"]
}, Open  ]],

Cell["The semiautomaton used in the test.", "ExampleText",
  CellTags->"FactorialQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FactorialQFA[s, Full \[Rule] True]\)], "Input",
  CellLabel->"In[296]:=",
  CellTags->"FactorialQFA"],

Cell[BoxData[
    \({True, 
      SA[5, \(-2\), {{1, 1, 2}, {2, 1, 2}, {3, 1, 4}, {4, 1, 4}, {1, 2, 
            1}, {2, 2, 3}, {3, 2, 1}, {4, 2, 5}, {5, 2, 2}}, {}, {1, 2, 3, 4, 
          5}]}\)], "Output",
  CellLabel->"Out[296]=",
  CellTags->"FactorialQFA"]
}, Open  ]]
}, Closed]],

Cell["FinalVectorFA", "ObjectName",
  CellTags->"FinalVectorFA"],

Cell["Type: function", "Highlight",
  CellTags->"FinalVectorFA"],

Cell[TextData[{
  StyleBox["FinalVectorFA[M]", "MR"],
  " returns the bitvector representing the  final states of M."
}], "Usage",
  CellTags->"FinalVectorFA"],

Cell["For efficiency reasons, 0/1-vectors are used. ", "Notes",
  CellTags->"FinalVectorFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["InitialVectorFA",
    ButtonData:>"InitialVectorFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["Final",
    ButtonData:>"Final",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FinalVectorFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FinalVectorFA"],

Cell["A random DFA and its finat states bitvector.", "ExampleText",
  CellTags->"FinalVectorFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m\  = \ 
        DFA[6, 2, {{2, 2, 4, 4, 6, 6}, {1, 3, 1, 5, 2, 6}}, 
          1, {1, 2, 3, 4, 5}];\)\), "\n", 
    \(FinalVectorFA[m]\)}], "Input",
  CellLabel->"In[300]:=",
  CellTags->"FinalVectorFA"],

Cell[BoxData[
    \({1, 1, 1, 1, 1, 0}\)], "Output",
  CellLabel->"Out[301]=",
  CellTags->"FinalVectorFA"]
}, Open  ]]
}, Closed]],

Cell["Final", "ObjectName",
  CellTags->"Final"],

Cell["Type: function", "Highlight",
  CellTags->"Final"],

Cell[TextData[{
  StyleBox["Final[M]", "MR"],
  "  returns a list of the final states of finite state machine ",
  StyleBox["M", "MR"],
  " in positional notation."
}], "Usage",
  CellTags->"Final"],

Cell[TextData[{
  "See also ",
  ButtonBox["FinalVectorFA",
    ButtonData:>"FinalVectorFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["Initial",
    ButtonData:>"Initial",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Final"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Final"],

Cell["\<\
A somewhat complicated  FA for all words of length 2, and its \
initial states bitvector.\
\>", "ExampleText",
  CellTags->"Final"],

Cell[BoxData[
    \(\(m = 
        UnionFA @@ \(\((ToFA[BuildDFA[#1]] &)\) /@ Words[2]\);\)\)], "Input",
  CellLabel->"In[309]:=",
  CellTags->"Final"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Final[m]\)], "Input",
  CellLabel->"In[316]:=",
  CellTags->"Final"],

Cell[BoxData[
    \({4, 8, 12, 16}\)], "Output",
  CellLabel->"Out[316]=",
  CellTags->"Final"]
}, Open  ]]
}, Closed]],

Cell["FiniteComplementSA", "ObjectName",
  CellTags->"FiniteComplementSA"],

Cell["Type: function", "Highlight",
  CellTags->"FiniteComplementSA"],

Cell[TextData[{
  StyleBox["FiniteComplementSA[W,K]", "MR"],
  "  returns the canonical semiatautomaton that accepts the language of all \
words not containing any word in ",
  StyleBox["W", "MR"],
  " as a factor. "
}], "Usage",
  CellTags->"FiniteComplementSA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"FiniteComplementSA"],

Cell[TextData[{
  StyleBox["W", "MR"],
  " may also be a single word."
}], "Notes",
  CellTags->"FiniteComplementSA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FiniteComplementSA"],

Cell["All words not containing the factors aa and bb.", "ExampleText",
  CellTags->"FiniteComplementSA"],

Cell[CellGroupData[{

Cell["FiniteComplementSA[{aa,bb},2]", "Input",
  CellLabel->"In[4]:=",
  CellTags->"FiniteComplementSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {1, 2, 3}, {2, 2, 3}, {3, 1, 2}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[4]=",
  CellTags->"FiniteComplementSA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[%, \(-5\)]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"FiniteComplementSA"],

Cell[BoxData[
    \({{\[Epsilon]}, {"a", "b"}, {"ab", "ba"}, {"aba", "bab"}, {"abab", 
        "baba"}, {"ababa", "babab"}}\)], "Output",
  CellLabel->"Out[5]=",
  CellTags->"FiniteComplementSA"]
}, Open  ]]
}, Closed]],

Cell["FormatAutomata", "ObjectName",
  CellTags->"FormatAutomata"],

Cell["Type: function", "Highlight",
  CellTags->"FormatAutomata"],

Cell[TextData[{
  StyleBox["FormatAutomata[fmt]", "MR"],
  "  controls formatting of the output form of finite state machines and \
graphs. "
}], "Usage",
  CellTags->"FormatAutomata"],

Cell[TextData[{
  StyleBox["FormatAutomata[None]", "MR"],
  "  turns all formatting off. This may lead to the display of very large \
expressions."
}], "Notes",
  CellTags->"FormatAutomata"],

Cell[TextData[{
  " ",
  StyleBox["FormatAutomata[Some]", "MR"],
  " supresses display of the structured part of machines. "
}], "Notes",
  CellTags->"FormatAutomata"],

Cell[TextData[{
  StyleBox["FormatAutomata[Automatic]", "MR"],
  " applies ",
  StyleBox["Short", "MR"],
  " to potentially large parts of the expression. "
}], "Notes",
  CellTags->"FormatAutomata"],

Cell[TextData[{
  StyleBox["FormatAutomata[Full]", "MR"],
  " only prints a string such as ",
  StyleBox["-DFA-", "MR"],
  "."
}], "Notes",
  CellTags->"FormatAutomata"],

Cell["\<\
Note that formatted expression may cause problems when copied to \
produce input for further computations.\
\>", "Notes",
  CellTags->"FormatAutomata"],

Cell[TextData[{
  "See also ",
  ButtonBox["$shortlines",
    ButtonData:>"shortlines",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FormatAutomata"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FormatAutomata"],

Cell["The same DFA, displayed in four different ways. ", "ExampleText",
  CellTags->"FormatAutomata"],

Cell[BoxData[
    \(\(m = ToDFA[IthSymbolFA[a, \(-5\)], Normalize \[Rule] 1];\)\)], "Input",\

  CellLabel->"In[61]:=",
  CellTags->"FormatAutomata"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FormatAutomata[None]\), "\n", 
    \(m\)}], "Input",
  CellLabel->"In[62]:=",
  CellTags->"FormatAutomata"],

Cell[BoxData[
    \(DFA[32, 
      2, {{2, 3, 5, 7, 9, 11, 13, 15, 17, 19, 21, 23, 25, 27, 29, 31, 17, 19, 
          21, 23, 25, 27, 29, 31, 9, 11, 13, 15, 5, 7, 3, 2}, {1, 4, 6, 8, 
          10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32, 18, 20, 22, 24, 26, 
          28, 30, 32, 10, 12, 14, 16, 6, 8, 4, 1}}, 
      1, {17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 
        32}, {}, {{1}, {1, 2}, {1, 2, 3}, {1, 3}, {1, 2, 3, 4}, {1, 3, 
          4}, {1, 2, 4}, {1, 4}, {1, 2, 3, 4, 5}, {1, 3, 4, 5}, {1, 2, 4, 
          5}, {1, 4, 5}, {1, 2, 3, 5}, {1, 3, 5}, {1, 2, 5}, {1, 5}, {1, 2, 
          3, 4, 5, 6}, {1, 3, 4, 5, 6}, {1, 2, 4, 5, 6}, {1, 4, 5, 6}, {1, 2, 
          3, 5, 6}, {1, 3, 5, 6}, {1, 2, 5, 6}, {1, 5, 6}, {1, 2, 3, 4, 
          6}, {1, 3, 4, 6}, {1, 2, 4, 6}, {1, 4, 6}, {1, 2, 3, 6}, {1, 3, 
          6}, {1, 2, 6}, {1, 6}}]\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->"FormatAutomata"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FormatAutomata[Some]\), "\n", 
    \(m\)}], "Input",
  CellLabel->"In[64]:=",
  CellTags->"FormatAutomata"],

Cell[BoxData[
    TagBox[\(DFA[32, 
        2, {{2, 3, 5, 7, 9, 11, 13, 15, 17, 19, 21, 23, 25, 27, 29, 31, 17, 
            19, 21, 23, 25, 27, 29, 31, 9, 11, 13, 15, 5, 7, 3, 2}, {1, 4, 6, 
            8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32, 18, 20, 22, 
            24, 26, 28, 30, 32, 10, 12, 14, 16, 6, 8, 4, 1}}, 
        1, {17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 
          32}]\),
      HoldForm]], "Output",
  CellLabel->"Out[65]=",
  CellTags->"FormatAutomata"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FormatAutomata[Automatic]\), "\n", 
    \(m\)}], "Input",
  CellLabel->"In[70]:=",
  CellTags->"FormatAutomata"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"32", ",", "2", ",", 
          
          TagBox[\({{2, 3, 5, 7, 9, 11, 13, 15, 17, 19, 21, 23, 25, 27, 29, 
                31, 17, 19, 21, 23, 25, 27, 29, 31, 9, 11, 13, 15, 5, 7, 3, 
                2}, \[LeftSkeleton]1\[RightSkeleton]}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          
          TagBox[\({17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
              31, 32}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[71]=",
  CellTags->"FormatAutomata"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FormatAutomata[Full]\), "\n", 
    \(m\)}], "Input",
  CellLabel->"In[72]:=",
  CellTags->"FormatAutomata"],

Cell[BoxData[
    \("-DFA-"\)], "Output",
  CellLabel->"Out[73]=",
  CellTags->"FormatAutomata"]
}, Open  ]],

Cell["Back to the default.", "ExampleText",
  CellTags->"FormatAutomata"],

Cell[BoxData[
    \(FormatAutomata[Automatic]\)], "Input",
  CellLabel->"In[74]:=",
  CellTags->"FormatAutomata"]
}, Closed]],

Cell["FormatX", "ObjectName",
  CellTags->"FormatX"],

Cell["Type: function", "Highlight",
  CellTags->"FormatX"],

Cell[TextData[{
  StyleBox["FormatX[True]", "MR"],
  " formats ",
  StyleBox["X", "MR"],
  " so ",
  StyleBox["X[i]", "MR"],
  " prints in subscript notation. "
}], "Usage",
  CellTags->"FormatX"],

Cell["\<\
Mildly useful to display a system of linear equations over the \
language semiring. \
\>", "Notes",
  CellTags->"FormatX"],

Cell[TextData[{
  StyleBox["FormatX[False]", "MR"],
  " turns formatting off. Default is formatting on."
}], "Notes",
  CellTags->"FormatX"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToEquationsDFA",
    ButtonData:>"ToEquationsDFA",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"FormatX"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FormatX"],

Cell["Converting a DFA into a system of equations.", "ExampleText",
  CellTags->"FormatX"],

Cell[CellGroupData[{

Cell["ModCounterDFA[b,0,3,2] // ToEquationsDFA // TableForm", "Input",
  CellLabel->"In[188]:=",
  CellTags->"FormatX"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("X"\_1 == 
              REP[\[Epsilon], RET["a", "X"\_1], RET["b", "X"\_2]]\)},
          {\("X"\_2 == REP[RET["a", "X"\_2], RET["b", "X"\_3]]\)},
          {\("X"\_3 == REP[RET["a", "X"\_3], RET["b", "X"\_1]]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Automata`automata`Private`X[ 1], 
          REP[ \[Epsilon], 
            RET[ "a", 
              Automata`automata`Private`X[ 1]], 
            RET[ "b", 
              Automata`automata`Private`X[ 2]]]], 
        Equal[ 
          Automata`automata`Private`X[ 2], 
          REP[ 
            RET[ "a", 
              Automata`automata`Private`X[ 2]], 
            RET[ "b", 
              Automata`automata`Private`X[ 3]]]], 
        Equal[ 
          Automata`automata`Private`X[ 3], 
          REP[ 
            RET[ "a", 
              Automata`automata`Private`X[ 3]], 
            RET[ "b", 
              Automata`automata`Private`X[ 1]]]]}]]], "Output",
  CellLabel->"Out[188]//TableForm=",
  CellTags->"FormatX"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  /. \ {REP \[Rule] Plus, RET \[Rule] NonCommutativeMultiply}\  // \ 
      TableForm\)], "Input",
  CellLabel->"In[189]:=",
  CellTags->"FormatX"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("X"\_1 == \[Epsilon] + "a" ** "X"\_1 + "b" ** "X"\_2\)},
          {\("X"\_2 == "a" ** "X"\_2 + "b" ** "X"\_3\)},
          {\("X"\_3 == "a" ** "X"\_3 + "b" ** "X"\_1\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Automata`automata`Private`X[ 1], 
          Plus[ \[Epsilon], 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 1]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 2]]]], 
        Equal[ 
          Automata`automata`Private`X[ 2], 
          Plus[ 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 2]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 3]]]], 
        Equal[ 
          Automata`automata`Private`X[ 3], 
          Plus[ 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 3]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 1]]]]}]]], "Output",
  CellLabel->"Out[189]//TableForm=",
  CellTags->"FormatX"]
}, Open  ]]
}, Closed]],

Cell["FrontierQ", "ObjectName",
  CellTags->"FrontierQ"],

Cell["Type: function", "Highlight",
  CellTags->"FrontierQ"],

Cell[TextData[{
  StyleBox["FrontierQ[L,K]", "MR"],
  "  test whether the finite language ",
  StyleBox["L", "MR"],
  " is a frontier over alphabet ",
  StyleBox["K", "MR"],
  "."
}], "Usage",
  CellTags->"FrontierQ"],

Cell["\<\
 Note that L is supposed to be prefix, the algorithm does not \
check.\
\>", "Notes",
  CellTags->"FrontierQ"],

Cell[TextData[{
  "See also  ",
  ButtonBox["ToPrefix",
    ButtonData:>"ToPrefix",
    ButtonStyle->"AddOnsLink"],
  "  and ",
  ButtonBox["FrontierToDFA",
    ButtonData:>"FrontierToDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FrontierQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FrontierQ"],

Cell["A small frontier language.", "ExampleText",
  CellTags->"FrontierQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FrontierQ[{aa, bb, baa, bab, aba, abb}, 2]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"FrontierQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"FrontierQ"]
}, Open  ]],

Cell["Note that the underlying alphabet matters.", "ExampleText",
  CellTags->"FrontierQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FrontierQ[{aa, bb, baa, bab, aba, abb}, 3]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"FrontierQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[7]=",
  CellTags->"FrontierQ"]
}, Open  ]]
}, Closed]],

Cell["FrontierToDFA", "ObjectName",
  CellTags->"FrontierToDFA"],

Cell["Type: function", "Highlight",
  CellTags->"FrontierToDFA"],

Cell[TextData[{
  StyleBox["FrontierToDFA[g,F]", "MR"],
  "  converts frontier automaton ",
  Cell[BoxData[
      \(TraditionalForm\`\((g, F)\)\)]],
  " into a DFA.  "
}], "Usage",
  CellTags->"FrontierToDFA"],

Cell[TextData[{
  "Here ",
  StyleBox["g", "MR"],
  " is a list of word pairs (the first components form a frontier language), \
",
  StyleBox["F", "MR"],
  " a list of words."
}], "Notes",
  CellTags->"FrontierToDFA"],

Cell[TextData[{
  " See also ",
  ButtonBox["ToPeriodicFrontierDFA",
    ButtonData:>"ToPeriodicFrontierDFA",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["FrontierToDFA",
    ButtonData:>"FrontierToDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["FrontierQ",
    ButtonData:>"FrontierQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FrontierToDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FrontierToDFA"],

Cell["\<\
Constructing a frontier automaton. The word pairs are used as \
rewrite rules on the input.\
\>", "ExampleText",
  CellTags->"FrontierToDFA"],

Cell[BoxData[
    \(FormatAutomata[None]\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"FrontierToDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[CapitalGamma] = {{aa, \[Epsilon]}, {bb, \[Epsilon]}, {baa, 
            b}, {bab, a}, {aba, b}, {abb, a}};\)\), "\n", 
    \(FrontierQ[First /@ \[CapitalGamma], {a, b}]\)}], "Input",
  CellLabel->"In[42]:=",
  AspectRatioFixed->True,
  CellTags->"FrontierToDFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->"FrontierToDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = FrontierToDFA[\[CapitalGamma], {\[Epsilon]}]\)], "Input",
  CellLabel->"In[44]:=",
  AspectRatioFixed->True,
  CellTags->"FrontierToDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{2, 1, 5, 3, 3}, {3, 4, 1, 2, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[44]=",
  CellTags->"FrontierToDFA"]
}, Open  ]],

Cell["\<\
The states of the automaton correspond to the proper prefixes of \
the frontier associated with \[CapitalGamma].\
\>", "ExampleText",
  CellTags->"FrontierToDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[m]\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"FrontierToDFA"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "ab", "ba"}\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"FrontierToDFA"]
}, Open  ]],

Cell["A few words accepted by the automaton.", "ExampleText",
  CellTags->"FrontierToDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-6\)\ ]\)], "Input",
  CellLabel->"In[47]:=",
  CellTags->"FrontierToDFA"],

Cell[BoxData[
    \({{\[Epsilon]}, {}, {"aa", "bb"}, {}, {"aaaa", "aabb", "abab", "abba", 
        "baab", "baba", "bbaa", "bbbb"}, {}, {"aaaaaa", "aaaabb", "aaabab", 
        "aaabba", "aabaab", "aababa", "aabbaa", "aabbbb", "abaaab", "abaaba", 
        "ababaa", "ababbb", "abbaaa", "abbabb", "abbbab", "abbbba", "baaaab", 
        "baaaba", "baabaa", "baabbb", "babaaa", "bababb", "babbab", "babbba", 
        "bbaaaa", "bbaabb", "bbabab", "bbabba", "bbbaab", "bbbaba", "bbbbaa", 
        "bbbbbb"}}\)], "Output",
  CellLabel->"Out[47]=",
  CellTags->"FrontierToDFA"]
}, Open  ]]
}, Closed]],

Cell["FSMQ", "ObjectName",
  CellTags->"FSMQ"],

Cell["Type: function", "Highlight",
  CellTags->"FSMQ"],

Cell[TextData[{
  StyleBox["FSMQ[M]", "MR"],
  "  tests whether ",
  StyleBox["M", "MR"],
  " is a finite state machine."
}], "Usage",
  CellTags->"FSMQ"],

Cell[TextData[{
  " Currently allowed headers for ",
  StyleBox["M", "MR"],
  ": DFA, NFA, FA, SA, NNFA and BEFA."
}], "Notes",
  CellTags->"FSMQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FSMQ"],

Cell["Should be used in functions defined on machines.", "ExampleText",
  CellTags->"FSMQ"],

Cell["f[M_?FSMQ] := ToDFA[ReverseFA[M]];", "Input",
  CellLabel->"In[183]:=",
  CellTags->"FSMQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(f[\ IthSymbolFA[a, 3, 2]]\)\(\ \)\)\)], "Input",
  CellLabel->"In[184]:=",
  CellTags->"FSMQ"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{2, 3, 5, 7, 5, 7, 3, 2}, {1, 4, 6, 8, 6, 8, 4, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[184]=",
  CellTags->"FSMQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[\ Range[5]\ ]\)], "Input",
  CellLabel->"In[185]:=",
  CellTags->"FSMQ"],

Cell[BoxData[
    \(f[{1, 2, 3, 4, 5}]\)], "Output",
  CellLabel->"Out[185]=",
  CellTags->"FSMQ"]
}, Open  ]]
}, Closed]],

Cell["FSurjectiveCA", "ObjectName",
  CellTags->"FSurjectiveCA"],

Cell["Type: function", "Highlight",
  CellTags->"FSurjectiveCA"],

Cell[TextData[{
  StyleBox["FSurjectiveCA[C]", "MR"],
  "  tests whether a given surjective CA C  is  surjective on all finite \
configurations."
}], "Usage",
  CellTags->"FSurjectiveCA"],

Cell["\<\
 The cellular automaton C must be quiescent (a configuration of all \
0's is mapped to all 0's).\
\>", "Notes",
  CellTags->"FSurjectiveCA"],

Cell[TextData[{
  " F-surjectivity is equivalent to the preimage of ",
  StyleBox["0",
    FontWeight->"Bold"],
  " being ",
  StyleBox["0",
    FontWeight->"Bold"],
  ". The latter property can be tested in the de Bruijn graph of the CA."
}], "Notes",
  CellTags->"FSurjectiveCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FSurjectiveCA"],

Cell["\<\
By compactness, F-surjectivity implies surjectivity. We determine \
which surjective elementary CAs are F-surjective.\
\>", "ExampleText",
  CellTags->"FSurjectiveCA"],

Cell[BoxData[
    \(\(surj\  = \ {30, 60, 86, 90, 102, 106, 120, 150, 154, 166, 170, 180, 
          204, 210, 240};\)\)], "Input",
  CellLabel->"In[98]:=",
  CellTags->"FSurjectiveCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[\ surj, \ FSurjectiveCA[CA[#]] > 0 &\ ]\)], "Input",
  CellLabel->"In[99]:=",
  CellTags->"FSurjectiveCA"],

Cell[BoxData[
    \({166, 170, 180, 204, 240}\)], "Output",
  CellLabel->"Out[99]=",
  CellTags->"FSurjectiveCA"]
}, Open  ]]
}, Closed]],

Cell["FullAlphabet", "ObjectName",
  CellTags->"FullAlphabet"],

Cell["Type: function", "Highlight",
  CellTags->"FullAlphabet"],

Cell[TextData[{
  StyleBox["FullAlphabet[M]", "MR"],
  "  returns ",
  StyleBox["{k,K}", "MR"],
  " where ",
  StyleBox["k", "MR"],
  " is the size of the proper alphabet of machine ",
  StyleBox["M", "MR"],
  " and ",
  StyleBox["K", "MR"],
  " is the proper alphabet."
}], "Usage",
  CellTags->"FullAlphabet"],

Cell["\<\
Unlike with input alphabets the characters in the proper alphabet \
are always strings (of length 1). \
\>", "Notes",
  CellTags->"FullAlphabet"],

Cell[TextData[{
  "See also ",
  ButtonBox["Alphabet",
    ButtonData:>"Alphabet",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["AlphabetSize",
    ButtonData:>"AlphabetSize",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FullAlphabet"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FullAlphabet"],

Cell["The full alphabet of a machine.", "ExampleText",
  CellTags->"FullAlphabet"],

Cell[CellGroupData[{

Cell[TextData[{
  "m = IthSymbolFA[a,-5,{a,b,c}];\nFull",
  Cell[BoxData[
      \(Alphabet[m]\)], "Input",
    CellLabel->"In[127]:="],
  "\nFullForm[%]"
}], "Input",
  CellLabel->"In[146]:=",
  CellTags->"FullAlphabet"],

Cell[BoxData[
    \({3, {"a", "b", "c"}}\)], "Output",
  CellLabel->"Out[147]=",
  CellTags->"FullAlphabet"],

Cell[BoxData[
    TagBox[
      StyleBox[\(List[3, List["\<a\>", "\<b\>", "\<c\>"]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[148]//FullForm=",
  CellTags->"FullAlphabet"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "m = IthSymbolFA[a,-5,-2];\nFull",
  Cell[BoxData[
      \(Alphabet[m]\)], "Input",
    CellLabel->"In[127]:="],
  "\nFullForm[%]"
}], "Input",
  CellLabel->"In[149]:=",
  CellTags->"FullAlphabet"],

Cell[BoxData[
    \({2, {"0", "1"}}\)], "Output",
  CellLabel->"Out[150]=",
  CellTags->"FullAlphabet"],

Cell[BoxData[
    TagBox[
      StyleBox[\(List[2, List["\<0\>", "\<1\>"]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[151]//FullForm=",
  CellTags->"FullAlphabet"]
}, Open  ]]
}, Closed]],

Cell["FullTransitionMatrixFA", "ObjectName",
  CellTags->"FullTransitionMatrixFA"],

Cell["Type: function", "Highlight",
  CellTags->"FullTransitionMatrixFA"],

Cell[TextData[{
  StyleBox["FullTransitionMatrixFA[M]", "MR"],
  "  returns the transitions of a machine expressed as a matrix over a \
semiring  (integers, Boolean, or tropical)."
}], "Usage",
  CellTags->"FullTransitionMatrixFA"],

Cell[TextData[{
  "Options\n",
  Cell[BoxData[GridBox[{
          {"Type", "\[Rule]", "None", \(Boolean, Tropical\)}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"FullTransitionMatrixFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Type->Boolean", "MR"],
  " returns a 0/1-matrix for efficiency reasons."
}], "Notes",
  CellTags->"FullTransitionMatrixFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FullTransitionMatrixFA"],

Cell["A DFA for a finite language and its transition matrix.", "ExampleText",
  CellTags->"FullTransitionMatrixFA"],

Cell[CellGroupData[{

Cell["m = BuildDFA[aaa,abb,bbb,2]", "Input",
  CellLabel->"In[76]:=",
  CellTags->"FullTransitionMatrixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 4, 6, 7, 6, 6, 6}, {3, 5, 5, 6, 7, 6, 6}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({7}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[76]=",
  CellTags->"FullTransitionMatrixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(A\  = \ FullTransitionMatrixFA[m];\)\), "\n", 
    \(A\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[77]:=",
  CellTags->"FullTransitionMatrixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "1", "1", "0", "0"},
            {"0", "0", "0", "0", "1", "1", "0"},
            {"0", "0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "2", "0"},
            {"0", "0", "0", "0", "0", "2", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[78]//MatrixForm=",
  CellTags->"FullTransitionMatrixFA"]
}, Open  ]],

Cell["\<\
The 3rd power of the matrix indicates that there are 3 accepted \
words.\
\>", "ExampleText",
  CellTags->"FullTransitionMatrixFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MatrixPower[A, 3]\)[\([1, 7]\)]\)], "Input",
  CellLabel->"In[80]:=",
  CellTags->"FullTransitionMatrixFA"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"FullTransitionMatrixFA"]
}, Open  ]]
}, Closed]],

Cell["FullTransitions", "ObjectName",
  CellTags->"FullTransitions"],

Cell["Type: function", "Highlight",
  CellTags->"FullTransitions"],

Cell[TextData[{
  StyleBox["FullTransitions[M]", "MR"],
  "  returns a list of the transitionsa finite state machine M."
}], "Usage",
  CellTags->"FullTransitions"],

Cell[TextData[{
  "The entries in a labeled transition list are of the ",
  StyleBox["{p,a,q}", "MR"],
  " where ",
  StyleBox["p", "MR"],
  " and ",
  StyleBox["q", "MR"],
  " are states in positional notation, and ",
  StyleBox["a", "MR"],
  " is a symbol from the alphabet of the automaton (not in positional \
notation) or \[Epsilon]."
}], "Notes",
  CellTags->"FullTransitions"],

Cell[TextData[{
  "See also ",
  ButtonBox["Transitions",
    ButtonData:>"Transitions",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["FullTransitionMatrixFA",
    ButtonData:>"FullTransitionMatrixFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FullTransitions"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FullTransitions"],

Cell["A DFA for a finite language and its transition table.", "ExampleText",
  CellTags->"FullTransitions"],

Cell[CellGroupData[{

Cell["m = BuildDFA[aaa,abb,bbb,2]", "Input",
  CellLabel->"In[76]:=",
  CellTags->"FullTransitions"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 4, 6, 7, 6, 6, 6}, {3, 5, 5, 6, 7, 6, 6}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({7}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[76]=",
  CellTags->"FullTransitions"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullTransitions[m]\  // \ TableForm\)], "Input",
  CellLabel->"In[86]:=",
  CellTags->"FullTransitions"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"a\"\>", "2"},
          {"2", "\<\"a\"\>", "4"},
          {"3", "\<\"a\"\>", "6"},
          {"4", "\<\"a\"\>", "7"},
          {"5", "\<\"a\"\>", "6"},
          {"6", "\<\"a\"\>", "6"},
          {"7", "\<\"a\"\>", "6"},
          {"1", "\<\"b\"\>", "3"},
          {"2", "\<\"b\"\>", "5"},
          {"3", "\<\"b\"\>", "5"},
          {"4", "\<\"b\"\>", "6"},
          {"5", "\<\"b\"\>", "7"},
          {"6", "\<\"b\"\>", "6"},
          {"7", "\<\"b\"\>", "6"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[86]//TableForm=",
  CellTags->"FullTransitions"]
}, Open  ]]
}, Closed]],

Cell["FunctionToCA", "ObjectName",
  CellTags->"FunctionToCA"],

Cell["Type: function", "Highlight",
  CellTags->"FunctionToCA"],

Cell[TextData[{
  StyleBox["FunctionToCA[f,w,k]", "MR"],
  "  constructs a cellular automaton of width ",
  StyleBox["w", "MR"],
  " over digit alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{0,  .. , k - 1}\)]],
  " whose local map is given by ",
  StyleBox["f", "MR"],
  "."
}], "Usage",
  CellTags->"FunctionToCA"],

Cell[TextData[{
  " The input function ",
  StyleBox["f", "MR"],
  " must be a ",
  StyleBox["w", "MR"],
  "-ary function of integer arguments and return integer results in the \
proper range. "
}], "Notes",
  CellTags->"FunctionToCA"],

Cell[TextData[{
  "See alse ",
  ButtonBox["ToFunctionCA",
    ButtonData:>"ToFunctionCA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["PolynomialToCA",
    ButtonData:>"PolynomialToCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FunctionToCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FunctionToCA"],

Cell["\<\
Modular arithmetic can be used to construct cellular \
automata.\
\>", "ExampleText",
  CellTags->"FunctionToCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c = FunctionToCA[Mod[\(+##1\), 3] &, 3, \(-3\)]\)], "Input",
  CellLabel->"In[101]:=",
  CellTags->"FunctionToCA"],

Cell[BoxData[
    \(CA[2201243116917, 3, \(-3\)]\)], "Output",
  CellLabel->"Out[101]=",
  CellTags->"FunctionToCA"]
}, Open  ]],

Cell["These automata have open global maps. ", "ExampleText",
  CellTags->"FunctionToCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ClassifyCA[c]\)], "Input",
  CellLabel->"In[103]:=",
  CellTags->"FunctionToCA"],

Cell[BoxData[
    \(2\)], "Output",
  CellLabel->"Out[103]=",
  CellTags->"FunctionToCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EvolutionCA[c, 50];\)\)], "Input",
  CellLabel->"In[106]:=",
  CellTags->"FunctionToCA"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .50495 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00942951 0.0120226 0.00942951 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .50495 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .50495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .50495 L
s
0 .50495 m
1 .50495 L
s
1 0 m
1 .50495 L
s
0 0 m
1 0 L
1 .50495 L
0 .50495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01202 translate
.95238 .48091 scale
303 string
101 51 8 [101 0 0 51 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFFF00FF0000FF
CCFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
FF00FF0000FFCCFFFF0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
FF00FF0000FFCCFFFF0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
FF00FF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFFF00FFFF00FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFFF00FFFF00FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF
0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFFF00FFFF00FF
FF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFFF00FFFF00FFFF00FF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
FF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
FF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF
FF00FF0000FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
0000FFFF00FFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFF
FF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFFF00FFFF00FFFF00FFCCFFFFCCFFFF
CCFFFFFF00FFFF00FFFF00FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFFF00FFFF00FF
FF00FFCCFFFFCCFFFFCCFFFFFF00FFFF00FFFF00FF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFFF00FFFF00FFFF00FFCCFFFFCCFFFFCCFFFFFF00FFFF00FFFF00FF0000FF0000FF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
FF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF
0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFF
FF00FF0000FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFF
FF00FF0000FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FFFF00FFFF00FFFF00FFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFFF00FFFF00FFFF00FFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFFF00FFFF00FF
FF00FFCCFFFFCCFFFFCCFFFFFF00FFFF00FFFF00FF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFFF00FFFF00FFFF00FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFFF00FFFF00FF
FF00FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
FF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFFF00FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFFF00FFFF00FFFF00FFFF00FF
FF00FFFF00FFFF00FFFF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFFFF00FFCCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFF0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFF
0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFFF00FFFF00FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFFF00FF
FF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
0000FFFF00FFCCFFFF0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
FF00FF0000FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFFF00FFFF00FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFFF00FFFF00FFFF00FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
FF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF0000FFFF00FFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFFFF00FF0000FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF0000FFFF00FFFF00FF
FF00FFCCFFFFCCFFFFCCFFFFFF00FFFF00FFFF00FF0000FF0000FF0000FFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFCCFFFFCCFFFFFF00FF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FFFF00FFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF0000FF
CCFFFFCCFFFF0000FFCCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
0000FFFF00FFCCFFFFFF00FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFF0000FF0000FF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFF0000FFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
CCFFFFCCFFFFCCFFFFCCFFFFCCFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[106]:=",
  ImageSize->{288, 145.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"FunctionToCA"]
}, Open  ]]
}, Closed]],

Cell["FunctionToDFA", "ObjectName",
  CellTags->"FunctionToDFA"],

Cell["Type: function", "Highlight",
  CellTags->"FunctionToDFA"],

Cell[TextData[{
  StyleBox["FunctionToDFA[Q,K,del,q0,F,opts]", "MR"],
  "  returns the DFA determined by Q, K, del, q0 and F. Option Normalize."
}], "Usage",
  CellTags->"FunctionToDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Alphabetic", "\[Rule]", "True", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"FunctionToDFA"],

Cell[TextData[{
  "Here ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["del",
            "MR"], " ", ":", " ", \(Q\ \[Cross]\ K\ \[LongRightArrow]\ Q\)}], 
        TraditionalForm]]],
  " is a function that determines the transitions of the machine."
}], "Notes",
  CellTags->"FunctionToDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Alphabetic->False", "MR"],
  " uses integers ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], k}\)]],
  "  as input to ",
  StyleBox["del", "MR"],
  ", rather then letters of the alphabet."
}], "Notes",
  CellTags->"FunctionToDFA"],

Cell[TextData[{
  "See also ",
  Cell[BoxData[GridBox[{
          {"FunctionToSA"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]],
  ", ",
  ButtonBox["GenerateDFA",
    ButtonData:>"GenerateDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FunctionToDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FunctionToDFA"],

Cell["A machine whose states are pairs of modular numbers. ", "ExampleText",
  CellTags->"FunctionToDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Q\  = \ CartesianProduct[3, 5] - 1\)], "Input",
  CellLabel->"In[42]:=",
  CellTags->"FunctionToDFA"],

Cell[BoxData[
    \({{0, 0}, {0, 1}, {0, 2}, {0, 3}, {0, 4}, {1, 0}, {1, 1}, {1, 2}, {1, 
        3}, {1, 4}, {2, 0}, {2, 1}, {2, 2}, {2, 3}, {2, 4}}\)], "Output",
  CellLabel->"Out[42]=",
  CellTags->"FunctionToDFA"]
}, Open  ]],

Cell[BoxData[
    \(\(del[{p_, q_}, s_\ ] := {Mod[p + s, 3], Mod[q + 1, 5]};\)\)], "Input",
  CellLabel->"In[44]:=",
  CellTags->"FunctionToDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FunctionToDFA[Q, 2, del, 1, {1}, \ 
      Alphabetic \[Rule] False\ ]\)], "Input",
  CellLabel->"In[45]:=",
  CellTags->"FunctionToDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"15", ",", "2", ",", 
          
          TagBox[\({{7, 8, 9, 10, 6, 12, 13, 14, 15, 11, 2, 3, 4, 5, 1}, {12, 
                13, 14, 15, 11, 2, 3, 4, 5, 1, 7, 8, 9, 10, 6}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[45]=",
  CellTags->"FunctionToDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ %, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"FunctionToDFA"],

Cell[BoxData[
    \({{\[Epsilon]}, {}, {}, {}, {}, {"aaaab", "aaaba", "aabaa", "abaaa", 
        "abbbb", "baaaa", "babbb", "bbabb", "bbbab", "bbbba"}}\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"FunctionToDFA"]
}, Open  ]]
}, Closed]],

Cell["FunctionToSA", "ObjectName",
  CellTags->"FunctionToSA"],

Cell["Type: function", "Highlight",
  CellTags->"FunctionToSA"],

Cell[TextData[{
  StyleBox["FunctionToSA[Q,K,del]", "MR"],
  "  returns the semiautomaton determined by ",
  StyleBox["Q", "MR"],
  ", ",
  StyleBox["K", "MR"],
  ", and ",
  StyleBox["del", "MR"],
  ". "
}], "Usage",
  CellTags->"FunctionToSA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Alphabetic", "\[Rule]", "True", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"FunctionToSA"],

Cell[TextData[{
  "Here  ",
  Cell[BoxData[
      \(TraditionalForm\`del\  : \ 
        Q\ \[Cross]\ K\ \[LongRightArrow]\ \(\[ScriptCapitalP](Q)\)\)]],
  "  is a function describing the transition behavior."
}], "Notes",
  CellTags->"FunctionToSA"],

Cell[TextData[{
  "Option ",
  StyleBox["Alphabetic->False", "MR"],
  "  uses positions instead of letters. "
}], "Notes",
  CellTags->"FunctionToSA"],

Cell[TextData[{
  "See also ",
  Cell[BoxData[GridBox[{
          {"FunctionToDFA"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]],
  StyleBox[", ", "Text"],
  ButtonBox["FunctionToCA",
    ButtonData:>"FunctionToCA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"FunctionToSA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FunctionToSA"],

Cell["\<\
Constructing a semiautomaton with 4 states by specifying the \
transition function.\
\>", "ExampleText",
  CellTags->"FunctionToSA"],

Cell[BoxData[{
    \(\(Q\  = \ Range[0, 3];\)\), "\n", 
    \(del[0, 1]\  := \ {0, 1}\), "\n", 
    \(del[p_, 1]\  := \ {Mod[p + 1, 4]}\), "\n", 
    \(del[p_, 2]\  := \ {Mod[p + 2, 4]}\)}], "Input",
  CellLabel->"In[225]:=",
  CellTags->"FunctionToSA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ 
      FunctionToSA[\ Q, \ 2, \ del, \ 
        Alphabetic \[Rule] False\ \ ]\)], "Input",
  CellLabel->"In[229]:=",
  CellTags->"FunctionToSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 3}, {2, 1, 3}, {2, 2, 
                4}, {3, 1, 4}, {3, 2, 1}, {4, 1, 1}, {4, 2, 2}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[229]=",
  CellTags->"FunctionToSA"]
}, Open  ]],

Cell["Adding initial and final states.", "ExampleText",
  CellTags->"FunctionToSA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ss = \ SetInitialFinalFA[s, {1}, {1}]\)], "Input",
  CellLabel->"In[233]:=",
  CellTags->"FunctionToSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 3}, {2, 1, 3}, {2, 2, 
                4}, {3, 1, 4}, {3, 2, 1}, {4, 1, 1}, {4, 2, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[233]=",
  CellTags->"FunctionToSA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ ss, \(-8\), SizeOnly \[Rule] True]\)], "Input",
  CellLabel->"In[234]:=",
  CellTags->"FunctionToSA"],

Cell[BoxData[
    \({1, 1, 2, 6, 9, 23, 47, 92, 206}\)], "Output",
  CellLabel->"Out[234]=",
  CellTags->"FunctionToSA"]
}, Open  ]]
}, Closed]],

Cell["GenerateDFA", "ObjectName",
  CellTags->"GenerateDFA"],

Cell["Type: function", "Highlight",
  CellTags->"GenerateDFA"],

Cell[TextData[{
  StyleBox["GenerateDFA[q0,dot,K,fin]", "MR"],
  "  produces the cyclic semimodule generated by ",
  StyleBox["q0", "Program"],
  " and operation ",
  StyleBox["dot, ", "Program"],
  "as well as the corresponding accessible DFA.  "
}], "Usage",
  CellTags->"GenerateDFA"],

Cell[TextData[{
  "Returns the triple  {Q,,W,M}  where Q is the semimodule, W a set of \
witnesses for the elements of Q, and M the corresponding DFA whose final \
states are determined by predicate ",
  StyleBox["fin", "Program"],
  ". "
}], "Notes",
  CellTags->"GenerateDFA"],

Cell[TextData[{
  "The operation ",
  StyleBox["dot[p,s]", "Program"],
  " must return an element of the semimodule (where ",
  StyleBox["p", "Program"],
  " is an element of the semimodule and ",
  StyleBox["s", "Program"],
  " is a symbol in the alphabet). "
}], "Notes",
  CellTags->"GenerateDFA"],

Cell[TextData[{
  "See also ",
  StyleBox["GenerateCSM", "Program"],
  "  and  ",
  ButtonBox["FunctionToDFA",
    ButtonData:>"FunctionToDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GenerateDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"GenerateDFA"],

Cell[TextData[{
  "An operation based on modular arithmetic on ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalZ]\_6\[Cross]\ \
\[DoubleStruckCapitalZ]\_3\)]],
  ". "
}], "ExampleText",
  CellTags->"GenerateDFA"],

Cell[BoxData[{
    \(\(dot[{p_, q_}, "\<a\>"] := {Mod[p + 2, 6], q};\)\), "\n", 
    \(\(dot[{p_, q_}, "\<b\>"] := {p, Mod[q + 1, 3]};\)\)}], "Input",
  CellLabel->"In[1]:=",
  CellTags->"GenerateDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Q, W, m} = GenerateDFA[{0, 0}, dot, 2, # \[Equal] {0, 0} &]\)], "Input",\

  CellLabel->"In[94]:=",
  AspectRatioFixed->True,
  CellTags->"GenerateDFA"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({{0, 0}, {2, 0}, {0, 1}, {4, 0}, {2, 1}, {0, 2}, {4, 1}, {2, 
            2}, {4, 2}}\), 
        ",", \({\[Epsilon], "a", "b", "aa", "ab", "bb", "aab", "abb", 
          "aabb"}\), ",", 
        TagBox[
          RowBox[{"DFA", "[", 
            RowBox[{"9", ",", "2", ",", 
              
              TagBox[\({{2, 4, 5, 1, 7, 8, 3, 9, 6}, {3, 5, 6, 7, 8, 1, 9, 2, 
                    4}}\),
                (Short[ #, 4]&)], ",", 
              TagBox["1",
                (Short[ #, 4]&)], ",", 
              TagBox[\({1}\),
                (Short[ #, 4]&)]}], "]"}],
          HoldForm]}], "}"}]], "Output",
  CellLabel->"Out[94]=",
  CellTags->"GenerateDFA"]
}, Open  ]],

Cell[TextData[{
  "The elements of the semimodule  ",
  Cell[BoxData[
      \(TraditionalForm\`Q\ \  \[Subset] \ \[DoubleStruckCapitalZ]\_6\[Cross]\
\ \[DoubleStruckCapitalZ]\_3\)]],
  " and their witnesses."
}], "ExampleText",
  CellTags->"GenerateDFA"],

Cell[CellGroupData[{

Cell["{Q,W} // Thread // MatrixForm", "Input",
  CellLabel->"In[97]:=",
  AspectRatioFixed->True,
  CellTags->"GenerateDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({0, 0}\), "\[Epsilon]"},
            {\({2, 0}\), "\<\"a\"\>"},
            {\({0, 1}\), "\<\"b\"\>"},
            {\({4, 0}\), "\<\"aa\"\>"},
            {\({2, 1}\), "\<\"ab\"\>"},
            {\({0, 2}\), "\<\"bb\"\>"},
            {\({4, 1}\), "\<\"aab\"\>"},
            {\({2, 2}\), "\<\"abb\"\>"},
            {\({4, 2}\), "\<\"aabb\"\>"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[97]//MatrixForm=",
  CellTags->"GenerateDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-10\), SizeOnly \[Rule] True]\)], "Input",
  CellLabel->"In[100]:=",
  AspectRatioFixed->True,
  CellTags->"GenerateDFA"],

Cell[BoxData[
    \({1, 0, 0, 2, 0, 0, 22, 0, 0, 170, 0}\)], "Output",
  CellLabel->"Out[100]=",
  CellTags->"GenerateDFA"]
}, Open  ]]
}, Closed]],

Cell["GenerateQuotients", "ObjectName",
  CellTags->"GenerateQuotients"],

Cell["Type: function", "Highlight",
  CellTags->"GenerateQuotients"],

Cell[TextData[{
  StyleBox["GenerateQuotients[L,K]", "MR"],
  "  computes all quotients of a finite language ",
  StyleBox["L", "MR"],
  "  over alphabet ",
  StyleBox["K", "MR"],
  " ."
}], "Usage",
  CellTags->"GenerateQuotients"],

Cell[TextData[{
  "The left quotients form the state set of the automaton produced by ",
  StyleBox["QuotientDFA", "MR"],
  "."
}], "Notes",
  CellTags->"GenerateQuotients"],

Cell[TextData[{
  "See also ",
  ButtonBox["BuildDFA",
    ButtonData:>"BuildDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LeftQuotient",
    ButtonData:>"LeftQuotient",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["QuotientDFA",
    ButtonData:>"QuotientDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["QuotientMachineFA",
    ButtonData:>"QuotientMachineFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GenerateQuotients"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"GenerateQuotients"],

Cell["\<\
The language of all words of length 3 other than aaa and all its \
left quotients.\
\>", "ExampleText",
  CellTags->"GenerateQuotients"],

Cell[CellGroupData[{

Cell["W = Rest[Words[3]]", "Input",
  CellLabel->"In[155]:=",
  CellTags->"GenerateQuotients"],

Cell[BoxData[
    \({"aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[155]=",
  CellTags->"GenerateQuotients"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenerateQuotients[W, 2]\)], "Input",
  CellLabel->"In[166]:=",
  CellTags->"GenerateQuotients"],

Cell[BoxData[
    \({{"aab", "aba", "abb", "baa", "bab", "bba", "bbb"}, {"ab", "ba", 
        "bb"}, {"aa", "ab", "ba", "bb"}, {"b"}, {"a", 
        "b"}, {}, {\[Epsilon]}}\)], "Output",
  CellLabel->"Out[166]=",
  CellTags->"GenerateQuotients"]
}, Open  ]]
}, Closed]],

Cell["GlobalMapCA", "ObjectName",
  CellTags->"GlobalMapCA"],

Cell["Type: function", "Highlight",
  CellTags->"GlobalMapCA"],

Cell[TextData[{
  StyleBox["GlobalMapCA[f,C]", "MR"],
  "  assigns the global map of cellular automaton ",
  StyleBox["C", "MR"],
  " to symbol ",
  StyleBox["f", "MR"],
  ". Valid input for ",
  StyleBox["f", "MR"],
  " is a  list of integers in the appropriate range."
}], "Usage",
  CellTags->"GlobalMapCA"],

Cell[TextData[{
  "Options\n",
  Cell[BoxData[GridBox[{
          {"Boundary", "\[Rule]", "Cyclic", "-"},
          {"WordMap", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"GlobalMapCA"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["HoldFirst", "MR"],
  "."
}], "Notes",
  CellTags->"GlobalMapCA"],

Cell[TextData[{
  "Option ",
  StyleBox["Boundary->Fixed", "MR"],
  " uses fixed boundary conditions."
}], "Notes",
  CellTags->"GlobalMapCA"],

Cell[TextData[{
  "Option ",
  StyleBox["WordMap->True", "MR"],
  " can be used to generate a function that operates on strings rather than \
lists."
}], "Notes",
  CellTags->"GlobalMapCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["LocalMapCA",
    ButtonData:>"LocalMapCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GlobalMapCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"GlobalMapCA"],

Cell["A well-known additive cellular automaton: rule 90.", "ExampleText",
  CellTags->"GlobalMapCA"],

Cell[BoxData[
    \(GlobalMapCA[f, CA[90]]\)], "Input",
  CellLabel->"In[211]:=",
  CellTags->"GlobalMapCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(NestList[\ f, \ {0, 0, 0, 1, 0, 0, 0}, \ 10\ ]\)\(\ \)\)\)], "Input",\

  CellLabel->"In[267]:=",
  CellTags->"GlobalMapCA"],

Cell[BoxData[
    \({{0, 0, 0, 1, 0, 0, 0}, {0, 0, 1, 0, 1, 0, 0}, {0, 1, 0, 0, 0, 1, 
        0}, {1, 0, 1, 0, 1, 0, 1}, {1, 0, 0, 0, 0, 0, 1}, {1, 1, 0, 0, 0, 1, 
        1}, {0, 1, 1, 0, 1, 1, 0}, {1, 1, 1, 0, 1, 1, 1}, {0, 0, 1, 0, 1, 0, 
        0}, {0, 1, 0, 0, 0, 1, 0}, {1, 0, 1, 0, 1, 0, 1}}\)], "Output",
  CellLabel->"Out[267]=",
  CellTags->"GlobalMapCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[%, TableSpacing \[Rule] {0, 0}]\)], "Input",
  CellLabel->"In[271]:=",
  CellTags->"GlobalMapCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "0", "0", "1", "0", "0", "0"},
          {"0", "0", "1", "0", "1", "0", "0"},
          {"0", "1", "0", "0", "0", "1", "0"},
          {"1", "0", "1", "0", "1", "0", "1"},
          {"1", "0", "0", "0", "0", "0", "1"},
          {"1", "1", "0", "0", "0", "1", "1"},
          {"0", "1", "1", "0", "1", "1", "0"},
          {"1", "1", "1", "0", "1", "1", "1"},
          {"0", "0", "1", "0", "1", "0", "0"},
          {"0", "1", "0", "0", "0", "1", "0"},
          {"1", "0", "1", "0", "1", "0", "1"}
          },
        RowSpacings->0,
        ColumnSpacings->0,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {0, 0}]]]], "Output",
  CellLabel->"Out[271]//TableForm=",
  CellTags->"GlobalMapCA"]
}, Open  ]],

Cell["We can test additivity computationally.", "ExampleText",
  CellTags->"GlobalMapCA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\  = \ Table[Random[Integer, {0, 1}], {50}];\)\), "\n", 
    \(\(Y\  = \ Table[Random[Integer, {0, 1}], {50}];\)\), "\n", 
    \(Mod[\ f[X] + f[Y], 2]\  === f[Mod[X + Y, 2]]\)}], "Input",
  CellLabel->"In[276]:=",
  CellTags->"GlobalMapCA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[278]=",
  CellTags->"GlobalMapCA"]
}, Open  ]]
}, Closed]],

Cell["HomomorphismFA", "ObjectName",
  CellTags->"HomomorphismFA"],

Cell["Type: function", "Highlight",
  CellTags->"HomomorphismFA"],

Cell[TextData[{
  StyleBox["HomomorphismFA[M,h,K]", "MR"],
  "  generates an FA that accepts the image of the acceptance language of ",
  StyleBox["M", "MR"],
  " under homomorphism ",
  StyleBox["h", "MR"],
  ". "
}], "Usage",
  CellTags->"HomomorphismFA"],

Cell[TextData[{
  "The homomorphism is given as a list of words over the target alphabet ",
  StyleBox["K", "MR"],
  ". "
}], "Notes",
  CellTags->"HomomorphismFA"],

Cell[TextData[{
  "Alternatively, hom may be a homomorphism as defined by ",
  StyleBox["MakeHomomorphism", "MR"],
  "."
}], "Notes",
  CellTags->"HomomorphismFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["MakeHomomorphism",
    ButtonData:>"MakeHomomorphism",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"HomomorphismFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"HomomorphismFA"],

Cell[TextData[{
  "Applying a homomorphism that erases letter ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", replaces ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " by 0, and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " by 11."
}], "ExampleText",
  CellTags->"HomomorphismFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = IthSymbolFA[b, \(-3\), {a, b, c}]\), "\n", 
    \(mm = HomomorphismFA[m, {0, 11, \[Epsilon]}, \(-2\)]\)}], "Input",
  CellLabel->"In[66]:=",
  AspectRatioFixed->True,
  CellTags->"HomomorphismFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "3", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {1, 3, 1}, {2, 1, 
                3}, {2, 2, 3}, {2, 3, 3}, {3, 1, 4}, {3, 2, 4}, {3, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[66]=",
  CellTags->"HomomorphismFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"8", ",", \(-2\), ",", 
          
          TagBox[\({{1, 0, 1}, {1, 1, 1}, {1, 2, 5}, {5, 2, 1}, {1, 2, 
                6}, {6, 2, 2}, \[LeftSkeleton]2\[RightSkeleton], {2, 2, 
                7}, {7, 2, 3}, {3, 0, 4}, {3, 1, 4}, {3, 2, 8}, {8, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[67]=",
  CellTags->"HomomorphismFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[mm, \(-5\)]\)], "Input",
  CellLabel->"In[68]:=",
  CellTags->"HomomorphismFA"],

Cell[BoxData[
    \({{}, {}, {"11"}, {"011", "110"}, {"0011", "0110", "1100", 
        "1111"}, {"00011", "00110", "01100", "01111", "11011", 
        "11110"}}\)], "Output",
  CellLabel->"Out[68]=",
  CellTags->"HomomorphismFA"]
}, Open  ]]
}, Closed]],

Cell["HurwitzProduct", "ObjectName",
  CellTags->"HurwitzProduct"],

Cell["Type: function", "Highlight",
  CellTags->"HurwitzProduct"],

Cell[TextData[{
  StyleBox["HurwitzProduct[S1,S2]", "MR"],
  "  computes the Hurwitz product of two formal power series."
}], "Usage",
  CellTags->"HurwitzProduct"],

Cell["Corresponds to the shuffle operation.", "Notes",
  CellTags->"HurwitzProduct"],

Cell[TextData[{
  "See ",
  ButtonBox["ToSeries",
    ButtonData:>"ToSeries",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["ShuffleProductFA",
    ButtonData:>"ShuffleProductFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["WordShuffle",
    ButtonData:>"WordShuffle",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"HurwitzProduct"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"HurwitzProduct"],

Cell["Shuffling words produces rather complicated multiplicities.", \
"ExampleText",
  CellTags->"HurwitzProduct"],

Cell[CellGroupData[{

Cell["\<\
L = {aa,ab,ba,bb};
WordShuffle[L,L]\
\>", "Input",
  CellLabel->"In[170]:=",
  AspectRatioFixed->True,
  CellTags->"HurwitzProduct"],

Cell[BoxData[
    \({"aaaa", "aaab", "aaba", "aabb", "abaa", "abab", "abba", "abbb", 
      "baaa", "baab", "baba", "babb", "bbaa", "bbab", "bbba", 
      "bbbb"}\)], "Output",
  CellLabel->"Out[171]=",
  CellTags->"HurwitzProduct"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
LL = L // LanguageToSeries;
H = HurwitzProduct[LL,LL]\
\>", "Input",
  CellLabel->"In[172]:=",
  AspectRatioFixed->True,
  CellTags->"HurwitzProduct"],

Cell[BoxData[
    \({{"aaaa", 1}, {"aaab", 2}, {"aaba", 4}, {"aabb", 3}, {"abaa", 
        4}, {"abab", 5}, {"abba", 4}, {"abbb", 2}, {"baaa", 2}, {"baab", 
        4}, {"baba", 5}, {"babb", 4}, {"bbaa", 3}, {"bbab", 4}, {"bbba", 
        2}, {"bbbb", 1}}\)], "Output",
  CellLabel->"Out[173]=",
  CellTags->"HurwitzProduct"]
}, Open  ]],

Cell[CellGroupData[{

Cell["H // ToSeries", "Input",
  CellLabel->"In[174]:=",
  AspectRatioFixed->True,
  CellTags->"HurwitzProduct"],

Cell[BoxData[
    TagBox[\("aaaa" + 2\ "aaab" + 4\ "aaba" + 3\ "aabb" + 4\ "abaa" + 
        5\ "abab" + 4\ "abba" + 2\ "abbb" + 2\ "baaa" + 4\ "baab" + 
        5\ "baba" + 4\ "babb" + 3\ "bbaa" + 4\ "bbab" + 2\ "bbba" + "bbbb"\),
      HoldForm]], "Output",
  CellLabel->"Out[174]=",
  CellTags->"HurwitzProduct"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  StyleBox["WordShuffle", "MR"],
  " eliminates duplicates we have to apply it pointwise to preserve \
multiplicities."
}], "ExampleText",
  CellTags->"HurwitzProduct"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Apply[\ WordShuffle, \ CartesianProduct[L, L], {1}]\  // \ 
        Flatten;\)\), "\n", 
    \(\(%\  // \ Frequencies\)\  // \ TableForm\)}], "Input",
  CellLabel->"In[181]:=",
  CellTags->"HurwitzProduct"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"aaaa\"\>", "1"},
          {"\<\"aaab\"\>", "2"},
          {"\<\"aaba\"\>", "4"},
          {"\<\"aabb\"\>", "3"},
          {"\<\"abaa\"\>", "4"},
          {"\<\"abab\"\>", "5"},
          {"\<\"abba\"\>", "4"},
          {"\<\"abbb\"\>", "2"},
          {"\<\"baaa\"\>", "2"},
          {"\<\"baab\"\>", "4"},
          {"\<\"baba\"\>", "5"},
          {"\<\"babb\"\>", "4"},
          {"\<\"bbaa\"\>", "3"},
          {"\<\"bbab\"\>", "4"},
          {"\<\"bbba\"\>", "2"},
          {"\<\"bbbb\"\>", "1"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[182]//TableForm=",
  CellTags->"HurwitzProduct"]
}, Open  ]]
}, Closed]],

Cell["IdealBaseFA", "ObjectName",
  CellTags->"IdealBaseFA"],

Cell["Type: function", "Highlight",
  CellTags->"IdealBaseFA"],

Cell[TextData[{
  StyleBox["IdealBaseFA[M]", "MR"],
  "  constructs a DFA for the base of the language of ",
  StyleBox["M", "MR"],
  "."
}], "Usage",
  CellTags->"IdealBaseFA"],

Cell[TextData[{
  "Assumes that the language of ",
  StyleBox["M", "MR"],
  " forms an ideal; does not check. Use ",
  StyleBox["IdealQFA", "MR"],
  " to verify that ",
  StyleBox["M", "MR"],
  " is suitable input."
}], "Notes",
  CellTags->"IdealBaseFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["NoSuffixFA",
    ButtonData:>"NoSuffixFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NoPrefixFA",
    ButtonData:>"NoPrefixFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NoFactorFA",
    ButtonData:>"NoFactorFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdealQFA",
    ButtonData:>"IdealQFA",
    ButtonStyle->"AddOnsLink"],
  " . "
}], "Notes",
  CellTags->"IdealBaseFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IdealBaseFA"],

Cell["A machine whose acceptance language is an ideal.", "ExampleText",
  CellTags->"IdealBaseFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = ComplementFA[CounterDFA[a, \(-2\), 2]]\)], "Input",
  CellLabel->"In[69]:=",
  CellTags->"IdealBaseFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 4}, {1, 2, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[69]=",
  CellTags->"IdealBaseFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IdealQFA[m]\)], "Input",
  CellLabel->"In[70]:=",
  CellTags->"IdealBaseFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[70]=",
  CellTags->"IdealBaseFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ IdealBaseFA[m]\)], "Input",
  CellLabel->"In[253]:=",
  CellTags->"IdealBaseFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{3, 2, 4, 5, 2}, {2, 2, 3, 4, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[253]=",
  CellTags->"IdealBaseFA"]
}, Open  ]],

Cell[TextData[{
  "The ideal base here is the language of all words containing 3 ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s, and starting and ending in ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". "
}], "ExampleText",
  CellTags->"IdealBaseFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ mm, \(-6\)\ ]\)], "Input",
  CellLabel->"In[254]:=",
  CellTags->"IdealBaseFA"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa"}, {"aaba", "abaa"}, {"aabba", "ababa", 
        "abbaa"}, {"aabbba", "ababba", "abbaba", "abbbaa"}}\)], "Output",
  CellLabel->"Out[254]=",
  CellTags->"IdealBaseFA"]
}, Open  ]]
}, Closed]],

Cell["IdealQFA", "ObjectName",
  CellTags->"IdealQFA"],

Cell["Type: function", "Highlight",
  CellTags->"IdealQFA"],

Cell[TextData[{
  StyleBox["IdealQFA[M]", "MR"],
  "  tests whether the language of ",
  StyleBox["M", "MR"],
  " forms an ideal. "
}], "Usage",
  CellTags->"IdealQFA"],

Cell[TextData[{
  "Use as test for ",
  StyleBox["IdeaBaseFA", "MR"],
  " to verify that M is suitable input."
}], "Notes",
  CellTags->"IdealQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["IdealBaseFA",
    ButtonData:>"IdealBaseFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IdealQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IdealQFA"],

Cell["A machine whose acceptance language is an ideal.", "ExampleText",
  CellTags->"IdealQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = ComplementFA[CounterDFA[a, \(-2\), 2]]\)], "Input",
  CellLabel->"In[71]:=",
  CellTags->"IdealQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 4}, {1, 2, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[71]=",
  CellTags->"IdealQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IdealQFA[m]\)], "Input",
  CellLabel->"In[72]:=",
  CellTags->"IdealQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[72]=",
  CellTags->"IdealQFA"]
}, Open  ]]
}, Closed]],

Cell["IdentityCA", "ObjectName",
  CellTags->"IdentityCA"],

Cell["Type: function", "Highlight",
  CellTags->"IdentityCA"],

Cell[TextData[{
  StyleBox["IdentityCA[k]", "MR"],
  "  returns the CA whose global map is the identity map, properly centered."
}], "Usage",
  CellTags->"IdentityCA"],

Cell["Composition with identity CAs add superfluous variables.", "Notes",
  CellTags->"IdentityCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ShrinkCA",
    ButtonData:>"ShrinkCA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["DependencyCA",
    ButtonData:>"DependencyCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IdentityCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IdentityCA"],

Cell["Composition with the identity CA.", "ExampleText",
  CellTags->"IdentityCA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(IdentityCA[2]\), "\n", 
    \(c = ComposeCA[CA[90], IdentityCA[2]]\)}], "Input",
  CellLabel->"In[110]:=",
  CellTags->"IdentityCA"],

Cell[BoxData[
    \(CA[12, 2, \(-2\)]\)], "Output",
  CellLabel->"Out[110]=",
  CellTags->"IdentityCA"],

Cell[BoxData[
    \(CA[13260, 4, \(-2\)]\)], "Output",
  CellLabel->"Out[111]=",
  CellTags->"IdentityCA"]
}, Open  ]],

Cell["\<\
The new CA has width 4, but is essentially the same as rule 90. \
\
\>", "ExampleText",
  CellTags->"IdentityCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DependencyCA[c]\)], "Input",
  CellLabel->"In[112]:=",
  CellTags->"IdentityCA"],

Cell[BoxData[
    \({1, 3}\)], "Output",
  CellLabel->"Out[112]=",
  CellTags->"IdentityCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShrinkCA[c]\)], "Input",
  CellLabel->"In[113]:=",
  CellTags->"IdentityCA"],

Cell[BoxData[
    \(CA[90, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[113]=",
  CellTags->"IdentityCA"]
}, Open  ]]
}, Closed]],

Cell["InfiniteQFA", "ObjectName",
  CellTags->"InfiniteQFA"],

Cell["Type: function", "Highlight",
  CellTags->"InfiniteQFA"],

Cell[TextData[{
  StyleBox["InfiniteQFA[M]", "MR"],
  "  tests whether the acceptance language of ",
  StyleBox["M", "MR"],
  " is infinite."
}], "Usage",
  CellTags->"InfiniteQFA"],

Cell[TextData[{
  "Searches for cycles in the trim part of ",
  StyleBox["M", "MR"],
  "."
}], "Notes",
  CellTags->"InfiniteQFA"],

Cell[TextData[{
  "See ",
  ButtonBox["ToGraphFA",
    ButtonData:>"ToGraphFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"InfiniteQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"InfiniteQFA"],

Cell["A machine with a finite language.", "ExampleText",
  CellTags->"InfiniteQFA"],

Cell[CellGroupData[{

Cell["m = BuildDFA[ Words[-3,2], 3 ]", "Input",
  CellLabel->"In[258]:=",
  CellTags->"InfiniteQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "3", ",", 
          TagBox[\({{2, 4, 3, 5, 3}, {2, 4, 3, 5, 3}, {3, 3, 3, 3, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 4, 5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[258]=",
  CellTags->"InfiniteQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InfiniteQFA[m]\)], "Input",
  CellLabel->"In[259]:=",
  CellTags->"InfiniteQFA"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[259]=",
  CellTags->"InfiniteQFA"]
}, Open  ]],

Cell["But the Kleene star should have infinite language.", "ExampleText",
  CellTags->"InfiniteQFA"],

Cell[CellGroupData[{

Cell["mm = StarFA[m]", "Input",
  CellLabel->"In[260]:=",
  CellTags->"InfiniteQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"6", ",", "3", ",", 
          
          TagBox[\({{2, 1, 1}, {2, 1, 2}, {2, 1, 3}, {2, 2, 1}, {2, 2, 
                2}, \[LeftSkeleton]17\[RightSkeleton], {5, 2, 6}, {5, 3, 
                4}, {6, 1, 4}, {6, 2, 4}, {6, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[260]=",
  CellTags->"InfiniteQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InfiniteQFA[mm]\)], "Input",
  CellLabel->"In[261]:=",
  CellTags->"InfiniteQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[261]=",
  CellTags->"InfiniteQFA"]
}, Open  ]]
}, Closed]],

Cell["InfixFA", "ObjectName",
  CellTags->"InfixFA"],

Cell["Type: function", "Highlight",
  CellTags->"InfixFA"],

Cell[TextData[{
  StyleBox["InfixFA[w,K]", "MR"],
  "  constructs an FA that accepts all words with factor ",
  StyleBox["w", "MR"],
  " (over alphabet K)."
}], "Usage",
  CellTags->"InfixFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"InfixFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["PrefixDFA",
    ButtonData:>"PrefixDFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SuffixesFA",
    ButtonData:>"SuffixesFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"InfixFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"InfixFA"],

Cell["All words containing abc.", "ExampleText",
  CellTags->"InfixFA"],

Cell[CellGroupData[{

Cell["m = InfixFA[abc,3]", "Input",
  CellLabel->"In[73]:=",
  CellTags->"InfixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "3", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 3, 1}, {1, 1, 2}, {2, 2, 
                3}, {3, 3, 4}, {4, 1, 4}, {4, 2, 4}, {4, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[73]=",
  CellTags->"InfixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-5\)]\)], "Input",
  CellLabel->"In[74]:=",
  CellTags->"InfixFA"],

Cell[BoxData[
    \({{}, {}, {}, {"abc"}, {"aabc", "abca", "abcb", "abcc", "babc", 
        "cabc"}, {"aaabc", "aabca", "aabcb", "aabcc", "ababc", "abcaa", 
        "abcab", "abcac", "abcba", "abcbb", "abcbc", "abcca", "abccb", 
        "abccc", "acabc", "baabc", "babca", "babcb", "babcc", "bbabc", 
        "bcabc", "caabc", "cabca", "cabcb", "cabcc", "cbabc", 
        "ccabc"}}\)], "Output",
  CellLabel->"Out[74]=",
  CellTags->"InfixFA"]
}, Open  ]]
}, Closed]],

Cell["InitialVectorFA", "ObjectName",
  CellTags->"InitialVectorFA"],

Cell["Type: function", "Highlight",
  CellTags->"InitialVectorFA"],

Cell[TextData[{
  StyleBox["InitialVectorFA[M]", "MR"],
  "   returns the bitvector representing the  initial states of M."
}], "Usage",
  CellTags->"InitialVectorFA"],

Cell["For efficiency reasons, 0/1-vectors are used. ", "Notes",
  CellTags->"InitialVectorFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["FinalVectorFA",
    ButtonData:>"FinalVectorFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["Initial",
    ButtonData:>"Initial",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"InitialVectorFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"InitialVectorFA"],

Cell["\<\
A somewhat complicated  FA for all words of length 2, and its \
initial states bitvector.\
\>", "ExampleText",
  CellTags->"InitialVectorFA"],

Cell[BoxData[
    \(\(m = 
        UnionFA @@ \(\((ToFA[BuildDFA[#1]] &)\) /@ Words[2]\);\)\)], "Input",
  CellLabel->"In[309]:=",
  CellTags->"InitialVectorFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InitialVectorFA[m]\)], "Input",
  CellLabel->"In[310]:=",
  CellTags->"InitialVectorFA"],

Cell[BoxData[
    \({1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0}\)], "Output",
  CellLabel->"Out[310]=",
  CellTags->"InitialVectorFA"]
}, Open  ]]
}, Closed]],

Cell["Initial", "ObjectName",
  CellTags->"Initial"],

Cell["Type: function", "Highlight",
  CellTags->"Initial"],

Cell[TextData[{
  StyleBox["Initial[M]", "MR"],
  "  returns a list of the initial states of finite state machine M in \
positional notation."
}], "Usage",
  CellTags->"Initial"],

Cell[TextData[{
  "See also ",
  ButtonBox["InitialVectorFA",
    ButtonData:>"InitialVectorFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["Final",
    ButtonData:>"Final",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Initial"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Initial"],

Cell["\<\
A somewhat complicated  FA for all words of length 2, and its \
initial states bitvector.\
\>", "ExampleText",
  CellTags->"Initial"],

Cell[BoxData[
    \(\(m = 
        UnionFA @@ \(\((ToFA[BuildDFA[#1]] &)\) /@ Words[2]\);\)\)], "Input",
  CellLabel->"In[318]:=",
  CellTags->"Initial"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Initial[m]\)], "Input",
  CellLabel->"In[319]:=",
  CellTags->"Initial"],

Cell[BoxData[
    \({1, 5, 9, 13}\)], "Output",
  CellLabel->"Out[319]=",
  CellTags->"Initial"]
}, Open  ]]
}, Closed]],

Cell["IntersectionFA", "ObjectName",
  CellTags->"IntersectionFA"],

Cell["Type: function", "Highlight",
  CellTags->"IntersectionFA"],

Cell[TextData[{
  StyleBox["IntersectionFA[M1,M2]", "MR"],
  "  generates a finite state machine that accepts the intersection of the \
acceptance languages of ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2.", "MR"],
  " "
}], "Usage",
  CellTags->"IntersectionFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"IntersectionFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " constructs full product machine."
}], "Notes",
  CellTags->"IntersectionFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->1", "MR"],
  " preserves state set ",
  Cell[BoxData[
      \(TraditionalForm\`Q\_1\[Cross]Q\_2\)]],
  ". "
}], "Notes",
  CellTags->"IntersectionFA"],

Cell["Uses a product machine construction.", "Notes",
  CellTags->"IntersectionFA"],

Cell["Is polyadic.", "Notes",
  CellTags->"IntersectionFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ProductFA",
    ButtonData:>"ProductFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SumFA",
    ButtonData:>"SumFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UnionFA",
    ButtonData:>"UnionFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IntersectionFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IntersectionFA"],

Cell["\<\
Two machines for unary languages. The first accepts all words of \
length a multiple of 3, and the second all words of length a multiple of 4.\
\
\>", "ExampleText",
  CellTags->"IntersectionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m3 = ModCounterDFA[a, 0, 3, 1]\), "\n", 
    \(m4 = ModCounterDFA[a, 0, 4, 1]\)}], "Input",
  CellLabel->"In[55]:=",
  CellTags->"IntersectionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "1", ",", 
          TagBox[\({{2, 3, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[55]=",
  CellTags->"IntersectionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "1", ",", 
          TagBox[\({{2, 3, 4, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[56]=",
  CellTags->"IntersectionFA"]
}, Open  ]],

Cell["\<\
The intersection machine accepts all words of length a multiple of \
12.\
\>", "ExampleText",
  CellTags->"IntersectionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(IntersectionFA[m3, m4]\), "\n", 
    \(LanguageFA[\ %, \ \(-25\), \ SizeOnly \[Rule] True\ ]\)}], "Input",
  CellLabel->"In[57]:=",
  CellTags->"IntersectionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"12", ",", "1", ",", 
          TagBox[\({{6, 7, 8, 5, 10, 11, 12, 9, 2, 3, 4, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[57]=",
  CellTags->"IntersectionFA"],

Cell[BoxData[
    \({1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 1, 0}\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"IntersectionFA"]
}, Open  ]]
}, Closed]],

Cell["InverseCA", "ObjectName",
  CellTags->"InverseCA"],

Cell["Type: function", "Highlight",
  CellTags->"InverseCA"],

Cell[TextData[{
  StyleBox["InverseCA[C]", "MR"],
  "  computes the inverse of a reversible cellular automaton ",
  StyleBox["C", "MR"],
  "."
}], "Usage",
  CellTags->"InverseCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"InverseCA"],

Cell["\<\
The algorithm expects C to be reversible,  it does not check.\
\>", \
"Notes",
  CellTags->"InverseCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"InverseCA"],

Cell["A reversible CA and its inverse.", "ExampleText",
  CellTags->"InverseCA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(C = CA[3915, 4, \(-2\)];\)\), "\n", 
    \(ClassifyCA[C]\)}], "Input",
  CellLabel->"In[126]:=",
  AspectRatioFixed->True,
  CellTags->"InverseCA"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[127]=",
  CellTags->"InverseCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Ci = InverseCA[C];\)\), "\n", 
    \(CC = ComposeCA[C, Ci]\), "\n", 
    \(ShrinkCA[CC]\)}], "Input",
  CellLabel->"In[128]:=",
  AspectRatioFixed->True,
  CellTags->"InverseCA"],

Cell[BoxData[
    \(CA[340277174703306882242637262502835978240, 7, \(-2\)]\)], "Output",
  CellLabel->"Out[129]=",
  CellTags->"InverseCA"],

Cell[BoxData[
    \(CA[2, 1, \(-2\)]\)], "Output",
  CellLabel->"Out[130]=",
  CellTags->"InverseCA"]
}, Open  ]]
}, Closed]],

Cell["IrreducibleFA", "ObjectName",
  CellTags->"IrreducibleFA"],

Cell["Type: function", "Highlight",
  CellTags->"IrreducibleFA"],

Cell[TextData[{
  StyleBox["IrreducibleFA[W,K]", "MR"],
  "  returns the canonical tree automaton that accepte all words not containg \
a factor ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " from the the list ",
  StyleBox["W", "MR"],
  ". "
}], "Usage",
  CellTags->"IrreducibleFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"IrreducibleFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " produces a machine that accepts all words of the form ",
  Cell[BoxData[
      \(TraditionalForm\`x\[VeryThinSpace]w\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " is in ",
  StyleBox["W", "MR"],
  ". The latter machine is used in ",
  StyleBox["WordReduce", "MR"],
  "."
}], "Notes",
  CellTags->"IrreducibleFA"],

Cell[TextData[{
  "Assumes that no word in ",
  StyleBox["W", "MR"],
  " occurs as a factor of another."
}], "Notes",
  CellTags->"IrreducibleFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"IrreducibleFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IrreducibleFA"],

Cell[TextData[{
  "Excluding consecutive ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s and consecutive ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s. "
}], "ExampleText",
  CellTags->"IrreducibleFA"],

Cell["W = {aa,bb}", "Input",
  CellLabel->"In[51]:=",
  CellTags->"IrreducibleFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ IrreducibleFA[W, 2]\)], "Input",
  CellLabel->"In[57]:=",
  CellTags->"IrreducibleFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {1, 2, 3}, {2, 2, 3}, {3, 1, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[57]=",
  CellTags->"IrreducibleFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->"IrreducibleFA"],

Cell[BoxData[
    \({{\[Epsilon]}, {"a", "b"}, {"ab", "ba"}, {"aba", "bab"}, {"abab", 
        "baba"}, {"ababa", "babab"}}\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"IrreducibleFA"]
}, Open  ]],

Cell["The census function is bounded in this case.", "ExampleText",
  CellTags->"IrreducibleFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-10\), \ SizeOnly \[Rule] True\ \ ]\)], "Input",
  CellLabel->"In[59]:=",
  CellTags->"IrreducibleFA"],

Cell[BoxData[
    \({1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2}\)], "Output",
  CellLabel->"Out[59]=",
  CellTags->"IrreducibleFA"]
}, Open  ]]
}, Closed]],

Cell["IsomorphicQDFA", "ObjectName",
  CellTags->"IsomorphicQDFA"],

Cell["Type: function", "Highlight",
  CellTags->"IsomorphicQDFA"],

Cell[TextData[{
  StyleBox["IsomorphicQDFA[M1,M2]", "MR"],
  "  tests whether two DFAs M1 and M2 are isomorphic. "
}], "Usage",
  CellTags->"IsomorphicQDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"IsomorphicQDFA"],

Cell[TextData[{
  StyleBox["IsomorphicQDFA", "MR"],
  " can be used to test equivalence of (minimal) DFAs."
}], "Notes",
  CellTags->"IsomorphicQDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True", "MR"],
  " causes the isomorphism to be displayed (if it exists). "
}], "Notes",
  CellTags->"IsomorphicQDFA"],

Cell["\<\
Note that only the accessible part of the machines is considered, \
so the isomorphism may be a partial map.\
\>", "Notes",
  CellTags->"IsomorphicQDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IsomorphicQDFA"],

Cell["Two isomorphic machines.", "ExampleText",
  CellTags->"IsomorphicQDFA"],

Cell[BoxData[{
    \(\(m1\  = \ 
        DFA[8, 2, {{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}, 
          1, {5, 6, 7, 8}];\)\), "\n", 
    \(\(m2\  = \ 
        DFA[8, 2, {{2, 4, 8, 6, 2, 6, 8, 4}, {3, 1, 7, 5, 3, 5, 7, 1}}, 
          6, {1, 4, 7, 8}];\)\)}], "Input",
  CellLabel->"In[131]:=",
  CellTags->"IsomorphicQDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IsomorphicQDFA[m1, m2]\)], "Input",
  CellLabel->"In[133]:=",
  CellTags->"IsomorphicQDFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[133]=",
  CellTags->"IsomorphicQDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IsomorphicQDFA[m1, m2, DoTrace \[Rule] True]\)], "Input",
  CellLabel->"In[134]:=",
  CellTags->"IsomorphicQDFA"],

Cell[BoxData[
    \({{1, 6}, {2, 5}, {3, 2}, {4, 3}, {5, 4}, {6, 1}, {7, 8}, {8, 
        7}}\)], "Output",
  CellLabel->"Out[134]=",
  CellTags->"IsomorphicQDFA"]
}, Open  ]]
}, Closed]],

Cell["IterateCA", "ObjectName",
  CellTags->"IterateCA"],

Cell["Type: function", "Highlight",
  CellTags->"IterateCA"],

Cell[TextData[{
  StyleBox["IterateCA[C,t]", "MR"],
  "  returns the cellular automaton corresponding to iterating C  t-times. "
}], "Usage",
  CellTags->"IterateCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"IterateCA"],

Cell[TextData[{
  "Note that iteration produces an exponential blow-up in the size of the CA: \
the width is ",
  Cell[BoxData[
      \(TraditionalForm\`t(w - 1) + 1\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " is the width of ",
  StyleBox["C", "MR"],
  "."
}], "Notes",
  CellTags->"IterateCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IterateCA"],

Cell["Iterating an open CA will produce another open CA.", "ExampleText",
  CellTags->"IterateCA"],

Cell[CellGroupData[{

Cell["c = IterateCA[ CA[90], 3 ]", "Input",
  CellLabel->"In[43]:=",
  CellTags->"IterateCA"],

Cell[BoxData[
    \(CA[120101186036105216880950898523352947290, 7, \(-2\)]\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->"IterateCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($RecursionLimit = 10000;\)\), "\n", 
    \(ClassifyCA[c]\)}], "Input",
  CellLabel->"In[45]:=",
  CellTags->"IterateCA"],

Cell[BoxData[
    \(2\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"IterateCA"]
}, Open  ]]
}, Closed]],

Cell["IthSymbolDFA", "ObjectName",
  CellTags->"IthSymbolDFA"],

Cell["Type: function", "Highlight",
  CellTags->"IthSymbolDFA"],

Cell[TextData[{
  StyleBox["IthSymbolDFA[a,i,K]", "MR"],
  "  constructs a DFA for the language of all words whose whose i-th symbol \
is a (over alphabet K)."
}], "Usage",
  CellTags->"IthSymbolDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"IthSymbolDFA"],

Cell["Position parameter i may be negative.", "Notes",
  CellTags->"IthSymbolDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["IthSymbolFA",
    ButtonData:>"IthSymbolFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IthSymbolDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IthSymbolDFA"],

Cell[TextData[{
  "All words that have a ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " in the third position from the end. "
}], "ExampleText",
  CellTags->"IthSymbolDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = IthSymbolDFA[b, \(-3\), 2]\)], "Input",
  CellLabel->"In[223]:=",
  CellTags->"IthSymbolDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"15", ",", "2", ",", 
          
          TagBox[\({{2, 4, 6, 8, 10, 12, 14, 8, 10, 12, 14, 8, 10, 12, 
                14}, {3, 5, 7, 9, 11, 13, 15, 9, 11, 13, 15, 9, 11, 13, 
                15}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({12, 13, 14, 15}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[223]=",
  CellTags->"IthSymbolDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[225]:=",
  CellTags->"IthSymbolDFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[225]=",
  CellTags->"IthSymbolDFA"]
}, Open  ]],

Cell["Note that this machine is not minimal.", "ExampleText",
  CellTags->"IthSymbolDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinimizeFA[m]\  // \ Size\)], "Input",
  CellLabel->"In[227]:=",
  CellTags->"IthSymbolDFA"],

Cell[BoxData[
    \(8\)], "Output",
  CellLabel->"Out[227]=",
  CellTags->"IthSymbolDFA"]
}, Open  ]]
}, Closed]],

Cell["IthSymbolFA", "ObjectName",
  CellTags->"IthSymbolFA"],

Cell["Type: function", "Highlight",
  CellTags->"IthSymbolFA"],

Cell[TextData[{
  StyleBox["IthSymbolFA[a,i,K]", "MR"],
  "  constructs an FA for the language of all words whose whose i-th symbol \
is ",
  StyleBox["a", "MR"],
  " (over alphabet K)."
}], "Usage",
  CellTags->"IthSymbolFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"IthSymbolFA"],

Cell[TextData[{
  "Position parameter ",
  StyleBox["i", "MR"],
  " may be negative."
}], "Notes",
  CellTags->"IthSymbolFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["IthSymbolFA",
    ButtonData:>"IthSymbolFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IthSymbolFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IthSymbolFA"],

Cell[TextData[{
  "All words that have a ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " in the third position from the end. "
}], "ExampleText",
  CellTags->"IthSymbolFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = IthSymbolFA[b, \(-3\), 2]\)], "Input",
  CellLabel->"In[228]:=",
  CellTags->"IthSymbolFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[228]=",
  CellTags->"IthSymbolFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[229]:=",
  CellTags->"IthSymbolFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[229]=",
  CellTags->"IthSymbolFA"]
}, Open  ]]
}, Closed]],

Cell["JoinSA", "ObjectName",
  CellTags->"JoinSA"],

Cell["Type: function", "Highlight",
  CellTags->"JoinSA"],

Cell[TextData[{
  StyleBox["JoinSA[M1,M2,A]", "MR"],
  "  determines the join of two semiautomata according to overlap list ",
  StyleBox["A", "MR"],
  "."
}], "Usage",
  CellTags->"JoinSA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"JoinSA"],

Cell[TextData[{
  "The states that are to be identified are specified in the list of pairs ",
  StyleBox["A", "MR"],
  ". "
}], "Notes",
  CellTags->"JoinSA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SumFA",
    ButtonData:>"SumFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"JoinSA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"JoinSA"],

Cell["Glueing two semiautomata together.", "ExampleText",
  CellTags->"JoinSA"],

Cell[BoxData[{
    \(\(s1 = SA[2, 2, {{1, 1, 2}, {2, 1, 1}}];\)\), "\n", 
    \(\(s2 = SA[2, 2, {{1, 2, 2}, {2, 2, 1}}];\)\)}], "Input",
  CellLabel->"In[93]:=",
  CellTags->"JoinSA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ JoinSA[\ s1, s2, \ {{2, 1}}\ ]\)], "Input",
  CellLabel->"In[97]:=",
  CellTags->"JoinSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {2, 1, 1}, {2, 2, 3}, {3, 2, 2}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[97]=",
  CellTags->"JoinSA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[SetInitialFinalFA[s, {1}, {1}], \(-6\)]\)], "Input",
  CellLabel->"In[100]:=",
  CellTags->"JoinSA"],

Cell[BoxData[
    \({{\[Epsilon]}, {}, {"aa"}, {}, {"aaaa", "abba"}, {}, {"aaaaaa", 
        "aaabba", "abbaaa", "abbbba"}}\)], "Output",
  CellLabel->"Out[100]=",
  CellTags->"JoinSA"]
}, Open  ]]
}, Closed]],

Cell["LabelToCodeCA", "ObjectName",
  CellTags->"LabelToCodeCA"],

Cell["Type: function", "Highlight",
  CellTags->"LabelToCodeCA"],

Cell[TextData[{
  StyleBox["LabelToCodeCA[C]", "MR"],
  " ] converts a CA from label to rule number form. "
}], "Usage",
  CellTags->"LabelToCodeCA"],

Cell["\<\
The least significant digit of code number r is determined by the \
last element of list lab.\
\>", "Notes",
  CellTags->"LabelToCodeCA"],

Cell["\<\
Deprecated.  In the next release all CAs will be in rule number \
form.\
\>", "Notes",
  CellTags->"LabelToCodeCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LabelToCodeCA"],

Cell["Conversion into traditional form.", "ExampleText",
  CellTags->"LabelToCodeCA"],

Cell[CellGroupData[{

Cell["CA[{\"1\",\"0\",\"0\",\"1\",\"0\",\"1\",\"1\",\"0\"},3,-2] // \
LabelToCodeCA", "Input",
  CellLabel->"In[50]:=",
  CellTags->"LabelToCodeCA"],

Cell[BoxData[
    \(CA[150, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[50]=",
  CellTags->"LabelToCodeCA"]
}, Open  ]]
}, Closed]],

Cell["LanguageFA", "ObjectName",
  CellTags->"LanguageFA"],

Cell["Type: function", "Highlight",
  CellTags->"LanguageFA"],

Cell[TextData[{
  StyleBox["LanguageFA[M,n]", "MR"],
  "  displays all words of length ",
  StyleBox["n", "MR"],
  " accepted by machine ",
  StyleBox["M", "MR"],
  "."
}], "Usage",
  CellTags->"LanguageFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Multiplicity", "\[Rule]", "False", "-"},
          {"SizeOnly", "\[Rule]", "False", "-"},
          {"MakeTrim", "\[Rule]", "False", "-"},
          {"Full", "\[Rule]", "False", "-"},
          {"FLBound", "\[Rule]", "50", "-"},
          {"Implementation", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"LanguageFA"],

Cell[TextData[{
  "For negative ",
  StyleBox["n", "MR"],
  " all accepted words up to length  ",
  StyleBox["-n", "MR"],
  "  are generated."
}], "Notes",
  CellTags->"LanguageFA"],

Cell[TextData[{
  "Option ",
  StyleBox["SizeOnly->True", "MR"],
  " generates only the first ",
  StyleBox["n", "MR"],
  " values of the growth function of the language. "
}], "Notes",
  CellTags->"LanguageFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Multiplicity->True", "MR"],
  " generates a multiset rather than a set for nondeterministic machines. "
}], "Notes",
  CellTags->"LanguageFA"],

Cell[TextData[{
  "Option ",
  StyleBox["MakeTrim->True", "MR"],
  " first transforms the automaton into a trim FA. "
}], "Notes",
  CellTags->"LanguageFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " generates all words accepted by a FSM, but does not check first whether \
the acceptance language is finite. One can use ",
  StyleBox["FLBound", "MR"],
  " to control size of computation, default is ",
  StyleBox["FLBound->50", "MR"],
  "."
}], "Notes",
  CellTags->"LanguageFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Implementation->i", "MR"],
  " selects an algorithm (",
  Cell[BoxData[
      \(TraditionalForm\`i\  = \ 1, 2, 3\)]],
  " for deterministic machines and ",
  Cell[BoxData[
      \(TraditionalForm\`i\  = \ 1, 2\)]],
  " for nondeterministic ones, default is ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1\)]],
  ")."
}], "Notes",
  CellTags->"LanguageFA"],

Cell[TextData[{
  "Use with caution, since in general the number of accepted words grows \
exponentially with ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Notes",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LanguageFA"],

Cell["\<\
The acceptance language of a DFA. This is an example of exponential \
growth.\
\>", "ExampleText",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \(\(m = 
        DFA[8, 2, {{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}, 
          1, {5, 6, 7, 8}];\)\)], "Input",
  CellLabel->"In[42]:=",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-5\)]\)], "Input",
  CellLabel->"In[43]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(LanguageFA[m, \(-10\), \ 
      SizeOnly \[Rule] True\ ]\)\(\ \)\)\)], "Input",
  CellLabel->"In[44]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({0, 0, 0, 4, 8, 16, 32, 64, 128, 256, 512}\)], "Output",
  CellLabel->"Out[44]=",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell["The  same acceptance language, but this time using an  FA. ", \
"ExampleText",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \(\(m\  = \ 
        FA[4, 2, {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[45]:=",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(LanguageFA[m, \(-5\)]\n
    LanguageFA[m, \(-10\), \ SizeOnly \[Rule] True\ ]\)\(\ \)\)\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({0, 0, 0, 4, 8, 16, 32, 64, 128, 256, 512}\)], "Output",
  CellLabel->"Out[47]=",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell["\<\
Every word in the language has exactly one accepting computation.\
\
\>", "ExampleText",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, 5, Multiplicity \[Rule] True]\)], "Input",
  CellLabel->"In[48]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({{"aabaa", 1}, {"aabab", 1}, {"aabba", 1}, {"aabbb", 1}, {"abbaa", 
        1}, {"abbab", 1}, {"abbba", 1}, {"abbbb", 1}, {"babaa", 1}, {"babab", 
        1}, {"babba", 1}, {"babbb", 1}, {"bbbaa", 1}, {"bbbab", 1}, {"bbbba", 
        1}, {"bbbbb", 1}}\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell["\<\
Here is a semiautomaton with more interesting behavior when it \
comes to multiplicity.\
\>", "ExampleText",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \(\(m\  = \ 
        SA[4, \(-2\), {{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 
              1}, {3, 1, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[49]:=",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-8\), SizeOnly \[Rule] True]\)], "Input",
  CellLabel->"In[50]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({1, 2, 4, 8, 16, 32, 64, 128, 256}\)], "Output",
  CellLabel->"Out[50]=",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, 4, Multiplicity \[Rule] True]\)], "Input",
  CellLabel->"In[51]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({{"0000", 4}, {"0001", 4}, {"0010", 4}, {"0011", 4}, {"0100", 
        4}, {"0101", 4}, {"0110", 4}, {"0111", 4}, {"1000", 4}, {"1001", 
        4}, {"1010", 4}, {"1011", 4}, {"1100", 4}, {"1101", 4}, {"1110", 
        4}, {"1111", 4}}\)], "Output",
  CellLabel->"Out[51]=",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell["Lastly, a DFA for a finite language.", "ExampleText",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ BuildDFA[\ Words[3]\ ]\)], "Input",
  CellLabel->"In[52]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 5}, {2, 3, 4, 5, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[52]=",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-6\), SizeOnly \[Rule] True]\)], "Input",
  CellLabel->"In[53]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({0, 0, 0, 8, 0, 0, 0}\)], "Output",
  CellLabel->"Out[53]=",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, Full \[Rule] True]\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"LanguageFA"],

Cell[BoxData[
    \({"aaa", "aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"LanguageFA"]
}, Open  ]]
}, Closed]],

Cell["LanguageSort", "ObjectName",
  CellTags->"LanguageSort"],

Cell["Type: function", "Highlight",
  CellTags->"LanguageSort"],

Cell[TextData[{
  StyleBox["LanguageSort[LL]", "MR"],
  "  sorts a list ",
  StyleBox["LL ", "MR"],
  "of finite languages in natural order, also sorts the languages"
}], "Usage",
  CellTags->"LanguageSort"],

Cell[TextData[{
  " Uses ",
  StyleBox["WordSort", "MR"],
  " to sort the languages (length-lex order)."
}], "Notes",
  CellTags->"LanguageSort"],

Cell[TextData[{
  "See ",
  ButtonBox["SyntacticCongruence",
    ButtonData:>"SyntacticCongruence",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LanguageSort"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LanguageSort"],

Cell["\<\
A counting machine and part of the associated syntactic congruence \
relation. The classes are sorted naturally.\
\>", "ExampleText",
  CellTags->"LanguageSort"],

Cell[BoxData[
    \(\(m = 
        IntersectionFA[ModCounterDFA[a, 0, 2, {a, b}], 
          ModCounterDFA[b, 0, 2, {a, b}]];\)\)], "Input",
  CellLabel->"In[148]:=",
  AspectRatioFixed->True,
  CellTags->"LanguageSort"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cong = LanguageSort[SyntacticCongruence[m, \(-4\)]];\)\), "\n", 
    \(ColumnForm[cong]\)}], "Input",
  CellLabel->"In[153]:=",
  AspectRatioFixed->True,
  CellTags->"LanguageSort"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\({\[Epsilon], "aa", "bb", "aaaa", "aabb", "abab", "abba", "baab", 
              "baba", "bbaa", "bbbb"}\)},
          {\({"a", "aaa", "abb", "bab", "bba"}\)},
          {\({"b", "aab", "aba", "baa", "bbb"}\)},
          {\({"ab", "ba", "aaab", "aaba", "abaa", "abbb", "baaa", "babb", 
              "bbab", "bbba"}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{\[Epsilon], "aa", "bb", "aaaa", "aabb", "abab", "abba", 
        "baab", "baba", "bbaa", "bbbb"}, {"a", "aaa", "abb", "bab", "bba"}, {
        "b", "aab", "aba", "baa", "bbb"}, {"ab", "ba", "aaab", "aaba", "abaa",
         "abbb", "baaa", "babb", "bbab", "bbba"}}],
      Editable->False]], "Output",
  CellLabel->"Out[154]=",
  CellTags->"LanguageSort"]
}, Open  ]]
}, Closed]],

Cell["LanguageToSeries", "ObjectName",
  CellTags->"LanguageToSeries"],

Cell["Type: function", "Highlight",
  CellTags->"LanguageToSeries"],

Cell[TextData[{
  StyleBox["LanguageToSeries[L]", "MR"],
  "  adds multiplicities 1 to a language ",
  StyleBox["L", "MR"],
  ". "
}], "Usage",
  CellTags->"LanguageToSeries"],

Cell[TextData[{
  "Output can be printed as a formal power series using ",
  StyleBox["ToSeries", "MR"],
  ". "
}], "Notes",
  CellTags->"LanguageToSeries"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToSeries",
    ButtonData:>"ToSeries",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["HurwitzProduct",
    ButtonData:>"HurwitzProduct",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LanguageToSeries"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LanguageToSeries"],

Cell["All words of length 3.", "ExampleText",
  CellTags->"LanguageToSeries"],

Cell[CellGroupData[{

Cell["Words[3]", "Input",
  CellLabel->"In[140]:=",
  CellTags->"LanguageToSeries"],

Cell[BoxData[
    \({"aaa", "aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[140]=",
  CellTags->"LanguageToSeries"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageToSeries[%]\)], "Input",
  CellLabel->"In[141]:=",
  CellTags->"LanguageToSeries"],

Cell[BoxData[
    \({{"aaa", 1}, {"aab", 1}, {"aba", 1}, {"abb", 1}, {"baa", 1}, {"bab", 
        1}, {"bba", 1}, {"bbb", 1}}\)], "Output",
  CellLabel->"Out[141]=",
  CellTags->"LanguageToSeries"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToSeries[%]\)], "Input",
  CellLabel->"In[142]:=",
  CellTags->"LanguageToSeries"],

Cell[BoxData[
    TagBox[\("aaa" + "aab" + "aba" + "abb" + "baa" + "bab" + "bba" + "bbb"\),
      HoldForm]], "Output",
  CellLabel->"Out[142]=",
  CellTags->"LanguageToSeries"]
}, Open  ]]
}, Closed]],

Cell["LeftQuotient", "ObjectName",
  CellTags->"LeftQuotient"],

Cell["Type: function", "Highlight",
  CellTags->"LeftQuotient"],

Cell[TextData[{
  StyleBox["LeftQuotient[w,L]", "MR"],
  "  computes the left quotient of a finite language ",
  StyleBox["L", "MR"],
  " with respect to word ",
  StyleBox["w", "MR"],
  "."
}], "Usage",
  CellTags->"LeftQuotient"],

Cell[TextData[{
  "Returns ",
  Cell[BoxData[
      \(TraditionalForm\`{\ 
        x\  | \ w\[VeryThinSpace]x\  \[Element] \ L\ }\)]],
  ". "
}], "Notes",
  CellTags->"LeftQuotient"],

Cell[TextData[{
  "See also ",
  ButtonBox["BuildDFA",
    ButtonData:>"BuildDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GenerateQuotients",
    ButtonData:>"GenerateQuotients",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["QuotientDFA",
    ButtonData:>"QuotientDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["QuotientMachineFA",
    ButtonData:>"QuotientMachineFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LeftQuotient"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LeftQuotient"],

Cell["\<\
The language of all words of length 3 other than aaa and some of \
its left quotients.\
\>", "ExampleText",
  CellTags->"LeftQuotient"],

Cell[CellGroupData[{

Cell["W = Rest[Words[3]]", "Input",
  CellLabel->"In[155]:=",
  CellTags->"LeftQuotient"],

Cell[BoxData[
    \({"aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[155]=",
  CellTags->"LeftQuotient"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftQuotient[a, W]\)], "Input",
  CellLabel->"In[167]:=",
  CellTags->"LeftQuotient"],

Cell[BoxData[
    \({"ab", "ba", "bb"}\)], "Output",
  CellLabel->"Out[167]=",
  CellTags->"LeftQuotient"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftQuotient[aa, W]\)], "Input",
  CellLabel->"In[168]:=",
  CellTags->"LeftQuotient"],

Cell[BoxData[
    \({"b"}\)], "Output",
  CellLabel->"Out[168]=",
  CellTags->"LeftQuotient"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftQuotient[aaa, W]\)], "Input",
  CellLabel->"In[170]:=",
  CellTags->"LeftQuotient"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[170]=",
  CellTags->"LeftQuotient"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftQuotient[bb, W]\)], "Input",
  CellLabel->"In[169]:=",
  CellTags->"LeftQuotient"],

Cell[BoxData[
    \({"a", "b"}\)], "Output",
  CellLabel->"Out[169]=",
  CellTags->"LeftQuotient"]
}, Open  ]]
}, Closed]],

Cell["LeftShiftCA", "ObjectName",
  CellTags->"LeftShiftCA"],

Cell["Type: function", "Highlight",
  CellTags->"LeftShiftCA"],

Cell[TextData[{
  StyleBox["LeftShiftCA[k]", "MR"],
  "  returns the left shift cellular automaton over digit alphabet k."
}], "Usage",
  CellTags->"LeftShiftCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["RightShiftCA",
    ButtonData:>"RightShiftCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LeftShiftCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LeftShiftCA"],

Cell["The shift.", "ExampleText",
  CellTags->"LeftShiftCA"],

Cell[CellGroupData[{

Cell["LeftShiftCA[-2]", "Input",
  CellLabel->"In[53]:=",
  CellTags->"LeftShiftCA"],

Cell[BoxData[
    \(CA[170, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[53]=",
  CellTags->"LeftShiftCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComposeCA[\ LeftShiftCA[\(-2\)], RightShiftCA[\(-2\)]]\)], "Input",
  CellLabel->"In[54]:=",
  CellTags->"LeftShiftCA"],

Cell[BoxData[
    \(CA[52428, 4, \(-2\)]\)], "Output",
  CellLabel->"Out[54]=",
  CellTags->"LeftShiftCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShrinkCA[%]\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"LeftShiftCA"],

Cell[BoxData[
    \(CA[2, 1, \(-2\)]\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"LeftShiftCA"]
}, Open  ]]
}, Closed]],

Cell["LengthDFA", "ObjectName",
  CellTags->"LengthDFA"],

Cell["Type: function", "Highlight",
  CellTags->"LengthDFA"],

Cell[TextData[{
  StyleBox["LengthDFA[n,K]", "MR"],
  "  constructs a DFA for the language of all words over alphabet ",
  StyleBox["K", "MR"],
  " of length ",
  StyleBox["n", "MR"],
  ". "
}], "Usage",
  CellTags->"LengthDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"LengthDFA"],

Cell["\<\
For negative n, all words of length at most -n are accepted. \
\>", \
"Notes",
  CellTags->"LengthDFA"],

Cell[TextData[{
  "Length parameter ",
  StyleBox["n", "MR"],
  " can also be replaced by a list of non-negative integers."
}], "Notes",
  CellTags->"LengthDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LengthDFA"],

Cell["A machine for all words of length at most 4.", "ExampleText",
  CellTags->"LengthDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(m\  = \ LengthDFA[\ \(-4\), \ 2\ ]\)\)\)], "Input",
  CellLabel->"In[218]:=",
  CellTags->"LengthDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"6", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 6, 6}, {2, 3, 4, 5, 6, 6}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4, 5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[218]=",
  CellTags->"LengthDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-8\), \ SizeOnly \[Rule] True\ ]\)], "Input",
  CellLabel->"In[219]:=",
  CellTags->"LengthDFA"],

Cell[BoxData[
    \({1, 2, 4, 8, 16, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[219]=",
  CellTags->"LengthDFA"]
}, Open  ]],

Cell["We can explicitely select a number of lengths.", "ExampleText",
  CellTags->"LengthDFA"],

Cell[BoxData[
    \(\(\(\ \)\(m\  = \ LengthDFA[\ {2, 4}, \ 2\ ];\)\)\)], "Input",
  CellLabel->"In[221]:=",
  CellTags->"LengthDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-8\), \ SizeOnly \[Rule] True\ ]\)], "Input",
  CellLabel->"In[222]:=",
  CellTags->"LengthDFA"],

Cell[BoxData[
    \({0, 0, 4, 0, 16, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[222]=",
  CellTags->"LengthDFA"]
}, Open  ]]
}, Closed]],

Cell["LocalMapCA", "ObjectName",
  CellTags->"LocalMapCA"],

Cell["Type: function", "Highlight",
  CellTags->"LocalMapCA"],

Cell[TextData[{
  StyleBox["LocalMapCA[f,C]", "MR"],
  "  assigns the local map of cellular automaton ",
  StyleBox["C", "MR"],
  " to symbol ",
  StyleBox["f", "MR"],
  ". "
}], "Usage",
  CellTags->"LocalMapCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"WordMap", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"LocalMapCA"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["HoldFirst", "MR"],
  "."
}], "Notes",
  CellTags->"LocalMapCA"],

Cell[TextData[{
  "Option ",
  StyleBox["Boundary->Fixed", "MR"],
  " uses fixed boundary conditions."
}], "Notes",
  CellTags->"LocalMapCA"],

Cell[TextData[{
  "Option ",
  StyleBox["WordMap->True", "MR"],
  " can be used to generate a function that operates on strings rather than \
lists."
}], "Notes",
  CellTags->"LocalMapCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["GlobalMapCA",
    ButtonData:>"GlobalMapCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LocalMapCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LocalMapCA"],

Cell["A well-known additive cellular automaton: rule 90.", "ExampleText",
  CellTags->"LocalMapCA"],

Cell[BoxData[
    \(LocalMapCA[f, CA[90]]\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"LocalMapCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Apply[\ f, \ Tuples[3, {0, 1}], \ {1}]\)], "Input",
  CellLabel->"In[50]:=",
  CellTags->"LocalMapCA"],

Cell[BoxData[
    \({0, 1, 0, 1, 1, 0, 1, 0}\)], "Output",
  CellLabel->"Out[50]=",
  CellTags->"LocalMapCA"]
}, Open  ]],

Cell["\<\
The global map of the cellular automaton is obtained by applying \
the local one in parallel to all blocks of length 3.\
\>", "ExampleText",
  CellTags->"LocalMapCA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X\  = \ {0, 0, 0, 1, 0, 0, 0};\)\), "\n", 
    \(Apply[\ f, Partition[X, 3, 1, 2], \ {1}]\)}], "Input",
  CellLabel->"In[61]:=",
  CellTags->"LocalMapCA"],

Cell[BoxData[
    \({0, 0, 1, 0, 1, 0, 0}\)], "Output",
  CellLabel->"Out[62]=",
  CellTags->"LocalMapCA"]
}, Open  ]]
}, Closed]],

Cell["LocalUniversalFA", "ObjectName",
  CellTags->"LocalUniversalFA"],

Cell["Type: function", "Highlight",
  CellTags->"LocalUniversalFA"],

Cell[TextData[{
  StyleBox["LocalUniversalFA[BBBBB]", "MR"],
  "  generates the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-local-universal FA. Supports option Normalize."
}], "Usage",
  CellTags->"LocalUniversalFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"EdgeLU", "\[Rule]", \(Function[x, True]\), "-"},
          {"IniLU", "\[Rule]", \(Function[x, True]\), "-"},
          {"FinLU", "\[Rule]", \(Function[x, True]\), "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"LocalUniversalFA"],

Cell[TextData[{
  "Transitions, initial and final states are determined via options ",
  StyleBox["EdgeLU", "MR"],
  ", ",
  StyleBox["IniLU", "MR"],
  " and ",
  StyleBox["FinLU", "MR"],
  "; the defaults are: ",
  StyleBox["True&", "MR"],
  ". "
}], "Notes",
  CellTags->"LocalUniversalFA"],

Cell["Is based on a de Bruijn automaton.", "Notes",
  CellTags->"LocalUniversalFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["DeBruijnGraph",
    ButtonData:>"DeBruijnGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LocalUniversalFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LocalUniversalFA"],

Cell[TextData[{
  "The underlying state set here is ",
  Cell[BoxData[
      \(TraditionalForm\`\((a + b)\)\^\(\(\ \)\(3\)\)\)]],
  ". We select the initial state to be aaa, the final states to be ",
  Cell[BoxData[
      \(TraditionalForm\`b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  ". "
}], "ExampleText",
  CellTags->"LocalUniversalFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ini = #1 === "\<aaa\>" &;\)\), "\n", 
    \(\(fin = StringMatchQ[#1, "\<b*\>"] &;\)\), "\n", 
    \(m = 
      LocalUniversalFA[3, 2, IniLU \[Rule] ini, FinLU \[Rule] fin, 
        Normalize \[Rule] 1]\)}], "Input",
  CellLabel->"In[296]:=",
  CellTags->"LocalUniversalFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"8", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 1, 
                5}, \[LeftSkeleton]6\[RightSkeleton], {6, 2, 4}, {7, 1, 
                5}, {7, 2, 6}, {8, 1, 7}, {8, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[298]=",
  CellTags->"LocalUniversalFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[m]\)], "Input",
  CellLabel->"In[299]:=",
  CellTags->"LocalUniversalFA"],

Cell[BoxData[
    \({"aaa", "aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[299]=",
  CellTags->"LocalUniversalFA"]
}, Open  ]],

Cell[TextData[{
  "The language is ",
  Cell[BoxData[
      \(TraditionalForm\`b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  ". "
}], "ExampleText",
  CellTags->"LocalUniversalFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[300]:=",
  CellTags->"LocalUniversalFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[300]=",
  CellTags->"LocalUniversalFA"]
}, Open  ]]
}, Closed]],

Cell["LoopAutomatonFA", "ObjectName",
  CellTags->"LoopAutomatonFA"],

Cell["Type: function", "Highlight",
  CellTags->"LoopAutomatonFA"],

Cell[TextData[{
  StyleBox["LoopAutomatonFA[M]", "MR"],
  "  converts DFA ",
  StyleBox["M", "MR"],
  " into a loop automaton. "
}], "Usage",
  CellTags->"LoopAutomatonFA"],

Cell["Only useful in connecton with the finite power property.", "Notes",
  CellTags->"LoopAutomatonFA"],

Cell[TextData[{
  "See ",
  ButtonBox["TransitionMatrixFA",
    ButtonData:>"TransitionMatrixFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Tropical",
    ButtonData:>"Tropical",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LoopAutomatonFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LoopAutomatonFA"],

Cell["\<\
A small DFA and its corresponding loop-automaton. The latter \
accepts the Kleene star of the language of the DFA.\
\>", "ExampleText",
  CellTags->"LoopAutomatonFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m\  = \ DFA[3, 2, {{1, 3, 3}, {2, 2, 2}}, 1, {1, 2}];\)\), "\n", 
    \(mloop = LoopAutomatonFA[ToFA[m]]\)}], "Input",
  CellLabel->"In[80]:=",
  CellTags->"LoopAutomatonFA"],

Cell[BoxData[
    \(FA[4, 
      2, {{1, 1, 1}, {1, 1, 4}, {1, 2, 2}, {1, 2, 4}, {2, 1, 3}, {2, 2, 
          2}, {2, 2, 4}, {3, 1, 3}, {3, 2, 2}, {3, 2, 4}, {4, 1, 1}, {4, 1, 
          4}, {4, 2, 2}, {4, 2, 4}}, {4}, {4}, {}, {}]\)], "Output",
  CellLabel->"Out[81]=",
  CellTags->"LoopAutomatonFA"]
}, Open  ]],

Cell[BoxData[
    \(EquivalentQFA[StarFA[m], mloop]\)], "Input",
  AspectRatioFixed->True,
  CellTags->"LoopAutomatonFA"],

Cell[TextData[{
  "We assign the homomorphism from words to matrices over the tropical \
semiring induced by the loop-automaton to symbol ",
  StyleBox["f", "MR"],
  "."
}], "ExampleText",
  CellTags->"LoopAutomatonFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(TransitionMatrixFA[mloop, f, Type \[Rule] Tropical];\)\), "\n", 
    \(MatrixForm /@ {f[a], f[b]}\)}], "Input",
  CellLabel->"In[99]:=",
  CellTags->"LoopAutomatonFA"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]},
                {"0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "}"}]], "Output",
  CellLabel->"Out[100]=",
  CellTags->"LoopAutomatonFA"]
}, Open  ]],

Cell["\<\
The values of the homomorphism on all words of length at most \
3.\
\>", "ExampleText",
  CellTags->"LoopAutomatonFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm\  /@ \ Union[f /@ Words[\(-3\), {a, b}]]\)], "Input",
  CellLabel->"In[101]:=",
  AspectRatioFixed->True,
  CellTags->"LoopAutomatonFA"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]},
                {"0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]]},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", "2"},
                {"1", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", "2"},
                {"1", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", "2"},
                {"1", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", "2"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"},
                {
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "0", 
                  InterpretationBox["\[Infinity]",
                    DirectedInfinity[ 1]], "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "}"}]], "Output",
  CellLabel->"Out[101]=",
  CellTags->"LoopAutomatonFA"]
}, Open  ]]
}, Closed]],

Cell["MakeHomoDFA", "ObjectName",
  CellTags->"MakeHomoDFA"],

Cell["Type: function", "Highlight",
  CellTags->"MakeHomoDFA"],

Cell[TextData[{
  StyleBox["MakeHomomorphism[M1,M2,f]", "MR"],
  "  attempts to construct a homomorphism from ",
  StyleBox["M1", "MR"],
  " to ",
  StyleBox["M2", "MR"],
  ", and assigns it to symbol ",
  StyleBox["f", "MR"],
  ". "
}], "Usage",
  CellTags->"MakeHomoDFA"],

Cell[TextData[{
  "Symbol ",
  StyleBox["h", "MR"],
  " represents the homomorphism; has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"MakeHomoDFA"],

Cell[TextData[{
  "Returns ",
  StyleBox["True", "MR"],
  "/",
  StyleBox["False", "MR"],
  " indicating success or failure."
}], "Notes",
  CellTags->"MakeHomoDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MakeHomoDFA"],

Cell["A DFA and the corresponding minimal DFA.", "ExampleText",
  CellTags->"MakeHomoDFA"],

Cell[CellGroupData[{

Cell["\<\
 m = IthSymbolDFA[a,-3]
mm = MinimizeFA[m]\
\>", "Input",
  CellLabel->"In[101]:=",
  CellTags->"MakeHomoDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"15", ",", "2", ",", 
          
          TagBox[\({{2, 4, 6, 8, 10, 12, 14, 8, 10, 12, 14, 8, 10, 12, 
                14}, {3, 5, 7, 9, 11, 13, 15, 9, 11, 13, 15, 9, 11, 13, 
                15}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({8, 9, 10, 11}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[101]=",
  CellTags->"MakeHomoDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 4, 6, 3, 6, 2}, {1, 7, 5, 5, 8, 7, 8, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4, 5, 6, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[102]=",
  CellTags->"MakeHomoDFA"]
}, Open  ]],

Cell["\<\
We construct the natural homomorphism, and test some of its \
properties. \
\>", "ExampleText",
  CellTags->"MakeHomoDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeHomoDFA[\ m, \ mm, \ h\ \ \ ]\)], "Input",
  CellLabel->"In[130]:=",
  CellTags->"MakeHomoDFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[130]=",
  CellTags->"MakeHomoDFA"]
}, Open  ]],

Cell[BoxData[{
    \(TransitionFunctionFA[m, dm]\), "\n", 
    \(TransitionFunctionFA[mm, dmm]\)}], "Input",
  CellLabel->"In[119]:=",
  CellTags->"MakeHomoDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(h[\(dm[#, a] &\)\ \  /@ \ Range[15]]\), "\n", 
    \(\(dmm[#, a] &\)\ \  /@ \ h[Range[15]]\)}], "Input",
  CellLabel->"In[131]:=",
  CellTags->"MakeHomoDFA"],

Cell[BoxData[
    \({2, 3, 2, 4, 6, 3, 2, 4, 6, 3, 2, 4, 6, 3, 2}\)], "Output",
  CellLabel->"Out[131]=",
  CellTags->"MakeHomoDFA"],

Cell[BoxData[
    \({2, 3, 2, 4, 6, 3, 2, 4, 6, 3, 2, 4, 6, 3, 2}\)], "Output",
  CellLabel->"Out[132]=",
  CellTags->"MakeHomoDFA"]
}, Open  ]]
}, Closed]],

Cell["MakeHomomorphism", "ObjectName",
  CellTags->"MakeHomomorphism"],

Cell["Type: function", "Highlight",
  CellTags->"MakeHomomorphism"],

Cell[TextData[{
  StyleBox["MakeHomomorphism[f,A,B]", "MR"],
  "  assigns the monoid homomorphism on words given by ",
  StyleBox["A", "MR"],
  " and ",
  StyleBox["B", "MR"],
  " to symbol ",
  StyleBox["f", "MR"],
  ". "
}], "Usage",
  CellTags->"MakeHomomorphism"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"ListAble", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"MakeHomomorphism"],

Cell[TextData[{
  "Option ",
  StyleBox["ListAble->True", "MR"],
  " attaches the attribute ",
  StyleBox["Listable", "MR"],
  " to the function."
}], "Notes",
  CellTags->"MakeHomomorphism"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["HoldFirst", "MR"],
  "."
}], "Notes",
  CellTags->"MakeHomomorphism"],

Cell[TextData[{
  StyleBox["A", "MR"],
  " must be an alphabet, ",
  StyleBox["B", "MR"],
  " a list of words of the same length as ",
  StyleBox["A", "MR"],
  "."
}], "Notes",
  CellTags->"MakeHomomorphism"],

Cell[TextData[{
  "See also ",
  ButtonBox["HomomorphismFA",
    ButtonData:>"HomomorphismFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MakeHomomorphism"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MakeHomomorphism"],

Cell["Iterating a homomorphism on a binary alphabet.", "ExampleText",
  CellTags->"MakeHomomorphism"],

Cell[CellGroupData[{

Cell[" MakeHomomorphism[f,{0,1},{1,10}]", "Input",
  CellLabel->"In[55]:=",
  CellTags->"MakeHomomorphism"],

Cell[BoxData[
    \({"0" \[Rule] "1", "1" \[Rule] "10"}\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"MakeHomomorphism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(LS = NestList[\ f, "\<0\>", 9];\)\), "\n", 
    \(ColumnForm[LS]\)}], "Input",
  CellLabel->"In[62]:=",
  AspectRatioFixed->True,
  CellTags->"MakeHomomorphism"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"0\"\>"},
          {"\<\"1\"\>"},
          {"\<\"10\"\>"},
          {"\<\"101\"\>"},
          {"\<\"10110\"\>"},
          {"\<\"10110101\"\>"},
          {"\<\"1011010110110\"\>"},
          {"\<\"101101011011010110101\"\>"},
          {"\<\"1011010110110101101011011010110110\"\>"},
          {"\<\"1011010110110101101011011010110110101101011011010110101\"\>"}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"0", "1", "10", "101", "10110", "10110101", 
        "1011010110110", "101101011011010110101", 
        "1011010110110101101011011010110110", 
        "1011010110110101101011011010110110101101011011010110101"}],
      Editable->False]], "Output",
  CellLabel->"Out[63]=",
  CellTags->"MakeHomomorphism"]
}, Open  ]],

Cell["The lengths of these strings are the Fibonacci numbers:", "ExampleText",
  Evaluatable->False,
  CellTags->"MakeHomomorphism"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordLength[LS]\)], "Input",
  CellLabel->"In[64]:=",
  CellTags->"MakeHomomorphism"],

Cell[BoxData[
    \({1, 1, 2, 3, 5, 8, 13, 21, 34, 55}\)], "Output",
  CellLabel->"Out[64]=",
  CellTags->"MakeHomomorphism"]
}, Open  ]]
}, Closed]],

Cell["MakeWord", "ObjectName",
  CellTags->"MakeWord"],

Cell["Type: function", "Highlight",
  CellTags->"MakeWord"],

Cell[TextData[{
  StyleBox["MakeWord[a,i,b,j,...]", "MR"],
  "  generates the word ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\^\(\(\ \)\(i\)\)\) 
        b\^\(\(\ \)\(j\)\)\ \[Ellipsis]\)]]
}], "Usage",
  CellTags->"MakeWord"],

Cell["Mildly useful to generate examples.", "Notes",
  CellTags->"MakeWord"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordPower",
    ButtonData:>"WordPower",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MakeWord"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MakeWord"],

Cell["Producing long words.", "ExampleText",
  CellTags->"MakeWord"],

Cell[CellGroupData[{

Cell["MakeWord[ab,5,c,17]", "Input",
  CellLabel->"In[139]:=",
  CellTags->"MakeWord"],

Cell[BoxData[
    \("abababababccccccccccccccccc"\)], "Output",
  CellLabel->"Out[139]=",
  CellTags->"MakeWord"]
}, Open  ]]
}, Closed]],

Cell["MatrixToTransitions", "ObjectName",
  CellTags->"MatrixToTransitions"],

Cell["Type: function", "Highlight",
  CellTags->"MatrixToTransitions"],

Cell[TextData[{
  StyleBox["MatrixToTransitions[k,A]", "MR"],
  "  converts a transition matrix ",
  StyleBox["A", "MR"],
  " into the corresponding list of transitions, ",
  StyleBox["k", "MR"],
  " denotes the size of the alphabet."
}], "Usage",
  CellTags->"MatrixToTransitions"],

Cell[TextData[{
  "See also ",
  ButtonBox["TransitionMatrixFA",
    ButtonData:>"TransitionMatrixFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToMatrix",
    ButtonData:>"ToMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MatrixToTransitions"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MatrixToTransitions"],

Cell["\<\
Turning the transition matrix of a DFA into a transition \
list.\
\>", "ExampleText",
  CellTags->"MatrixToTransitions"],

Cell[CellGroupData[{

Cell["A = ModCounterDFA[b,0,3,2] // Transitions", "Input",
  CellLabel->"In[88]:=",
  CellTags->"MatrixToTransitions"],

Cell[BoxData[
    \({{1, 2, 3}, {2, 3, 1}}\)], "Output",
  CellLabel->"Out[88]=",
  CellTags->"MatrixToTransitions"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MatrixToTransitions[2,A]", "Input",
  CellLabel->"In[92]:=",
  CellTags->"MatrixToTransitions"],

Cell[BoxData[
    \({{1, 1, 1}, {2, 1, 2}, {3, 1, 3}, {1, 2, 2}, {2, 2, 3}, {3, 2, 
        1}}\)], "Output",
  CellLabel->"Out[92]=",
  CellTags->"MatrixToTransitions"]
}, Open  ]]
}, Closed]],

Cell["MinimalFischerFA", "ObjectName",
  CellTags->"MinimalFischerFA"],

Cell["Type: function", "Highlight",
  CellTags->"MinimalFischerFA"],

Cell[TextData[{
  StyleBox["MinimalFischerFA[M]", "MR"],
  "  returns the minimal Fischer automaton associated with M. "
}], "Usage",
  CellTags->"MinimalFischerFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"MinimalFischerFA"],

Cell[TextData[{
  "Machine ",
  StyleBox["M", "MR"],
  " must accept a factorial, extensible and transitive (FET) language for \
this to work, ",
  StyleBox["MinimalFischerFA", "MR"],
  " does not check. "
}], "Notes",
  CellTags->"MinimalFischerFA"],

Cell[TextData[{
  "Options are ",
  StyleBox["Full->True", "MR"],
  " causes the minimal DFA of the language to be returned, in addition to the \
minimal Fischer automaton."
}], "Notes",
  CellTags->"MinimalFischerFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MinimalFischerFA"],

Cell["Cellular automata are good source of FET languages.", "ExampleText",
  CellTags->"MinimalFischerFA"],

Cell[CellGroupData[{

Cell["m = ToSA[ CA[91] ]", "Input",
  CellLabel->"In[266]:=",
  CellTags->"MinimalFischerFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", \(-2\), ",", 
          
          TagBox[\({{1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 
                1}, {3, 1, 2}, {4, 2, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[266]=",
  CellTags->"MinimalFischerFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ MinimalFischerFA[m]\)], "Input",
  CellLabel->"In[268]:=",
  CellTags->"MinimalFischerFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"15", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 2}, {2, 1, 2}, {3, 1, 4}, {4, 1, 6}, {5, 1, 
                7}, \[LeftSkeleton]20\[RightSkeleton], {12, 2, 8}, {13, 2, 
                14}, {14, 2, 15}, {15, 2, 12}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[268]=",
  CellTags->"MinimalFischerFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeterministicQFA[mm]\)], "Input",
  CellLabel->"In[269]:=",
  CellTags->"MinimalFischerFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[269]=",
  CellTags->"MinimalFischerFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[\ m, mm\ ]\)], "Input",
  CellLabel->"In[271]:=",
  CellTags->"MinimalFischerFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[271]=",
  CellTags->"MinimalFischerFA"]
}, Open  ]]
}, Closed]],

Cell["MinimizeDFA", "ObjectName",
  CellTags->"MinimizeDFA"],

Cell["Type: function", "Highlight",
  CellTags->"MinimizeDFA"],

Cell[TextData[{
  StyleBox["MinimizeDFA[M]", "MR"],
  "  computes the minimal automaton of a DFA M. "
}], "Usage",
  CellTags->"MinimizeDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"DoTrace", "\[Rule]", "False", "-"},
          {"Hopcroft", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"MinimizeDFA"],

Cell[TextData[{
  "Unlike ",
  StyleBox["MinimizeFA", "MR"],
  ", this function does not handle nondeterministic machines and is useful \
mostly to produce traces of the minimization algorithm in conjunction with \
option ",
  StyleBox["DoTrace->True", "MR"],
  "."
}], "Notes",
  CellTags->"MinimizeDFA"],

Cell[TextData[{
  "Unlike ",
  StyleBox["MinimizeFA", "MR"],
  ", this function cannot use external code."
}], "Notes",
  CellTags->"MinimizeDFA"],

Cell[TextData[{
  "The standard algorithm has quadratic time complexity, and option ",
  StyleBox["Hopcroft->True", "MR"],
  " uses a ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\ log\ n)\)]],
  " algorithm, at least in theory. "
}], "Notes",
  CellTags->"MinimizeDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["MinimizeFA",
    ButtonData:>"MinimizeFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["StateMergeDFA",
    ButtonData:>"StateMergeDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MinimizeDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MinimizeDFA"],

Cell["Round up the usual suspects.", "ExampleText",
  CellTags->"MinimizeDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ IthSymbolDFA[b, \(-3\), 2]\)], "Input",
  CellLabel->"In[198]:=",
  CellTags->"MinimizeDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"15", ",", "2", ",", 
          
          TagBox[\({{2, 4, 6, 8, 10, 12, 14, 8, 10, 12, 14, 8, 10, 12, 
                14}, {3, 5, 7, 9, 11, 13, 15, 9, 11, 13, 15, 9, 11, 13, 
                15}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({12, 13, 14, 15}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[198]=",
  CellTags->"MinimizeDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({mm, tr} = 
        MinimizeDFA[m, DoTrace \[Rule] True, 
          Normalize \[Rule] 1];\)\), "\n", 
    \(mm\), "\n", 
    \(States[mm]\), "\n", 
    \(TableForm[tr, TableSpacing \[Rule] {1, 1}]\)}], "Input",
  CellLabel->"In[213]:=",
  CellTags->"MinimizeDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[214]=",
  CellTags->"MinimizeDFA"],

Cell[BoxData[
    \({{1, 2, 4, 8}, {3, 5, 9}, {6, 10}, {7, 
        11}, {12}, {13}, {14}, {15}}\)], "Output",
  CellLabel->"Out[215]=",
  CellTags->"MinimizeDFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"6"},
                {"6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"6"},
                {"6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6"},
                {"14"},
                {"14"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"6"},
                {"6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6"},
                {"14"},
                {"14"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12"},
                {"1"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12"},
                {"6"},
                {"6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"14"},
                {"12"},
                {"12"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"14"},
                {"14"},
                {"14"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"1"},
                {"1"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"6"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"6"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6"},
                {"12"},
                {"13"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"7"},
                {"14"},
                {"15"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"1"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"6"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6"},
                {"12"},
                {"13"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"7"},
                {"14"},
                {"15"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"12"},
                {"1"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"13"},
                {"6"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"14"},
                {"12"},
                {"13"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"15"},
                {"14"},
                {"15"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{1, 1, 1}, {1, 1, 1}, {1, 1, 1}, {1, 1, 1}, {1, 1, 1}, {1, 
        12, 12}, {1, 12, 12}, {1, 1, 1}, {1, 1, 1}, {1, 12, 12}, {1, 12, 
        12}, {12, 1, 1}, {12, 1, 1}, {12, 12, 12}, {12, 12, 12}}, {{1, 1, 
        1}, {1, 1, 1}, {1, 6, 6}, {1, 1, 1}, {1, 6, 6}, {6, 12, 12}, {6, 14, 
        14}, {1, 1, 1}, {1, 6, 6}, {6, 12, 12}, {6, 14, 14}, {12, 1, 1}, {12, 
        6, 6}, {14, 12, 12}, {14, 14, 14}}, {{1, 1, 3}, {1, 1, 3}, {3, 6, 
        7}, {1, 1, 3}, {3, 6, 7}, {6, 12, 13}, {7, 14, 15}, {1, 1, 3}, {3, 6, 
        7}, {6, 12, 13}, {7, 14, 15}, {12, 1, 3}, {13, 6, 7}, {14, 12, 13}, {
        15, 14, 15}}}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[216]//TableForm=",
  CellTags->"MinimizeDFA"]
}, Open  ]]
}, Closed]],

Cell["MinimizeFA", "ObjectName",
  CellTags->"MinimizeFA"],

Cell["Type: function", "Highlight",
  CellTags->"MinimizeFA"],

Cell[TextData[{
  StyleBox["MinimizeFA[M,opts]", "MR"],
  "  computes the minimal automaton of a finite state machine ",
  StyleBox["M", "MR"],
  ", using the external code whenever possible. "
}], "Usage",
  CellTags->"MinimizeFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"MinimizeFA"],

Cell[TextData[{
  "If ",
  StyleBox["M", "MR"],
  " is nondeterministic, the power automaton is computed first, therefore the \
time and space complexity is potentially exponential. "
}], "Notes",
  CellTags->"MinimizeFA"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True", "MR"],
  " generates a trace to the minimization process, but only for the internal \
version of the algorithms."
}], "Notes",
  CellTags->"MinimizeFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["MinimizeDFA,",
    ButtonData:>"MinimizeDFA,",
    ButtonStyle->"AddOnsLink"],
  " ",
  ButtonBox["CoverQDFA",
    ButtonData:>"CoverQDFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EquivalentQFA",
    ButtonData:>"EquivalentQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MinimizeFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MinimizeFA"],

Cell["\<\
Minimization can shrink DFAs, but for nondeterministic machines it \
may involve exponential blow-up.\
\>", "ExampleText",
  CellTags->"MinimizeFA"],

Cell[CellGroupData[{

Cell["\<\
m = IthSymbolDFA[b,-3,2]
MinimizeFA[m]\
\>", "Input",
  CellLabel->"In[262]:=",
  CellTags->"MinimizeFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"15", ",", "2", ",", 
          
          TagBox[\({{2, 4, 6, 8, 10, 12, 14, 8, 10, 12, 14, 8, 10, 12, 
                14}, {3, 5, 7, 9, 11, 13, 15, 9, 11, 13, 15, 9, 11, 13, 
                15}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({12, 13, 14, 15}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[262]=",
  CellTags->"MinimizeFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{1, 3, 4, 1, 3, 7, 4, 7}, {2, 6, 5, 2, 6, 8, 5, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4, 5, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[263]=",
  CellTags->"MinimizeFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ Size[MinimizeFA[IthSymbolFA[b, \(-k\), 2]]], {k, 8}]\)], "Input",\

  CellLabel->"In[265]:=",
  CellTags->"MinimizeFA"],

Cell[BoxData[
    \({2, 4, 8, 16, 32, 64, 128, 256}\)], "Output",
  CellLabel->"Out[265]=",
  CellTags->"MinimizeFA"]
}, Open  ]]
}, Closed]],

Cell["ModCounterDFA", "ObjectName",
  CellTags->"ModCounterDFA"],

Cell["Type: function", "Highlight",
  CellTags->"ModCounterDFA"],

Cell[TextData[{
  StyleBox["ModCounterDFA[a,r,m,K]", "MR"],
  "  constructs a DFA for the language of all words w over alphabet K such \
that the number of a's in w is congruent r modulo m."
}], "Usage",
  CellTags->"ModCounterDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ModCounterDFA"],

Cell[TextData[{
  "See also  ",
  ButtonBox["CounterDFA",
    ButtonData:>"CounterDFA",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"ModCounterDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ModCounterDFA"],

Cell["\<\
All words containing exactly 1, 4, 7, \[Ellipsis] many b's.\
\>", \
"ExampleText",
  CellTags->"ModCounterDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = ModCounterDFA[b, 1, 3]\)], "Input",
  CellLabel->"In[148]:=",
  CellTags->"ModCounterDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 2, 3}, {2, 3, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[148]=",
  CellTags->"ModCounterDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[149]:=",
  CellTags->"ModCounterDFA"],

Cell[BoxData[
    \({{}, {"b"}, {"ab", "ba"}, {"aab", "aba", "baa"}, {"aaab", "aaba", 
        "abaa", "baaa", "bbbb"}, {"aaaab", "aaaba", "aabaa", "abaaa", 
        "abbbb", "baaaa", "babbb", "bbabb", "bbbab", "bbbba"}}\)], "Output",
  CellLabel->"Out[149]=",
  CellTags->"ModCounterDFA"]
}, Open  ]],

Cell["\<\
The canonical state set of these autoamata are the modular numbers \
mod m.\
\>", "ExampleText",
  CellTags->"ModCounterDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ModCounterDFA[b, 1, 3, 2, \ Normalize \[Rule] 1\ ]\  // \ 
      States\)], "Input",
  CellLabel->"In[151]:=",
  CellTags->"ModCounterDFA"],

Cell[BoxData[
    \({0, 1, 2}\)], "Output",
  CellLabel->"Out[151]=",
  CellTags->"ModCounterDFA"]
}, Open  ]]
}, Closed]],

Cell["NNFAToFA", "ObjectName",
  CellTags->"NNFAToFA"],

Cell["Type: function", "Highlight",
  CellTags->"NNFAToFA"],

Cell[TextData[{
  StyleBox["NNFAToFA[M]", "MR"],
  "  converts the tail ",
  StyleBox["M", "MR"],
  " of an NNFA into the corresponding FA."
}], "Usage",
  CellTags->"NNFAToFA"],

Cell["\<\
Only used in connection with McNaughton-Yamada style conversion \
from regular expressions.\
\>", "Notes",
  CellTags->"NNFAToFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["RegularExpressionToNNFA",
    ButtonData:>"RegularExpressionToNNFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NNFAToFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NNFAToFA"],

Cell[TextData[{
  "A regular expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^\(\(\ \)\(*\)\)\) 
        b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  " and the corresponding NNFA."
}], "ExampleText",
  CellTags->"NNFAToFA"],

Cell[CellGroupData[{

Cell["re = RET[ RES[REP[a,b]],b,REP[a,b],REP[a,b]]", "Input",
  CellLabel->"In[75]:=",
  CellTags->"NNFAToFA"],

Cell[BoxData[
    \(RET[RES[REP[a, b]], b, REP[a, b], REP[a, b]]\)], "Output",
  CellLabel->"Out[75]=",
  CellTags->"NNFAToFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RegularExpressionToNNFA[re]\)], "Input",
  CellLabel->"In[76]:=",
  CellTags->"NNFAToFA"],

Cell[BoxData[
    \(NNFA[
      7, {{1, 1}, {1, 2}, {1, 3}, {2, 1}, {2, 2}, {2, 3}, {3, 4}, {3, 5}, {4, 
          6}, {4, 7}, {5, 6}, {5, 7}}, {"a", "b", "b", "a", "b", "a", 
        "b"}, {1, 2, 3}, {6, 7}, 0]\)], "Output",
  CellLabel->"Out[76]=",
  CellTags->"NNFAToFA"]
}, Open  ]],

Cell["Conversion to an FA.", "ExampleText",
  CellTags->"NNFAToFA"],

Cell[CellGroupData[{

Cell["NNFAToFA[%]", "Input",
  CellLabel->"In[77]:=",
  CellTags->"NNFAToFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"8", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 3}, {1, 2, 4}, {2, 1, 2}, {2, 2, 
                3}, \[LeftSkeleton]5\[RightSkeleton], {4, 2, 6}, {5, 1, 
                7}, {5, 2, 8}, {6, 1, 7}, {6, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[77]=",
  CellTags->"NNFAToFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[%, \(-5\)]\)], "Input",
  CellLabel->"In[78]:=",
  CellTags->"NNFAToFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[78]=",
  CellTags->"NNFAToFA"]
}, Open  ]]
}, Closed]],

Cell["NoFactorFA", "ObjectName",
  CellTags->"NoFactorFA"],

Cell["Type: function", "Highlight",
  CellTags->"NoFactorFA"],

Cell[TextData[{
  StyleBox["NoFactorFA[M,opts]", "MR"],
  "  constructs an FA for the language of all words x in the acceptance \
language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of ",
  StyleBox["M", "MR"],
  " such that no factor of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is also in ",
  StyleBox["L", "Input"],
  ". "
}], "Usage",
  CellTags->"NoFactorFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"NoFactorFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["NoPrefixFA",
    ButtonData:>"NoPrefixFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NoSuffixFA",
    ButtonData:>"NoSuffixFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdealBaseFA",
    ButtonData:>"IdealBaseFA",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"NoFactorFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NoFactorFA"],

Cell[TextData[{
  "A machine for all words containing 3 ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s."
}], "ExampleText",
  CellTags->"NoFactorFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = CounterDFA[a, 3, 2]\)], "Input",
  CellLabel->"In[255]:=",
  CellTags->"NoFactorFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 5}, {1, 2, 3, 4, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[255]=",
  CellTags->"NoFactorFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ NoFactorFA[\ m\ ]\)], "Input",
  CellLabel->"In[256]:=",
  CellTags->"NoFactorFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"25", ",", "2", ",", 
          
          TagBox[\({{1, 1, 7}, {2, 1, 8}, {3, 1, 9}, {4, 1, 10}, {5, 1, 
                10}, \[LeftSkeleton]41\[RightSkeleton], {22, 2, 22}, {23, 2, 
                23}, {24, 2, 24}, {25, 2, 25}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({16, 17, 18, 19}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[256]=",
  CellTags->"NoFactorFA"]
}, Open  ]],

Cell[TextData[{
  "We obtain the language of all words containing 3 ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s starting and ending in ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". "
}], "ExampleText",
  CellTags->"NoFactorFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[mm, \(-6\)]\)], "Input",
  CellLabel->"In[248]:=",
  CellTags->"NoFactorFA"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa"}, {"aaba", "abaa"}, {"aabba", "ababa", 
        "abbaa"}, {"aabbba", "ababba", "abbaba", "abbbaa"}}\)], "Output",
  CellLabel->"Out[248]=",
  CellTags->"NoFactorFA"]
}, Open  ]]
}, Closed]],

Cell["NoPrefixFA", "ObjectName",
  CellTags->"NoPrefixFA"],

Cell["Type: function", "Highlight",
  CellTags->"NoPrefixFA"],

Cell[TextData[{
  StyleBox["NoPrefixFA[M]", "MR"],
  "  constructs an FA for the language of all words ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in the acceptance language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of M such that no proper prefix of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is also in ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". "
}], "Usage",
  CellTags->"NoPrefixFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"NoPrefixFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["NoSuffixFA",
    ButtonData:>"NoSuffixFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdealBaseFA",
    ButtonData:>"IdealBaseFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NoFactorFA",
    ButtonData:>"NoFactorFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NoPrefixFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NoPrefixFA"],

Cell[TextData[{
  "A machine for all words containing 3 ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s."
}], "ExampleText",
  CellTags->"NoPrefixFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = CounterDFA[a, 3, 2]\)], "Input",
  CellLabel->"In[241]:=",
  CellTags->"NoPrefixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 5}, {1, 2, 3, 4, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[241]=",
  CellTags->"NoPrefixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ NoPrefixFA[\ m\ ]\)], "Input",
  CellLabel->"In[242]:=",
  CellTags->"NoPrefixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 2}, {3, 1, 
                4}, {3, 2, 3}, {5, 1, 5}, {5, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[242]=",
  CellTags->"NoPrefixFA"]
}, Open  ]],

Cell[TextData[{
  "We obtain the language of all words containing 3 ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s and ending in ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". "
}], "ExampleText",
  CellTags->"NoPrefixFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[mm, \(-6\)]\)], "Input",
  CellLabel->"In[243]:=",
  CellTags->"NoPrefixFA"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa"}, {"aaba", "abaa", "baaa"}, {"aabba", "ababa", 
        "abbaa", "baaba", "babaa", "bbaaa"}, {"aabbba", "ababba", "abbaba", 
        "abbbaa", "baabba", "bababa", "babbaa", "bbaaba", "bbabaa", 
        "bbbaaa"}}\)], "Output",
  CellLabel->"Out[243]=",
  CellTags->"NoPrefixFA"]
}, Open  ]]
}, Closed]],

Cell["NormalizeControl", "ObjectName",
  CellTags->"NormalizeControl"],

Cell["Type: function", "Highlight",
  CellTags->"NormalizeControl"],

Cell[TextData[{
  StyleBox["NormalizeControl[]", "MR"],
  "  turns off normalization for finite state machines. "
}], "Usage",
  CellTags->"NormalizeControl"],

Cell[TextData[{
  "Equivalent to setting  ",
  StyleBox["Normalize\[Rule]2 ", "MR"],
  "in all functions supporting this option.  "
}], "Notes",
  CellTags->"NormalizeControl"],

Cell[TextData[{
  "Normalization can be turned back on with ",
  StyleBox["NormalizeControl[0]", "MR"],
  "."
}], "Notes",
  CellTags->"NormalizeControl"],

Cell["\<\
Note that machines can become significantly larger as data \
structures when normalization is turned off. \
\>", "Notes",
  CellTags->"NormalizeControl"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NormalizeControl"],

Cell["\<\
By default, normalization is turned on, but can be controlled in \
each single function call. \
\>", "ExampleText",
  CellTags->"NormalizeControl"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ToDFA[IthSymbolFA[a, \(-3\)]];\)\), "\n", 
    \(States[%]\)}], "Input",
  CellLabel->"In[25]:=",
  CellTags->"NormalizeControl"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8}\)], "Output",
  CellLabel->"Out[26]=",
  CellTags->"NormalizeControl"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ToDFA[IthSymbolFA[a, \(-3\)], Normalize \[Rule] 1];\)\), "\n", 
    \(States[%]\)}], "Input",
  CellLabel->"In[27]:=",
  CellTags->"NormalizeControl"],

Cell[BoxData[
    \({{1}, {1, 2}, {1, 2, 3}, {1, 3}, {1, 2, 3, 4}, {1, 3, 4}, {1, 2, 
        4}, {1, 4}}\)], "Output",
  CellLabel->"Out[28]=",
  CellTags->"NormalizeControl"]
}, Open  ]],

Cell["\<\
Turning normalization permanently off is sometimes preferable. \
\
\>", "ExampleText",
  CellTags->"NormalizeControl"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(NormalizeControl[]\), "\n", 
    \(\(ToDFA[IthSymbolFA[a, \(-3\)]];\)\), "\n", 
    \(States[%]\)}], "Input",
  CellLabel->"In[29]:=",
  CellTags->"NormalizeControl"],

Cell[BoxData[
    \(NormalizeControl::"off" \(\(:\)\(\ \)\) 
      "Normalization is turned on (level \!\(2\))."\)], "Message",
  CellLabel->"From In[29]:=",
  CellTags->"NormalizeControl"],

Cell[BoxData[
    \({{0}, {0, 1}, {0, 1, 2}, {0, 2}, {0, 1, 2, 3}, {0, 2, 3}, {0, 1, 
        3}, {0, 3}}\)], "Output",
  CellLabel->"Out[31]=",
  CellTags->"NormalizeControl"]
}, Open  ]]
}, Closed]],

Cell["NormalizeFA", "ObjectName",
  CellTags->"NormalizeFA"],

Cell["Type: function", "Highlight",
  CellTags->"NormalizeFA"],

Cell[TextData[{
  StyleBox["NormalizeFA[M]", "MR"],
  "  normalizes finite state machine ",
  StyleBox["M", "MR"],
  "."
}], "Usage",
  CellTags->"NormalizeFA"],

Cell[TextData[{
  "The effect of normalization is that the state set is forced to be ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], n}\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the size of the machine. "
}], "Notes",
  CellTags->"NormalizeFA"],

Cell["\<\
This may significantly reduce the size of the expression \
representing the automaton. \
\>", "Notes",
  CellTags->"NormalizeFA"],

Cell[TextData[{
  "See ",
  ButtonBox["FormatAutomata",
    ButtonData:>"FormatAutomata",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"NormalizeFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NormalizeFA"],

Cell["\<\
We build a machine with structured state set by deterministic \
simulation.\
\>", "ExampleText",
  CellTags->"NormalizeFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = ToDFA[IthSymbolFA[b, \(-3\), 2], Normalize \[Rule] 1]\), "\n", 
    \(States[m]\)}], "Input",
  CellLabel->"In[229]:=",
  CellTags->"NormalizeFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[229]=",
  CellTags->"NormalizeFA"],

Cell[BoxData[
    \({{1}, {1, 2}, {1, 3}, {1, 2, 3}, {1, 4}, {1, 2, 4}, {1, 3, 4}, {1, 2, 
        3, 4}}\)], "Output",
  CellLabel->"Out[230]=",
  CellTags->"NormalizeFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(mm\  = \ NormalizeFA[m]\), "\n", 
    \(States[mm]\)}], "Input",
  CellLabel->"In[231]:=",
  CellTags->"NormalizeFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[231]=",
  CellTags->"NormalizeFA"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8}\)], "Output",
  CellLabel->"Out[232]=",
  CellTags->"NormalizeFA"]
}, Open  ]]
}, Closed]],

Cell["NoSuffixFA", "ObjectName",
  CellTags->"NoSuffix"],

Cell["Type: function", "Highlight",
  CellTags->"NoSuffix"],

Cell[TextData[{
  StyleBox["NoSuffixFA[M,opts]", "MR"],
  " constructs an FA for the language of all words ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in the acceptance language ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of M such that no proper suffix of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is also in ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ". "
}], "Usage",
  CellTags->"NoSuffix"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"NoSuffix"],

Cell[TextData[{
  "See also ",
  ButtonBox["NoPrefixFA",
    ButtonData:>"NoPrefixFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdealBaseFA",
    ButtonData:>"IdealBaseFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NoFactorFA",
    ButtonData:>"NoFactorFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NoSuffix"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NoSuffix"],

Cell[TextData[{
  "A machine for all words containing 3 ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s."
}], "ExampleText",
  CellTags->"NoSuffix"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = CounterDFA[a, 3, 2]\)], "Input",
  CellLabel->"In[244]:=",
  CellTags->"NoSuffix"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 5}, {1, 2, 3, 4, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[244]=",
  CellTags->"NoSuffix"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ NoSuffixFA[\ m\ ]\)], "Input",
  CellLabel->"In[245]:=",
  CellTags->"NoSuffix"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{2, 1, 1}, {1, 2, 1}, {3, 1, 2}, {2, 2, 2}, {4, 1, 
                3}, {3, 2, 3}, {5, 1, 5}, {5, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[245]=",
  CellTags->"NoSuffix"]
}, Open  ]],

Cell[TextData[{
  "We obtain the language of all words containing 3 ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s and starting in ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". "
}], "ExampleText",
  CellTags->"NoSuffix"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[mm, \(-6\)]\)], "Input",
  CellLabel->"In[246]:=",
  CellTags->"NoSuffix"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa"}, {"aaab", "aaba", "abaa"}, {"aaabb", "aabab", 
        "aabba", "abaab", "ababa", "abbaa"}, {"aaabbb", "aababb", "aabbab", 
        "aabbba", "abaabb", "ababab", "ababba", "abbaab", "abbaba", 
        "abbbaa"}}\)], "Output",
  CellLabel->"Out[246]=",
  CellTags->"NoSuffix"]
}, Open  ]]
}, Closed]],

Cell["NumberOfCA", "ObjectName",
  CellTags->"NumberOfCA"],

Cell["Type: function", "Highlight",
  CellTags->"NumberOfCA"],

Cell[TextData[{
  StyleBox["NumberOfCA[w,k]", "MR"],
  "  returnes the number of cellular automata of width ",
  StyleBox["w", "MR"],
  " and and alphabet of size ",
  StyleBox["k", "MR"],
  ". "
}], "Usage",
  CellTags->"NumberOfCA"],

Cell[TextData[{
  "Returns ",
  Cell[BoxData[
      \(TraditionalForm\`k\^\(k\^w\)\)]],
  "."
}], "Notes",
  CellTags->"NumberOfCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["NumberOfTotalisticCA",
    ButtonData:>"NumberOfTotalisticCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NumberOfCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NumberOfCA"],

Cell["Super-exponential blow-up.", "ExampleText",
  CellTags->"NumberOfCA"],

Cell[CellGroupData[{

Cell[" Table[{w,NumberOfCA[w,2]}, {w,5} ] // TableForm", "Input",
  CellLabel->"In[62]:=",
  CellTags->"NumberOfCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "4"},
          {"2", "16"},
          {"3", "256"},
          {"4", "65536"},
          {"5", "4294967296"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[62]//TableForm=",
  CellTags->"NumberOfCA"]
}, Open  ]]
}, Closed]],

Cell["NumberOfDFA", "ObjectName",
  CellTags->"NumberOfDFA"],

Cell["Type: function", "Highlight",
  CellTags->"NumberOfDFA"],

Cell[TextData[{
  StyleBox["NumberOfDFA[n,k]", "MR"],
  "  computes the number of DFAs on ",
  StyleBox["n", "MR"],
  " states and ",
  StyleBox["k", "MR"],
  " symbols."
}], "Usage",
  CellTags->"NumberOfDFA"],

Cell[TextData[{
  StyleBox["NumberOfDFA", "MR"],
  " does not account for isomorphic machines."
}], "Notes",
  CellTags->"NumberOfDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["RandomDFA",
    ButtonData:>"RandomDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["RankToDFA",
    ButtonData:>"RankToDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["RankOfDFA",
    ButtonData:>"RankOfDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NumberOfDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NumberOfDFA"],

Cell["The number of binary DFAs up to 8 states.", "ExampleText",
  CellTags->"NumberOfDFA"],

Cell[CellGroupData[{

Cell["Table[ NumberOfDFA[n,2], {n,8} ] // TableForm", "Input",
  CellLabel->"In[151]:=",
  CellTags->"NumberOfDFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"2"},
          {"128"},
          {"17496"},
          {"4194304"},
          {"1562500000"},
          {"835884417024"},
          {"607687873272704"},
          {"576460752303423488"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {2, 128, 17496, 4194304, 1562500000, 835884417024, 
        607687873272704, 576460752303423488}]]], "Output",
  CellLabel->"Out[151]//TableForm=",
  CellTags->"NumberOfDFA"]
}, Open  ]]
}, Closed]],

Cell["NumberOfTotalisticCA", "ObjectName",
  CellTags->"NumberOfTotalisticCA"],

Cell["Type: function", "Highlight",
  CellTags->"NumberOfTotalisticCA"],

Cell[TextData[{
  StyleBox["NumberOfTotalisticCA[w,K]", "MR"],
  "  determinces the number of totalistic cellular automata of width ",
  StyleBox["w", "MR"],
  " and and alphabet of size ",
  StyleBox["k", "MR"],
  ". "
}], "Usage",
  CellTags->"NumberOfTotalisticCA"],

Cell[TextData[{
  "Returns ",
  Cell[BoxData[
      \(TraditionalForm\`k\^\(w(k - 1) + 1\)\)]],
  "."
}], "Notes",
  CellTags->"NumberOfTotalisticCA"],

Cell[TextData[{
  "See also  ",
  ButtonBox["NumberOfCA",
    ButtonData:>"NumberOfCA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToTotalisticRuleCA",
    ButtonData:>"ToTotalisticRuleCA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["TotalisticRuleToCA",
    ButtonData:>"TotalisticRuleToCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NumberOfTotalisticCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NumberOfTotalisticCA"],

Cell["Exponential blow-up.", "ExampleText",
  CellTags->"NumberOfTotalisticCA"],

Cell[CellGroupData[{

Cell[" Table[{w,NumberOfTotalisticCA[w,3]}, {w,5} ] // TableForm", "Input",
  CellLabel->"In[70]:=",
  CellTags->"NumberOfTotalisticCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "27"},
          {"2", "243"},
          {"3", "2187"},
          {"4", "19683"},
          {"5", "177147"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[70]//TableForm=",
  CellTags->"NumberOfTotalisticCA"]
}, Open  ]]
}, Closed]],

Cell["NumTransitions", "ObjectName",
  CellTags->"NumTransitions"],

Cell["Type: function", "Highlight",
  CellTags->"NumTransitions"],

Cell[TextData[{
  StyleBox["NumTransitions[M]", "MR"],
  "  returns the number of transitions in machine ",
  StyleBox["M", "MR"],
  "."
}], "Usage",
  CellTags->"NumTransitions"],

Cell[TextData[{
  "See also ",
  ButtonBox["Size",
    ButtonData:>"Size",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NumTransitions"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NumTransitions"],

Cell["Extracting the number of transitions of a semiautomaton.", "ExampleText",
  CellTags->"NumTransitions"],

Cell[BoxData[
    \(\(m = 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 1}, {3, 
              2, 2}, {4, 2, 3}}];\)\)], "Input",
  CellLabel->"In[134]:=",
  CellTags->"NumTransitions"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumTransitions[m]\)], "Input",
  CellLabel->"In[135]:=",
  CellTags->"NumTransitions"],

Cell[BoxData[
    \(7\)], "Output",
  CellLabel->"Out[135]=",
  CellTags->"NumTransitions"]
}, Open  ]]
}, Closed]],

Cell["OrbitCA", "ObjectName",
  CellTags->"OrbitCA"],

Cell["Type: function", "Highlight",
  CellTags->"OrbitCA"],

Cell[TextData[{
  StyleBox["OrbitCA[C,pat,t,opts]", "MR"],
  "  computes the orbit of pattern pat under application of the global map of \
cellular automaton C up to time t. "
}], "Usage",
  CellTags->"OrbitCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Boundary", "\[Rule]", "Cyclic", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"OrbitCA"],

Cell[TextData[{
  "Option ",
  StyleBox["Boundary->Fixed", "MR"],
  " uses fixed boundary conditions."
}], "Notes",
  CellTags->"OrbitCA"],

Cell[TextData[{
  "The output is a matrix of integers that can be rendered by ",
  StyleBox["PlotMatrix.", "MR"]
}], "Notes",
  CellTags->"OrbitCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["GlobalMapCA",
    ButtonData:>"GlobalMapCA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"OrbitCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"OrbitCA"],

Cell["\<\
A classical example: additive rule 90 on a random initial \
configuration.\
\>", "ExampleText",
  CellTags->"OrbitCA"],

Cell["\<\
X = Table[ Random[Integer,{0,1}],{50} ];
orb = OrbitCA[ CA[90], X, 100 ];\
\>", "Input",
  CellLabel->"In[205]:=",
  CellTags->"OrbitCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(orb\  // \ Dimensions\)], "Input",
  CellLabel->"In[207]:=",
  CellTags->"OrbitCA"],

Cell[BoxData[
    \({101, 50}\)], "Output",
  CellLabel->"Out[207]=",
  CellTags->"OrbitCA"]
}, Open  ]],

Cell["\<\
The relative frequencies of 0's and 1's is approximately 1/2.\
\>", \
"ExampleText",
  CellTags->"OrbitCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Flatten[orb]\  // \ Frequencies\)], "Input",
  CellLabel->"In[208]:=",
  CellTags->"OrbitCA"],

Cell[BoxData[
    \({{0, 2557}, {1, 2493}}\)], "Output",
  CellLabel->"Out[208]=",
  CellTags->"OrbitCA"]
}, Open  ]]
}, Closed]],

Cell["ParikhVector", "ObjectName",
  CellTags->"ParikhVector"],

Cell["Type: function", "Highlight",
  CellTags->"ParikhVector"],

Cell[TextData[{
  StyleBox["ParikhVector[w,K]", "MR"],
  "  computes the Parihk vector of word w over alphabet K."
}], "Usage",
  CellTags->"ParikhVector"],

Cell["Also works for lists of words.", "Notes",
  CellTags->"ParikhVector"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ParikhVector"],

Cell["The Parikh vectors of all words of length 4.", "ExampleText",
  CellTags->"ParikhVector"],

Cell[CellGroupData[{

Cell["ParikhVector[ Words[4], 2 ]", "Input",
  CellLabel->"In[131]:=",
  CellTags->"ParikhVector"],

Cell[BoxData[
    \({{4, 0}, {3, 1}, {3, 1}, {2, 2}, {3, 1}, {2, 2}, {2, 2}, {1, 3}, {3, 
        1}, {2, 2}, {2, 2}, {1, 3}, {2, 2}, {1, 3}, {1, 3}, {0, 
        4}}\)], "Output",
  CellLabel->"Out[131]=",
  CellTags->"ParikhVector"]
}, Open  ]]
}, Closed]],

Cell["PermutationSA", "ObjectName",
  CellTags->"PermutationSA"],

Cell["Type: function", "Highlight",
  CellTags->"PermutationSA"],

Cell[TextData[{
  StyleBox["PermutationSA[perm,K]", "MR"],
  "  constructs a semiautomaton from the list of permuations ",
  StyleBox["perm", "MR"],
  " over alphabet K."
}], "Usage",
  CellTags->"PermutationSA"],

Cell["\<\
List perm must have length the size of K, and contain integer lists \
representing permutations.\
\>", "Notes",
  CellTags->"PermutationSA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PermutationSA"],

Cell["Turning permutations into automata.", "ExampleText",
  CellTags->"PermutationSA"],

Cell[CellGroupData[{

Cell["s = PermutationSA[{{2,3,4,1},{2,1,3,4}},2]", "Input",
  CellLabel->"In[125]:=",
  CellTags->"PermutationSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 2}, {2, 1, 3}, {2, 2, 1}, {3, 1, 
                4}, {3, 2, 3}, {4, 1, 1}, {4, 2, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[125]=",
  CellTags->"PermutationSA"]
}, Open  ]],

Cell["\<\
The transformation semigroup here is the symmetric group on 4 \
points.\
\>", "ExampleText",
  CellTags->"PermutationSA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ToGeneratorsFA[s];\)\), "\n", 
    \(GenerateSG[%]\), "\n", 
    \(%\  // \ Length\)}], "Input",
  CellLabel->"In[128]:=",
  CellTags->"PermutationSA"],

Cell[BoxData[
    \(SG[T[1, 2, 3, 4], T[1, 2, 4, 3], T[1, 3, 2, 4], T[1, 3, 4, 2], 
      T[1, 4, 2, 3], T[1, 4, 3, 2], T[2, 1, 3, 4], T[2, 1, 4, 3], 
      T[2, 3, 1, 4], T[2, 3, 4, 1], T[2, 4, 1, 3], T[2, 4, 3, 1], 
      T[3, 1, 2, 4], T[3, 1, 4, 2], T[3, 2, 1, 4], T[3, 2, 4, 1], 
      T[3, 4, 1, 2], T[3, 4, 2, 1], T[4, 1, 2, 3], T[4, 1, 3, 2], 
      T[4, 2, 1, 3], T[4, 2, 3, 1], T[4, 3, 1, 2], T[4, 3, 2, 1]]\)], "Output",\

  CellLabel->"Out[129]=",
  CellTags->"PermutationSA"],

Cell[BoxData[
    \(24\)], "Output",
  CellLabel->"Out[130]=",
  CellTags->"PermutationSA"]
}, Open  ]]
}, Closed]],

Cell["PermuteFA", "ObjectName",
  CellTags->"PermuteFA"],

Cell["Type: function", "Highlight",
  CellTags->"PermuteFA"],

Cell[TextData[{
  StyleBox["PermuteFA[M,perm]", "MR"],
  "  permutes the states of FSM ",
  StyleBox["M", "MR"],
  " according to permutation ",
  StyleBox["perm", "MR"],
  ". "
}], "Usage",
  CellTags->"PermuteFA"],

Cell[TextData[{
  "List ",
  StyleBox["perm", "MR"],
  " is required to be a permutation of length ",
  StyleBox["Size[M]", "MR"],
  StyleBox[", there is no check.", "Text"]
}], "Notes",
  CellTags->"PermuteFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PermuteFA"],

Cell["Permuting a DFA will not change the acceptance language.", "ExampleText",
  CellTags->"PermuteFA"],

Cell[CellGroupData[{

Cell[" m = ModCounterDFA[ b, 1, 3, 2 ]", "Input",
  CellLabel->"In[225]:=",
  CellTags->"PermuteFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 2, 3}, {2, 3, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[225]=",
  CellTags->"PermuteFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ PermuteFA[\ m, \ {3, 2, 1}\ ]\)], "Input",
  CellLabel->"In[226]:=",
  CellTags->"PermuteFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 2, 3}, {3, 1, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["3",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[226]=",
  CellTags->"PermuteFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IsomorphicQDFA[m, mm]\)], "Input",
  CellLabel->"In[227]:=",
  CellTags->"PermuteFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[227]=",
  CellTags->"PermuteFA"]
}, Open  ]]
}, Open  ]],

Cell["PlotComputationFA", "ObjectName",
  CellTags->"PlotComputationFA"],

Cell["Type: function", "Highlight",
  CellTags->"PlotComputationFA"],

Cell[TextData[{
  StyleBox["PlotComputationFA[M,w,opts]", "MR"],
  "  graphs the computation of FSM ",
  StyleBox["M", "MR"],
  " on input word ",
  StyleBox["w", "MR"],
  ". "
}], "Usage",
  CellTags->"PlotComputationFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "Automatic", "-"},
          {"LabelGrid", "\[Rule]", "None", "-"},
          {"Full", "\[Rule]", "True", "-"},
          {"Frame", "\[Rule]", "True", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PlotComputationFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->False", "MR"],
  " causes only persistent branches to be displayed."
}], "Notes",
  CellTags->"PlotComputationFA"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->I", "MR"],
  "  treats I as the set of initial states."
}], "Notes",
  CellTags->"PlotComputationFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ComputationFA",
    ButtonData:>"ComputationFA",
    ButtonStyle->"AddOnsLink"],
  "  and  ",
  ButtonBox["ComputationGraphFA",
    ButtonData:>"ComputationGraphFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PlotComputationFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PlotComputationFA"],

Cell[TextData[{
  "A machine for the language of all words whose 4th symbol from the end is \
an ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". "
}], "ExampleText",
  CellTags->"PlotComputationFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = IthSymbolFA[a, \(-4\)]\)], "Input",
  CellLabel->"In[90]:=",
  CellTags->"PlotComputationFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}, {4, 1, 5}, {4, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[90]=",
  CellTags->"PlotComputationFA"]
}, Open  ]],

Cell["\<\
There is exactly one accepting computation in this machine for each \
word in the language.\
\>", "ExampleText",
  CellTags->"PlotComputationFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotComputationFA[m, aabaa\ ];\)\)], "Input",
  CellLabel->"In[109]:=",
  CellTags->"PlotComputationFA"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.030303 0.151515 -0.0220726 0.110363 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 g
.003 w
[ ] 0 setdash
.12121 .08829 m
.27273 .08829 L
s
.12121 .08829 m
.27273 .19865 L
s
.12121 .19865 m
.27273 .30902 L
s
.12121 .30902 m
.27273 .41938 L
s
.12121 .41938 m
.27273 .52974 L
s
.27273 .08829 m
.42424 .08829 L
s
.27273 .08829 m
.42424 .19865 L
s
.27273 .19865 m
.42424 .30902 L
s
.27273 .30902 m
.42424 .41938 L
s
.27273 .41938 m
.42424 .52974 L
s
.42424 .08829 m
.57576 .08829 L
s
.42424 .19865 m
.57576 .30902 L
s
.42424 .30902 m
.57576 .41938 L
s
.42424 .41938 m
.57576 .52974 L
s
.57576 .08829 m
.72727 .08829 L
s
.57576 .08829 m
.72727 .19865 L
s
.57576 .19865 m
.72727 .30902 L
s
.57576 .30902 m
.72727 .41938 L
s
.57576 .41938 m
.72727 .52974 L
s
.72727 .08829 m
.87879 .08829 L
s
.72727 .08829 m
.87879 .19865 L
s
.72727 .19865 m
.87879 .30902 L
s
.72727 .30902 m
.87879 .41938 L
s
.72727 .41938 m
.87879 .52974 L
s
0 0 0 r
.005 w
.12121 .08829 m
.27273 .08829 L
s
.27273 .08829 m
.42424 .19865 L
s
.42424 .19865 m
.57576 .30902 L
s
.57576 .30902 m
.72727 .41938 L
s
.72727 .41938 m
.87879 .52974 L
s
0 0 1 r
.012 w
.12121 .19865 Mdot
.12121 .30902 Mdot
.12121 .41938 Mdot
.12121 .52974 Mdot
.27273 .19865 Mdot
.27273 .30902 Mdot
.27273 .41938 Mdot
.27273 .52974 Mdot
.42424 .08829 Mdot
.42424 .30902 Mdot
.42424 .41938 Mdot
.42424 .52974 Mdot
.57576 .08829 Mdot
.57576 .19865 Mdot
.57576 .41938 Mdot
.57576 .52974 Mdot
.72727 .08829 Mdot
.72727 .19865 Mdot
.72727 .30902 Mdot
.72727 .52974 Mdot
.87879 .08829 Mdot
.87879 .19865 Mdot
.87879 .30902 Mdot
.87879 .41938 Mdot
1 0 0 r
.0144 w
.12121 .08829 Mdot
.27273 .08829 Mdot
.42424 .19865 Mdot
.57576 .30902 Mdot
.72727 .41938 Mdot
.87879 .52974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[109]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"PlotComputationFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotComputationFA[m, aabaa, Full \[Rule] False, 
        LabelGrid \[Rule] Automatic\ ];\)\)], "Input",
  CellLabel->"In[113]:=",
  CellTags->"PlotComputationFA"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.030303 0.151515 -0.0220726 0.110363 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.12121 .08829 m
.27273 .08829 L
s
.27273 .08829 m
.42424 .19865 L
s
.42424 .19865 m
.57576 .30902 L
s
.57576 .30902 m
.72727 .41938 L
s
.72727 .41938 m
.87879 .52974 L
s
0 g
[(1)] .06818 .08829 0 0 Mshowa
[(2)] .06818 .19865 0 0 Mshowa
[(3)] .06818 .30902 0 0 Mshowa
[(4)] .06818 .41938 0 0 Mshowa
[(5)] .06818 .52974 0 0 Mshowa
[(1)] .93182 .08829 0 0 Mshowa
[(2)] .93182 .19865 0 0 Mshowa
[(3)] .93182 .30902 0 0 Mshowa
[(4)] .93182 .41938 0 0 Mshowa
[(5)] .93182 .52974 0 0 Mshowa
0 0 1 r
.012 w
.12121 .19865 Mdot
.12121 .30902 Mdot
.12121 .41938 Mdot
.12121 .52974 Mdot
.27273 .19865 Mdot
.27273 .30902 Mdot
.27273 .41938 Mdot
.27273 .52974 Mdot
.42424 .08829 Mdot
.42424 .30902 Mdot
.42424 .41938 Mdot
.42424 .52974 Mdot
.57576 .08829 Mdot
.57576 .19865 Mdot
.57576 .41938 Mdot
.57576 .52974 Mdot
.72727 .08829 Mdot
.72727 .19865 Mdot
.72727 .30902 Mdot
.72727 .52974 Mdot
.87879 .08829 Mdot
.87879 .19865 Mdot
.87879 .30902 Mdot
.87879 .41938 Mdot
1 0 0 r
.0144 w
.12121 .08829 Mdot
.27273 .08829 Mdot
.42424 .19865 Mdot
.57576 .30902 Mdot
.72727 .41938 Mdot
.87879 .52974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[113]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"PlotComputationFA"]
}, Open  ]]
}, Closed]],

Cell["PolynomialToCA", "ObjectName",
  CellTags->"PolynomialToCA"],

Cell["Type: function", "Highlight",
  CellTags->"PolynomialToCA"],

Cell[TextData[{
  StyleBox["PolynomialToCA[pol,w,k]", "MR"],
  "  constructs a CA of width w over digit alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{0,  .. , k - 1}\)]],
  " whose local map is given by the polynomial ",
  StyleBox["pol", "MR"],
  ". "
}], "Usage",
  CellTags->"PolynomialToCA"],

Cell[TextData[{
  "The values of ",
  StyleBox["pol", "MR"],
  " are taken modulo ",
  StyleBox["k", "MR"],
  ", and the variables are assumed to be  ",
  StyleBox["x1", "MR"],
  ", ",
  StyleBox["x2", "MR"],
  ", \[Ellipsis] "
}], "Notes",
  CellTags->"PolynomialToCA"],

Cell[TextData[{
  "See alse ",
  ButtonBox["BFunctionToCA",
    ButtonData:>"BFunctionToCA",
    ButtonStyle->"AddOnsLink"],
  "  and ",
  ButtonBox["FunctionToCA",
    ButtonData:>"FunctionToCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PolynomialToCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PolynomialToCA"],

Cell["\<\
Addition modulo 2 of the left and right neighbors produces ECA with \
rule number 90.\
\>", "ExampleText",
  CellTags->"PolynomialToCA"],

Cell[CellGroupData[{

Cell["\<\
PolynomialToCA[ x1 + x3, 3, - 2]
PrintCA[%]\
\>", "Input",
  CellLabel->"In[73]:=",
  CellTags->"PolynomialToCA"],

Cell[BoxData[
    \(CA[90, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[73]=",
  CellTags->"PolynomialToCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {\("000" \[Rule] "0"\), \("100" \[Rule] "1"\)},
          {\("001" \[Rule] "1"\), \("101" \[Rule] "0"\)},
          {\("010" \[Rule] "0"\), \("110" \[Rule] "1"\)},
          {\("011" \[Rule] "1"\), \("111" \[Rule] "0"\)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {1, 2}]]]], "Output",
  CellLabel->"Out[74]//TableForm=",
  CellTags->"PolynomialToCA"]
}, Open  ]]
}, Closed]],

Cell["PrefixDFA", "ObjectName",
  CellTags->"PrefixDFA"],

Cell["Type: function", "Highlight",
  CellTags->"PrefixDFA"],

Cell[TextData[{
  StyleBox["PrefixDFA[w,K,opts]", "MR"],
  "  constructs a DFA that accepts all words with prefix w (over alphabet \
K)."
}], "Usage",
  CellTags->"PrefixDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PrefixDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrefixDFA"],

Cell["A machine for all words starting in abab.", "ExampleText",
  CellTags->"PrefixDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = PrefixDFA[abab]\)], "Input",
  CellLabel->"In[137]:=",
  CellTags->"PrefixDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"6", ",", "2", ",", 
          TagBox[\({{2, 6, 4, 6, 5, 6}, {6, 3, 6, 5, 5, 6}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[137]=",
  CellTags->"PrefixDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, 6]\)], "Input",
  CellLabel->"In[138]:=",
  CellTags->"PrefixDFA"],

Cell[BoxData[
    \({"ababaa", "ababab", "ababba", "ababbb"}\)], "Output",
  CellLabel->"Out[138]=",
  CellTags->"PrefixDFA"]
}, Open  ]]
}, Closed]],

Cell["PrefixQ", "ObjectName",
  CellTags->"PrefixQ"],

Cell["Type: function", "Highlight",
  CellTags->"PrefixQ"],

Cell[TextData[{
  StyleBox["PrefixQ[x,y]", "MR"],
  "  tests whether word ",
  StyleBox["x", "MR"],
  " is a prefix of word ",
  StyleBox["y", "MR"],
  "."
}], "Usage",
  CellTags->"PrefixQ"],

Cell["Also works on symbols and treats epsilon properly.", "Notes",
  CellTags->"PrefixQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordQ",
    ButtonData:>"WordQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PrefixQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrefixQ"],

Cell["Working with symbols rather than strings.", "ExampleText",
  CellTags->"PrefixQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrefixQ[a, abc]\)], "Input",
  CellLabel->"In[79]:=",
  CellTags->"PrefixQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[79]=",
  CellTags->"PrefixQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrefixQ[b, abc]\)], "Input",
  CellLabel->"In[80]:=",
  CellTags->"PrefixQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"PrefixQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrefixQ[\[Epsilon], abc]\)], "Input",
  CellLabel->"In[81]:=",
  CellTags->"PrefixQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[81]=",
  CellTags->"PrefixQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[\ Words[5], \ PrefixQ[aaa, #] &\ ]\)], "Input",
  CellLabel->"In[82]:=",
  CellTags->"PrefixQ"],

Cell[BoxData[
    \({"aaaaa", "aaaab", "aaaba", "aaabb"}\)], "Output",
  CellLabel->"Out[82]=",
  CellTags->"PrefixQ"]
}, Open  ]]
}, Closed]],

Cell["PrimitiveCount", "ObjectName",
  CellTags->"PrimitiveCount"],

Cell["Type: function", "Highlight",
  CellTags->"PrimitiveCount"],

Cell[TextData[{
  StyleBox["PrimitiveCount[n,k]", "MR"],
  "  returns the number of primitive words of length ",
  StyleBox["n", "MR"],
  " over a ",
  StyleBox["k", "MR"],
  " symbol alphabet. "
}], "Usage",
  CellTags->"PrimitiveCount"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"PrimitiveCount"],

Cell["Uses the built-in Moebius function.", "Notes",
  CellTags->"PrimitiveCount"],

Cell[TextData[{
  "See also ",
  ButtonBox["PrimitiveQ",
    ButtonData:>"PrimitiveQ",
    ButtonStyle->"AddOnsLink"],
  " ",
  ButtonBox["WordRoot",
    ButtonData:>"WordRoot",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["WordPower",
    ButtonData:>"WordPower",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PrimitiveCount"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrimitiveCount"],

Cell["Most words are primitive.", "ExampleText",
  CellTags->"PrimitiveCount"],

Cell[CellGroupData[{

Cell["Table[{n,2^n,PrimitiveCount[n,2]},{n,10}] // TableForm", "Input",
  CellLabel->"In[132]:=",
  CellTags->"PrimitiveCount"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "2", "2"},
          {"2", "4", "2"},
          {"3", "8", "6"},
          {"4", "16", "12"},
          {"5", "32", "30"},
          {"6", "64", "54"},
          {"7", "128", "126"},
          {"8", "256", "240"},
          {"9", "512", "504"},
          {"10", "1024", "990"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[132]//TableForm=",
  CellTags->"PrimitiveCount"]
}, Open  ]]
}, Closed]],

Cell["PrimitiveQ", "ObjectName",
  CellTags->"PrimitiveQ"],

Cell["Type: function", "Highlight",
  CellTags->"PrimitiveQ"],

Cell[TextData[{
  StyleBox["PrimitiveQ[w]", "MR"],
  "  tests whether word ",
  StyleBox["w", "MR"],
  " is primitive, i.e, not the power of a shorter word. Uses built-in ",
  StyleBox["StringPosition", "MR"],
  "."
}], "Usage",
  CellTags->"PrimitiveQ"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"PrimitiveQ"],

Cell[TextData[{
  " Uses built-in ",
  StyleBox["StringPosition", "MR"],
  " and is thus linear."
}], "Notes",
  CellTags->"PrimitiveQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["PrimitiveCount",
    ButtonData:>"PrimitiveCount",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["WordRoot",
    ButtonData:>"WordRoot",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["WordPower",
    ButtonData:>"WordPower",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PrimitiveQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrimitiveQ"],

Cell["\<\
16 words of length 8 (over a 2-symbol alphabet) fail to be \
primitive.\
\>", "ExampleText",
  CellTags->"PrimitiveQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[Words[8], PrimitiveQ] // \ Length\)], "Input",
  CellLabel->"In[126]:=",
  CellTags->"PrimitiveQ"],

Cell[BoxData[
    \(240\)], "Output",
  CellLabel->"Out[126]=",
  CellTags->"PrimitiveQ"]
}, Open  ]],

Cell["\<\
Only 2 words of length 7 (over a 2-symbol alphabet) fail to be \
primitive.\
\>", "ExampleText",
  CellTags->"PrimitiveQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[Words[7], PrimitiveQ] // \ Length\)], "Input",
  CellLabel->"In[127]:=",
  CellTags->"PrimitiveQ"],

Cell[BoxData[
    \(126\)], "Output",
  CellLabel->"Out[127]=",
  CellTags->"PrimitiveQ"]
}, Open  ]]
}, Closed]],

Cell["PrintCA", "ObjectName",
  CellTags->"PrintCA"],

Cell["Type: function", "Highlight",
  CellTags->"PrintCA"],

Cell[TextData[{
  StyleBox["PrintCA[C]", "MR"],
  "  pretty-prints the local function of cellular automaton C as a table of \
replacement rules."
}], "Usage",
  CellTags->"PrintCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrintCA"],

Cell["Some cellular automata.", "ExampleText",
  CellTags->"PrintCA"],

Cell[CellGroupData[{

Cell["CA[110] // PrintCA", "Input",
  CellLabel->"In[76]:=",
  CellTags->"PrintCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {\("000" \[Rule] "0"\), \("100" \[Rule] "0"\)},
          {\("001" \[Rule] "1"\), \("101" \[Rule] "1"\)},
          {\("010" \[Rule] "1"\), \("110" \[Rule] "1"\)},
          {\("011" \[Rule] "1"\), \("111" \[Rule] "0"\)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {1, 2}]]]], "Output",
  CellLabel->"Out[76]//TableForm=",
  CellTags->"PrintCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CA[12345,4,-2] // PrintCA", "Input",
  CellLabel->"In[77]:=",
  CellTags->"PrintCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {\("0000" \[Rule] "1"\), \("0100" \[Rule] "1"\), \("1000" \[Rule] 
              "0"\), \("1100" \[Rule] "1"\)},
          {\("0001" \[Rule] "0"\), \("0101" \[Rule] "1"\), \("1001" \[Rule] 
              "0"\), \("1101" \[Rule] "1"\)},
          {\("0010" \[Rule] "0"\), \("0110" \[Rule] "0"\), \("1010" \[Rule] 
              "0"\), \("1110" \[Rule] "0"\)},
          {\("0011" \[Rule] "1"\), \("0111" \[Rule] "0"\), \("1011" \[Rule] 
              "0"\), \("1111" \[Rule] "0"\)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {1, 2}]]]], "Output",
  CellLabel->"Out[77]//TableForm=",
  CellTags->"PrintCA"]
}, Open  ]]
}, Closed]],

Cell["PrintFA", "ObjectName",
  CellTags->"PrintFA"],

Cell["Type: function", "Highlight",
  CellTags->"PrintFA"],

Cell[TextData[{
  StyleBox["PrintFA[M]", "MR"],
  "  pretty prints a finite state machine ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"PrintFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"TransOnly", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PrintFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " tries to print non-normalized state sets. "
}], "Notes",
  CellTags->"PrintFA"],

Cell[TextData[{
  "Option ",
  StyleBox["TransOnly->True", "MR"],
  " only prints the transitions."
}], "Notes",
  CellTags->"PrintFA"],

Cell["This is useful only for small machines.", "Notes",
  CellTags->"PrintFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrintFA"],

Cell["Printing a DFA.", "ExampleText",
  CellTags->"PrintFA"],

Cell[CellGroupData[{

Cell["m = CounterDFA[ b, 3, 3 ]", "Input",
  CellLabel->"In[220]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "3", ",", 
          TagBox[\({{1, 2, 3, 4, 5}, {2, 3, 4, 5, 5}, {1, 2, 3, 4, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[220]=",
  CellTags->"PrintFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintFA[m]\)], "Input",
  CellLabel->"In[222]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("no. of states:  "\[InvisibleSpace]5\),
      SequenceForm[ "no. of states:  ", 5],
      Editable->False]], "Print",
  CellLabel->"From In[222]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("alphabet:       "\[InvisibleSpace]{"a", "b", "c"}\),
      SequenceForm[ "alphabet:       ", {"a", "b", "c"}],
      Editable->False]], "Print",
  CellLabel->"From In[222]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("initial states: "\[InvisibleSpace]{1}\),
      SequenceForm[ "initial states: ", {1}],
      Editable->False]], "Print",
  CellLabel->"From In[222]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("final states:   "\[InvisibleSpace]{4}\),
      SequenceForm[ "final states:   ", {4}],
      Editable->False]], "Print",
  CellLabel->"From In[222]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "1", "2", "3", "4", "5"},
          {"\<\"a\"\>", "1", "2", "3", "4", "5"},
          {"\<\"b\"\>", "2", "3", "4", "5", "5"},
          {"\<\"c\"\>", "1", "2", "3", "4", "5"}
          },
        RowSpacings->0,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDepth -> 2, TableSpacing -> {0, 2}, 
          TableHeadings -> {{"a", "b", "c"}, Automatic}]]]], "Output",
  CellLabel->"Out[222]//TableForm=",
  CellTags->"PrintFA"]
}, Open  ]],

Cell["Printing an FA.", "ExampleText",
  CellTags->"PrintFA"],

Cell[CellGroupData[{

Cell["m = IthSymbolFA[ b, -3, 3 ]", "Input",
  CellLabel->"In[223]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "3", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {1, 3, 1}, {2, 1, 
                3}, {2, 2, 3}, {2, 3, 3}, {3, 1, 4}, {3, 2, 4}, {3, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[223]=",
  CellTags->"PrintFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintFA[m]\)], "Input",
  CellLabel->"In[224]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("no. of states:   "\[InvisibleSpace]4\),
      SequenceForm[ "no. of states:   ", 4],
      Editable->False]], "Print",
  CellLabel->"From In[224]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("no. transitions: "\[InvisibleSpace]10\),
      SequenceForm[ "no. transitions: ", 10],
      Editable->False]], "Print",
  CellLabel->"From In[224]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("alphabet:        "\[InvisibleSpace]{"a", "b", "c"}\),
      
      SequenceForm[ "alphabet:        ", {"a", "b", "c"}],
      Editable->False]], "Print",
  CellLabel->"From In[224]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("initial states:  "\[InvisibleSpace]{1}\),
      SequenceForm[ "initial states:  ", {1}],
      Editable->False]], "Print",
  CellLabel->"From In[224]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[\("final states:    "\[InvisibleSpace]{4}\),
      SequenceForm[ "final states:    ", {4}],
      Editable->False]], "Print",
  CellLabel->"From In[224]:=",
  CellTags->"PrintFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"1"},
                {"\<\"a\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"\<\"b\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"\<\"b\"\>"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"\<\"c\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"a\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"b\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"c\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"\<\"a\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"\<\"b\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"\<\"c\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{1, "a", 1}, {1, "b", 1}, {1, "b", 2}, {1, "c", 1}, {2, 
        "a", 3}, {2, "b", 3}, {2, "c", 3}, {3, "a", 4}, {3, "b", 4}, {3, "c", 
        4}}}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[224]//TableForm=",
  CellTags->"PrintFA"]
}, Open  ]]
}, Closed]],

Cell["ProductFA", "ObjectName",
  CellTags->"ProductFA"],

Cell["Type: function", "Highlight",
  CellTags->"ProductFA"],

Cell[TextData[{
  StyleBox["ProductFA[M1,M2]", "MR"],
  "  computes the product automaton of ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  ". "
}], "Usage",
  CellTags->"ProductFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"Type", "\[Rule]", "Intersection", "Union"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ProductFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  "  causes the full product machine to be generated, rather than just the \
accessible part.  \nCurrently works only of DFAs."
}], "Notes",
  CellTags->"ProductFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Type->Union", "MR"],
  "  causes a machine for the intersection of the two regular languages to be \
returned. By default, a machine for union is produced."
}], "Notes",
  CellTags->"ProductFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SumFA",
    ButtonData:>"SumFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UnionFA",
    ButtonData:>"UnionFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IntersectionFA",
    ButtonData:>"IntersectionFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProductGraph",
    ButtonData:>"ProductGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ProductFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ProductFA"],

Cell["We construct the product of two counter automata.", "ExampleText",
  CellTags->"ProductFA"],

Cell[CellGroupData[{

Cell["\<\
m1 = CounterDFA[ a, 2, 2 ]
m2 = CounterDFA[ b, 3, 2 ]\
\>", "Input",
  CellLabel->"In[47]:=",
  CellTags->"ProductFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 4}, {1, 2, 3, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[47]=",
  CellTags->"ProductFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{1, 2, 3, 4, 5}, {2, 3, 4, 5, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[48]=",
  CellTags->"ProductFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ ProductFA[m1, m2]\)], "Input",
  CellLabel->"In[49]:=",
  CellTags->"ProductFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"20", ",", "2", ",", 
          
          TagBox[\({{6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
                16, 17, 18, 19, 20}, \[LeftSkeleton]1\[RightSkeleton]}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({14}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[49]=",
  CellTags->"ProductFA"]
}, Open  ]],

Cell[TextData[{
  "The product automaton accepts only words containing two ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s and three ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s."
}], "ExampleText",
  CellTags->"ProductFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-7\)]\)], "Input",
  CellLabel->"In[50]:=",
  CellTags->"ProductFA"],

Cell[BoxData[
    \({{}, {}, {}, {}, {}, {"aabbb", "ababb", "abbab", "abbba", "baabb", 
        "babab", "babba", "bbaab", "bbaba", "bbbaa"}, {}, {}}\)], "Output",
  CellLabel->"Out[50]=",
  CellTags->"ProductFA"]
}, Open  ]]
}, Closed]],

Cell["ProductTransitions", "ObjectName",
  CellTags->"ProductTransitions"],

Cell["Type: function", "Highlight",
  CellTags->"ProductTransitions"],

Cell[TextData[{
  StyleBox["ProductTransitions[T1,T2,k]", "MR"],
  "  computes the product of transition lists T1 and T2 over an alphabet of \
size k. "
}], "Usage",
  CellTags->"ProductTransitions"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "0", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ProductTransitions"],

Cell[TextData[{
  "The new transitions are of the form",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((\((p, q)\), a, \((p', q')\))\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, a, p')\)\)]],
  " is a transition in ",
  StyleBox["T1", "MR"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((q, a, q')\)\)]],
  " is a transition in ",
  StyleBox["T2", "MR"],
  ". "
}], "Notes",
  CellTags->"ProductTransitions"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->1", "MR"],
  " identifies ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, q)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((q, p)\)\)]],
  "."
}], "Notes",
  CellTags->"ProductTransitions"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->2", "MR"],
  " identifies ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, q)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((q, p)\)\)]],
  " and omits the diagonal."
}], "Notes",
  CellTags->"ProductTransitions"],

Cell[TextData[{
  "See also ",
  ButtonBox["ProductFA",
    ButtonData:>"ProductFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  " ",
  ButtonBox["SquareSA",
    ButtonData:>"SquareSA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ProductTransitions"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ProductTransitions"],

Cell["The transitions of a semiautomaton, and their product. ", "ExampleText",
  CellTags->"ProductTransitions"],

Cell[BoxData[
    \(\(t = {{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 1}, {3, 2, 
            2}, {4, 2, 3}, {4, 1, 4}};\)\)], "Input",
  CellLabel->"In[116]:=",
  CellTags->"ProductTransitions"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProductTransitions[t, t, 2]\)], "Input",
  CellLabel->"In[117]:=",
  CellTags->"ProductTransitions"],

Cell[BoxData[
    \({{{1, 1}, 1, {1, 1}}, {{1, 3}, 1, {1, 1}}, {{1, 4}, 
        1, {1, 4}}, {{3, 1}, 1, {1, 1}}, {{3, 3}, 1, {1, 1}}, {{3, 4}, 
        1, {1, 4}}, {{4, 1}, 1, {4, 1}}, {{4, 3}, 1, {4, 1}}, {{4, 4}, 
        1, {4, 4}}, {{1, 1}, 2, {2, 2}}, {{1, 2}, 2, {2, 3}}, {{1, 2}, 
        2, {2, 4}}, {{1, 3}, 2, {2, 2}}, {{1, 4}, 2, {2, 3}}, {{2, 1}, 
        2, {3, 2}}, {{2, 2}, 2, {3, 3}}, {{2, 2}, 2, {3, 4}}, {{2, 3}, 
        2, {3, 2}}, {{2, 4}, 2, {3, 3}}, {{2, 1}, 2, {4, 2}}, {{2, 2}, 
        2, {4, 3}}, {{2, 2}, 2, {4, 4}}, {{2, 3}, 2, {4, 2}}, {{2, 4}, 
        2, {4, 3}}, {{3, 1}, 2, {2, 2}}, {{3, 2}, 2, {2, 3}}, {{3, 2}, 
        2, {2, 4}}, {{3, 3}, 2, {2, 2}}, {{3, 4}, 2, {2, 3}}, {{4, 1}, 
        2, {3, 2}}, {{4, 2}, 2, {3, 3}}, {{4, 2}, 2, {3, 4}}, {{4, 3}, 
        2, {3, 2}}, {{4, 4}, 2, {3, 3}}}\)], "Output",
  CellLabel->"Out[117]=",
  CellTags->"ProductTransitions"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProductTransitions[t, t, 2, \ Full \[Rule] 1]\)], "Input",
  CellLabel->"In[118]:=",
  CellTags->"ProductTransitions"],

Cell[BoxData[
    \({{{1, 1}, 1, {1, 1}}, {{1, 1}, 2, {2, 2}}, {{1, 2}, 
        2, {2, 3}}, {{1, 2}, 2, {2, 4}}, {{1, 3}, 1, {1, 1}}, {{1, 3}, 
        2, {2, 2}}, {{1, 4}, 1, {1, 4}}, {{1, 4}, 2, {2, 3}}, {{2, 2}, 
        2, {3, 3}}, {{2, 2}, 2, {3, 4}}, {{2, 2}, 2, {4, 4}}, {{2, 3}, 
        2, {2, 3}}, {{2, 3}, 2, {2, 4}}, {{2, 4}, 2, {3, 3}}, {{2, 4}, 
        2, {3, 4}}, {{3, 3}, 1, {1, 1}}, {{3, 3}, 2, {2, 2}}, {{3, 4}, 
        1, {1, 4}}, {{3, 4}, 2, {2, 3}}, {{4, 4}, 1, {4, 4}}, {{4, 4}, 
        2, {3, 3}}}\)], "Output",
  CellLabel->"Out[118]=",
  CellTags->"ProductTransitions"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProductTransitions[t, t, 2, \ Full \[Rule] 2]\)], "Input",
  CellLabel->"In[119]:=",
  CellTags->"ProductTransitions"],

Cell[BoxData[
    \({{{1, 2}, 2, {2, 3}}, {{1, 2}, 2, {2, 4}}, {{1, 4}, 
        1, {1, 4}}, {{1, 4}, 2, {2, 3}}, {{2, 3}, 2, {2, 3}}, {{2, 3}, 
        2, {2, 4}}, {{2, 4}, 2, {3, 4}}, {{3, 4}, 1, {1, 4}}, {{3, 4}, 
        2, {2, 3}}}\)], "Output",
  CellLabel->"Out[119]=",
  CellTags->"ProductTransitions"]
}, Open  ]]
}, Closed]],

Cell["ProperPrefixes", "ObjectName",
  CellTags->"ProperPrefixes"],

Cell["Type: function", "Highlight",
  CellTags->"ProperPrefixes"],

Cell[TextData[{
  StyleBox["ProperPrefixes[W]", "MR"],
  "  computes the set of all proper prefixes of the finite language W. "
}], "Usage",
  CellTags->"ProperPrefixes"],

Cell[TextData[{
  "On frontiers, this operation is the inverse to ",
  StyleBox["ToPrefix", "MR"],
  ". "
}], "Notes",
  CellTags->"ProperPrefixes"],

Cell[TextData[{
  "If W is only prefix but not right closed, the corresponding set would be \
",
  Cell[BoxData[
      \(TraditionalForm\`\(K\^*\) - W\ \(K\^*\)\)]],
  "   and therefore infinite."
}], "Notes",
  CellTags->"ProperPrefixes"],

Cell[TextData[{
  StyleBox["ProperPrefixes", "MR"],
  " returns a list of lists of words, make sure to Flatten and Union if a set \
is needed."
}], "Notes",
  CellTags->"ProperPrefixes"],

Cell[TextData[{
  "See also  ",
  ButtonBox["ToPrefix",
    ButtonData:>"ToPrefix",
    ButtonStyle->"AddOnsLink"],
  "  and ",
  ButtonBox["FrontierQ",
    ButtonData:>"FrontierQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ProperPrefixes"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ProperPrefixes"],

Cell["A small frontier language and its prefixes.", "ExampleText",
  CellTags->"ProperPrefixes"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(W\  = \ {aa, bb, baa, bab, aba, abb};\)\), "\n", 
    \(ProperPrefixes[W]\)}], "Input",
  CellLabel->"In[50]:=",
  CellTags->"ProperPrefixes"],

Cell[BoxData[
    \({{\[Epsilon], "a"}, {\[Epsilon], "b"}, {\[Epsilon], "a", 
        "ab"}, {\[Epsilon], "b", "ba"}}\)], "Output",
  CellLabel->"Out[51]=",
  CellTags->"ProperPrefixes"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WordSort[Union[Flatten[%]]]", "Input",
  CellLabel->"In[52]:=",
  CellTags->"ProperPrefixes"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "ab", "ba"}\)], "Output",
  CellLabel->"Out[52]=",
  CellTags->"ProperPrefixes"]
}, Open  ]]
}, Closed]],

Cell["QuotientDFA", "ObjectName",
  CellTags->"QuotientDFA"],

Cell["Type: function", "Highlight",
  CellTags->"QuotientDFA"],

Cell[TextData[{
  StyleBox["QuotientDFA[L,K]", "MR"],
  "  computes the quotient automaton of a finite language ",
  StyleBox["L", "MR"],
  "  over alphabet ",
  StyleBox["K", "MR"],
  "."
}], "Usage",
  CellTags->"QuotientDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"QuotientDFA"],

Cell["The resulting DFA is minimal. ", "Notes",
  CellTags->"QuotientDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["BuildDFA",
    ButtonData:>"BuildDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GenerateQuotients",
    ButtonData:>"GenerateQuotients",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LeftQuotient",
    ButtonData:>"LeftQuotient",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["QuotientDFA",
    ButtonData:>"QuotientDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["QuotientMachineFA",
    ButtonData:>"QuotientMachineFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"QuotientDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"QuotientDFA"],

Cell["\<\
The language of all words of length 3 other than aaa, and the \
corresponding quotient automaton.\
\>", "ExampleText",
  CellTags->"QuotientDFA"],

Cell[CellGroupData[{

Cell["W = Rest[Words[3]]", "Input",
  CellLabel->"In[155]:=",
  CellTags->"QuotientDFA"],

Cell[BoxData[
    \({"aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[155]=",
  CellTags->"QuotientDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = QuotientDFA[W, 2, Normalize \[Rule] 1]\)], "Input",
  CellLabel->"In[158]:=",
  CellTags->"QuotientDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 4, 5, 6, 7, 6, 6}, {3, 5, 5, 7, 7, 6, 6}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({7}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[158]=",
  CellTags->"QuotientDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[m]\  // \ ColumnForm\)], "Input",
  CellLabel->"In[161]:=",
  CellTags->"QuotientDFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\({"aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)},
          {\({"ab", "ba", "bb"}\)},
          {\({"aa", "ab", "ba", "bb"}\)},
          {\({"b"}\)},
          {\({"a", "b"}\)},
          {\({}\)},
          {\({\[Epsilon]}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{"aab", "aba", "abb", "baa", "bab", "bba", "bbb"}, {"ab", 
        "ba", "bb"}, {"aa", "ab", "ba", "bb"}, {"b"}, {"a", 
        "b"}, {}, {\[Epsilon]}}],
      Editable->False]], "Output",
  CellLabel->"Out[161]=",
  CellTags->"QuotientDFA"]
}, Open  ]],

Cell["The states are the left quotients of the original language.", \
"ExampleText",
  CellTags->"QuotientDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(LeftQuotient[a, W]\), "\n", 
    \(LeftQuotient[aa, W]\)}], "Input",
  CellLabel->"In[163]:=",
  CellTags->"QuotientDFA"],

Cell[BoxData[
    \({"ab", "ba", "bb"}\)], "Output",
  CellLabel->"Out[163]=",
  CellTags->"QuotientDFA"],

Cell[BoxData[
    \({"b"}\)], "Output",
  CellLabel->"Out[164]=",
  CellTags->"QuotientDFA"]
}, Open  ]]
}, Closed]],

Cell["QuotientMachineFA", "ObjectName",
  CellTags->"QuotientMachineFA"],

Cell["Type: function", "Highlight",
  CellTags->"QuotientMachineFA"],

Cell[TextData[{
  StyleBox["QuotientMachineFA[M1,M2]", "MR"],
  "  computes an FA for the language: all words ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " such that there is a word ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL](M\_1)\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`x\[VeryThinSpace]y\)]],
  " is in ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalL](M\_2)\)]],
  ". "
}], "Usage",
  CellTags->"QuotientMachineFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"QuotientMachineFA"],

Cell["Uses a product machine construction an is thus quadratic.", "Notes",
  CellTags->"QuotientMachineFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["BuildDFA",
    ButtonData:>"BuildDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GenerateQuotients",
    ButtonData:>"GenerateQuotients",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LeftQuotient",
    ButtonData:>"LeftQuotient",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["QuotientDFA",
    ButtonData:>"QuotientDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"QuotientMachineFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"QuotientMachineFA"],

Cell[TextData[{
  "Machines for  ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\^*\) b\ \(a\^*\)\)]],
  " and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a\^*\), "b", " ", 
          FormBox[\(\(a\^*\) \(b\)\(\ \)\),
            "TraditionalForm"], " ", \(a\^*\)}], TraditionalForm]]],
  ", and their left quotient."
}], "ExampleText",
  CellTags->"QuotientMachineFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinimizeFA[\ 
      RegularExpressionToFA[RET[RES[a], b, RES[a], b, RES[a]], 2]]\)], "Input",\

  CellLabel->"In[182]:=",
  CellTags->"QuotientMachineFA"],

Cell[BoxData[
    \(DFA[4, 2, {{1, 2, 3, 4}, {2, 3, 4, 4}}, 1, {3}, {}, {}]\)], "Output",
  CellLabel->"Out[182]=",
  CellTags->"QuotientMachineFA"]
}, Open  ]],

Cell[BoxData[
    \(\(m1 = DFA[3, 2, {{1, 2, 3}, {2, 3, 3}}, 1, {2}];\)\)], "Input",
  CellLabel->"In[190]:=",
  CellTags->"QuotientMachineFA"],

Cell[BoxData[
    \(\(m2\  = \ 
        DFA[4, 2, {{1, 2, 3, 4}, {2, 3, 4, 4}}, 1, {3}];\)\)], "Input",
  CellLabel->"In[191]:=",
  CellTags->"QuotientMachineFA"],

Cell[CellGroupData[{

Cell["m = QuotientMachineFA[ m1, m2 ]", "Input",
  CellLabel->"In[192]:=",
  CellTags->"QuotientMachineFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {2, 1, 2}, {3, 1, 3}, {4, 1, 4}, {1, 2, 
                2}, {2, 2, 3}, {3, 2, 4}, {4, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[192]=",
  CellTags->"QuotientMachineFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[194]:=",
  CellTags->"QuotientMachineFA"],

Cell[BoxData[
    \({{}, {"b"}, {"ab", "ba"}, {"aab", "aba", "baa"}, {"aaab", "aaba", 
        "abaa", "baaa"}, {"aaaab", "aaaba", "aabaa", "abaaa", 
        "baaaa"}}\)], "Output",
  CellLabel->"Out[194]=",
  CellTags->"QuotientMachineFA"]
}, Open  ]],

Cell["The quotient machine is duly equivalent to m1. ", "ExampleText",
  CellTags->"QuotientMachineFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[\ m, \ m1\ ]\)], "Input",
  CellLabel->"In[195]:=",
  CellTags->"QuotientMachineFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[195]=",
  CellTags->"QuotientMachineFA"]
}, Open  ]]
}, Closed]],

Cell["RandomDFA", "ObjectName",
  CellTags->"RandomDFA"],

Cell["Type: function", "Highlight",
  CellTags->"RandomDFA"],

Cell[TextData[{
  StyleBox["RandomDFA[n,k]", "MR"],
  "  produces a random DFA over alphabet K on n states. "
}], "Usage",
  CellTags->"RandomDFA"],

Cell["The machines are chosen according to a uniform distribution.", "Notes",
  CellTags->"RandomDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["NumberOfDFA",
    ButtonData:>"NumberOfDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["RankToDFA",
    ButtonData:>"RankToDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["RankOfDFA",
    ButtonData:>"RankOfDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RandomDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RandomDFA"],

Cell["A random DFA on 5 states over a 3-letter alphabet. ", "ExampleText",
  CellTags->"RandomDFA"],

Cell[CellGroupData[{

Cell["RandomDFA[5,3]", "Input",
  CellLabel->"In[153]:=",
  CellTags->"RandomDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "3", ",", 
          TagBox[\({{4, 5, 3, 2, 2}, {4, 4, 4, 2, 3}, {3, 5, 5, 1, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2, 3, 4, 5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[153]=",
  CellTags->"RandomDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RandomDFA[5,3]", "Input",
  CellLabel->"In[154]:=",
  CellTags->"RandomDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "3", ",", 
          TagBox[\({{2, 4, 2, 4, 2}, {5, 1, 3, 5, 2}, {5, 4, 2, 1, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 3, 4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[154]=",
  CellTags->"RandomDFA"]
}, Open  ]]
}, Closed]],

Cell["RandomWord", "ObjectName",
  CellTags->"RandomWord"],

Cell["Type: function", "Highlight",
  CellTags->"RandomWord"],

Cell[TextData[{
  StyleBox["RandomWord[n,K]", "MR"],
  "  produces a random word over alphabet K of length n. "
}], "Usage",
  CellTags->"RandomWord"],

Cell["Symbols are chosen uniformly.", "Notes",
  CellTags->"RandomWord"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToWord",
    ButtonData:>"ToWord",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RandomWord"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RandomWord"],

Cell["Random words.", "ExampleText",
  CellTags->"RandomWord"],

Cell[CellGroupData[{

Cell["RandomWord[20,2]", "Input",
  CellLabel->"In[114]:=",
  CellTags->"RandomWord"],

Cell[BoxData[
    \("baabbbaabaaaaabbbaba"\)], "Output",
  CellLabel->"Out[114]=",
  CellTags->"RandomWord"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RandomWord[20,-3]", "Input",
  CellLabel->"In[115]:=",
  CellTags->"RandomWord"],

Cell[BoxData[
    \("12200012210111122220"\)], "Output",
  CellLabel->"Out[115]=",
  CellTags->"RandomWord"]
}, Open  ]]
}, Closed]],

Cell["RankOfDFA", "ObjectName",
  CellTags->"RankOfDFA"],

Cell["Type: function", "Highlight",
  CellTags->"RankOfDFA"],

Cell[TextData[{
  StyleBox["RankOfDFA[M]", "MR"],
  "  computes the rank of the DFA M with respect to the canonical \
enumeration."
}], "Usage",
  CellTags->"RankOfDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["RandomDFA",
    ButtonData:>"RandomDFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["RankToDFA",
    ButtonData:>"RankToDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["RankOfDFA",
    ButtonData:>"RankOfDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RankOfDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RankOfDFA"],

Cell["The rank of a DFA.", "ExampleText",
  CellTags->"RankOfDFA"],

Cell[CellGroupData[{

Cell["m = IthSymbolDFA[b,-2]", "Input",
  CellLabel->"In[147]:=",
  CellTags->"RankOfDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 4, 6, 4, 6, 4, 6}, {3, 5, 7, 5, 7, 5, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({6, 7}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[147]=",
  CellTags->"RankOfDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RankOfDFA[\ m\ ]\)], "Input",
  CellLabel->"In[148]:=",
  CellTags->"RankOfDFA"],

Cell[BoxData[
    \(133835905510368\)], "Output",
  CellLabel->"Out[148]=",
  CellTags->"RankOfDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RankToDFA[\ %, \ 7, \ 2\ ]\)], "Input",
  CellLabel->"In[149]:=",
  CellTags->"RankOfDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 4, 6, 4, 6, 4, 6}, {3, 5, 7, 5, 7, 5, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({7, 6}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[149]=",
  CellTags->"RankOfDFA"]
}, Open  ]]
}, Closed]],

Cell["RankToDFA", "ObjectName",
  CellTags->"RankToDFA"],

Cell["Type: function", "Highlight",
  CellTags->"RankToDFA"],

Cell[TextData[{
  StyleBox["RankToDFA[r,n,k]", "MR"],
  "  computes the DFA of rank r on n states and k symbols with respect to the \
canonical enumeration"
}], "Usage",
  CellTags->"RankToDFA"],

Cell["This can be useful to test algorithms.", "Notes",
  CellTags->"RankToDFA"],

Cell[TextData[{
  "See also ",
  " ",
  ButtonBox["RandomDFA",
    ButtonData:>"RandomDFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  " ",
  ButtonBox["RankOfDFA",
    ButtonData:>"RankOfDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["NumberOfDFA",
    ButtonData:>"NumberOfDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RankToDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RankToDFA"],

Cell["A random DFA.", "ExampleText",
  CellTags->"RankToDFA"],

Cell[CellGroupData[{

Cell["\<\
NumberOfDFA[5,2]
RankToDFA[ Random[Integer,{1,%}], 5, 2 ]\
\>", "Input",
  CellLabel->"In[144]:=",
  CellTags->"RankToDFA"],

Cell[BoxData[
    \(1562500000\)], "Output",
  CellLabel->"Out[144]=",
  CellTags->"RankToDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{3, 4, 2, 1, 1}, {1, 1, 5, 4, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["5",
            (Short[ #, 4]&)], ",", 
          TagBox[\({3, 2, 1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[145]=",
  CellTags->"RankToDFA"]
}, Open  ]]
}, Closed]],

Cell["REEpsQ", "ObjectName",
  CellTags->"REEpsQ"],

Cell["Type: function", "Highlight",
  CellTags->"REEpsQ"],

Cell[TextData[{
  StyleBox["REEpsQ[reg]", "MR"],
  "  tests whether the language denoted by regular expression ",
  StyleBox["reg", "MR"],
  " contains epsilon. "
}], "Usage",
  CellTags->"REEpsQ"],

Cell[TextData[{
  "The regular expression must be proper, i.e., it must be built solely from \
the headers ",
  StyleBox["REP", "MR"],
  ", ",
  StyleBox["RES", "MR"],
  " and ",
  StyleBox["RET", "MR"],
  " (rather than arithmetic operators such as ",
  StyleBox["Plus", "MR"],
  " and ",
  StyleBox["NonCommutativeMultiply", "MR"],
  "). "
}], "Notes",
  CellTags->"REEpsQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToRegExp",
    ButtonData:>"ToRegExp",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"REEpsQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"REEpsQ"],

Cell["Some simple regular expressions. ", "ExampleText",
  CellTags->"REEpsQ"],

Cell[CellGroupData[{

Cell["REEpsQ[ REP[a,b,c] ]", "Input",
  CellLabel->"In[109]:=",
  CellTags->"REEpsQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[109]=",
  CellTags->"REEpsQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell["REEpsQ[ RES[REP[a,b,c]] ]", "Input",
  CellLabel->"In[110]:=",
  CellTags->"REEpsQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[110]=",
  CellTags->"REEpsQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell["REEpsQ[ RET[a,RES[REP[a,b,c]]] ]", "Input",
  CellLabel->"In[111]:=",
  CellTags->"REEpsQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[111]=",
  CellTags->"REEpsQ"]
}, Open  ]]
}, Closed]],

Cell["RegularExpressionToBEFA", "ObjectName",
  CellTags->"RegularExpressionToBEFA"],

Cell["Type: function", "Highlight",
  CellTags->"RegularExpressionToBEFA"],

Cell[TextData[{
  StyleBox["RegularExpressionToBEFA[exp]", "MR"],
  "  computes the BEFA for regular expression ",
  StyleBox["exp", "MR"],
  "."
}], "Usage",
  CellTags->"RegularExpressionToBEFA"],

Cell["This algorithm uses McNaughton-Yamada automata.", "Notes",
  CellTags->"RegularExpressionToBEFA"],

Cell["\<\
The begin/exit automata will in general have epsilon transitions.\
\
\>", "Notes",
  CellTags->"RegularExpressionToBEFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["BEFA",
    ButtonData:>"BEFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RegularExpressionToFA",
    ButtonData:>"RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RegularExpressionToBEFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RegularExpressionToBEFA"],

Cell[TextData[{
  "A regular expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^\(\(\ \)\(*\)\)\) 
        b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  " and the corresponding BEFA."
}], "ExampleText",
  CellTags->"RegularExpressionToBEFA"],

Cell[CellGroupData[{

Cell["re = RET[ RES[REP[a,b]],b,REP[a,b],REP[a,b]]", "Input",
  CellLabel->"In[202]:=",
  CellTags->"RegularExpressionToBEFA"],

Cell[BoxData[
    \(RET[RES[REP[a, b]], b, REP[a, b], REP[a, b]]\)], "Output",
  CellLabel->"Out[202]=",
  CellTags->"RegularExpressionToBEFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RegularExpressionToBEFA[re]\)], "Input",
  CellLabel->"In[204]:=",
  CellTags->"RegularExpressionToBEFA"],

Cell[BoxData[
    \(BEFA[
      7, {{1, \[Epsilon], 2}, {2, "a", 3}, {2, "b", 3}, {2, \[Epsilon], 
          4}, {3, \[Epsilon], 2}, {4, "b", 5}, {5, "a", 6}, {5, "b", 6}, {6, 
          "a", 7}, {6, "b", 7}}]\)], "Output",
  CellLabel->"Out[204]=",
  CellTags->"RegularExpressionToBEFA"]
}, Open  ]]
}, Closed]],

Cell["RegularExpressionToFA", "ObjectName",
  CellTags->"RegularExpressionToFA"],

Cell["Type: function", "Highlight",
  CellTags->"RegularExpressionToFA"],

Cell[TextData[{
  StyleBox["RegularExpressionToFA[exp,K]", "MR"],
  "  computes an FA for regular expression ",
  StyleBox["exp", "MR"],
  " over alphabet ",
  StyleBox["K", "MR"],
  ". "
}], "Usage",
  CellTags->"RegularExpressionToFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"SizeOnly", "\[Rule]", "False", "-"},
          {"EpsElim", "\[Rule]", "True", "-"},
          {"Thompson", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"RegularExpressionToFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Thompson->True", "MR"],
  " will build a Thompson style FA with epsilon-moves. "
}], "Notes",
  CellTags->"RegularExpressionToFA"],

Cell[TextData[{
  "Option ",
  StyleBox["EpsElim->True", "MR"],
  " constructs a Thompson style FA and performs eps-elimination. "
}], "Notes",
  CellTags->"RegularExpressionToFA"],

Cell[TextData[{
  "Option ",
  StyleBox["SizeOnly->True", "MR"],
  " will return the size of the FA without computing it."
}], "Notes",
  CellTags->"RegularExpressionToFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["RegularExpressionToNNFA, RegularExpressionToBEFA.",
    ButtonData:>"RegularExpressionToNNFA, RegularExpressionToBEFA.",
    ButtonStyle->"AddOnsLink"]
}], "Notes",
  CellTags->"RegularExpressionToFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RegularExpressionToFA"],

Cell[TextData[{
  "A regular expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^\(\(\ \)\(*\)\)\) 
        b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  " and the corresponding  FA."
}], "ExampleText",
  CellTags->"RegularExpressionToFA"],

Cell[CellGroupData[{

Cell["re = RET[ RES[REP[a,b]],b,REP[a,b],REP[a,b]]", "Input",
  CellLabel->"In[202]:=",
  CellTags->"RegularExpressionToFA"],

Cell[BoxData[
    \(RET[RES[REP[a, b]], b, REP[a, b], REP[a, b]]\)], "Output",
  CellLabel->"Out[202]=",
  CellTags->"RegularExpressionToFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ RegularExpressionToFA[re]\)], "Input",
  CellLabel->"In[206]:=",
  CellTags->"RegularExpressionToFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"8", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 3}, {1, 2, 4}, {2, 1, 2}, {2, 2, 
                3}, \[LeftSkeleton]5\[RightSkeleton], {4, 2, 6}, {5, 1, 
                7}, {5, 2, 8}, {6, 1, 7}, {6, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[206]=",
  CellTags->"RegularExpressionToFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-5\)]\)], "Input",
  CellLabel->"In[207]:=",
  CellTags->"RegularExpressionToFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[207]=",
  CellTags->"RegularExpressionToFA"]
}, Open  ]],

Cell["\<\
The machine obtained from Thompson's algorithm, without epsilon \
elimination.\
\>", "ExampleText",
  CellTags->"RegularExpressionToFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ 
      RegularExpressionToFA[re, 2, Thompson \[Rule] True, \ 
        EpsElim \[Rule] False]\)], "Input",
  CellLabel->"In[211]:=",
  CellTags->"RegularExpressionToFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"7", ",", "2", ",", 
          
          TagBox[\({{1, 0, 2}, {2, 1, 3}, {2, 2, 3}, {2, 0, 4}, {3, 0, 
                2}, {4, 2, 5}, {5, 1, 6}, {5, 2, 6}, {6, 1, 7}, {6, 2, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({7}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[211]=",
  CellTags->"RegularExpressionToFA"]
}, Open  ]]
}, Closed]],

Cell["RegularExpressionToNNFA", "ObjectName",
  CellTags->"RegularExpressionToNNFA"],

Cell["Type: function", "Highlight",
  CellTags->"RegularExpressionToNNFA"],

Cell[TextData[{
  StyleBox["RegularExpressionToNNFA[exp]", "MR"],
  "  computes the NNFA for regular expression ",
  StyleBox["exp", "MR"],
  "."
}], "Usage",
  CellTags->"RegularExpressionToNNFA"],

Cell["\<\
This algorithm uses McNaughton-Yamada automata (no epsilon \
transitions).\
\>", "Notes",
  CellTags->"RegularExpressionToNNFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["NNFA",
    ButtonData:>"NNFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RegularExpressionToFA",
    ButtonData:>"RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RegularExpressionToNNFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RegularExpressionToNNFA"],

Cell[TextData[{
  "A regular expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^\(\(\ \)\(*\)\)\) 
        b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  " and the corresponding NNFA."
}], "ExampleText",
  CellTags->"RegularExpressionToNNFA"],

Cell[CellGroupData[{

Cell["re = RET[ RES[REP[a,b]],b,REP[a,b],REP[a,b]]", "Input",
  CellLabel->"In[202]:=",
  CellTags->"RegularExpressionToNNFA"],

Cell[BoxData[
    \(RET[RES[REP[a, b]], b, REP[a, b], REP[a, b]]\)], "Output",
  CellLabel->"Out[202]=",
  CellTags->"RegularExpressionToNNFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RegularExpressionToNNFA[re]\)], "Input",
  CellLabel->"In[203]:=",
  CellTags->"RegularExpressionToNNFA"],

Cell[BoxData[
    \(NNFA[
      7, {{1, 1}, {1, 2}, {1, 3}, {2, 1}, {2, 2}, {2, 3}, {3, 4}, {3, 5}, {4, 
          6}, {4, 7}, {5, 6}, {5, 7}}, {"a", "b", "b", "a", "b", "a", 
        "b"}, {1, 2, 3}, {6, 7}, 0]\)], "Output",
  CellLabel->"Out[203]=",
  CellTags->"RegularExpressionToNNFA"]
}, Open  ]]
}, Closed]],

Cell["RemoveTransitionFA", "ObjectName",
  CellTags->"RemoveTransitionFA"],

Cell["Type: function", "Highlight",
  CellTags->"RemoveTransitionFA"],

Cell[TextData[{
  " ",
  StyleBox["RemoveTransitionFA[M,p,w,q]", "MR"],
  " removes the transition ",
  Cell[BoxData[
      \(TraditionalForm\`{p, w, q}\)]],
  " from ",
  StyleBox["M", "MR"],
  ". Here w may be a symbol or an integer. "
}], "Usage",
  CellTags->"RemoveTransitionFA"],

Cell[TextData[{
  "Can also be used in the form ",
  StyleBox["RemoveTransitionFA[M,{p,w,q}]", "MR"],
  " or ",
  StyleBox["RemoveTransitionFA[M,L]", "MR"],
  " where L is a list of transitions. "
}], "Notes",
  CellTags->"RemoveTransitionFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["AddTransitionFA",
    ButtonData:>"AddTransitionFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SwitchTransitionFA",
    ButtonData:>"SwitchTransitionFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RemoveTransitionFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RemoveTransitionFA"],

Cell["A semiautomaton that accepts all words.", "ExampleText",
  CellTags->"RemoveTransitionFA"],

Cell[BoxData[
    \(\(m = 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 1}, {3, 
              1, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[62]:=",
  CellTags->"RemoveTransitionFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinimizeFA[m]\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->"RemoveTransitionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"1", ",", "2", ",", 
          TagBox[\({{1}, {1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[63]=",
  CellTags->"RemoveTransitionFA"]
}, Open  ]],

Cell["\<\
Removing one transition makes the acceptance language significantly \
more complicated.\
\>", "ExampleText",
  CellTags->"RemoveTransitionFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ RemoveTransitionFA[m, 1, 1, 1]\)], "Input",
  CellLabel->"In[71]:=",
  CellTags->"RemoveTransitionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 1, 2}, {3, 2, 
                1}, {4, 1, 4}, {4, 2, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[71]=",
  CellTags->"RemoveTransitionFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MinimizeFA[mm]\)], "Input",
  CellLabel->"In[72]:=",
  CellTags->"RemoveTransitionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"16", ",", "2", ",", 
          
          TagBox[\({{2, 2, 4, 6, 7, 4, 7, 6, 11, 13, 14, 14, 13, 11, 16, 
                16}, {1, 3, 5, 6, 8, 9, 10, 2, 12, 7, 13, 4, 14, 15, 11, 
                16}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[72]=",
  CellTags->"RemoveTransitionFA"]
}, Open  ]]
}, Closed]],

Cell["REQ", "ObjectName",
  CellTags->"REQ"],

Cell["Type: function", "Highlight",
  CellTags->"REQ"],

Cell[TextData[{
  StyleBox["REQ[w,exp]", "MR"],
  "  computes the left quotient rational expression ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\^\(\(-1\)\(\ \)\)\) exp\)]],
  ". Here exp is a proper rational expression and w is a word. "
}], "Usage",
  CellTags->"REQ"],

Cell[TextData[{
  "Note that no attempt at simplification is made (neither for the result nor \
for the intermediate expressions when ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\(\(>\)\(1\)\)\)\)]],
  "). Thus, the size of the expressions may grow exponentially."
}], "Notes",
  CellTags->"REQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["RegularExpressionToFA",
    ButtonData:>"RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"REQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"REQ"],

Cell[TextData[{
  "Removing an initial ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " from all words."
}], "ExampleText",
  CellTags->"REQ"],

Cell[CellGroupData[{

Cell["REQ[ a, RES[REP[a,b] ]]", "Input",
  CellLabel->"In[75]:=",
  CellTags->"REQ"],

Cell[BoxData[
    \(RET[REP[\[Epsilon], Empty], RES[REP[a, b]]]\)], "Output",
  CellLabel->"Out[75]=",
  CellTags->"REQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RESimplify[%]\)], "Input",
  CellLabel->"In[77]:=",
  CellTags->"REQ"],

Cell[BoxData[
    \(RET[\[Epsilon], RES[REP[a, b]]]\)], "Output",
  CellLabel->"Out[77]=",
  CellTags->"REQ"]
}, Open  ]],

Cell[TextData[{
  "Note that the last expression should simplify to ",
  Cell[BoxData[
      \(TraditionalForm\`\((a + b)\)\^\(\(\ \)\(*\)\)\)]],
  "."
}], "ExampleText",
  CellTags->"REQ"]
}, Closed]],

Cell["RESimplify", "ObjectName",
  CellTags->"RESimplify"],

Cell["Type: function", "Highlight",
  CellTags->"RESimplify"],

Cell[TextData[{
  StyleBox["RESimplify[exp]", "MR"],
  "  tries to simplify the regular expression ",
  StyleBox["exp", "MR"],
  " using the rules defined in ",
  StyleBox["$regexrules", "MR"],
  "."
}], "Usage",
  CellTags->"RESimplify"],

Cell["\<\
Uses only rewrite rules and cannot simplify mildly complicated \
expressions. \
\>", "Notes",
  CellTags->"RESimplify"],

Cell[TextData[{
  "See also ",
  ButtonBox["$regexrules",
    ButtonData:>"$regexrules",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RESimplify"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RESimplify"],

Cell["Very primitive simplifications work.", "ExampleText",
  CellTags->"RESimplify"],

Cell[CellGroupData[{

Cell["RESimplify[ RES[REP[a,a]] ]", "Input",
  CellLabel->"In[72]:=",
  CellTags->"RESimplify"],

Cell[BoxData[
    \(RES[a]\)], "Output",
  CellLabel->"Out[72]=",
  CellTags->"RESimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RESimplify[ REP[RES[REP[a,b]],Eps] ]", "Input",
  CellLabel->"In[74]:=",
  CellTags->"RESimplify"],

Cell[BoxData[
    \(RES[REP[a, b]]\)], "Output",
  CellLabel->"Out[74]=",
  CellTags->"RESimplify"]
}, Open  ]]
}, Closed]],

Cell["ReverseFA", "ObjectName",
  CellTags->"ReverseFA"],

Cell["Type: function", "Highlight",
  CellTags->"ReverseFA"],

Cell[TextData[{
  StyleBox["ReverseFA[M]", "MR"],
  "  reverses a FSM ",
  StyleBox["M", "MR"],
  " by flipping transitions and interchanging initial and final states. "
}], "Usage",
  CellTags->"ReverseFA"],

Cell["\<\
The result is an FA or SA, even if the original machine is a DFA.\
\
\>", "Notes",
  CellTags->"ReverseFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ReverseFA"],

Cell[TextData[{
  "A DFA for all words whose 3rd symbol is a ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " and its reversal."
}], "ExampleText",
  CellTags->"ReverseFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = IthSymbolDFA[b, 3, 2]\)], "Input",
  CellLabel->"In[198]:=",
  CellTags->"ReverseFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{2, 3, 5, 4, 5}, {2, 3, 4, 4, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[198]=",
  CellTags->"ReverseFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm = ReverseFA[m]\)], "Input",
  CellLabel->"In[199]:=",
  CellTags->"ReverseFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{2, 1, 1}, {3, 1, 2}, {5, 1, 3}, {4, 1, 4}, {5, 1, 
                5}, {2, 2, 1}, {3, 2, 2}, {4, 2, 3}, {4, 2, 4}, {5, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[199]=",
  CellTags->"ReverseFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ mm, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[200]:=",
  CellTags->"ReverseFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[200]=",
  CellTags->"ReverseFA"]
}, Open  ]]
}, Closed]],

Cell["RightShiftCA", "ObjectName",
  CellTags->"RightShiftCA"],

Cell["Type: function", "Highlight",
  CellTags->"RightShiftCA"],

Cell[TextData[{
  StyleBox["RightShiftCA[k]", "MR"],
  "  returns the right shift cellular automaton over digit alphabet k."
}], "Usage",
  CellTags->"RightShiftCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["LeftShiftCA",
    ButtonData:>"LeftShiftCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RightShiftCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RightShiftCA"],

Cell["The shift.", "ExampleText",
  CellTags->"RightShiftCA"],

Cell[CellGroupData[{

Cell["RightShiftCA[-2]", "Input",
  CellLabel->"In[56]:=",
  CellTags->"RightShiftCA"],

Cell[BoxData[
    \(CA[12, 2, \(-2\)]\)], "Output",
  CellLabel->"Out[56]=",
  CellTags->"RightShiftCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComposeCA[\ LeftShiftCA[\(-2\)], RightShiftCA[\(-2\)]]\)], "Input",
  CellLabel->"In[57]:=",
  CellTags->"RightShiftCA"],

Cell[BoxData[
    \(CA[52428, 4, \(-2\)]\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->"RightShiftCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShrinkCA[%]\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->"RightShiftCA"],

Cell[BoxData[
    \(CA[2, 1, \(-2\)]\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"RightShiftCA"]
}, Open  ]]
}, Closed]],

Cell["SelectFA", "ObjectName",
  CellTags->"SelectFA"],

Cell["Type: function", "Highlight",
  CellTags->"SelectFA"],

Cell[TextData[{
  StyleBox["SelectFA[M,L]", "MR"],
  "  computes the subautomaton of ",
  StyleBox["M", "MR"],
  " induced by the states in ",
  StyleBox["L", "MR"],
  "."
}], "Usage",
  CellTags->"SelectFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SelectFA"],

Cell["L is required to be a list in positional notation.", "Notes",
  CellTags->"SelectFA"],

Cell["\<\
The state set of the original machine is maintained by \
default.\
\>", "Notes",
  CellTags->"SelectFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SelectFA"],

Cell[TextData[{
  "A DFA for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^\(\(\ \)\(*\)\)\) 
        b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  ".  We select the subautomaton with states 8 through 15."
}], "ExampleText",
  CellTags->"SelectFA"],

Cell[BoxData[
    \(\(m = 
        DFA[15, 2, {{2, 4, 6, 8, 10, 12, 14, 8, 10, 12, 14, 8, 10, 12, 
              14}, {3, 5, 7, 9, 11, 13, 15, 9, 11, 13, 15, 9, 11, 13, 15}}, 
          1, {12, 13, 14, 15}];\)\)], "Input",
  CellLabel->"In[193]:=",
  CellTags->"SelectFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ 
      SetInitialFA[\ SelectFA[\ m, \ Range[8, 15]\ ], {1}]\)], "Input",
  CellLabel->"In[194]:=",
  CellTags->"SelectFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"8", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {2, 1, 3}, {3, 1, 5}, {4, 1, 7}, {5, 1, 
                1}, {6, 1, 3}, \[LeftSkeleton]4\[RightSkeleton], {3, 2, 
                6}, {4, 2, 8}, {5, 2, 2}, {6, 2, 4}, {7, 2, 6}, {8, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[194]=",
  CellTags->"SelectFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[mm]\)], "Input",
  CellLabel->"In[195]:=",
  CellTags->"SelectFA"],

Cell[BoxData[
    \({8, 9, 10, 11, 12, 13, 14, 15}\)], "Output",
  CellLabel->"Out[195]=",
  CellTags->"SelectFA"]
}, Open  ]],

Cell["\<\
By choosing the proper initial state we magically obtain an \
equivalent automaton.\
\>", "ExampleText",
  CellTags->"SelectFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ SetInitialFA[\ mm, {1}]\)], "Input",
  CellLabel->"In[196]:=",
  CellTags->"SelectFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"8", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {2, 1, 3}, {3, 1, 5}, {4, 1, 7}, {5, 1, 
                1}, {6, 1, 3}, \[LeftSkeleton]4\[RightSkeleton], {3, 2, 
                6}, {4, 2, 8}, {5, 2, 2}, {6, 2, 4}, {7, 2, 6}, {8, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[196]=",
  CellTags->"SelectFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[m, mm]\)], "Input",
  CellLabel->"In[197]:=",
  CellTags->"SelectFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[197]=",
  CellTags->"SelectFA"]
}, Open  ]]
}, Closed]],

Cell["SetFinalFA", "ObjectName",
  CellTags->"SetFinalFA"],

Cell["Type: function", "Highlight",
  CellTags->"SetFinalFA"],

Cell[TextData[{
  StyleBox["SetFinalFA[m,F]", "MR"],
  "  returns FSM ",
  StyleBox["M", "MR"],
  " with final states changed to ",
  StyleBox["F", "MR"],
  ". "
}], "Usage",
  CellTags->"SetFinalFA"],

Cell[TextData[{
  " ",
  StyleBox["F", "MR"],
  " is required to be a list in positional notation."
}], "Notes",
  CellTags->"SetFinalFA"],

Cell["SAs are converted to FAs.", "Notes",
  CellTags->"SetFinalFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SetInitialFA",
    ButtonData:>"SetInitialFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetInitialFinalFA",
    ButtonData:>"SetInitialFinalFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SetFinalFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SetFinalFA"],

Cell[TextData[{
  "An automaton for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + 
                b)\)\^*\)\ b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  " and the machine obtained by modifying the final states."
}], "ExampleText",
  CellTags->"SetFinalFA"],

Cell[BoxData[
    \(\(m = 
        FA[4, 2, {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[165]:=",
  CellTags->"SetFinalFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetFinalFA[m, {3}]\)], "Input",
  CellLabel->"In[166]:=",
  CellTags->"SetFinalFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[166]=",
  CellTags->"SetFinalFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[%, \(-5\)]\)], "Input",
  CellLabel->"In[167]:=",
  CellTags->"SetFinalFA"],

Cell[BoxData[
    \({{}, {}, {"ba", "bb"}, {"aba", "abb", "bba", "bbb"}, {"aaba", "aabb", 
        "abba", "abbb", "baba", "babb", "bbba", "bbbb"}, {"aaaba", "aaabb", 
        "aabba", "aabbb", "ababa", "ababb", "abbba", "abbbb", "baaba", 
        "baabb", "babba", "babbb", "bbaba", "bbabb", "bbbba", 
        "bbbbb"}}\)], "Output",
  CellLabel->"Out[167]=",
  CellTags->"SetFinalFA"]
}, Open  ]]
}, Open  ]],

Cell["SetInitialFA", "ObjectName",
  CellTags->"SetInitialFA"],

Cell["Type: function", "Highlight",
  CellTags->"SetInitialFA"],

Cell[TextData[{
  StyleBox["SetInitialFinalFA[m,I]", "MR"],
  "  returns FSM ",
  StyleBox["M", "MR"],
  " with initial states changed to ",
  StyleBox["I", "MR"],
  "."
}], "Usage",
  CellTags->"SetInitialFA"],

Cell[TextData[{
  " ",
  StyleBox["I", "MR"],
  " is required to be a list in positional notation."
}], "Notes",
  CellTags->"SetInitialFA"],

Cell["SAs are converted to FAs.", "Notes",
  CellTags->"SetInitialFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SetInitialFinalFA",
    ButtonData:>"SetInitialFinalFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetFinalFA",
    ButtonData:>"SetFinalFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SetInitialFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SetInitialFA"],

Cell[TextData[{
  "An automaton for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + 
                b)\)\^*\)\ b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  " and the machine obtained by modifying the final states."
}], "ExampleText",
  CellTags->"SetInitialFA"],

Cell[BoxData[
    \(\(m = 
        FA[4, 2, {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[165]:=",
  CellTags->"SetInitialFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetInitialFA[m, {2}]\)], "Input",
  CellLabel->"In[168]:=",
  CellTags->"SetInitialFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[168]=",
  CellTags->"SetInitialFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[%, \(-5\)]\)], "Input",
  CellLabel->"In[169]:=",
  CellTags->"SetInitialFA"],

Cell[BoxData[
    \({{}, {}, {"aa", "ab", "ba", "bb"}, {}, {}, {}}\)], "Output",
  CellLabel->"Out[169]=",
  CellTags->"SetInitialFA"]
}, Open  ]]
}, Closed]],

Cell["SetInitialFinalFA", "ObjectName",
  CellTags->"SetInitialFinalFA"],

Cell["Type: function", "Highlight",
  CellTags->"SetInitialFinalFA"],

Cell[TextData[{
  StyleBox["SetInitialFinalFA[m,I,F]", "MR"],
  "  returns FSM ",
  StyleBox["M", "MR"],
  " with initial states changed to ",
  StyleBox["I", "MR"],
  " and final states changed to ",
  StyleBox["F", "MR"],
  ". "
}], "Usage",
  CellTags->"SetInitialFinalFA"],

Cell[TextData[{
  "Both ",
  StyleBox["I", "MR"],
  " and ",
  StyleBox["F", "MR"],
  " are required to be lists in positional notation."
}], "Notes",
  CellTags->"SetInitialFinalFA"],

Cell["SAs are converted to FAs.", "Notes",
  CellTags->"SetInitialFinalFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SetInitialFA",
    ButtonData:>"SetInitialFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetFinalFA",
    ButtonData:>"SetFinalFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SetInitialFinalFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SetInitialFinalFA"],

Cell["\<\
A semiautomaton and the machine obtained by selecting 1 to be the \
initial and final state.\
\>", "ExampleText",
  CellTags->"SetInitialFinalFA"],

Cell[BoxData[
    \(\(m = 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 1}, {3, 
              1, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[161]:=",
  CellTags->"SetInitialFinalFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetInitialFinalFA[m, {1}, {1}]\)], "Input",
  CellLabel->"In[163]:=",
  CellTags->"SetInitialFinalFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 
                1}, {3, 1, 2}, {4, 2, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[163]=",
  CellTags->"SetInitialFinalFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[%, \(-5\)]\)], "Input",
  CellLabel->"In[164]:=",
  CellTags->"SetInitialFinalFA"],

Cell[BoxData[
    \({{\[Epsilon]}, {"a"}, {"aa"}, {"aaa", "bab"}, {"aaaa", "abab", "baba", 
        "bbbb"}, {"aaaaa", "aabab", "ababa", "abbbb", "baaab", "babaa", 
        "bbabb", "bbbba"}}\)], "Output",
  CellLabel->"Out[164]=",
  CellTags->"SetInitialFinalFA"]
}, Open  ]]
}, Closed]],

Cell["ShowAcceptQFA", "ObjectName",
  CellTags->"ShowAcceptQFA"],

Cell["Type: function", "Highlight",
  CellTags->"ShowAcceptQFA"],

Cell[TextData[{
  StyleBox["ShowAcceptQFA[x,M]", "MR"],
  "  produces a tabular trace of the computation of machine ",
  StyleBox["M", "MR"],
  " on input ",
  StyleBox["x", "MR"]
}], "Usage",
  CellTags->"ShowAcceptQFA"],

Cell[TextData[{
  "Pipe through ",
  StyleBox["MatrixForm", "MR"],
  "."
}], "Notes",
  CellTags->"ShowAcceptQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ShowAcceptQFA"],

Cell["The usual suspect.", "ExampleText",
  CellTags->"ShowAcceptQFA"],

Cell[BoxData[
    \(\(m = 
        FA[4, 2, {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[156]:=",
  CellTags->"ShowAcceptQFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowAcceptQFA[\ m, \ abba\ ]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[160]:=",
  CellTags->"ShowAcceptQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1}\), "\<\"a\"\>"},
            {\({1}\), "\<\"b\"\>"},
            {\({1, 2}\), "\<\"b\"\>"},
            {\({1, 2, 3}\), "\<\"a\"\>"},
            {\({1, 3, 4}\), "\<\"-\"\>"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[160]//MatrixForm=",
  CellTags->"ShowAcceptQFA"]
}, Open  ]]
}, Closed]],

Cell["ShrinkCA", "ObjectName",
  CellTags->"ShrinkCA"],

Cell["Type: function", "Highlight",
  CellTags->"ShrinkCA"],

Cell[TextData[{
  StyleBox["ShrinkCA[C]", "MR"],
  "  eliminates the initial and final segment of variables that are \
superfluous in cellular automaton C, if any. "
}], "Usage",
  CellTags->"ShrinkCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ShrinkCA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " also returns the number of deleted variables."
}], "Notes",
  CellTags->"ShrinkCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ShrinkCA"],

Cell["\<\
Composition with the identity CA produces a new CA that has width \
4, but is essentially the same as rule 90. \
\>", "ExampleText",
  CellTags->"ShrinkCA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(IdentityCA[2]\), "\n", 
    \(c = ComposeCA[CA[90], IdentityCA[2]]\), "\n", 
    \(ShrinkCA[c]\)}], "Input",
  CellLabel->"In[114]:=",
  CellTags->"ShrinkCA"],

Cell[BoxData[
    \(CA[12, 2, \(-2\)]\)], "Output",
  CellLabel->"Out[114]=",
  CellTags->"ShrinkCA"],

Cell[BoxData[
    \(CA[13260, 4, \(-2\)]\)], "Output",
  CellLabel->"Out[115]=",
  CellTags->"ShrinkCA"],

Cell[BoxData[
    \(CA[90, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[116]=",
  CellTags->"ShrinkCA"]
}, Open  ]],

Cell["\<\
Shrinking is also useful to check the correctness of the inversion \
algorithm.\
\>", "ExampleText",
  CellTags->"ShrinkCA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(C = CA[3915, 4, \(-2\)];\)\), "\n", 
    \(\(Ci = InverseCA[C];\)\), "\n", 
    \(CC = ComposeCA[C, Ci]\), "\n", 
    \(ShrinkCA[CC]\)}], "Input",
  CellLabel->"In[121]:=",
  AspectRatioFixed->True,
  CellTags->"ShrinkCA"],

Cell[BoxData[
    \(CA[340277174703306882242637262502835978240, 7, \(-2\)]\)], "Output",
  CellLabel->"Out[123]=",
  CellTags->"ShrinkCA"],

Cell[BoxData[
    \(CA[2, 1, \(-2\)]\)], "Output",
  CellLabel->"Out[124]=",
  CellTags->"ShrinkCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintCA[%]\)], "Input",
  CellLabel->"In[125]:=",
  CellTags->"ShrinkCA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("0" \[Rule] "0"\)},
          {\("1" \[Rule] "1"\)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {"0" -> "0", "1" -> "1"}, TableSpacing -> {1, 2}]]], "Output",\

  CellLabel->"Out[125]//TableForm=",
  CellTags->"ShrinkCA"]
}, Open  ]]
}, Closed]],

Cell["ShuffleProductFA", "ObjectName",
  CellTags->"ShuffleProductFA"],

Cell["Type: function", "Highlight",
  CellTags->"ShuffleProductFA"],

Cell[TextData[{
  StyleBox["ShuffleProductFA[M1,M2]", "MR"],
  "  generates a finite state machine that accepts the shuffle product of the \
acceptance languages of FSMs ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  "."
}], "Usage",
  CellTags->"ShuffleProductFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ShuffleProductFA"],

Cell["Uses a product machine construction and is thus quadratic.", "Notes",
  CellTags->"ShuffleProductFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordShuffle",
    ButtonData:>"WordShuffle",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ShuffleProductFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ShuffleProductFA"],

Cell[TextData[{
  "Two machines for words consisting either of all ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s or all ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s.  Their shuffle product ought to be everything."
}], "ExampleText",
  CellTags->"ShuffleProductFA"],

Cell[CellGroupData[{

Cell["\<\
 m1 = CounterDFA[ a, 0, 2 ]
m2 = CounterDFA[ b, 0, 2 ]\
\>", "Input",
  CellLabel->"In[150]:=",
  CellTags->"ShuffleProductFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"2", ",", "2", ",", 
          TagBox[\({{2, 2}, {1, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[150]=",
  CellTags->"ShuffleProductFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"2", ",", "2", ",", 
          TagBox[\({{1, 2}, {2, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[151]=",
  CellTags->"ShuffleProductFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ ShuffleProductFA[m1, m2]\)], "Input",
  CellLabel->"In[153]:=",
  CellTags->"ShuffleProductFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 3}, {1, 2, 1}, {1, 2, 2}, {2, 1, 
                2}, \[LeftSkeleton]2\[RightSkeleton], {3, 1, 3}, {3, 2, 
                3}, {3, 2, 4}, {4, 1, 4}, {4, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[153]=",
  CellTags->"ShuffleProductFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[mm, \(-8\), SizeOnly \[Rule] True\ ]\)], "Input",
  CellLabel->"In[155]:=",
  CellTags->"ShuffleProductFA"],

Cell[BoxData[
    \({1, 2, 4, 8, 16, 32, 64, 128, 256}\)], "Output",
  CellLabel->"Out[155]=",
  CellTags->"ShuffleProductFA"]
}, Open  ]]
}, Closed]],

Cell["SinkQDFA", "ObjectName",
  CellTags->"SinkQDFA"],

Cell["Type: function", "Highlight",
  CellTags->"SinkQDFA"],

Cell[TextData[{
  StyleBox["SinkQDFA[M]", "MR"],
  "  tests whether DFA ",
  StyleBox["M", "MR"],
  " is a sink automaton, i.e., whether the only non-final state of ",
  StyleBox["M", "MR"],
  " is a trap state."
}], "Usage",
  CellTags->"SinkQDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["TheSinkDFA",
    ButtonData:>"TheSinkDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["SinksDFA",
    ButtonData:>"SinksDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SinkQDFA"],

Cell["Further Examples", "ExampleSection",
  CellTags->"SinkQDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SinkQDFA"],

Cell["A machine with two trap states. ", "ExampleText",
  CellTags->"SinkQDFA"],

Cell[BoxData[
    \(\(m\  = \ 
        DFA[4, 2, {{2, 2, 3, 4}, {3, 1, 3, 4}}, 1, {1, 2}];\)\)], "Input",
  CellLabel->"In[65]:=",
  CellTags->"SinkQDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SinkQDFA[m]\)], "Input",
  CellLabel->"In[66]:=",
  CellTags->"SinkQDFA"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[66]=",
  CellTags->"SinkQDFA"]
}, Open  ]],

Cell["Removing state number 4 produces a sink automaton.", "ExampleText",
  CellTags->"SinkQDFA"],

Cell[BoxData[
    \(\(m\  = \ DFA[3, 2, {{2, 2, 3}, {3, 1, 3}}, 1, {1, 2}];\)\)], "Input",
  CellLabel->"In[67]:=",
  CellTags->"SinkQDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SinkQDFA[m]\)], "Input",
  CellLabel->"In[68]:=",
  CellTags->"SinkQDFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[68]=",
  CellTags->"SinkQDFA"]
}, Open  ]]
}, Open  ]],

Cell["SinksDFA", "ObjectName",
  CellTags->"SinksDFA"],

Cell["Type: function", "Highlight",
  CellTags->"SinksDFA"],

Cell[TextData[{
  StyleBox["SinksDFA[M]", "MR"],
  "  returns a list of all sinks in DFA M (in positional notation). "
}], "Usage",
  CellTags->"SinksDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["TheSinkDFA",
    ButtonData:>"TheSinkDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["SinkQDFA",
    ButtonData:>"SinkQDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SinksDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SinksDFA"],

Cell["A machine with two sinks. ", "ExampleText",
  CellTags->"SinksDFA"],

Cell[BoxData[
    \(\(m\  = \ DFA[4, 2, {{2, 2, 3, 4}, {3, 1, 3, 4}}, 1, {2}];\)\)], "Input",\

  CellLabel->"In[59]:=",
  CellTags->"SinksDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(SinksDFA[m]\)\)\)], "Input",
  CellLabel->"In[61]:=",
  CellTags->"SinksDFA"],

Cell[BoxData[
    \({3, 4}\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->"SinksDFA"]
}, Open  ]]
}, Closed]],

Cell["Size", "ObjectName",
  CellTags->"Size"],

Cell["Type: function", "Highlight",
  CellTags->"Size"],

Cell[TextData[{
  StyleBox["Size[M]", "MR"],
  "  returns the number of states of machine M."
}], "Usage",
  CellTags->"Size"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"Size"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"Size"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Size"],

Cell["Extracting the size field.", "ExampleText",
  CellTags->"Size"],

Cell[CellGroupData[{

Cell["IthSymbolDFA[a,-5,2] // Size", "Input",
  CellLabel->"In[68]:=",
  CellTags->"Size"],

Cell[BoxData[
    \(63\)], "Output",
  CellLabel->"Out[68]=",
  CellTags->"Size"]
}, Open  ]]
}, Closed]],

Cell["SquareSA", "ObjectName",
  CellTags->"SquareSA"],

Cell["Type: function", "Highlight",
  CellTags->"SquareSA"],

Cell[TextData[{
  StyleBox["SquareSA[M]", "MR"],
  "  computes the product semiautomaton of semiautomaton ",
  StyleBox["M", "MR"],
  " with itself. "
}], "Usage",
  CellTags->"SquareSA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "0", \(1, 2\)},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", \(0, 1, 2\)}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SquareSA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->1", "MR"],
  "  generates only the part below and including the diagonal. "
}], "Notes",
  CellTags->"SquareSA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->2", "MR"],
  "  generates only the part below the diagonal. "
}], "Notes",
  CellTags->"SquareSA"],

Cell["Used in the classification algorithm for cellular automata.", "Notes",
  CellTags->"SquareSA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ProductFA",
    ButtonData:>"ProductFA",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ClassifyCA",
    ButtonData:>"ClassifyCA",
    ButtonStyle->"AddOnsLink"],
  " . "
}], "Notes",
  CellTags->"SquareSA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SquareSA"],

Cell["A semiautomaton and its square.", "ExampleText",
  CellTags->"SquareSA"],

Cell[BoxData[
    \(\(m = 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 1}, {3, 
              2, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[64]:=",
  CellTags->"SquareSA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SquareSA[m]\)], "Input",
  CellLabel->"In[65]:=",
  CellTags->"SquareSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"16", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {3, 1, 1}, {4, 1, 4}, {9, 1, 1}, {11, 1, 
                1}, \[LeftSkeleton]25\[RightSkeleton], {14, 2, 11}, {14, 2, 
                12}, {15, 2, 10}, {16, 2, 11}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[65]=",
  CellTags->"SquareSA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SquareSA[m, Full \[Rule] 1]\)], "Input",
  CellLabel->"In[66]:=",
  CellTags->"SquareSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"10", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 5}, {2, 2, 6}, {2, 2, 7}, {3, 1, 
                1}, \[LeftSkeleton]11\[RightSkeleton], {8, 2, 5}, {9, 1, 
                4}, {9, 2, 6}, {10, 1, 10}, {10, 2, 8}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[66]=",
  CellTags->"SquareSA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SquareSA[m, Full \[Rule] 2]\)], "Input",
  CellLabel->"In[67]:=",
  CellTags->"SquareSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"6", ",", "2", ",", 
          
          TagBox[\({{1, 2, 4}, {1, 2, 5}, {3, 1, 3}, {3, 2, 4}, {4, 2, 
                4}, {4, 2, 5}, {5, 2, 6}, {6, 1, 3}, {6, 2, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[67]=",
  CellTags->"SquareSA"]
}, Open  ]]
}, Closed]],

Cell["StarFA", "ObjectName",
  CellTags->"StarFA"],

Cell["Type: function", "Highlight",
  CellTags->"StarFA"],

Cell[TextData[{
  StyleBox["StarFA[M]", "MR"],
  "  generates a FA that accepts the Kleene star of the acceptance languages \
of ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"StarFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", \(0, 1, 2\)},
          {"EpsElim", "\[Rule]", "True", "False"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"StarFA"],

Cell[TextData[{
  "Option ",
  StyleBox["EpsElim->False", "MR"],
  " supresses epsilon elimination and returns a machine with epsilon moves."
}], "Notes",
  CellTags->"StarFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["UnionFA",
    ButtonData:>"UnionFA",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["SumFA",
    ButtonData:>"SumFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProductFA",
    ButtonData:>"ProductFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IntersectionFA",
    ButtonData:>"IntersectionFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"StarFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"StarFA"],

Cell[TextData[{
  "Starring a machine for ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " should produce a machine accepting all words."
}], "ExampleText",
  CellTags->"StarFA"],

Cell[CellGroupData[{

Cell["m = BuildDFA[a,b,2]", "Input",
  CellLabel->"In[146]:=",
  CellTags->"StarFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{2, 3, 3}, {2, 3, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[146]=",
  CellTags->"StarFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ StarFA[m]\)], "Input",
  CellLabel->"In[147]:=",
  CellTags->"StarFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{2, 1, 1}, {2, 1, 2}, {2, 1, 3}, {2, 2, 1}, {2, 2, 
                2}, {2, 2, 3}, {3, 1, 4}, {3, 2, 4}, {4, 1, 4}, {4, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[147]=",
  CellTags->"StarFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ mm, \ \(-8\), \ SizeOnly \[Rule] True\ ]\)], "Input",
  CellLabel->"In[148]:=",
  CellTags->"StarFA"],

Cell[BoxData[
    \({1, 2, 4, 8, 16, 32, 64, 128, 256}\)], "Output",
  CellLabel->"Out[148]=",
  CellTags->"StarFA"]
}, Open  ]]
}, Closed]],

Cell["StateMergeDFA", "ObjectName",
  CellTags->"StateMergeDFA"],

Cell["Type: function", "Highlight",
  CellTags->"StateMergeDFA"],

Cell[TextData[{
  StyleBox["StateMergeDFA[M,R]", "MR"],
  "  performs state-merging on a DFA ",
  StyleBox["M", "MR"],
  " according to the equivalence relation represented by list R. "
}], "Usage",
  CellTags->"StateMergeDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"DoTrace", "\[Rule]", "False", "-"},
          {"Hopcroft", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"StateMergeDFA"],

Cell[TextData[{
  StyleBox["StateMergeDFA", "MR"],
  " is used in all minimization algorithms in this package (but they differ \
in how the behavioral equivalence relation is computed)."
}], "Notes",
  CellTags->"StateMergeDFA"],

Cell[TextData[{
  "No tests are performed to check if ",
  StyleBox["R", "MR"],
  " is admissible with respect to ",
  StyleBox["M", "MR"],
  "."
}], "Notes",
  CellTags->"StateMergeDFA"],

Cell[TextData[{
  " ",
  StyleBox["R", "MR"],
  " is required to be represented as an index, as produced for example by ",
  StyleBox["MakeIndex", "MR"],
  ". "
}], "Notes",
  CellTags->"StateMergeDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"StateMergeDFA"],

Cell[TextData[{
  "A DFA for all words of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^*\) 
        b\ \((a + b)\)\^\(\(\ \)\(2\)\)\)]],
  " and an equivalence relation. "
}], "ExampleText",
  CellTags->"StateMergeDFA"],

Cell[BoxData[{
    \(\(m = IthSymbolDFA[b, \(-3\), 2];\)\), "\n", 
    \(\(R\  = \ {1, 1, 2, 1, 2, 3, 4, 1, 2, 3, 4, 5, 6, 7, 8};\)\)}], "Input",\

  CellLabel->"In[122]:=",
  CellTags->"StateMergeDFA"],

Cell["The DFA obtained by merging the corresponding states.", "ExampleText",
  CellTags->"StateMergeDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm = StateMergeDFA[m, R]\)], "Input",
  CellLabel->"In[124]:=",
  CellTags->"StateMergeDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[124]=",
  CellTags->"StateMergeDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[mm, \(-5\)]\)], "Input",
  CellLabel->"In[125]:=",
  CellTags->"StateMergeDFA"],

Cell[BoxData[
    \({{}, {}, {}, {"baa", "bab", "bba", "bbb"}, {"abaa", "abab", "abba", 
        "abbb", "bbaa", "bbab", "bbba", "bbbb"}, {"aabaa", "aabab", "aabba", 
        "aabbb", "abbaa", "abbab", "abbba", "abbbb", "babaa", "babab", 
        "babba", "babbb", "bbbaa", "bbbab", "bbbba", "bbbbb"}}\)], "Output",
  CellLabel->"Out[125]=",
  CellTags->"StateMergeDFA"]
}, Open  ]]
}, Closed]],

Cell["States", "ObjectName",
  CellTags->"States"],

Cell["Type: function", "Highlight",
  CellTags->"States"],

Cell[TextData[{
  StyleBox["States[M]", "MR"],
  "  returns the state set of finite state machine ",
  StyleBox["M", "MR"],
  " "
}], "Usage",
  CellTags->"States"],

Cell[TextData[{
  "Returns the structured state set if it exists, otherwise a list ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], n}\)]],
  ". "
}], "Notes",
  CellTags->"States"],

Cell[TextData[{
  "See also ",
  ButtonBox["Normalize",
    ButtonData:>"Normalize",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NormalizeFA",
    ButtonData:>"NormalizeFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"States"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"States"],

Cell["Some constructors allow for structured state sets. ", "ExampleText",
  CellTags->"States"],

Cell[BoxData[
    \(\(SuffixFA[abc, 3];\)\)], "Input",
  CellLabel->"In[60]:=",
  CellTags->"States"],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[%]\)], "Input",
  CellLabel->"In[61]:=",
  CellTags->"States"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->"States"]
}, Open  ]],

Cell[BoxData[
    \(\(SuffixFA[abc, 3, Normalize \[Rule] 1];\)\)], "Input",
  CellLabel->"In[62]:=",
  CellTags->"States"],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[%]\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->"States"],

Cell[BoxData[
    \({\[Epsilon], "a", "ab", "abc"}\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->"States"]
}, Open  ]]
}, Closed]],

Cell["SubsetQFA", "ObjectName",
  CellTags->"SubsetQFA"],

Cell["Type: function", "Highlight",
  CellTags->"SubsetQFA"],

Cell[TextData[{
  StyleBox["SubsetQFA[M1,M2]", "MR"],
  "  tests whether the acceptance language of ",
  StyleBox["M1", "MR"],
  " is a subset of the acceptance language of ",
  StyleBox["M2", "MR"],
  ". "
}], "Usage",
  CellTags->"SubsetQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SubsetQFA"],

Cell[TextData[{
  "Uses ",
  StyleBox["ToDFA", "MR"],
  " if input is non-deterministic and therefore has potentially exponential \
space and time requirement."
}], "Notes",
  CellTags->"SubsetQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["EquivalentQFA",
    ButtonData:>"EquivalentQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SubsetQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SubsetQFA"],

Cell["\<\
Two machines whose acceptance depends on the length of input words.\
\
\>", "ExampleText",
  CellTags->"SubsetQFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m1 = LengthDFA[{1, 5}, 2]\), "\n", 
    \(m2 = LengthDFA[{1, 3, 5}, 2]\)}], "Input",
  CellLabel->"In[142]:=",
  CellTags->"SubsetQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 6, 7, 7}, {2, 3, 4, 5, 6, 7, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2, 6}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[142]=",
  CellTags->"SubsetQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"7", ",", "2", ",", 
          TagBox[\({{2, 3, 4, 5, 6, 7, 7}, {2, 3, 4, 5, 6, 7, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2, 4, 6}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[143]=",
  CellTags->"SubsetQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubsetQFA[\ m1, m2]\)], "Input",
  CellLabel->"In[144]:=",
  CellTags->"SubsetQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[144]=",
  CellTags->"SubsetQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubsetQFA[\ m2, m1]\)], "Input",
  CellLabel->"In[145]:=",
  CellTags->"SubsetQFA"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[145]=",
  CellTags->"SubsetQFA"]
}, Open  ]]
}, Closed]],

Cell["Substitute", "ObjectName",
  CellTags->"Substitute"],

Cell["Type: function", "Highlight",
  CellTags->"Substitute"],

Cell[TextData[{
  StyleBox["Substitute[eq1,eq2]", "MR"],
  "  substitutes a linear equation ",
  StyleBox["eq2", "MR"],
  " over the language semiring into ",
  StyleBox["eq1", "MR"],
  ". "
}], "Usage",
  CellTags->"Substitute"],

Cell[TextData[{
  "Mildy useful in conjunction with ",
  StyleBox["Arden", "MR"],
  "."
}], "Notes",
  CellTags->"Substitute"],

Cell[TextData[{
  "See also ",
  ButtonBox["Arden",
    ButtonData:>"Arden",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToEquationsDFA",
    ButtonData:>"ToEquationsDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Substitute"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Substitute"],

Cell["A small system of equations. ", "ExampleText",
  CellTags->"Substitute"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ CounterDFA[b, 2, 2]\)], "Input",
  CellLabel->"In[52]:=",
  CellTags->"Substitute"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{1, 2, 3, 4}, {2, 3, 4, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[52]=",
  CellTags->"Substitute"]
}, Open  ]],

Cell[BoxData[
    \(\({e1, e2, e3, e4}\  = \ ToEquationsDFA[m];\)\)], "Input",
  CellLabel->"In[53]:=",
  CellTags->"Substitute"],

Cell[CellGroupData[{

Cell[BoxData[
    \({e1, e2, e3, e4}\ \  // TableForm\)], "Input",
  CellLabel->"In[54]:=",
  CellTags->"Substitute"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("X"\_1 == REP[RET["a", "X"\_1], RET["b", "X"\_2]]\)},
          {\("X"\_2 == REP[RET["a", "X"\_2], RET["b", "X"\_3]]\)},
          {\("X"\_3 == 
              REP[\[Epsilon], RET["a", "X"\_3], RET["b", "X"\_4]]\)},
          {\("X"\_4 == REP[RET["a", "X"\_4], RET["b", "X"\_4]]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Automata`automata`Private`X[ 1], 
          REP[ 
            RET[ "a", 
              Automata`automata`Private`X[ 1]], 
            RET[ "b", 
              Automata`automata`Private`X[ 2]]]], 
        Equal[ 
          Automata`automata`Private`X[ 2], 
          REP[ 
            RET[ "a", 
              Automata`automata`Private`X[ 2]], 
            RET[ "b", 
              Automata`automata`Private`X[ 3]]]], 
        Equal[ 
          Automata`automata`Private`X[ 3], 
          REP[ \[Epsilon], 
            RET[ "a", 
              Automata`automata`Private`X[ 3]], 
            RET[ "b", 
              Automata`automata`Private`X[ 4]]]], 
        Equal[ 
          Automata`automata`Private`X[ 4], 
          REP[ 
            RET[ "a", 
              Automata`automata`Private`X[ 4]], 
            RET[ "b", 
              Automata`automata`Private`X[ 4]]]]}]]], "Output",
  CellLabel->"Out[54]//TableForm=",
  CellTags->"Substitute"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Substitute[e1, e2]\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"Substitute"],

Cell[BoxData[
    \("X"\_1 == 
      REP[RET["a", "X"\_1], RET["ba", "X"\_2], RET["bb", "X"\_3]]\)], "Output",\

  CellLabel->"Out[55]=",
  CellTags->"Substitute"]
}, Open  ]]
}, Closed]],

Cell["SubwordCounterDFA", "ObjectName",
  CellTags->"SubwordCounterDFA"],

Cell["Type: function", "Highlight",
  CellTags->"SubwordCounterDFA"],

Cell[TextData[{
  StyleBox["SubwordCounterDFA[w,p,K,opts]", "MR"],
  "  constructs a DFA that accepts all words ",
  StyleBox["x", "MR"],
  " such that ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(WordBinomial[x, w] = p\),
          "MR"], TraditionalForm]]],
  "  over alphabet K. "
}], "Usage",
  CellTags->"SubwordCounterDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "1"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SubwordCounterDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->1", "MR"],
  " preserves the states as length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\)\)]],
  " vectors over ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1, \[Ellipsis], p - 1}\)]],
  "."
}], "Notes",
  CellTags->"SubwordCounterDFA"],

Cell[TextData[{
  "The number of states in the DFA is bounded by ",
  Cell[BoxData[
      \(TraditionalForm\`p\^\(\(\ \)\(\(|\)\(w\)\(|\)\)\)\)]],
  "."
}], "Notes",
  CellTags->"SubwordCounterDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SubwordDFA",
    ButtonData:>"SubwordDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["SubwordModCounterDFA",
    ButtonData:>"SubwordModCounterDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SubwordCounterDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SubwordCounterDFA"],

Cell["\<\
A subword counter automaton and a trace of a computation of the \
machine.\
\>", "ExampleText",
  CellTags->"SubwordCounterDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = SubwordCounterDFA[abab, 3, 2, Normalize \[Rule] 1];\)\), "\n", 
    \(Size[m]\), "\n", 
    \(States[m]\)}], "Input",
  CellLabel->"In[81]:=",
  AspectRatioFixed->True,
  CellTags->"SubwordCounterDFA"],

Cell[BoxData[
    \(50\)], "Output",
  CellLabel->"Out[82]=",
  CellTags->"SubwordCounterDFA"],

Cell[BoxData[
    \({{0, 0, 0, 0}, {1, 0, 0, 0}, {2, 0, 0, 0}, {1, 1, 0, 0}, {3, 0, 0, 
        0}, {2, 2, 0, 0}, {2, 1, 1, 0}, {1, 2, 0, 0}, {4, 0, 0, 0}, {3, 3, 0, 
        0}, {3, 2, 2, 0}, {2, 4, 0, 0}, {3, 1, 2, 0}, {2, 3, 1, 1}, {2, 2, 2, 
        0}, {1, 3, 0, 0}, {4, 4, 0, 0}, {4, 3, 3, 0}, {3, 4, 0, 0}, {4, 2, 4, 
        0}, {3, 4, 2, 2}, {3, 4, 4, 0}, {4, 1, 3, 0}, {3, 3, 4, 1}, {2, 4, 1, 
        2}, {3, 2, 4, 0}, {2, 4, 2, 2}, {2, 3, 3, 0}, {1, 4, 0, 0}, {4, 4, 4, 
        0}, {4, 3, 4, 0}, {4, 4, 3, 3}, {4, 4, 4, 4}, {4, 4, 4, 2}, {3, 4, 2, 
        4}, {3, 4, 4, 4}, {4, 1, 4, 0}, {4, 3, 4, 1}, {3, 4, 4, 2}, {2, 4, 1, 
        3}, {2, 4, 2, 4}, {3, 3, 4, 0}, {2, 4, 3, 3}, {2, 4, 4, 0}, {4, 4, 4, 
        3}, {4, 4, 3, 4}, {3, 4, 4, 3}, {2, 4, 1, 4}, {2, 4, 3, 4}, {2, 4, 4, 
        4}}\)], "Output",
  CellLabel->"Out[83]=",
  CellTags->"SubwordCounterDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(w = bbaababbbb;\)\), "\n", 
    \(TableForm[AcceptQFA[m, w, DoTrace \[Rule] True]]\)}], "Input",
  CellLabel->"In[84]:=",
  AspectRatioFixed->True,
  CellTags->"SubwordCounterDFA"],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "0", "0", "0"},
          {"0", "0", "0", "0"},
          {"0", "0", "0", "0"},
          {"1", "0", "0", "0"},
          {"2", "0", "0", "0"},
          {"2", "2", "0", "0"},
          {"3", "2", "2", "0"},
          {"3", "4", "2", "2"},
          {"3", "4", "2", "4"},
          {"3", "4", "2", "4"},
          {"3", "4", "2", "4"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[85]//TableForm=",
  CellTags->"SubwordCounterDFA"]
}, Open  ]]
}, Closed]],

Cell["SubwordDFA", "ObjectName",
  CellTags->"SubwordDFA"],

Cell["Type: function", "Highlight",
  CellTags->"SubwordDFA"],

Cell[TextData[{
  StyleBox["SubwordDFA[w,K]", "MR"],
  "  constructs a DFA that accepts all words that contain subword ",
  StyleBox["w", "MR"],
  "  over alphabet ",
  StyleBox["K", "MR"],
  "."
}], "Usage",
  CellTags->"SubwordDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "1"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SubwordDFA"],

Cell[TextData[{
  "The structured state set consists of the prefixes of ",
  StyleBox["w", "MR"],
  "."
}], "Notes",
  CellTags->"SubwordDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SubwordCounterDFA",
    ButtonData:>"SubwordCounterDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["SubwordModCounterDFA",
    ButtonData:>"SubwordModCounterDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SubwordDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SubwordDFA"],

Cell["A DFA for all words containing the subword abb. ", "ExampleText",
  CellTags->"SubwordDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = SubwordDFA[abb, {a, b}, Normalize \[Rule] 1]\)], "Input",
  CellLabel->"In[92]:=",
  CellTags->"SubwordDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{2, 2, 3, 4}, {1, 3, 4, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[92]=",
  CellTags->"SubwordDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[m]\)], "Input",
  CellLabel->"In[93]:=",
  CellTags->"SubwordDFA"],

Cell[BoxData[
    \({\[Epsilon], "a", "ab", "abb"}\)], "Output",
  CellLabel->"Out[93]=",
  CellTags->"SubwordDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-5\)]\)], "Input",
  CellLabel->"In[89]:=",
  CellTags->"SubwordDFA"],

Cell[BoxData[
    \({{}, {}, {}, {"abb"}, {"aabb", "abab", "abba", "abbb", 
        "babb"}, {"aaabb", "aabab", "aabba", "aabbb", "abaab", "ababa", 
        "ababb", "abbaa", "abbab", "abbba", "abbbb", "baabb", "babab", 
        "babba", "babbb", "bbabb"}}\)], "Output",
  CellLabel->"Out[89]=",
  CellTags->"SubwordDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordBinomial[Flatten[%], abb]\)], "Input",
  CellLabel->"In[90]:=",
  CellTags->"SubwordDFA"],

Cell[BoxData[
    \({1, 2, 1, 1, 3, 1, 3, 2, 2, 6, 1, 1, 4, 1, 3, 3, 6, 2, 1, 1, 3, 
      1}\)], "Output",
  CellLabel->"Out[90]=",
  CellTags->"SubwordDFA"]
}, Open  ]]
}, Closed]],

Cell["SubwordModCounterDFA", "ObjectName",
  CellTags->"SubwordModCounterDFA"],

Cell["Type: function", "Highlight",
  CellTags->"SubwordModCounterDFA"],

Cell[TextData[{
  StyleBox["SubwordModCounterDFA[w,r,p,K]", "MR"],
  "  constructs a DFA that accepts all words x such that ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(WordBinomial[x, w] = r\ \((mod\ p)\)\),
          "MR"], TraditionalForm]]],
  "  over alphabet K. "
}], "Usage",
  CellTags->"SubwordModCounterDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "1"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SubwordModCounterDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->1", "MR"],
  " preserves the states as length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\)\)]],
  " vectors over ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1, \[Ellipsis], p, p + 1}\)]],
  "."
}], "Notes",
  CellTags->"SubwordModCounterDFA"],

Cell[TextData[{
  "The number of states in the DFA is bounded by ",
  Cell[BoxData[
      \(TraditionalForm\`\((p + 2)\)\^\(\(|\)\(w\)\(|\)\)\)]],
  "."
}], "Notes",
  CellTags->"SubwordModCounterDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SubwordCounterDFA",
    ButtonData:>"SubwordCounterDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["SubwordDFA",
    ButtonData:>"SubwordDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SubwordModCounterDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SubwordModCounterDFA"],

Cell["\<\
A machine for all words containing a multiple of 3 occurrences of \
ab.\
\>", "ExampleText",
  CellTags->"SubwordModCounterDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = SubwordModCounterDFA[ab, 0, 3]\)], "Input",
  CellLabel->"In[72]:=",
  CellTags->"SubwordModCounterDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"9", ",", "2", ",", 
          
          TagBox[\({{2, 3, 1, 6, 8, 9, 5, 7, 4}, {1, 4, 5, 7, 6, 3, 2, 8, 
                9}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[72]=",
  CellTags->"SubwordModCounterDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, 5]\)], "Input",
  CellLabel->"In[74]:=",
  CellTags->"SubwordModCounterDFA"],

Cell[BoxData[
    \({"aaaaa", "aaaba", "aaabb", "aabbb", "ababa", "abbba", "baaaa", 
      "baaab", "babab", "babbb", "bbaaa", "bbbaa", "bbbba", 
      "bbbbb"}\)], "Output",
  CellLabel->"Out[74]=",
  CellTags->"SubwordModCounterDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordBinomial[%, ab]\)], "Input",
  CellLabel->"In[75]:=",
  CellTags->"SubwordModCounterDFA"],

Cell[BoxData[
    \({0, 3, 6, 6, 3, 3, 0, 3, 3, 3, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[75]=",
  CellTags->"SubwordModCounterDFA"]
}, Open  ]]
}, Closed]],

Cell["SuffixesFA", "ObjectName",
  CellTags->"SuffixesFA"],

Cell["Type: function", "Highlight",
  CellTags->"SuffixesFA"],

Cell[TextData[{
  StyleBox["SuffixesFA[w,K]", "MR"],
  "  constructs an FA that accepts all suffixes of word ",
  StyleBox["w", "MR"],
  "  over alphabet ",
  StyleBox["K", "MR"],
  " ."
}], "Usage",
  CellTags->"SuffixesFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SuffixesFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SuffixFA",
    ButtonData:>"SuffixFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SuffixesFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SuffixesFA"],

Cell["A machine for all suffixes of abcabc.", "ExampleText",
  CellTags->"SuffixesFA"],

Cell[CellGroupData[{

Cell["SuffixesFA[ abcabc, 3 ]", "Input",
  CellLabel->"In[139]:=",
  CellTags->"SuffixesFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"7", ",", "3", ",", 
          
          TagBox[\({{1, 1, 2}, {2, 2, 3}, {3, 3, 4}, {4, 1, 5}, {5, 2, 
                6}, {6, 3, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4, 5, 6, 7}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({7}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[139]=",
  CellTags->"SuffixesFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ %, \(-7\)\ ]\)], "Input",
  CellLabel->"In[140]:=",
  CellTags->"SuffixesFA"],

Cell[BoxData[
    \({{\[Epsilon]}, {"c"}, {"bc"}, {"abc"}, {"cabc"}, {"bcabc"}, {"abcabc"}, \
{}}\)], "Output",
  CellLabel->"Out[140]=",
  CellTags->"SuffixesFA"]
}, Open  ]]
}, Closed]],

Cell["SuffixFA", "ObjectName",
  CellTags->"SuffixFA"],

Cell["Type: function", "Highlight",
  CellTags->"SuffixFA"],

Cell[TextData[{
  StyleBox["SuffixFA[w,K]", "MR"],
  "  constructs an FA that accepts all words with suffix ",
  StyleBox["w", "MR"],
  "  over alphabet ",
  StyleBox["K", "MR"],
  " ."
}], "Usage",
  CellTags->"SuffixFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SuffixFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["PrefixFA, ToSuffixFA, ToPrefixFA.",
    ButtonData:>"PrefixFA, ToSuffixFA, ToPrefixFA.",
    ButtonStyle->"AddOnsLink"]
}], "Notes",
  CellTags->"SuffixFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SuffixFA"],

Cell["A machine for all words ending in bbb.", "ExampleText",
  CellTags->"SuffixFA"],

Cell[CellGroupData[{

Cell["SuffixFA[bbb,2]", "Input",
  CellLabel->"In[137]:=",
  CellTags->"SuffixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 2, 3}, {3, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[137]=",
  CellTags->"SuffixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[%, \(-5\)]\)], "Input",
  CellLabel->"In[138]:=",
  CellTags->"SuffixFA"],

Cell[BoxData[
    \({{}, {}, {}, {"bbb"}, {"abbb", "bbbb"}, {"aabbb", "abbbb", "babbb", 
        "bbbbb"}}\)], "Output",
  CellLabel->"Out[138]=",
  CellTags->"SuffixFA"]
}, Open  ]]
}, Open  ]],

Cell["SumFA", "ObjectName",
  CellTags->"SumFA"],

Cell["Type: function", "Highlight",
  CellTags->"SumFA"],

Cell[TextData[{
  StyleBox["SumFA[M1,M2]", "MR"],
  "  computes the disjoint sum of two machines ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  ". "
}], "Usage",
  CellTags->"SumFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->1", "MR"],
  " preservers the state set as a disjoint union."
}], "Notes",
  CellTags->"SumFA"],

Cell["Is polyadic.", "Notes",
  CellTags->"SumFA"],

Cell["\<\
Has linear time complexity even for DFAs (but produces a \
nondeterministic machine as output). \
\>", "Notes",
  CellTags->"SumFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["UnionFA",
    ButtonData:>"UnionFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProductFA",
    ButtonData:>"ProductFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IntersectionFA",
    ButtonData:>"IntersectionFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SumFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SumFA"],

Cell["\<\
The disjoint union construction produces an FA even if the input \
machines are both DFAs.\
\>", "ExampleText",
  CellTags->"SumFA"],

Cell[CellGroupData[{

Cell["\<\
m1 = BuildDFA[aaa,2]
m2 = BuildDFA[bbb,2]
m = SumFA[ m1, m2 ]\
\>", "Input",
  CellLabel->"In[59]:=",
  CellTags->"SumFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{2, 4, 3, 5, 3}, {3, 3, 3, 3, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[59]=",
  CellTags->"SumFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{2, 2, 2, 2, 2}, {3, 2, 4, 5, 2}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[60]=",
  CellTags->"SumFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"10", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {2, 1, 4}, {3, 1, 3}, {4, 1, 5}, {5, 1, 
                3}, \[LeftSkeleton]10\[RightSkeleton], {6, 2, 8}, {7, 2, 
                7}, {8, 2, 9}, {9, 2, 10}, {10, 2, 7}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 6}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 10}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[61]=",
  CellTags->"SumFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-5\)]\)], "Input",
  CellLabel->"In[62]:=",
  CellTags->"SumFA"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa", "bbb"}, {}, {}}\)], "Output",
  CellLabel->"Out[62]=",
  CellTags->"SumFA"]
}, Open  ]],

Cell[TextData[{
  StyleBox["UnionFA", "MR"],
  " will produce a DFA for the union of the languages."
}], "ExampleText",
  CellTags->"SumFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\ \  = \ UnionFA[m1, m2]\)], "Input",
  CellLabel->"In[65]:=",
  CellTags->"SumFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"8", ",", "2", ",", 
          TagBox[\({{2, 7, 3, 3, 3, 3, 8, 3}, {4, 3, 3, 5, 6, 3, 3, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({6, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[65]=",
  CellTags->"SumFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[m, mm]\)], "Input",
  CellLabel->"In[66]:=",
  CellTags->"SumFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[66]=",
  CellTags->"SumFA"]
}, Open  ]]
}, Closed]],

Cell["SwitchTransitionFA", "ObjectName",
  CellTags->"SwitchTransitionFA"],

Cell["Type: function", "Highlight",
  CellTags->"SwitchTransitionFA"],

Cell[TextData[{
  StyleBox["SwitchTransitionFA[M,p,q]", "MR"],
  "  switches the transition ",
  StyleBox["{p,w,q}", "MR"],
  " in M to ",
  StyleBox["{p,w+1,q}", "MR"],
  ". Here ",
  StyleBox["w+1", "MR"],
  " denotes the successor of ",
  StyleBox["w", "MR"],
  " in the alphabet of the machine. "
}], "Usage",
  CellTags->"SwitchTransitionFA"],

Cell[TextData[{
  "Can also be used in the form ",
  StyleBox["SwitchTransitionFA[M,{p,q}] ", "MR"],
  "or ",
  StyleBox["SwitchTransitionFA[M,L]", "MR"],
  " where L is a list of pairs of states. "
}], "Notes",
  CellTags->"SwitchTransitionFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["AddTransitionFA",
    ButtonData:>"AddTransitionFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["RemoveTransitionFA",
    ButtonData:>"RemoveTransitionFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SwitchTransitionFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SwitchTransitionFA"],

Cell["\<\
A permutation automaton and a 1-permutation automaton. The latter \
demonstrates exponential blow-up during deterministic simulation.\
\>", \
"ExampleText",
  CellTags->"SwitchTransitionFA"],

Cell[BoxData[
    \(\(m = 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 1}, {3, 
              1, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[121]:=",
  CellTags->"SwitchTransitionFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m1\  = \ SwitchTransitionFA[m, 1, 1]\)], "Input",
  CellLabel->"In[126]:=",
  CellTags->"SwitchTransitionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 1, 
                2}, {3, 2, 1}, {4, 1, 4}, {4, 2, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[126]=",
  CellTags->"SwitchTransitionFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToDFA[m1]\  // \ Size\)], "Input",
  CellLabel->"In[125]:=",
  CellTags->"SwitchTransitionFA"],

Cell[BoxData[
    \(16\)], "Output",
  CellLabel->"Out[125]=",
  CellTags->"SwitchTransitionFA"]
}, Open  ]]
}, Closed]],

Cell["SyntacticCongruence", "ObjectName",
  CellTags->"SyntacticCongruence"],

Cell["Type: function", "Highlight",
  CellTags->"SyntacticCongruence"],

Cell[TextData[{
  StyleBox["SyntacticCongruence[M,r]", "MR"],
  "  determines the syntactic congruence classes of all words of length ",
  StyleBox["r", "MR"],
  ". "
}], "Usage",
  CellTags->"SyntacticCongruence"],

Cell[TextData[{
  "Can also be used in the form ",
  StyleBox["SyntacticCongruence[gen,r]", "MR"],
  " where ",
  StyleBox["gen", "MR"],
  " is a generator object."
}], "Notes",
  CellTags->"SyntacticCongruence"],

Cell[TextData[{
  "See also ",
  ButtonBox["SyntacticSG",
    ButtonData:>"SyntacticSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["ToGeneratorsFA",
    ButtonData:>"ToGeneratorsFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["GEN",
    ButtonData:>"GEN",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"SyntacticCongruence"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SyntacticCongruence"],

Cell["\<\
A counting machine and its syntactic congruence classes for words \
of length 3.\
\>", "ExampleText",
  CellTags->"SyntacticCongruence"],

Cell[CellGroupData[{

Cell["m = ModCounterDFA[ b,0,3,2]", "Input",
  CellLabel->"In[59]:=",
  CellTags->"SyntacticCongruence"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 2, 3}, {2, 3, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[59]=",
  CellTags->"SyntacticCongruence"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sc\  = \ SyntacticCongruence[m, 3]\)], "Input",
  CellLabel->"In[73]:=",
  CellTags->"SyntacticCongruence"],

Cell[BoxData[
    \({{"aaa", "bbb"}, {"aab", "aba", "baa"}, {"abb", "bab", 
        "bba"}}\)], "Output",
  CellLabel->"Out[73]=",
  CellTags->"SyntacticCongruence"]
}, Open  ]],

Cell["The equivalence is induced by the syntactic homomorphism.", \
"ExampleText",
  CellTags->"SyntacticCongruence"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SyntacticHomomorphism[f, m]\), "\n", 
    \(Map[\ f, \ sc, \ {1}\ ]\)}], "Input",
  CellLabel->"In[75]:=",
  CellTags->"SyntacticCongruence"],

Cell[BoxData[
    \({{T[1, 2, 3], T[1, 2, 3]}, {T[2, 3, 1], T[2, 3, 1], 
        T[2, 3, 1]}, {T[3, 1, 2], T[3, 1, 2], T[3, 1, 2]}}\)], "Output",
  CellLabel->"Out[76]=",
  CellTags->"SyntacticCongruence"]
}, Open  ]]
}, Closed]],

Cell["SyntacticHomomorphism", "ObjectName",
  CellTags->"SyntacticHomomorphism"],

Cell["Type: function", "Highlight",
  CellTags->"SyntacticHomomorphism"],

Cell[TextData[{
  StyleBox["SyntacticHomomorphism[f,M]", "MR"],
  "  assigns the syntactic homomorphism to symbol ",
  StyleBox["f", "MR"],
  ". "
}], "Usage",
  CellTags->"SyntacticHomomorphism"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["HoldFirst", "MR"],
  "."
}], "Notes",
  CellTags->"SyntacticHomomorphism"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f\  : \ \(K\^*\)\ \[LongRightArrow]\ S\)]],
  " is the natural homomorphism from the set of all words to the transition \
semigroup of DFA ",
  StyleBox["M", "MR"],
  "."
}], "Notes",
  CellTags->"SyntacticHomomorphism"],

Cell[TextData[{
  "See also ",
  ButtonBox["SyntacticSG",
    ButtonData:>"SyntacticSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["ToGeneratorsFA",
    ButtonData:>"ToGeneratorsFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"SyntacticHomomorphism"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SyntacticHomomorphism"],

Cell["A counting machine and its syntactic homomorphism.", "ExampleText",
  CellTags->"SyntacticHomomorphism"],

Cell[CellGroupData[{

Cell["m = ModCounterDFA[ b,0,3,2]", "Input",
  CellLabel->"In[59]:=",
  CellTags->"SyntacticHomomorphism"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 2, 3}, {2, 3, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[59]=",
  CellTags->"SyntacticHomomorphism"]
}, Open  ]],

Cell[BoxData[
    \(SyntacticHomomorphism[f, m]\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->"SyntacticHomomorphism"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[b]\)], "Input",
  CellLabel->"In[65]:=",
  CellTags->"SyntacticHomomorphism"],

Cell[BoxData[
    \(T[2, 3, 1]\)], "Output",
  CellLabel->"Out[65]=",
  CellTags->"SyntacticHomomorphism"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(f[bbb]\), "\n", 
    \(f[a]\)}], "Input",
  CellLabel->"In[67]:=",
  CellTags->"SyntacticHomomorphism"],

Cell[BoxData[
    \(T[1, 2, 3]\)], "Output",
  CellLabel->"Out[67]=",
  CellTags->"SyntacticHomomorphism"],

Cell[BoxData[
    \(T[1, 2, 3]\)], "Output",
  CellLabel->"Out[68]=",
  CellTags->"SyntacticHomomorphism"]
}, Open  ]]
}, Closed]],

Cell["SyntacticSG", "ObjectName",
  CellTags->"SyntacticSG"],

Cell["Type: function", "Highlight",
  CellTags->"SyntacticSG"],

Cell[TextData[{
  StyleBox["SyntacticSG[M]", "MR"],
  "  generates the transition semigroup of ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"SyntacticSG"],

Cell[TextData[{
  "Make sure to minimize ",
  StyleBox["M", "MR"],
  " to obtain the syntactic semigroup of the acceptance language of ",
  StyleBox["M", "MR"],
  "."
}], "Notes",
  CellTags->"SyntacticSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["ToGeneratorsFA",
    ButtonData:>"ToGeneratorsFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"SyntacticSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SyntacticSG"],

Cell["\<\
A counting machine and it syntactic semigroup, which happens to be \
a group.\
\>", "ExampleText",
  CellTags->"SyntacticSG"],

Cell[CellGroupData[{

Cell["m = ModCounterDFA[ b,0,3,2]", "Input",
  CellLabel->"In[59]:=",
  CellTags->"SyntacticSG"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 2, 3}, {2, 3, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[59]=",
  CellTags->"SyntacticSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SyntacticSG[m]\)], "Input",
  CellLabel->"In[60]:=",
  CellTags->"SyntacticSG"],

Cell[BoxData[
    \(SG[T[1, 2, 3], T[2, 3, 1], T[3, 1, 2]]\)], "Output",
  CellLabel->"Out[60]=",
  CellTags->"SyntacticSG"]
}, Open  ]]
}, Closed]],

Cell["TheInitial", "ObjectName",
  CellTags->"TheInitial"],

Cell["Type: function", "Highlight",
  CellTags->"TheInitial"],

Cell[TextData[{
  StyleBox["TheInitial[M]", "MR"],
  "  returns the initial state of a DFA ",
  StyleBox["M", "MR"],
  " in positional notation."
}], "Usage",
  CellTags->"TheInitial"],

Cell[TextData[{
  "See also ",
  ButtonBox["Initial",
    ButtonData:>"Initial",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TheInitial"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TheInitial"],

Cell["Most algorithms produce DFAs whose initial state is 1.", "ExampleText",
  CellTags->"TheInitial"],

Cell[CellGroupData[{

Cell["m = ModCounterDFA[b,2,3,3]", "Input",
  CellLabel->"In[57]:=",
  CellTags->"TheInitial"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "3", ",", 
          TagBox[\({{1, 2, 3}, {2, 3, 1}, {1, 2, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[57]=",
  CellTags->"TheInitial"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TheInitial[m]\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->"TheInitial"],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"TheInitial"]
}, Open  ]]
}, Closed]],

Cell["TheSinkDFA", "ObjectName",
  CellTags->"TheSinkDFA"],

Cell["Type: function", "Highlight",
  CellTags->"TheSinkDFA"],

Cell[TextData[{
  StyleBox["TheSinkDFA[M]", "MR"],
  " returns the position of the first sink (trap state) in the state list, or \
0 if no sink exists. "
}], "Usage",
  CellTags->"TheSinkDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SinkQDFA",
    ButtonData:>"SinkQDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["SinksDFA",
    ButtonData:>"SinksDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TheSinkDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TheSinkDFA"],

Cell["A machine with two sinks. ", "ExampleText",
  CellTags->"TheSinkDFA"],

Cell[BoxData[
    \(\(m\  = \ DFA[4, 2, {{2, 2, 3, 4}, {3, 1, 3, 4}}, 1, {2}];\)\)], "Input",\

  CellLabel->"In[59]:=",
  CellTags->"TheSinkDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TheSinkDFA[m]\)], "Input",
  CellLabel->"In[60]:=",
  CellTags->"TheSinkDFA"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[60]=",
  CellTags->"TheSinkDFA"]
}, Open  ]]
}, Closed]],

Cell["ToBlocks", "ObjectName",
  CellTags->"ToBlocks"],

Cell["Type: function", "Highlight",
  CellTags->"ToBlocks"],

Cell[TextData[{
  StyleBox["ToBlocks[L,w]", "MR"],
  "  partitions a list ",
  StyleBox["L", "MR"],
  " into a list of overlapping blocks of width w (with offset 1). "
}], "Usage",
  CellTags->"ToBlocks"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[
      RowBox[{GridBox[{
            {"Boundary", "\[Rule]", "Cyclic", "Fixed"}
            },
          ColumnWidths->Automatic,
          ColumnAlignments->{Left}], ",", "None", ",", "pelm"}]]]
}], "Notes",
  CellTags->"ToBlocks"],

Cell[TextData[{
  "Option ",
  StyleBox["Boundary->pelm", "MR"],
  "  uses a padding element. "
}], "Notes",
  CellTags->"ToBlocks"],

Cell[TextData[{
  "Has default ",
  StyleBox["Boundary->Cyclic", "MR"],
  ", alternatively ",
  StyleBox["Fixed", "MR"],
  ", a padding element, or None. "
}], "Notes",
  CellTags->"ToBlocks"],

Cell[TextData[{
  "Also works when ",
  StyleBox["L", "MR"],
  " is a word rather than a list, returns a list of words."
}], "Notes",
  CellTags->"ToBlocks"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToBlocks"],

Cell["Breaking a list into blocks.", "ExampleText",
  CellTags->"ToBlocks"],

Cell[CellGroupData[{

Cell["ToBlocks[ Range[5], 3 ]", "Input",
  CellLabel->"In[53]:=",
  CellTags->"ToBlocks"],

Cell[BoxData[
    \({{5, 1, 2}, {1, 2, 3}, {2, 3, 4}, {3, 4, 5}, {4, 5, 1}}\)], "Output",
  CellLabel->"Out[53]=",
  CellTags->"ToBlocks"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToBlocks[ Range[5], 3, Boundary->Fixed ]", "Input",
  CellLabel->"In[54]:=",
  CellTags->"ToBlocks"],

Cell[BoxData[
    \({{0, 1, 2}, {1, 2, 3}, {2, 3, 4}, {3, 4, 5}, {4, 5, 0}}\)], "Output",
  CellLabel->"Out[54]=",
  CellTags->"ToBlocks"]
}, Open  ]],

Cell["Also works on words.", "ExampleText",
  CellTags->"ToBlocks"],

Cell[CellGroupData[{

Cell["ToBlocks[ \"abcde\", 3  ]", "Input",
  CellLabel->"In[56]:=",
  CellTags->"ToBlocks"],

Cell[BoxData[
    \({"eab", "abc", "bcd", "cde", "dea"}\)], "Output",
  CellLabel->"Out[56]=",
  CellTags->"ToBlocks"]
}, Open  ]]
}, Closed]],

Cell["ToCharacters", "ObjectName",
  CellTags->"ToCharacters"],

Cell["Type: function", "Highlight",
  CellTags->"ToCharacters"],

Cell[TextData[{
  StyleBox["ToCharacters[w]", "MR"],
  "  converts symbols and strings to a list of atomic characters "
}], "Usage",
  CellTags->"ToCharacters"],

Cell[TextData[{
  "Similar to the built-in command ",
  StyleBox["Characters", "MR"],
  " (which works for strings only). "
}], "Notes",
  CellTags->"ToCharacters"],

Cell["Behaves properly with respect to epsilon.", "Notes",
  CellTags->"ToCharacters"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToCharacters"],

Cell["\<\
Can be directly applied to symbols, without stringifying \
first.\
\>", "ExampleText",
  CellTags->"ToCharacters"],

Cell[CellGroupData[{

Cell["\<\
ToCharacters[aabb]
% // FullForm\
\>", "Input",
  CellLabel->"In[51]:=",
  CellTags->"ToCharacters"],

Cell[BoxData[
    \({"a", "a", "b", "b"}\)], "Output",
  CellLabel->"Out[51]=",
  CellTags->"ToCharacters"],

Cell[BoxData[
    TagBox[
      StyleBox[\(List["\<a\>", "\<a\>", "\<b\>", "\<b\>"]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[52]//FullForm=",
  CellTags->"ToCharacters"]
}, Open  ]]
}, Closed]],

Cell["ToDFA", "ObjectName",
  CellTags->"ToDFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToDFA"],

Cell[TextData[{
  StyleBox["ToDFA[M]", "MR"],
  "  converts a finite state machine into an equivalent DFA. "
}], "Usage",
  CellTags->"ToDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"SizeOnly", "\[Rule]", "False", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->1", "MR"],
  " preserves states as elements of power set of ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\)]],
  "."
}], "Notes",
  CellTags->"ToDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->2", "MR"],
  " preserves states as elements of power set of the state set of M. "
}], "Notes",
  CellTags->"ToDFA"],

Cell["\<\
Note the in particular the last option may increase the size of the \
date structure representing the automaton considerably (internally as well as \
externally). \
\>", "Notes",
  CellTags->"ToDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " causes the whole power automaton of size ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)]],
  " to be constructed. Only in internal implementation."
}], "Notes",
  CellTags->"ToDFA"],

Cell[TextData[{
  "Option ",
  StyleBox["SizeOnly->True", "MR"],
  " returns only the size of the power automaton. "
}], "Notes",
  CellTags->"ToDFA"],

Cell["\<\
The algorithm uses the Rabin-Scott subset construction and has \
potentially exponential time and space complexity.\
\>", "Notes",
  CellTags->"ToDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToSA",
    ButtonData:>"ToSA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToFA",
    ButtonData:>"ToFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToNFA",
    ButtonData:>"ToNFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToDFA"],

Cell["\<\
A nondeterministic machine and the corresponding DFA. Note the \
exponential increase in size. \
\>", "ExampleText",
  CellTags->"ToDFA"],

Cell[BoxData[
    \(FormatAutomata[Automatic]\)], "Input",
  CellLabel->"In[173]:=",
  CellTags->"ToDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = IthSymbolFA[a, \(-9\)]\), "\n", 
    \(mm\  = \ ToDFA[\ m\ ]\)}], "Input",
  CellLabel->"In[133]:=",
  CellTags->"ToDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"10", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 
                4}, \[LeftSkeleton]5\[RightSkeleton], {6, 2, 7}, {7, 1, 
                8}, {7, 2, 8}, {8, 1, 9}, {8, 2, 9}, {9, 1, 10}, {9, 2, 
                10}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({10}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[133]=",
  CellTags->"ToDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"512", ",", "2", ",", 
          
          TagBox[\({\[LeftSkeleton]1\[RightSkeleton], \[LeftSkeleton]1\
\[RightSkeleton]}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          
          TagBox[\({257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
              268, 269, 270, \[LeftSkeleton]228\[RightSkeleton], 499, 500, 
              501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[134]=",
  CellTags->"ToDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[m, mm]\)], "Input",
  CellLabel->"In[176]:=",
  CellTags->"ToDFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[176]=",
  CellTags->"ToDFA"]
}, Open  ]],

Cell["We can preserve the structure of the state set of the DFA. ", \
"ExampleText",
  CellTags->"ToDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = IthSymbolFA[a, \(-3\)]\), "\n", 
    \(\(mm\  = \ ToDFA[\ m, \ Normalize \[Rule] 1\ ];\)\), "\n", 
    \(States[mm]\)}], "Input",
  CellLabel->"In[177]:=",
  CellTags->"ToDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[177]=",
  CellTags->"ToDFA"],

Cell[BoxData[
    \({{1}, {1, 2}, {1, 2, 3}, {1, 3}, {1, 2, 3, 4}, {1, 3, 4}, {1, 2, 
        4}, {1, 4}}\)], "Output",
  CellLabel->"Out[179]=",
  CellTags->"ToDFA"]
}, Open  ]]
}, Closed]],

Cell["ToEquationsDFA", "ObjectName",
  CellTags->"ToEquationsDFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToEquationsDFA"],

Cell[TextData[{
  StyleBox["ToEquationsDFA[M]", "MR"],
  "  converts DFA ",
  StyleBox["M", "MR"],
  "  into a system of equations."
}], "Usage",
  CellTags->"ToEquationsDFA"],

Cell["\<\
The equations are to be interpreted over the language semiring with \
operations union, concatenation and Kleene star.\
\>", "Notes",
  CellTags->"ToEquationsDFA"],

Cell[TextData[{
  "See ",
  ButtonBox["Arden",
    ButtonData:>"Arden",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["Substitute",
    ButtonData:>"Substitute",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToEquationsDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToEquationsDFA"],

Cell["A counter machine and the corresponding system of equations.", \
"ExampleText",
  CellTags->"ToEquationsDFA"],

Cell[CellGroupData[{

Cell[" m = ModCounterDFA[a,1,3]", "Input",
  CellLabel->"In[65]:=",
  CellTags->"ToEquationsDFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{2, 3, 1}, {1, 2, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({2}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[65]=",
  CellTags->"ToEquationsDFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToEquationsDFA[m]\  // \ TableForm\)], "Input",
  CellLabel->"In[67]:=",
  CellTags->"ToEquationsDFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("X"\_1 == REP[RET["a", "X"\_2], RET["b", "X"\_1]]\)},
          {\("X"\_2 == 
              REP[\[Epsilon], RET["a", "X"\_3], RET["b", "X"\_2]]\)},
          {\("X"\_3 == REP[RET["a", "X"\_1], RET["b", "X"\_3]]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Automata`automata`Private`X[ 1], 
          REP[ 
            RET[ "a", 
              Automata`automata`Private`X[ 2]], 
            RET[ "b", 
              Automata`automata`Private`X[ 1]]]], 
        Equal[ 
          Automata`automata`Private`X[ 2], 
          REP[ \[Epsilon], 
            RET[ "a", 
              Automata`automata`Private`X[ 3]], 
            RET[ "b", 
              Automata`automata`Private`X[ 2]]]], 
        Equal[ 
          Automata`automata`Private`X[ 3], 
          REP[ 
            RET[ "a", 
              Automata`automata`Private`X[ 1]], 
            RET[ "b", 
              Automata`automata`Private`X[ 3]]]]}]]], "Output",
  CellLabel->"Out[67]//TableForm=",
  CellTags->"ToEquationsDFA"]
}, Open  ]],

Cell["The system in algebraic form.", "ExampleText",
  CellTags->"ToEquationsDFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToEquationsDFA[m]\  /. \ {REP \[Rule] Plus, 
          RET \[Rule] NonCommutativeMultiply} // \ TableForm\)], "Input",
  CellLabel->"In[68]:=",
  CellTags->"ToEquationsDFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("X"\_1 == "a" ** "X"\_2 + "b" ** "X"\_1\)},
          {\("X"\_2 == \[Epsilon] + "a" ** "X"\_3 + "b" ** "X"\_2\)},
          {\("X"\_3 == "a" ** "X"\_1 + "b" ** "X"\_3\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Equal[ 
          Automata`automata`Private`X[ 1], 
          Plus[ 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 2]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 1]]]], 
        Equal[ 
          Automata`automata`Private`X[ 2], 
          Plus[ \[Epsilon], 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 3]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 2]]]], 
        Equal[ 
          Automata`automata`Private`X[ 3], 
          Plus[ 
            NonCommutativeMultiply[ "a", 
              Automata`automata`Private`X[ 1]], 
            NonCommutativeMultiply[ "b", 
              Automata`automata`Private`X[ 3]]]]}]]], "Output",
  CellLabel->"Out[68]//TableForm=",
  CellTags->"ToEquationsDFA"]
}, Open  ]]
}, Closed]],

Cell["ToFA", "ObjectName",
  CellTags->"ToFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToFA"],

Cell[TextData[{
  StyleBox["ToFA[M]", "MR"],
  "  converts a FSM to an equivalent FA. "
}], "Usage",
  CellTags->"ToFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToFA"],

Cell["\<\
If M is a semiautomaton all states will be initial as well as \
final. \
\>", "Notes",
  CellTags->"ToFA"],

Cell["\<\
Also converts a cellular automaton to the corresponding de Bruijn \
automaton.\
\>", "Notes",
  CellTags->"ToFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToSA",
    ButtonData:>"ToSA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToNFA",
    ButtonData:>"ToNFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToFA"],

Cell["Converting a DFA to an FA.", "ExampleText",
  CellTags->"ToFA"],

Cell[BoxData[
    \(\(m = 
        DFA[8, 2, {{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}, 
          1, {5, 6, 7, 8}];\)\)], "Input",
  CellLabel->"In[101]:=",
  CellTags->"ToFA"],

Cell[CellGroupData[{

Cell["ToFA[m]", "Input",
  CellLabel->"In[104]:=",
  CellTags->"ToFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"8", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {2, 1, 3}, {3, 1, 5}, {4, 1, 7}, {5, 1, 
                1}, \[LeftSkeleton]6\[RightSkeleton], {4, 2, 8}, {5, 2, 
                2}, {6, 2, 4}, {7, 2, 6}, {8, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5, 6, 7, 8}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[104]=",
  CellTags->"ToFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeterministicQFA[%]\)], "Input",
  CellLabel->"In[105]:=",
  CellTags->"ToFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[105]=",
  CellTags->"ToFA"]
}, Open  ]],

Cell["Converting a cellular automaton.", "ExampleText",
  CellTags->"ToFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToFA[CA[110]]\)], "Input",
  CellLabel->"In[106]:=",
  CellTags->"ToFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 
                1}, {3, 2, 2}, {4, 2, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[106]=",
  CellTags->"ToFA"]
}, Open  ]]
}, Closed]],

Cell["ToFrontierDFA", "ObjectName",
  CellTags->"ToFrontierDFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToFrontierDFA"],

Cell[TextData[{
  StyleBox["ToFrontierDFA[M]", "MR"],
  "  converts DFA M into the corresponding frontier automaton ",
  Cell[BoxData[
      \(TraditionalForm\`\((g, F)\)\)]],
  "."
}], "Usage",
  CellTags->"ToFrontierDFA"],

Cell[TextData[{
  "The frontier rewrite system ",
  StyleBox["g", "MR"],
  " is a list of word pairs, ",
  StyleBox["F", "MR"],
  " a list of words."
}], "Notes",
  CellTags->"ToFrontierDFA"],

Cell[TextData[{
  " See also ",
  ButtonBox["ToPeriodicFrontierDFA",
    ButtonData:>"ToPeriodicFrontierDFA",
    ButtonStyle->"AddOnsLink"],
  " , ",
  StyleBox["FrontierToDFA", "Program"],
  " and ",
  ButtonBox["FrontierQ",
    ButtonData:>"FrontierQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToFrontierDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToFrontierDFA"],

Cell[TextData[{
  "We start with a DFA for all words of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^*\) b\ \((a + b)\)\)]],
  ".  The plain frontier rewrite system looks like so."
}], "ExampleText",
  CellTags->"ToFrontierDFA"],

Cell[BoxData[
    \(\(m = DFA[4, 2, {{1, 3, 1, 3}, {2, 4, 2, 4}}, 1, {3, 4}];\)\)], "Input",\

  CellLabel->"In[42]:=",
  CellTags->"ToFrontierDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({\[CapitalGamma], F}\  = \ ToFrontierDFA[m];\)\), "\n", 
    \(PrintEquations[\[CapitalGamma]]\), "\n", 
    \(F\)}], "Input",
  CellLabel->"In[43]:=",
  AspectRatioFixed->True,
  CellTags->"ToFrontierDFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("1" \(\(:\)\(\ \)\) \("a" \[Rule] \[Epsilon]\)\)},
          {\("2" \(\(:\)\(\ \)\) \("baa" \[Rule] \[Epsilon]\)\)},
          {\("3" \(\(:\)\(\ \)\) \("bab" \[Rule] "b"\)\)},
          {\("4" \(\(:\)\(\ \)\) \("bba" \[Rule] "ba"\)\)},
          {\("5" \(\(:\)\(\ \)\) \("bbb" \[Rule] "bb"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ "1", "a" -> \[Epsilon]], 
        ColonForm[ "2", "baa" -> \[Epsilon]], 
        ColonForm[ "3", "bab" -> "b"], 
        ColonForm[ "4", "bba" -> "ba"], 
        ColonForm[ "5", "bbb" -> "bb"]}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[44]//TableForm=",
  CellTags->"ToFrontierDFA"],

Cell[BoxData[
    \({"ba", "bb"}\)], "Output",
  CellLabel->"Out[45]=",
  CellTags->"ToFrontierDFA"]
}, Open  ]],

Cell["\<\
We can translate back to a DFA, and check equivalence with the \
original machine. \
\>", "ExampleText",
  CellTags->"ToFrontierDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(mm\  = \ FrontierToDFA[\[CapitalGamma], F];\)\), "\n", 
    \(EquivalentQFA[m, mm]\)}], "Input",
  CellLabel->"In[47]:=",
  CellTags->"ToFrontierDFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->"ToFrontierDFA"]
}, Open  ]]
}, Closed]],

Cell["ToGeneratorsFA", "ObjectName",
  CellTags->"ToGeneratorsFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToGeneratorsFA"],

Cell[TextData[{
  StyleBox["ToGeneratorsFA[M]", "MR"],
  "  converts the transition matrix of a DFA into a list of generators for \
the transition semigroup of the machine."
}], "Usage",
  CellTags->"ToGeneratorsFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["SyntacticSG",
    ButtonData:>"SyntacticSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToGeneratorsFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToGeneratorsFA"],

Cell["A DFA and the corresponding generators.", "ExampleText",
  CellTags->"ToGeneratorsFA"],

Cell[BoxData[
    \(\(m = 
        DFA[8, 2, {{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}, 
          1, {5, 6, 7, 8}];\)\)], "Input",
  CellLabel->"In[98]:=",
  CellTags->"ToGeneratorsFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToGeneratorsFA[m]\)], "Input",
  CellLabel->"In[99]:=",
  CellTags->"ToGeneratorsFA"],

Cell[BoxData[
    \(GEN[8, 
      2, {T[1, 3, 5, 7, 1, 3, 5, 7], T[2, 4, 6, 8, 2, 4, 6, 8]}]\)], "Output",\

  CellLabel->"Out[99]=",
  CellTags->"ToGeneratorsFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GenerateSG[%]\)], "Input",
  CellLabel->"In[100]:=",
  CellTags->"ToGeneratorsFA"],

Cell[BoxData[
    \(SG[T[1, 1, 1, 1, 1, 1, 1, 1], T[1, 3, 5, 7, 1, 3, 5, 7], 
      T[1, 5, 1, 5, 1, 5, 1, 5], T[2, 2, 2, 2, 2, 2, 2, 2], 
      T[2, 4, 6, 8, 2, 4, 6, 8], T[2, 6, 2, 6, 2, 6, 2, 6], 
      T[3, 3, 3, 3, 3, 3, 3, 3], T[3, 7, 3, 7, 3, 7, 3, 7], 
      T[4, 4, 4, 4, 4, 4, 4, 4], T[4, 8, 4, 8, 4, 8, 4, 8], 
      T[5, 5, 5, 5, 5, 5, 5, 5], T[6, 6, 6, 6, 6, 6, 6, 6], 
      T[7, 7, 7, 7, 7, 7, 7, 7], T[8, 8, 8, 8, 8, 8, 8, 8]]\)], "Output",
  CellLabel->"Out[100]=",
  CellTags->"ToGeneratorsFA"]
}, Open  ]]
}, Closed]],

Cell["ToGraphFA", "ObjectName",
  CellTags->"ToGraphFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToGraphFA"],

Cell[TextData[{
  StyleBox["ToGraphFA[M]", "MR"],
  "  converts a finites state machine M into the underlying transition \
diagram: a directed graph with point set Q. "
}], "Usage",
  CellTags->"ToGraphFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Unlabeled", "\[Rule]", "True", "False"},
          {"Normalize", "\[Rule]", "$defaultnormalize", \(0, 1, 2\)}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToGraphFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Unlabeled->False", "MR"],
  " generates a labeled edge list."
}], "Notes",
  CellTags->"ToGraphFA"],

Cell[TextData[{
  "This is used in many algorithms such as ",
  ButtonBox["AccessibleFA",
    ButtonData:>"AccessibleFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToGraphFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToGraphFA"],

Cell["A small semiautomaton and its diagram.", "ExampleText",
  CellTags->"ToGraphFA"],

Cell[BoxData[
    \(\(m = 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 1}, {3, 
              2, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[90]:=",
  CellTags->"ToGraphFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\  = \ ToGraphFA[m]\)], "Input",
  CellLabel->"In[91]:=",
  CellTags->"ToGraphFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"4", ",", "8", ",", "1", ",", 
          
          TagBox[\({{1, 1}, {1, 2}, {2, 3}, {2, 4}, {3, 1}, {3, 2}, {4, 
                3}, {4, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[91]=",
  CellTags->"ToGraphFA"]
}, Open  ]],

Cell["The automaton is transitive.", "ExampleText",
  CellTags->"ToGraphFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[g]\)], "Input",
  CellLabel->"In[92]:=",
  CellTags->"ToGraphFA"],

Cell[BoxData[
    \({{1, 2, 3, 4}}\)], "Output",
  CellLabel->"Out[92]=",
  CellTags->"ToGraphFA"]
}, Open  ]]
}, Closed]],

Cell["ToIndex", "ObjectName",
  CellTags->"ToIndex"],

Cell["Type: function", "Highlight",
  CellTags->"ToIndex"],

Cell[TextData[{
  StyleBox["ToIndex[w,K]", "MR"],
  "  converts a word ",
  StyleBox["w", "MR"],
  " over a sorted alphabet ",
  StyleBox["K", "MR"],
  " to positional notation."
}], "Usage",
  CellTags->"ToIndex"],

Cell["Internally most algorithms use positional notation.", "Notes",
  CellTags->"ToIndex"],

Cell["Also works on symbols and treats epsilon properly.", "Notes",
  CellTags->"ToIndex"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToWord",
    ButtonData:>"ToWord",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToIndex"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToIndex"],

Cell["Replacing symbols by their index.", "ExampleText",
  CellTags->"ToIndex"],

Cell[CellGroupData[{

Cell["ToIndex[ abcde, 5 ]", "Input",
  CellLabel->"In[107]:=",
  CellTags->"ToIndex"],

Cell[BoxData[
    \({1, 2, 3, 4, 5}\)], "Output",
  CellLabel->"Out[107]=",
  CellTags->"ToIndex"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToWord[\ %, \ 5\ ]\)], "Input",
  CellLabel->"In[108]:=",
  CellTags->"ToIndex"],

Cell[BoxData[
    \("abcde"\)], "Output",
  CellLabel->"Out[108]=",
  CellTags->"ToIndex"]
}, Open  ]]
}, Closed]],

Cell["ToKernelFA", "ObjectName",
  CellTags->"ToKernelFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToKernelFA"],

Cell[TextData[{
  StyleBox["ToKernelFA[M,L,opts]", "MR"],
  "  generates the kernel automaton of ",
  StyleBox["M", "MR"],
  " generated from the states in list ",
  StyleBox["L", "MR"],
  ". "
}], "Usage",
  CellTags->"ToKernelFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "1", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToKernelFA"],

Cell[TextData[{
  "The entries in ",
  StyleBox["L", "MR"],
  " can be single integers in ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\)]],
  ", where ",
  StyleBox["n", "MR"],
  " is the size of ",
  StyleBox["M", "MR"],
  ", or lists of such integers. "
}], "Notes",
  CellTags->"ToKernelFA"],

Cell[TextData[{
  "The default for L is ",
  Cell[BoxData[
      \(TraditionalForm\`{{p\_1}, \[Ellipsis], {p\_m}}\)]],
  " where the ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  " are the initial states of ",
  StyleBox["M", "MR"],
  ". "
}], "Notes",
  CellTags->"ToKernelFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToKernelFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToKernelFA"],

Cell["\<\
A small semiautomaton and several associated kernel automata.\
\>", \
"ExampleText",
  CellTags->"ToKernelFA"],

Cell[BoxData[
    \(\(m = 
        SA[4, \(-2\), {{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 
              1}, {3, 2, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[80]:=",
  CellTags->"ToKernelFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ToKernelFA[m]\), "\n", 
    \(States[%]\)}], "Input",
  CellLabel->"In[83]:=",
  CellTags->"ToKernelFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"9", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 5}, {2, 2, 6}, {3, 1, 
                1}, \[LeftSkeleton]8\[RightSkeleton], {7, 2, 8}, {8, 1, 
                1}, {8, 2, 9}, {9, 1, 7}, {9, 2, 9}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[83]=",
  CellTags->"ToKernelFA"],

Cell[BoxData[
    \({{1}, {2}, {3}, {4}, {}, {3, 4}, {1, 4}, {2, 3}, {2, 3, 4}}\)], "Output",\

  CellLabel->"Out[84]=",
  CellTags->"ToKernelFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ToKernelFA[m, {1}]\), "\n", 
    \(States[%]\)}], "Input",
  CellLabel->"In[85]:=",
  CellTags->"ToKernelFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"7", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 1, 
                3}, \[LeftSkeleton]4\[RightSkeleton], {5, 2, 6}, {6, 1, 
                1}, {6, 2, 7}, {7, 1, 5}, {7, 2, 7}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[85]=",
  CellTags->"ToKernelFA"],

Cell[BoxData[
    \({{1}, {2}, {}, {3, 4}, {1, 4}, {2, 3}, {2, 3, 4}}\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->"ToKernelFA"]
}, Open  ]],

Cell[TextData[{
  "The automaton that would essemtially be produced by ",
  StyleBox["ToDFA", "MR"],
  "."
}], "ExampleText",
  CellTags->"ToKernelFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ToKernelFA[m, {{1, 2, 3, 4}}]\), "\n", 
    \(States[%]\)}], "Input",
  CellLabel->"In[87]:=",
  CellTags->"ToKernelFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"8", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 3}, {2, 1, 2}, {2, 2, 4}, {3, 1, 
                2}, \[LeftSkeleton]6\[RightSkeleton], {6, 2, 8}, {7, 1, 
                7}, {7, 2, 7}, {8, 1, 2}, {8, 2, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[87]=",
  CellTags->"ToKernelFA"],

Cell[BoxData[
    \({{1, 2, 3, 4}, {1, 4}, {2, 3, 4}, {2, 3}, {1}, {2}, {}, {3, 
        4}}\)], "Output",
  CellLabel->"Out[88]=",
  CellTags->"ToKernelFA"]
}, Open  ]]
}, Closed]],

Cell["ToLabelCA", "ObjectName",
  CellTags->"ToLabelCA"],

Cell["Type: function", "Highlight",
  CellTags->"ToLabelCA"],

Cell[TextData[{
  StyleBox["ToLabelCA[C]", "MR"],
  " converts cellular automaton C from rule number to label list form. "
}], "Usage",
  CellTags->"ToLabelCA"],

Cell["\<\
Deprecated.  In the next release all CAs will be in rule number \
form.\
\>", "Notes",
  CellTags->"ToLabelCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToLabelCA"],

Cell["Converting to label lists.", "ExampleText",
  CellTags->"ToLabelCA"],

Cell[CellGroupData[{

Cell["\<\
ToLabelCA[ CA[90] ]
% // FullForm\
\>", "Input",
  CellLabel->"In[79]:=",
  CellTags->"ToLabelCA"],

Cell[BoxData[
    \({"0", "1", "0", "1", "1", "0", "1", "0"}\)], "Output",
  CellLabel->"Out[79]=",
  CellTags->"ToLabelCA"],

Cell[BoxData[
    TagBox[
      StyleBox[\(List["\<0\>", "\<1\>", "\<0\>", "\<1\>", "\<1\>", "\<0\>", "\
\<1\>", "\<0\>"]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[80]//FullForm=",
  CellTags->"ToLabelCA"]
}, Open  ]]
}, Closed]],

Cell["ToNFA", "ObjectName",
  CellTags->"ToNFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToNFA"],

Cell[TextData[{
  StyleBox["ToNFA[M]", "MR"],
  "  converts FSM ",
  StyleBox["M", "MR"],
  " to an equivalent NFA."
}], "Usage",
  CellTags->"ToNFA"],

Cell["\<\
 If M is a semiautomaton all states will be initial as well as \
final.\
\>", "Notes",
  CellTags->"ToNFA"],

Cell[TextData[{
  " See also ",
  ButtonBox["ToSA",
    ButtonData:>"ToSA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToFA",
    ButtonData:>"ToFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToNFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToNFA"],

Cell["A semiautomaton and the corresponding NFA.", "ExampleText",
  CellTags->"ToNFA"],

Cell[BoxData[
    \(\(m\  = \ 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 1}, {3, 
              2, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[75]:=",
  CellTags->"ToNFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToNFA[m]\)], "Input",
  CellLabel->"In[78]:=",
  CellTags->"ToNFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"NFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{{1}, {}, {1}, {4}}, {{2}, {3, 4}, {2}, {3}}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[78]=",
  CellTags->"ToNFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transitions[%]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[79]:=",
  CellTags->"ToNFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1}\), \({}\), \({1}\), \({4}\)},
            {\({2}\), \({3, 4}\), \({2}\), \({3}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[79]//MatrixForm=",
  CellTags->"ToNFA"]
}, Open  ]]
}, Closed]],

Cell["ToPeriodicFrontierDFA", "ObjectName",
  CellTags->"ToPeriodicFrontierDFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[TextData[{
  StyleBox["ToPeriodicFrontierDFA[M]", "MR"],
  "  converts DFA M into the corresponding periodic rewrite system and \
collection of accepting words."
}], "Usage",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[TextData[{
  "Returns a list of rewrite rules ",
  Cell[BoxData[
      \(TraditionalForm\`\((u, v)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " is a prefix of ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", and a list of words corresponding to the final states of the automaton."
}], "Notes",
  CellTags->"ToPeriodicFrontierDFA"],

Cell["noteworthy", "Notes",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[TextData[{
  " See also ",
  ButtonBox["ToFrontierDFA",
    ButtonData:>"ToFrontierDFA",
    ButtonStyle->"AddOnsLink"],
  " , ",
  StyleBox["FrontierToDFA", "Program"],
  " and ",
  ButtonBox["FrontierQ",
    ButtonData:>"FrontierQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[TextData[{
  "We start with a DFA for all words of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^*\) b\ \((a + b)\)\)]],
  ".  The plain frontier rewrite system looks like so."
}], "ExampleText",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[BoxData[
    \(\(m = DFA[4, 2, {{1, 3, 1, 3}, {2, 4, 2, 4}}, 1, {3, 4}];\)\)], "Input",\

  CellLabel->"In[62]:=",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ToFrontierDFA[m];\)\), "\n", 
    \(PrintEquations[First[%]]\)}], "Input",
  CellLabel->"In[70]:=",
  AspectRatioFixed->True,
  CellTags->"ToPeriodicFrontierDFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("1" \(\(:\)\(\ \)\) \("a" \[Rule] \[Epsilon]\)\)},
          {\("2" \(\(:\)\(\ \)\) \("baa" \[Rule] \[Epsilon]\)\)},
          {\("3" \(\(:\)\(\ \)\) \("bab" \[Rule] "b"\)\)},
          {\("4" \(\(:\)\(\ \)\) \("bba" \[Rule] "ba"\)\)},
          {\("5" \(\(:\)\(\ \)\) \("bbb" \[Rule] "bb"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ "1", "a" -> \[Epsilon]], 
        ColonForm[ "2", "baa" -> \[Epsilon]], 
        ColonForm[ "3", "bab" -> "b"], 
        ColonForm[ "4", "bba" -> "ba"], 
        ColonForm[ "5", "bbb" -> "bb"]}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[71]//TableForm=",
  CellTags->"ToPeriodicFrontierDFA"]
}, Open  ]],

Cell["\<\
In the 4th rule, the right hand side is not a prefix of the left \
hand side.  Here is the corresponding periodic rewrite system.\
\>", \
"ExampleText",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({\[CapitalGamma], F} = ToPeriodicFrontierDFA[m];\)\), "\n", 
    \(PrintEquations[\[CapitalGamma]]\), "\n", 
    \(F\)}], "Input",
  CellLabel->"In[72]:=",
  AspectRatioFixed->True,
  CellTags->"ToPeriodicFrontierDFA"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("1" \(\(:\)\(\ \)\) \("a" \[Rule] \[Epsilon]\)\)},
          {\("2" \(\(:\)\(\ \)\) \("baa" \[Rule] \[Epsilon]\)\)},
          {\("3" \(\(:\)\(\ \)\) \("bab" \[Rule] "b"\)\)},
          {\("4" \(\(:\)\(\ \)\) \("bbb" \[Rule] "bb"\)\)},
          {\("5" \(\(:\)\(\ \)\) \("bbaa" \[Rule] \[Epsilon]\)\)},
          {\("6" \(\(:\)\(\ \)\) \("bbab" \[Rule] "b"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ "1", "a" -> \[Epsilon]], 
        ColonForm[ "2", "baa" -> \[Epsilon]], 
        ColonForm[ "3", "bab" -> "b"], 
        ColonForm[ "4", "bbb" -> "bb"], 
        ColonForm[ "5", "bbaa" -> \[Epsilon]], 
        ColonForm[ "6", "bbab" -> "b"]}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[73]//TableForm=",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[BoxData[
    \({"ba", "bb", "bba"}\)], "Output",
  CellLabel->"Out[74]=",
  CellTags->"ToPeriodicFrontierDFA"]
}, Open  ]],

Cell["\<\
We can translate back to a DFA, and check equivalence with the \
original machine. \
\>", "ExampleText",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(mm\  = \ FrontierToDFA[\[CapitalGamma], F];\)\), "\n", 
    \(EquivalentQFA[m, mm]\)}], "Input",
  CellLabel->"In[79]:=",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"ToPeriodicFrontierDFA"]
}, Open  ]]
}, Closed]],

Cell["ToPrefixFA", "ObjectName",
  CellTags->"ToPrefixFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToPrefixFA"],

Cell[TextData[{
  StyleBox["ToPrefixFA[M]", "MR"],
  "  converts a FSM into a machine that accepts the language of all prefixes \
of words in the language of M."
}], "Usage",
  CellTags->"ToPrefixFA"],

Cell["noteworthy", "Notes",
  CellTags->"ToPrefixFA"],

Cell["\<\
The input machine is first minimized to reduce the size of the \
output.\
\>", "Notes",
  CellTags->"ToPrefixFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToSuffixFA",
    ButtonData:>"ToSuffixFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToPrefixFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToPrefixFA"],

Cell[TextData[{
  "A machine accepting all words with exactly two ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s."
}], "ExampleText",
  CellTags->"ToPrefixFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ CounterDFA[b, 2, 2]\)], "Input",
  CellLabel->"In[67]:=",
  CellTags->"ToPrefixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{1, 2, 3, 4}, {2, 3, 4, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[67]=",
  CellTags->"ToPrefixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ ToPrefixFA[m]\)], "Input",
  CellLabel->"In[68]:=",
  CellTags->"ToPrefixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{1, 2, 3, 4}, {2, 3, 4, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[68]=",
  CellTags->"ToPrefixFA"]
}, Open  ]],

Cell[TextData[{
  "We obtain all words with at most two ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s."
}], "ExampleText",
  CellTags->"ToPrefixFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ mm, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[69]:=",
  CellTags->"ToPrefixFA"],

Cell[BoxData[
    \({{\[Epsilon]}, {"a", "b"}, {"aa", "ab", "ba", "bb"}, {"aaa", "aab", 
        "aba", "abb", "baa", "bab", "bba"}, {"aaaa", "aaab", "aaba", "aabb", 
        "abaa", "abab", "abba", "baaa", "baab", "baba", "bbaa"}, {"aaaaa", 
        "aaaab", "aaaba", "aaabb", "aabaa", "aabab", "aabba", "abaaa", 
        "abaab", "ababa", "abbaa", "baaaa", "baaab", "baaba", "babaa", 
        "bbaaa"}}\)], "Output",
  CellLabel->"Out[69]=",
  CellTags->"ToPrefixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[\ CounterDFA[b, \(-2\), 2], mm]\)], "Input",
  CellLabel->"In[70]:=",
  CellTags->"ToPrefixFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[70]=",
  CellTags->"ToPrefixFA"]
}, Open  ]]
}, Closed]],

Cell["ToPrefix", "ObjectName",
  CellTags->"ToPrefix"],

Cell["Type: function", "Highlight",
  CellTags->"ToPrefix"],

Cell[TextData[{
  StyleBox["ToPrefix[W,K]", "MR"],
  "  computes the prefix set corresponding to the finite language W over \
alphabet K. "
}], "Usage",
  CellTags->"ToPrefix"],

Cell[TextData[{
  "The algorithm actually computes ",
  Cell[BoxData[
      \(TraditionalForm\`W\ K\  - \ W\)]],
  ". "
}], "Notes",
  CellTags->"ToPrefix"],

Cell[TextData[{
  "On prefix-closed sets, this operation is the inverse to ",
  StyleBox["ProperPrefixes", "MR"],
  "."
}], "Notes",
  CellTags->"ToPrefix"],

Cell[TextData[{
  "See also  ",
  ButtonBox["ProperPrefixes",
    ButtonData:>"ProperPrefixes",
    ButtonStyle->"AddOnsLink"],
  "  and ",
  ButtonBox["FrontierQ",
    ButtonData:>"FrontierQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToPrefix"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToPrefix"],

Cell["A small frontier language and its prefixes.", "ExampleText",
  CellTags->"ToPrefix"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(W\  = \ {aa, bb, baa, bab, aba, abb};\)\), "\n", 
    \(WordSort[Union[Flatten[ProperPrefixes[W]]]]\)}], "Input",
  CellLabel->"In[57]:=",
  CellTags->"ToPrefix"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "ab", "ba"}\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"ToPrefix"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToPrefix[%]", "Input",
  CellLabel->"In[59]:=",
  CellTags->"ToPrefix"],

Cell[BoxData[
    \({"aa", "bb", "aba", "abb", "baa", "bab"}\)], "Output",
  CellLabel->"Out[59]=",
  CellTags->"ToPrefix"]
}, Open  ]]
}, Closed]],

Cell["ToRegExp", "ObjectName",
  CellTags->"ToRegExp"],

Cell["Type: function", "Highlight",
  CellTags->"ToRegExp"],

Cell[TextData[{
  StyleBox["ToRegExp[reg]", "MR"],
  "  converts an expression containing arithmetic operators +  and ** (Plus \
and NonCommutativeMultiply) into the corresponding regular expression \
containing only headers ",
  StyleBox["REP", "MR"],
  ", ",
  StyleBox["RET", "MR"],
  " and ",
  StyleBox["RES", "MR"],
  ". "
}], "Usage",
  CellTags->"ToRegExp"],

Cell["\<\
This conversion is used automatically in all commands operating on \
regular expressions.\
\>", "Notes",
  CellTags->"ToRegExp"],

Cell[TextData[{
  "See also ",
  ButtonBox["RegularExpressionToFA,",
    ButtonData:>"RegularExpressionToFA,",
    ButtonStyle->"AddOnsLink"],
  " ",
  ButtonBox["REP",
    ButtonData:>"REP",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RET",
    ButtonData:>"RET",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["RES",
    ButtonData:>"RES",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"ToRegExp"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToRegExp"],

Cell["\<\
Using arithmetic notation makes it somewhat easier to write \
complicated regular expressions. \
\>", "ExampleText",
  CellTags->"ToRegExp"],

Cell[CellGroupData[{

Cell["RES[ aa + bb + (ab+ba)**RES[aa+bb]**(ab+ba)]", "Input",
  CellLabel->"In[105]:=",
  CellTags->"ToRegExp"],

Cell[BoxData[
    \(RES[
      aa + bb + \((ab + ba)\) ** RES[aa + bb] ** \((ab + ba)\)]\)], "Output",
  CellLabel->"Out[105]=",
  CellTags->"ToRegExp"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToRegExp[%]\)], "Input",
  CellLabel->"In[106]:=",
  CellTags->"ToRegExp"],

Cell[BoxData[
    \(RES[
      REP[aa, bb, 
        RET[REP[ab, ba], RES[REP[aa, bb]], REP[ab, ba]]]]\)], "Output",
  CellLabel->"Out[106]=",
  CellTags->"ToRegExp"]
}, Open  ]]
}, Closed]],

Cell["ToRegularExpressionFA", "ObjectName",
  CellTags->"ToRegularExpressionFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToRegularExpressionFA"],

Cell[TextData[{
  StyleBox["ToRegularExpressionFA[M]", "MR"],
  "  uses Kleene's algorithm to convert an FA into an equivalent regular \
expression. "
}], "Usage",
  CellTags->"ToRegularExpressionFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"RegExpSimp", "\[Rule]", "True", "-"},
          {"DoTrace", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToRegularExpressionFA"],

Cell[TextData[{
  "Option ",
  StyleBox["RegExpSimp->False", "MR"],
  " turns the built-in simplification rules off.  This will ordinarily lead \
to very large expressions."
}], "Notes",
  CellTags->"ToRegularExpressionFA"],

Cell["\<\
Since simplification is very primitive, use only on small machines.\
\
\>", "Notes",
  CellTags->"ToRegularExpressionFA"],

Cell[TextData[{
  "See ",
  ButtonBox["$regexrules",
    ButtonData:>"$regexrules",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["RegExpSimp",
    ButtonData:>"RegExpSimp",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToRegularExpressionFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToRegularExpressionFA"],

Cell["A small nondeterministic machine.", "ExampleText",
  CellTags->"ToRegularExpressionFA"],

Cell[BoxData[
    \(\(m = 
        FA[4, 2, {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[62]:=",
  CellTags->"ToRegularExpressionFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToRegularExpressionFA[m]\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->"ToRegularExpressionFA"],

Cell[BoxData[
    \(RET[REP["b", RET[REP[\[Epsilon], "a", "b"], RES[REP["a", "b"]], "b"]], 
      REP["a", "b"], REP["a", "b"]]\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->"ToRegularExpressionFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\  /. \ {REP\  \[Rule] \ Plus, 
        RET \[Rule] \ NonCommutativeMultiply}\)], "Input",
  CellLabel->"In[64]:=",
  CellTags->"ToRegularExpressionFA"],

Cell[BoxData[
    \(\(("b" + \(("a" + "b" + \[Epsilon])\) ** RES["a" + "b"] ** 
            "b")\) ** \(("a" + "b")\) ** \(("a" + "b")\)\)], "Output",
  CellLabel->"Out[64]=",
  CellTags->"ToRegularExpressionFA"]
}, Open  ]],

Cell[TextData[{
  "Our simplification rules are too weak to rewrite this to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((a + b)\)\^\(\(\ \)\(*\)\)\) 
        b\ \((a + b)\) \((a + b)\)\)]],
  ". "
}], "ExampleText",
  CellTags->"ToRegularExpressionFA"]
}, Closed]],

Cell["ToRulesCA", "ObjectName",
  CellTags->"ToRulesCA"],

Cell["Type: function", "Highlight",
  CellTags->"ToRulesCA"],

Cell[TextData[{
  StyleBox["ToRulesCA[C]", "MR"],
  "  returns  a list of Mathematica replacement rules corresponding to the \
local map of cellular automaton C."
}], "Usage",
  CellTags->"ToRulesCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"WordMap", "\[Rule]", "True", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToRulesCA"],

Cell[TextData[{
  " Option ",
  StyleBox["WordMap->False", "MR"],
  " produces replacement rules for lists rather than words."
}], "Notes",
  CellTags->"ToRulesCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToRulesCA"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " rules corresponding to ECA number 90. "
}], "ExampleText",
  CellTags->"ToRulesCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToRulesCA[CA[90]]\)], "Input",
  CellLabel->"In[81]:=",
  CellTags->"ToRulesCA"],

Cell[BoxData[
    TagBox[
      RowBox[{"Dispatch", "[", 
        RowBox[{\({"000" \[Rule] "0", "001" \[Rule] "1", "010" \[Rule] "0", 
            "011" \[Rule] "1", "100" \[Rule] "1", "101" \[Rule] "0", 
            "110" \[Rule] "1", "111" \[Rule] "0"}\), ",", 
          TagBox[
            InterpretationBox[\(\(-DispatchTables\)\(-\)\),
              1],
            DisplayForm]}], "]"}],
      Function[ BoxForm`arg, 
        ReplacePart[ 
          HoldComplete[ 
            Dispatch[ ProgrammingDump`dumy]], 
          HoldComplete[ BoxForm`arg], {1, 1}, {1, 1}], {
        HoldAllComplete}]]], "Output",
  CellLabel->"Out[81]=",
  CellTags->"ToRulesCA"]
}, Open  ]],

Cell["Same in list form.", "ExampleText",
  CellTags->"ToRulesCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToRulesCA[CA[90], WordMap \[Rule] False]\)], "Input",
  CellLabel->"In[83]:=",
  CellTags->"ToRulesCA"],

Cell[BoxData[
    TagBox[
      RowBox[{"Dispatch", "[", 
        RowBox[{\({{0, 0, 0} \[Rule] 0, {0, 0, 1} \[Rule] 
              1, {0, 1, 0} \[Rule] 0, {0, 1, 1} \[Rule] 1, {1, 0, 0} \[Rule] 
              1, {1, 0, 1} \[Rule] 0, {1, 1, 0} \[Rule] 1, {1, 1, 1} \[Rule] 
              0}\), ",", 
          TagBox[
            InterpretationBox[\(\(-DispatchTables\)\(-\)\),
              1],
            DisplayForm]}], "]"}],
      Function[ BoxForm`arg, 
        ReplacePart[ 
          HoldComplete[ 
            Dispatch[ ProgrammingDump`dumy]], 
          HoldComplete[ BoxForm`arg], {1, 1}, {1, 1}], {
        HoldAllComplete}]]], "Output",
  CellLabel->"Out[83]=",
  CellTags->"ToRulesCA"]
}, Open  ]]
}, Closed]],

Cell["ToSA", "ObjectName",
  CellTags->"ToSA"],

Cell["Type: function", "Highlight",
  CellTags->"ToSA"],

Cell[TextData[{
  StyleBox["ToSA[M]", "MR"],
  "  converts any finite state machine to the corresponding semiautomaton. "
}], "Usage",
  CellTags->"ToSA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToSA"],

Cell["\<\
Also converts a cellular automaton to the corresponding de Bruijn \
semiautomaton.\
\>", "Notes",
  CellTags->"ToSA"],

Cell["\<\
Stripps off initial and final states  and converts to a list of \
transitions if necessary. \
\>", "Notes",
  CellTags->"ToSA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToFA",
    ButtonData:>"ToFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToNFA",
    ButtonData:>"ToNFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToSA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToSA"],

Cell["Removing initial and final states from a DFA. ", "ExampleText",
  CellTags->"ToSA"],

Cell[CellGroupData[{

Cell["m = CounterDFA[b,3,2]", "Input",
  CellLabel->"In[47]:=",
  CellTags->"ToSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{1, 2, 3, 4, 5}, {2, 3, 4, 5, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[47]=",
  CellTags->"ToSA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToSA[m]\)], "Input",
  CellLabel->"In[48]:=",
  CellTags->"ToSA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {2, 1, 2}, {3, 1, 3}, {4, 1, 4}, {5, 1, 
                5}, {1, 2, 2}, {2, 2, 3}, {3, 2, 4}, {4, 2, 5}, {5, 2, 5}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[48]=",
  CellTags->"ToSA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeterministicQFA[%]\)], "Input",
  CellLabel->"In[49]:=",
  CellTags->"ToSA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[49]=",
  CellTags->"ToSA"]
}, Open  ]]
}, Closed]],

Cell["ToSeries", "ObjectName",
  CellTags->"ToSeries"],

Cell["Type: function", "Highlight",
  CellTags->"ToSeries"],

Cell[TextData[{
  StyleBox["ToSeries[L]", "MR"],
  "  converts a list ",
  StyleBox["L", "MR"],
  " with multiplicities into a formal power series of words with integer \
coefficients. "
}], "Usage",
  CellTags->"ToSeries"],

Cell[TextData[{
  "Uses ",
  StyleBox["HoldForm", "MR"],
  " to bypass Mathematica's sorting algorithm."
}], "Notes",
  CellTags->"ToSeries"],

Cell[TextData[{
  "See ",
  ButtonBox["LanguageFA",
    ButtonData:>"LanguageFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Multiplicity",
    ButtonData:>"Multiplicity",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToSeries"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToSeries"],

Cell["Nothing at all.", "ExampleText",
  CellTags->"ToSeries"],

Cell["m = ToSA[CA[110,3,2]];", "Input",
  CellLabel->"In[42]:=",
  CellTags->"ToSeries"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ 4, \ Multiplicity \[Rule] True]\)], "Input",
  CellLabel->"In[43]:=",
  CellTags->"ToSeries"],

Cell[BoxData[
    \({{"aaaa", 3}, {"aaab", 3}, {"aaba", 1}, {"aabb", 5}, {"abaa", 
        1}, {"abab", 1}, {"abba", 4}, {"abbb", 6}, {"baaa", 3}, {"baab", 
        3}, {"baba", 1}, {"babb", 5}, {"bbaa", 5}, {"bbab", 5}, {"bbba", 
        6}, {"bbbb", 12}}\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->"ToSeries"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToSeries[%]\)], "Input",
  CellLabel->"In[44]:=",
  CellTags->"ToSeries"],

Cell[BoxData[
    TagBox[\(3\ "aaaa" + 3\ "aaab" + "aaba" + 5\ "aabb" + "abaa" + "abab" + 
        4\ "abba" + 6\ "abbb" + 3\ "baaa" + 3\ "baab" + "baba" + 5\ "babb" + 
        5\ "bbaa" + 5\ "bbab" + 6\ "bbba" + 12\ "bbbb"\),
      HoldForm]], "Output",
  CellLabel->"Out[44]=",
  CellTags->"ToSeries"]
}, Open  ]]
}, Closed]],

Cell["ToSuffixFA", "ObjectName",
  CellTags->"ToSuffixFA"],

Cell["Type: function", "Highlight",
  CellTags->"ToSuffixFA"],

Cell[TextData[{
  StyleBox["ToSuffixFA[M]", "MR"],
  "  converts a FSM into a machine that accepts the language of all suffixes \
of words in the language of M."
}], "Usage",
  CellTags->"ToSuffixFA"],

Cell["\<\
The input machine is first minimized to reduce the size of the \
output.\
\>", "Notes",
  CellTags->"ToSuffixFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToPrefixFA",
    ButtonData:>"ToPrefixFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToSuffixFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToSuffixFA"],

Cell[TextData[{
  "A machine accepting all words with exactly two ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s."
}], "ExampleText",
  CellTags->"ToSuffixFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ CounterDFA[b, 2, 2]\)], "Input",
  CellLabel->"In[53]:=",
  CellTags->"ToSuffixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{1, 2, 3, 4}, {2, 3, 4, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[53]=",
  CellTags->"ToSuffixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mm\  = \ ToSuffixFA[m]\)], "Input",
  CellLabel->"In[56]:=",
  CellTags->"ToSuffixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"4", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {2, 1, 2}, {3, 1, 3}, {4, 1, 4}, {1, 2, 
                2}, {2, 2, 3}, {3, 2, 4}, {4, 2, 4}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[56]=",
  CellTags->"ToSuffixFA"]
}, Open  ]],

Cell[TextData[{
  "We obtain all words with at most two ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s."
}], "ExampleText",
  CellTags->"ToSuffixFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ mm, \ \(-5\)\ ]\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->"ToSuffixFA"],

Cell[BoxData[
    \({{\[Epsilon]}, {"a", "b"}, {"aa", "ab", "ba", "bb"}, {"aaa", "aab", 
        "aba", "abb", "baa", "bab", "bba"}, {"aaaa", "aaab", "aaba", "aabb", 
        "abaa", "abab", "abba", "baaa", "baab", "baba", "bbaa"}, {"aaaaa", 
        "aaaab", "aaaba", "aaabb", "aabaa", "aabab", "aabba", "abaaa", 
        "abaab", "ababa", "abbaa", "baaaa", "baaab", "baaba", "babaa", 
        "bbaaa"}}\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"ToSuffixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquivalentQFA[\ CounterDFA[b, \(-2\), 2], mm]\)], "Input",
  CellLabel->"In[59]:=",
  CellTags->"ToSuffixFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[59]=",
  CellTags->"ToSuffixFA"]
}, Open  ]]
}, Closed]],

Cell["TotalisticRuleToCA", "ObjectName",
  CellTags->"TotalisticRuleToCA"],

Cell["Type: function", "Highlight",
  CellTags->"TotalisticRuleToCA"],

Cell[TextData[{
  StyleBox["TotalisticRuleToCA[r,w,k]", "MR"],
  "  produces the ordinary CA with totalistic rule number r and width w. "
}], "Usage",
  CellTags->"TotalisticRuleToCA"],

Cell[TextData[{
  "The alphabet is always of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1,  ... , k - 1}\)]],
  "."
}], "Notes",
  CellTags->"TotalisticRuleToCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToTotalisticRuleCA",
    ButtonData:>"ToTotalisticRuleCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TotalisticRuleToCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TotalisticRuleToCA"],

Cell["\<\
Conversion of a totalistic rule number to a standard rule number. \
\
\>", "ExampleText",
  CellTags->"TotalisticRuleToCA"],

Cell[CellGroupData[{

Cell["NumberOfTotalisticCA[3,2]", "Input",
  CellLabel->"In[84]:=",
  CellTags->"TotalisticRuleToCA"],

Cell[BoxData[
    \(16\)], "Output",
  CellLabel->"Out[84]=",
  CellTags->"TotalisticRuleToCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ TotalisticRuleToCA[r, 3, 2], {r, 0, 15}]\)], "Input",
  CellLabel->"In[86]:=",
  CellTags->"TotalisticRuleToCA"],

Cell[BoxData[
    \({CA[0, 3, \(-2\)], CA[1, 3, \(-2\)], CA[22, 3, \(-2\)], 
      CA[23, 3, \(-2\)], CA[104, 3, \(-2\)], CA[105, 3, \(-2\)], 
      CA[126, 3, \(-2\)], CA[127, 3, \(-2\)], CA[128, 3, \(-2\)], 
      CA[129, 3, \(-2\)], CA[150, 3, \(-2\)], CA[151, 3, \(-2\)], 
      CA[232, 3, \(-2\)], CA[233, 3, \(-2\)], CA[254, 3, \(-2\)], 
      CA[255, 3, \(-2\)]}\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->"TotalisticRuleToCA"]
}, Open  ]]
}, Closed]],

Cell["ToTotalisticRuleCA", "ObjectName",
  CellTags->"ToTotalisticRuleCA"],

Cell["Type: function", "Highlight",
  CellTags->"ToTotalisticRuleCA"],

Cell[TextData[{
  StyleBox["ToTotalisticRuleCA[C]", "MR"],
  "  determines the totalistic rule number r of a given CA C. "
}], "Usage",
  CellTags->"ToTotalisticRuleCA"],

Cell["No test is performed whether C is indeed totalistic.", "Notes",
  CellTags->"ToTotalisticRuleCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["TotalisticRuleToCA",
    ButtonData:>"TotalisticRuleToCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToTotalisticRuleCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToTotalisticRuleCA"],

Cell["Rule 150 is totalistic.", "ExampleText",
  CellTags->"ToTotalisticRuleCA"],

Cell[CellGroupData[{

Cell["ToTotalisticRuleCA[CA[150,3,2]]", "Input",
  CellLabel->"In[42]:=",
  CellTags->"ToTotalisticRuleCA"],

Cell[BoxData[
    \(10\)], "Output",
  CellLabel->"Out[42]=",
  CellTags->"ToTotalisticRuleCA"]
}, Open  ]]
}, Closed]],

Cell["ToTransitions", "ObjectName",
  CellTags->"ToTransitions"],

Cell["Type: function", "Highlight",
  CellTags->"ToTransitions"],

Cell[TextData[{
  StyleBox["ToTransitions[T,K]", "MR"],
  "  translates a list of transitions with string labels into a proper \
transition list in positional notation with respect to alphabet K."
}], "Usage",
  CellTags->"ToTransitions"],

Cell["\<\
The labels are required to be single characters, not strings.\
\>", \
"Notes",
  CellTags->"ToTransitions"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToTransitions"],

Cell["\<\
Translating string labeled transitions into positional \
representation, as required by all algorithms.\
\>", "ExampleText",
  CellTags->"ToTransitions"],

Cell[CellGroupData[{

Cell["ToTransitions[{{1,\"a\",2},{2,\"b\",3}},2]", "Input",
  CellLabel->"In[113]:=",
  CellTags->"ToTransitions"],

Cell[BoxData[
    \({{1, 1, 2}, {2, 2, 3}}\)], "Output",
  CellLabel->"Out[113]=",
  CellTags->"ToTransitions"]
}, Open  ]]
}, Closed]],

Cell["ToWord", "ObjectName",
  CellTags->"ToWord"],

Cell["Type: function", "Highlight",
  CellTags->"ToWord"],

Cell[TextData[{
  StyleBox["ToWord[L,K]", "MR"],
  "  converts a list of indexes to the corresponding word over sorted \
alphabet ",
  StyleBox["K", "MR"],
  "."
}], "Usage",
  CellTags->"ToWord"],

Cell[TextData[{
  " Default alphabet is ",
  StyleBox["$alphabet", "MR"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"ToWord"],

Cell[TextData[{
  "Thus ",
  StyleBox["ToWord[{1,2,2},{a,b}]\[Rule]\"abb\".", "MR"]
}], "Notes",
  CellTags->"ToWord"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToWord"],

Cell["Translating positional lists into words.", "ExampleText",
  CellTags->"ToWord"],

Cell[CellGroupData[{

Cell[" ToWord[Range[5],5]", "Input",
  CellLabel->"In[109]:=",
  CellTags->"ToWord"],

Cell[BoxData[
    \("abcde"\)], "Output",
  CellLabel->"Out[109]=",
  CellTags->"ToWord"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ToWord[{1,2,1,2},{\"aa\",\"bb\"}]", "Input",
  CellLabel->"In[110]:=",
  CellTags->"ToWord"],

Cell[BoxData[
    \("aabbaabb"\)], "Output",
  CellLabel->"Out[110]=",
  CellTags->"ToWord"]
}, Open  ]]
}, Closed]],

Cell["TransferSequenceFA", "ObjectName",
  CellTags->"TransferSequenceFA"],

Cell["Type: function", "Highlight",
  CellTags->"TransferSequenceFA"],

Cell[TextData[{
  StyleBox["TransferSequenceFA[M,S,T]", "MR"],
  "  computes a least word in length-lex order  that leads to state ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " from state ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " in machine M, if such a word exists, for ",
  Cell[BoxData[
      \(TraditionalForm\`\((s, t)\)\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`S\ \[Cross]\ T\)]],
  ". "
}], "Usage",
  CellTags->"TransferSequenceFA"],

Cell[TextData[{
  "Default for S is ",
  StyleBox["Initial[M]", "MR"],
  " and for T ",
  StyleBox["Final[M]", "MR"],
  ". "
}], "Notes",
  CellTags->"TransferSequenceFA"],

Cell[TextData[{
  "The output is given as a  ",
  Cell[BoxData[
      \(TraditionalForm\`S\ \[Cross]\ T\)]],
  "  matrix of words. A dash in position ",
  Cell[BoxData[
      \(TraditionalForm\`\((s, t)\)\)]],
  " indicates that there is no computation im M from s to t."
}], "Notes",
  CellTags->"TransferSequenceFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransferSequenceFA"],

Cell["A DFA based on a de Bruijn graph.", "ExampleText",
  CellTags->"TransferSequenceFA"],

Cell[BoxData[
    \(\(m\  = \ 
        DFA[8, 2, {{1, 3, 5, 7, 1, 3, 5, 7}, {2, 4, 6, 8, 2, 4, 6, 8}}, 
          1, {5, 6, 7, 8}\ ];\)\)], "Input",
  CellLabel->"In[47]:=",
  CellTags->"TransferSequenceFA"],

Cell[CellGroupData[{

Cell["TransferSequenceFA[ m ]", "Input",
  CellLabel->"In[48]:=",
  CellTags->"TransferSequenceFA"],

Cell[BoxData[
    \({{"baa", "bab", "bba", "bbb"}}\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->"TransferSequenceFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransferSequenceFA[ m, Range[8], Range[8] ] // MatrixForm", "Input",
  CellLabel->"In[50]:=",
  CellTags->"TransferSequenceFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "\[Epsilon]", "\<\"b\"\>", "\<\"ba\"\>", "\<\"bb\"\>", "\<\"baa\
\"\>", "\<\"bab\"\>", "\<\"bba\"\>", "\<\"bbb\"\>"},
            {"\<\"aaa\"\>", 
              "\[Epsilon]", "\<\"a\"\>", "\<\"b\"\>", "\<\"aa\"\>", "\<\"ab\"\
\>", "\<\"ba\"\>", "\<\"bb\"\>"},
            {"\<\"aa\"\>", "\<\"ab\"\>", 
              "\[Epsilon]", "\<\"bb\"\>", "\<\"a\"\>", "\<\"b\"\>", \
"\<\"bba\"\>", "\<\"bbb\"\>"},
            {"\<\"aaa\"\>", "\<\"aab\"\>", "\<\"aba\"\>", 
              "\[Epsilon]", "\<\"aa\"\>", "\<\"ab\"\>", "\<\"a\"\>", "\<\"b\"\
\>"},
            {"\<\"a\"\>", "\<\"b\"\>", "\<\"ba\"\>", "\<\"bb\"\>", 
              "\[Epsilon]", "\<\"bab\"\>", "\<\"bba\"\>", "\<\"bbb\"\>"},
            {"\<\"aaa\"\>", "\<\"aab\"\>", "\<\"a\"\>", "\<\"b\"\>", \
"\<\"aa\"\>", "\[Epsilon]", "\<\"ba\"\>", "\<\"bb\"\>"},
            {"\<\"aa\"\>", "\<\"ab\"\>", "\<\"ba\"\>", "\<\"bb\"\>", "\<\"a\"\
\>", "\<\"b\"\>", "\[Epsilon]", "\<\"bbb\"\>"},
            {"\<\"aaa\"\>", "\<\"aab\"\>", "\<\"aba\"\>", "\<\"abb\"\>", \
"\<\"aa\"\>", "\<\"ab\"\>", "\<\"a\"\>", "\[Epsilon]"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[50]//MatrixForm=",
  CellTags->"TransferSequenceFA"]
}, Open  ]]
}, Open  ]],

Cell["TransitionFunctionFA", "ObjectName",
  CellTags->"TransitionFunctionFA"],

Cell["Type: function", "Highlight",
  CellTags->"TransitionFunctionFA"],

Cell[TextData[{
  StyleBox["TransitionFunctionFA[delta,M]", "MR"],
  "  assigns to delta the transition function ",
  Cell[BoxData[
      \(TraditionalForm\`Q\ \[Cross]\ \(K\^*\)\[LongRightArrow]\ Q\)]],
  " (which may be multi-valued for nondeterministic machines). "
}], "Usage",
  CellTags->"TransitionFunctionFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"TransitionFunctionFA"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["HoldRest", "MR"],
  "."
}], "Notes",
  CellTags->"TransitionFunctionFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " causes delta to compute a whole trace of the computation."
}], "Notes",
  CellTags->"TransitionFunctionFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["Transitions",
    ButtonData:>"Transitions",
    ButtonStyle->"AddOnsLink"],
  " ."
}], "Notes",
  CellTags->"TransitionFunctionFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransitionFunctionFA"],

Cell["The transition function of a DFA is point-valued.", "ExampleText",
  CellTags->"TransitionFunctionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = BuildDFA[aaa, abb, bbb, 2];\)\), "\n", 
    \(TransitionFunctionFA[m, \[Delta]]\), "\n", 
    \(\[Delta][1, aaa]\)}], "Input",
  CellLabel->"In[118]:=",
  CellTags->"TransitionFunctionFA"],

Cell[BoxData[
    \(7\)], "Output",
  CellLabel->"Out[120]=",
  CellTags->"TransitionFunctionFA"]
}, Open  ]],

Cell["But for an FA the return value is always a list.", "ExampleText",
  CellTags->"TransitionFunctionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = IthSymbolFA[a, \(-3\)];\)\), "\n", 
    \(TransitionFunctionFA[m, \[Delta]]\), "\n", 
    \(\[Delta][1, aaa]\), "\n", 
    \(\[Delta][2, aaa]\)}], "Input",
  CellLabel->"In[121]:=",
  CellTags->"TransitionFunctionFA"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[123]=",
  CellTags->"TransitionFunctionFA"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[124]=",
  CellTags->"TransitionFunctionFA"]
}, Open  ]],

Cell["The complete unfolding of the computation.", "ExampleText",
  CellTags->"TransitionFunctionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(TransitionFunctionFA[m, \[Delta], Full \[Rule] True]\), "\n", 
    \(\[Delta][1, aaa]\), "\n", 
    \(\[Delta][2, aaa]\)}], "Input",
  CellLabel->"In[128]:=",
  CellTags->"TransitionFunctionFA"],

Cell[BoxData[
    \({{1}, {1, 2}, {1, 2, 3}, {1, 2, 3, 4}}\)], "Output",
  CellLabel->"Out[129]=",
  CellTags->"TransitionFunctionFA"],

Cell[BoxData[
    \({{2}, {3}, {4}, {}}\)], "Output",
  CellLabel->"Out[130]=",
  CellTags->"TransitionFunctionFA"]
}, Open  ]]
}, Closed]],

Cell["TransitionMatrixFA", "ObjectName",
  CellTags->"TransitionMatrixFA"],

Cell["Type: function", "Highlight",
  CellTags->"TransitionMatrixFA"],

Cell[TextData[{
  StyleBox["TransitionMatrixFA[m,f]", "MR"],
  "  constructs the natural homomorphism ",
  Cell[BoxData[
      \(TraditionalForm\`f\  : \ \(K\^*\)\[LongRightArrow]\ Q\[Cross]\ 
          Q\ \[LongRightArrow]\ R\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is a semiring. The default for R is the semiring of natural numbers. Note \
that Boolean matrices are implemented as binary matrices (see Boolean)."
}], "Usage",
  CellTags->"TransitionMatrixFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Type", "\[Rule]", "None", \(Boolean, Tropical\)}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"TransitionMatrixFA"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["HoldRest", "MR"],
  "."
}], "Notes",
  CellTags->"TransitionMatrixFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Type->Boolean", "MR"],
  " selects the Boolean semiring"
}], "Notes",
  CellTags->"TransitionMatrixFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Type->Tropical", "MR"],
  " selects the tropical semiring."
}], "Notes",
  CellTags->"TransitionMatrixFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["TransitionFunctionFA",
    ButtonData:>"TransitionFunctionFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["FullTransitionMatrixFA",
    ButtonData:>"FullTransitionMatrixFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TransitionMatrixFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransitionMatrixFA"],

Cell[TextData[{
  "The function ",
  StyleBox["f", "MR"],
  " takes as input words, and returns as output the corresponding matrix."
}], "ExampleText",
  CellTags->"TransitionMatrixFA"],

Cell[BoxData[{
    \(\(m = IthSymbolFA[a, \(-4\)];\)\), "\n", 
    \(TransitionMatrixFA[m, f]\)}], "Input",
  CellLabel->"In[143]:=",
  CellTags->"TransitionMatrixFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[aaa]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[145]:=",
  CellTags->"TransitionMatrixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "0"},
            {"0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[145]//MatrixForm=",
  CellTags->"TransitionMatrixFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f[aaaa]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[146]:=",
  CellTags->"TransitionMatrixFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[146]//MatrixForm=",
  CellTags->"TransitionMatrixFA"]
}, Open  ]]
}, Closed]],

Cell["TransitionsToMatrix", "ObjectName",
  CellTags->"TransitionsToMatrix"],

Cell["Type: function", "Highlight",
  CellTags->"TransitionsToMatrix"],

Cell[TextData[{
  StyleBox["TransitionsToMatrix[T,n,k]", "MR"],
  "  converts a list of transitions T into the corresponding k by n matrix, \
where k is the alphabet size. "
}], "Usage",
  CellTags->"TransitionsToMatrix"],

Cell["\<\
If the transitions are deterministic and complete a matrix for a \
DFA is produced (an integer matrix of depth 2), otherwise the matrix for an \
NFA is computed (an integer matrix of depth 3).\
\>", "Notes",
  CellTags->"TransitionsToMatrix"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransitionsToMatrix"],

Cell["Nothing at all.", "ExampleText",
  CellTags->"TransitionsToMatrix"],

Cell[CellGroupData[{

Cell["5", "Input",
  CellLabel->"In[1]:=",
  CellTags->"TransitionsToMatrix"],

Cell[BoxData[
    \(5\)], "Output",
  CellLabel->"Out[1]=",
  CellTags->"TransitionsToMatrix"]
}, Open  ]]
}, Closed]],

Cell["Transitions", "ObjectName",
  CellTags->"Transitions"],

Cell["Type: function", "Highlight",
  CellTags->"Transitions"],

Cell[TextData[{
  StyleBox["Transitions[M]", "MR"],
  "  returns the transition matrix (for DFAs) or transitions list (for all \
others), where M is a finite state machine. "
}], "Usage",
  CellTags->"Transitions"],

Cell[TextData[{
  "The entries in a labeled transition list are of the ",
  StyleBox["{p,a,q}", "MR"],
  " where ",
  StyleBox["p", "MR"],
  " and ",
  StyleBox["q", "MR"],
  " are states in positional notation, and ",
  StyleBox["a", "MR"],
  " is a symbol from the alphabet, also in positional notation (0 represents \
epsilon)."
}], "Notes",
  CellTags->"Transitions"],

Cell[TextData[{
  "See also ",
  ButtonBox["FullTransitions",
    ButtonData:>"FullTransitions",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["TransitionFunctionFA",
    ButtonData:>"TransitionFunctionFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Transitions"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Transitions"],

Cell["\<\
The type of the output depends on the type of the input \
machine.\
\>", "ExampleText",
  CellTags->"Transitions"],

Cell[CellGroupData[{

Cell["\<\
m = BuildDFA[aaa,abb,bbb,2];
Transitions[m]\
\>", "Input",
  CellLabel->"In[95]:=",
  CellTags->"Transitions"],

Cell[BoxData[
    \({{2, 4, 6, 7, 6, 6, 6}, {3, 5, 5, 6, 7, 6, 6}}\)], "Output",
  CellLabel->"Out[96]=",
  CellTags->"Transitions"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
m = IthSymbolFA[a,-3];
Transitions[m]\
\>", "Input",
  CellLabel->"In[97]:=",
  CellTags->"Transitions"],

Cell[BoxData[
    \({{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 3}, {3, 1, 4}, {3, 
        2, 4}}\)], "Output",
  CellLabel->"Out[98]=",
  CellTags->"Transitions"]
}, Open  ]]
}, Closed]],

Cell["TransitiveLangQFA", "ObjectName",
  CellTags->"TransitiveLangQFA"],

Cell["Type: function", "Highlight",
  CellTags->"TransitiveLangQFA"],

Cell[TextData[{
  StyleBox["TransitiveLangQFA[M]", "MR"],
  "  tests whether the language accepted by ",
  StyleBox["M", "MR"],
  " is transitive. "
}], "Usage",
  CellTags->"TransitiveLangQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"TransitiveLangQFA"],

Cell["The algorithms assumes that M is factorial, does not check. ", "Notes",
  CellTags->"TransitiveLangQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["TransitiveQFA",
    ButtonData:>"TransitiveQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TransitiveLangQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransitiveLangQFA"],

Cell["\<\
Transitive semiautomata naturally produce transitive \
languages.\
\>", "ExampleText",
  CellTags->"TransitiveLangQFA"],

Cell[CellGroupData[{

Cell[" s = ToSA[CA[110]]", "Input",
  CellLabel->"In[159]:=",
  CellTags->"TransitiveLangQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 
                1}, {3, 2, 2}, {4, 2, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[159]=",
  CellTags->"TransitiveLangQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TransitiveLangQFA[s]\)], "Input",
  CellLabel->"In[160]:=",
  CellTags->"TransitiveLangQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[160]=",
  CellTags->"TransitiveLangQFA"]
}, Open  ]]
}, Closed]],

Cell["TransitiveQFA", "ObjectName",
  CellTags->"TransitiveQFA"],

Cell["Type: function", "Highlight",
  CellTags->"TransitiveQFA"],

Cell[TextData[{
  StyleBox["TransitiveQFA[M,opts]", "MR"],
  "  tests whether M is transitive. "
}], "Usage",
  CellTags->"TransitiveQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"TransitiveQFA"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True", "MR"],
  " causes the strongly connected components of the transition diagram of M \
to be displayed."
}], "Notes",
  CellTags->"TransitiveQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["TransitiveLangQFA",
    ButtonData:>"TransitiveLangQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TransitiveQFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransitiveQFA"],

Cell["\<\
The de Bruijn automata associated with linear cellular automata are \
naturally transitive.\
\>", "ExampleText",
  CellTags->"TransitiveQFA"],

Cell[CellGroupData[{

Cell[" s = ToSA[CA[110]]", "Input",
  CellLabel->"In[163]:=",
  CellTags->"TransitiveQFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"SA", "[", 
        RowBox[{"4", ",", \(-2\), ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 2, 3}, {2, 2, 4}, {3, 1, 
                1}, {3, 2, 2}, {4, 2, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[163]=",
  CellTags->"TransitiveQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TransitiveQFA[s]\)], "Input",
  CellLabel->"In[164]:=",
  CellTags->"TransitiveQFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[164]=",
  CellTags->"TransitiveQFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TransitiveQFA[s, DoTrace \[Rule] True]\)], "Input",
  CellLabel->"In[165]:=",
  CellTags->"TransitiveQFA"],

Cell[BoxData[
    \({{1, 2, 3, 4}}\)], "Output",
  CellLabel->"Out[165]=",
  CellTags->"TransitiveQFA"]
}, Open  ]]
}, Closed]],

Cell["TrimFA", "ObjectName",
  CellTags->"TrimFA"],

Cell["Type: function", "Highlight",
  CellTags->"TrimFA"],

Cell[TextData[{
  StyleBox["TrimFA[M]", "MR"],
  "  constructs the trim part of FA M: only states that are accessible from \
the initial states and coaccessible from the final states are retained."
}], "Usage",
  CellTags->"TrimFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"TrimFA"],

Cell[TextData[{
  "Can also be used in the form ",
  StyleBox["TrimFA[M,S,T]", "MR"],
  " where S replaces the initial states, and T replaces the final states. "
}], "Notes",
  CellTags->"TrimFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["AccessibleFA",
    ButtonData:>"AccessibleFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["CoAccessibleFA",
    ButtonData:>"CoAccessibleFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TrimFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TrimFA"],

Cell["\<\
 A machine on 5 states whose trim part has size 3.The trim part is \
equivalent to the original machine.\
\>", "MathCaption",
  CellTags->"TrimFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ 
      FA[\ 5, \ 2, \ {{1, 1, 3}, {3, 2, 4}, {2, 1, 1}, {2, 2, 
            5}}, {1}, {4}\ ]\)], "Input",
  CellLabel->"In[173]:=",
  CellTags->"TrimFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          TagBox[\({{1, 1, 3}, {3, 2, 4}, {2, 1, 1}, {2, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[173]=",
  CellTags->"TrimFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ma\  = \ TrimFA[m]\), "\n", 
    \(EquivalentQFA[m, ma]\)}], "Input",
  CellLabel->"In[174]:=",
  CellTags->"TrimFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"3", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {2, 2, 3}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({3}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[174]=",
  CellTags->"TrimFA"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[175]=",
  CellTags->"TrimFA"]
}, Open  ]]
}, Closed]],

Cell["TropicalIdentityMatrix", "ObjectName",
  CellTags->"TropicalIdentityMatrix"],

Cell["Type: function", "Highlight",
  CellTags->"TropicalIdentityMatrix"],

Cell[TextData[{
  StyleBox["TropicalIdentityMatrix[n]", "MR"],
  "  generates the ",
  StyleBox["n", "MR"],
  " by ",
  StyleBox["n", "MR"],
  " identity matrix in the tropical semiring. "
}], "Usage",
  CellTags->"TropicalIdentityMatrix"],

Cell[TextData[{
  "See also ",
  ButtonBox["Tropical",
    ButtonData:>"Tropical",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TS",
    ButtonData:>"TS",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LoopAutomatonFA",
    ButtonData:>"LoopAutomatonFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TropicalIdentityMatrix"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TropicalIdentityMatrix"],

Cell[TextData[{
  "The tropical ",
  Cell[BoxData[
      \(TraditionalForm\`4\[Cross]\ 4\)]],
  " identity matrix."
}], "ExampleText",
  CellTags->"TropicalIdentityMatrix"],

Cell[CellGroupData[{

Cell["TropicalIdentityMatrix[4] // MatrixForm", "Input",
  CellLabel->"In[108]:=",
  CellTags->"TropicalIdentityMatrix"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]},
            {
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], "0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]},
            {
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], "0", 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]]},
            {
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 1]], "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[108]//MatrixForm=",
  CellTags->"TropicalIdentityMatrix"]
}, Open  ]]
}, Closed]],

Cell["UnionFA", "ObjectName",
  CellTags->"UnionFA"],

Cell["Type: function", "Highlight",
  CellTags->"UnionFA"],

Cell[TextData[{
  StyleBox["UnionFA[M1,M2]", "MR"],
  "  generates a finite state machine that accepts the union of the \
acceptance languages of ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  ". "
}], "Usage",
  CellTags->"UnionFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"UnionFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " constructs full product machine."
}], "Notes",
  CellTags->"UnionFA"],

Cell[TextData[{
  "Option ",
  StyleBox["Normalize->1", "MR"],
  " preserves state set ",
  Cell[BoxData[
      \(TraditionalForm\`Q\_1\[Cross]Q\_2\)]],
  ". "
}], "Notes",
  CellTags->"UnionFA"],

Cell["\<\
Uses a product machine construction for DFAs and disjoint union for \
other machines. \
\>", "Notes",
  CellTags->"UnionFA"],

Cell["Is polyadic.", "Notes",
  CellTags->"UnionFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["SumFA",
    ButtonData:>"SumFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ProductFA",
    ButtonData:>"ProductFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IntersectionFA",
    ButtonData:>"IntersectionFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"UnionFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"UnionFA"],

Cell["\<\
Two machines for unary languages. The first accepts all words of \
length a multiple of 3, and the second all words of length a multiple of 4.\
\
\>", "ExampleText",
  CellTags->"UnionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m3 = ModCounterDFA[a, 0, 3, 1]\), "\n", 
    \(m4 = ModCounterDFA[a, 0, 4, 1]\)}], "Input",
  CellLabel->"In[51]:=",
  CellTags->"UnionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"3", ",", "1", ",", 
          TagBox[\({{2, 3, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[51]=",
  CellTags->"UnionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"4", ",", "1", ",", 
          TagBox[\({{2, 3, 4, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[52]=",
  CellTags->"UnionFA"]
}, Open  ]],

Cell["\<\
The union machine accepts all words of length a multiple of 3 or 4.\
\
\>", "ExampleText",
  CellTags->"UnionFA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(UnionFA[m3, m4]\), "\n", 
    \(LanguageFA[\ %, \ \(-25\), \ SizeOnly \[Rule] True\ ]\)}], "Input",
  CellLabel->"In[53]:=",
  CellTags->"UnionFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"DFA", "[", 
        RowBox[{"12", ",", "1", ",", 
          TagBox[\({{6, 7, 8, 5, 10, 11, 12, 9, 2, 3, 4, 1}}\),
            (Short[ #, 4]&)], ",", 
          TagBox["1",
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 2, 3, 4, 5, 9}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[53]=",
  CellTags->"UnionFA"],

Cell[BoxData[
    \({1, 0, 0, 1, 1, 0, 1, 0, 1, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 0, 1, 1, 0, 
      0, 1, 0}\)], "Output",
  CellLabel->"Out[54]=",
  CellTags->"UnionFA"]
}, Open  ]]
}, Closed]],

Cell["VerifyFA", "ObjectName",
  CellTags->"VerifyFA"],

Cell["Type: function", "Highlight",
  CellTags->"VerifyFA"],

Cell[TextData[{
  StyleBox["VerifyFA[M]", "MR"],
  "  checks if M is properly constructed. Recommended if a machine is \
constructed 'by hand'. "
}], "Usage",
  CellTags->"VerifyFA"],

Cell[TextData[{
  "Currently, ",
  StyleBox["VerifyFA", "MR"],
  " is quite feeble and needs improvement."
}], "Notes",
  CellTags->"VerifyFA"],

Cell["Further Examples", "ExampleSection",
  CellTags->"VerifyFA"],

Cell["WelchCA", "ObjectName",
  CellTags->"WelchCA"],

Cell["Type: function", "Highlight",
  CellTags->"WelchCA"],

Cell[TextData[{
  StyleBox["WelchCA[C]", "MR"],
  "  computes the Welch indices of a surjective cellular automaton C. "
}], "Usage",
  CellTags->"WelchCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"},
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"WelchCA"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " also produces the actual Welch automata."
}], "Notes",
  CellTags->"WelchCA"],

Cell[TextData[{
  "The algorithm does not check that ",
  StyleBox["C", "MR"],
  " is in fact surjective."
}], "Notes",
  CellTags->"WelchCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WelchCA"],

Cell["\<\
Here is a list of all surjective elementary CAs, and their Welch \
indices.\
\>", "ExampleText",
  CellTags->"WelchCA"],

Cell[BoxData[
    \(\(surj\  = \ {30, 60, 86, 90, 102, 106, 120, 150, 154, 166, 170, 180, 
          204, 210, 240};\)\)], "Input",
  CellLabel->"In[50]:=",
  CellTags->"WelchCA"],

Cell[CellGroupData[{

Cell["WelchCA[CA[#]]& /@ surj // TableForm", "Input",
  CellLabel->"In[52]:=",
  CellTags->"WelchCA"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1", "4"},
          {"1", "2", "2"},
          {"4", "1", "1"},
          {"1", "4", "1"},
          {"2", "2", "1"},
          {"4", "1", "1"},
          {"1", "1", "4"},
          {"1", "4", "1"},
          {"4", "1", "1"},
          {"4", "1", "1"},
          {"4", "1", "1"},
          {"1", "1", "4"},
          {"2", "1", "2"},
          {"1", "1", "4"},
          {"1", "1", "4"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[52]//TableForm=",
  CellTags->"WelchCA"]
}, Open  ]],

Cell["The actual Welch automata for rule .", "ExampleText",
  CellTags->"WelchCA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WelchCA[CA[204], Full \[Rule] True]\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"WelchCA"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\({2, 2}\), ",", 
        RowBox[{"{", 
          RowBox[{
            TagBox[
              RowBox[{"SA", "[", 
                RowBox[{"2", ",", \(-2\), ",", 
                  TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 1}, {2, 2, 2}}\),
                    (Short[ #, 4]&)]}], "]"}],
              HoldForm], ",", 
            TagBox[
              RowBox[{"SA", "[", 
                RowBox[{"2", ",", \(-2\), ",", 
                  TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 1}, {2, 2, 2}}\),
                    (Short[ #, 4]&)]}], "]"}],
              HoldForm]}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[55]=",
  CellTags->"WelchCA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[%[\([2, 1]\)]]\)], "Input",
  CellLabel->"In[56]:=",
  CellTags->"WelchCA"],

Cell[BoxData[
    \({2, 4}\)], "Output",
  CellLabel->"Out[56]=",
  CellTags->"WelchCA"]
}, Open  ]]
}, Closed]],

Cell["WidthCA", "ObjectName",
  CellTags->"WidthCA"],

Cell["Type: function", "Highlight",
  CellTags->"WidthCA"],

Cell[TextData[{
  StyleBox["WidthCA[C]", "MR"],
  "  returns the width of a cellular automaton C."
}], "Usage",
  CellTags->"WidthCA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WidthCA"],

Cell["The width is simply the second field.", "ExampleText",
  CellTags->"WidthCA"],

Cell[CellGroupData[{

Cell["\<\
CA[110]
WidthCA[%]\
\>", "Input",
  CellLabel->"In[45]:=",
  CellTags->"WidthCA"],

Cell[BoxData[
    \(CA[110, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[45]=",
  CellTags->"WidthCA"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"WidthCA"]
}, Open  ]]
}, Closed]],

Cell["WordBinomial", "ObjectName",
  CellTags->"WordBinomial"],

Cell["Type: function", "Highlight",
  CellTags->"WordBinomial"],

Cell[TextData[{
  StyleBox["WordBinomial[u,v]", "MR"],
  "  generalizes binomial coefficients to words: counts the number of \
subwords ",
  StyleBox["v", "MR"],
  " in ",
  StyleBox["u", "MR"],
  ". "
}], "Usage",
  CellTags->"WordBinomial"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"WordBinomial"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True", "MR"],
  " shows values for all prefixes of ",
  StyleBox["u", "MR"],
  " and ",
  StyleBox["v", "MR"],
  "."
}], "Notes",
  CellTags->"WordBinomial"],

Cell["noteworthy", "Notes",
  CellTags->"WordBinomial"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordBinomial"],

Cell[TextData[{
  StyleBox["WordBinomial", "MR"],
  " properly generalizes ordinary binomial coefficients."
}], "ExampleText",
  CellTags->"WordBinomial"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(WordBinomial[aaaaa, aa]\), "\n", 
    \(Binomial[5, 2]\)}], "Input",
  CellLabel->"In[74]:=",
  CellTags->"WordBinomial"],

Cell[BoxData[
    \(10\)], "Output",
  CellLabel->"Out[74]=",
  CellTags->"WordBinomial"],

Cell[BoxData[
    \(10\)], "Output",
  CellLabel->"Out[75]=",
  CellTags->"WordBinomial"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordBinomial[ababa, ab]\)], "Input",
  CellLabel->"In[76]:=",
  CellTags->"WordBinomial"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[76]=",
  CellTags->"WordBinomial"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordBinomial[ababa, ab, DoTrace \[Rule] True]\)], "Input",
  CellLabel->"In[77]:=",
  CellTags->"WordBinomial"],

Cell[BoxData[
    \({{1, 0}, {1, 1}, {2, 1}, {2, 3}, {3, 3}}\)], "Output",
  CellLabel->"Out[77]=",
  CellTags->"WordBinomial"]
}, Open  ]]
}, Closed]],

Cell["WordConjugateQ", "ObjectName",
  CellTags->"WordConjugateQ"],

Cell["Type: function", "Highlight",
  CellTags->"WordConjugateQ"],

Cell[TextData[{
  StyleBox["WordConjugateQ[u,v]", "MR"],
  "  tests whether words ",
  StyleBox["u", "MR"],
  " and ",
  StyleBox["v", "MR"],
  " are conjugates."
}], "Usage",
  CellTags->"WordConjugateQ"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordConjugateQ"],

Cell[TextData[{
  "Uses ",
  StyleBox["StringPosition", "MR"],
  " to determine conjugacy and is therefore linear."
}], "Notes",
  CellTags->"WordConjugateQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordRotate",
    ButtonData:>"WordRotate",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"WordConjugateQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordConjugateQ"],

Cell["Conjugates are obtained by rotation.", "ExampleText",
  CellTags->"WordConjugateQ"],

Cell[CellGroupData[{

Cell["WordConjugateQ[ aaab, baaa ]", "Input",
  CellLabel->"In[95]:=",
  CellTags->"WordConjugateQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[95]=",
  CellTags->"WordConjugateQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WordConjugateQ[ aaab, baab ]", "Input",
  CellLabel->"In[96]:=",
  CellTags->"WordConjugateQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[96]=",
  CellTags->"WordConjugateQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WordConjugateQ[ aaab, Words[4] ]", "Input",
  CellLabel->"In[98]:=",
  CellTags->"WordConjugateQ"],

Cell[BoxData[
    \({False, True, True, False, True, False, False, False, True, False, 
      False, False, False, False, False, False}\)], "Output",
  CellLabel->"Out[98]=",
  CellTags->"WordConjugateQ"]
}, Open  ]]
}, Closed]],

Cell["WordConjugates", "ObjectName",
  CellTags->"WordConjugates"],

Cell["Type: function", "Highlight",
  CellTags->"WordConjugates"],

Cell[TextData[{
  StyleBox["WordConjugates[w]", "MR"],
  "  generates all conjugates of a word ",
  StyleBox["w", "MR"],
  ", in lexicographic order."
}], "Usage",
  CellTags->"WordConjugates"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordConjugates"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordConjugates"],

Cell[TextData[{
  "Conjugates are obtained by rotation. The number of conjugates depends on \
",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ", not just ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\)\)]],
  ". "
}], "ExampleText",
  CellTags->"WordConjugates"],

Cell[CellGroupData[{

Cell["WordConjugates[ aaaab ]", "Input",
  CellLabel->"In[99]:=",
  CellTags->"WordConjugates"],

Cell[BoxData[
    \({"aaaab", "aaaba", "aabaa", "abaaa", "baaaa"}\)], "Output",
  CellLabel->"Out[99]=",
  CellTags->"WordConjugates"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WordConjugates[ abab ]", "Input",
  CellLabel->"In[100]:=",
  CellTags->"WordConjugates"],

Cell[BoxData[
    \({"abab", "baba"}\)], "Output",
  CellLabel->"Out[100]=",
  CellTags->"WordConjugates"]
}, Open  ]]
}, Closed]],

Cell["WordFactorizations", "ObjectName",
  CellTags->"WordFactorizations"],

Cell["Type: function", "Highlight",
  CellTags->"WordFactorizations"],

Cell[TextData[{
  StyleBox["WordFactorizations[w]", "MR"],
  "  generates all factorizations ",
  StyleBox["uv", "MR"],
  " of a word ",
  StyleBox["w.", "MR"],
  " "
}], "Usage",
  CellTags->"WordFactorizations"],

Cell[TextData[{
  "Returns a list of pairs ",
  StyleBox["{u,v}", "MR"],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`w\  = \ uv\)]],
  "."
}], "Notes",
  CellTags->"WordFactorizations"],

Cell["noteworthy", "Notes",
  CellTags->"WordFactorizations"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordFactorizations"],

Cell[TextData[{
  "The output list has length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\(+1\)\)\)]],
  "."
}], "ExampleText",
  CellTags->"WordFactorizations"],

Cell[CellGroupData[{

Cell[" WordFactorizations[abcabc]", "Input",
  CellLabel->"In[93]:=",
  CellTags->"WordFactorizations"],

Cell[BoxData[
    \({{\[Epsilon], "abcabc"}, {"a", "bcabc"}, {"ab", "cabc"}, {"abc", 
        "abc"}, {"abca", "bc"}, {"abcab", 
        "c"}, {"abcabc", \[Epsilon]}}\)], "Output",
  CellLabel->"Out[93]=",
  CellTags->"WordFactorizations"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Concatenate\  /@ \ %\  // \ Union\)], "Input",
  CellLabel->"In[94]:=",
  CellTags->"WordFactorizations"],

Cell[BoxData[
    \({"abcabc"}\)], "Output",
  CellLabel->"Out[94]=",
  CellTags->"WordFactorizations"]
}, Open  ]]
}, Closed]],

Cell["WordFactors", "ObjectName",
  CellTags->"WordFactors"],

Cell["Type: function", "Highlight",
  CellTags->"WordFactors"],

Cell[TextData[{
  StyleBox["WordFactors[w]", "MR"],
  "  generates a list of all factors of word w, in length-lex order. "
}], "Usage",
  CellTags->"WordFactors"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordFactors"],

Cell["Also works on lists of words.", "Notes",
  CellTags->"WordFactors"],

Cell["noteworthy", "Notes",
  CellTags->"WordFactors"],

Cell["noteworthy", "Notes",
  CellTags->"WordFactors"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordPrefixes",
    ButtonData:>"WordPrefixes",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["WordSuffixes",
    ButtonData:>"WordSuffixes",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"WordFactors"],

Cell[TextData[{
  "See also ",
  StyleBox["WordFactorizations", "MR"],
  "."
}], "Notes",
  CellTags->"WordFactors"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordFactors"],

Cell[TextData[{
  "The length of the output list depends on ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  ". "
}], "ExampleText",
  CellTags->"WordFactors"],

Cell[CellGroupData[{

Cell[" WordFactors[aaaaaa]", "Input",
  CellLabel->"In[84]:=",
  CellTags->"WordFactors"],

Cell[BoxData[
    \({\[Epsilon], "a", "aa", "aaa", "aaaa", "aaaaa", "aaaaaa"}\)], "Output",
  CellLabel->"Out[84]=",
  CellTags->"WordFactors"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" WordFactors[abcdef]", "Input",
  CellLabel->"In[86]:=",
  CellTags->"WordFactors"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "c", "d", "e", "f", "ab", "bc", "cd", "de", 
      "ef", "abc", "bcd", "cde", "def", "abcd", "bcde", "cdef", "abcde", 
      "bcdef", "abcdef"}\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->"WordFactors"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" WordPrefixes[{abc,cba}]", "Input",
  CellLabel->"In[87]:=",
  CellTags->"WordFactors"],

Cell[BoxData[
    \({{\[Epsilon], "a", "ab", "abc"}, {\[Epsilon], "c", "cb", 
        "cba"}}\)], "Output",
  CellLabel->"Out[87]=",
  CellTags->"WordFactors"]
}, Open  ]]
}, Closed]],

Cell["WordFusion", "ObjectName",
  CellTags->"WordFusion"],

Cell["Type: function", "Highlight",
  CellTags->"WordFusion"],

Cell[TextData[{
  StyleBox["WordFusion[u,v,r]", "MR"],
  "  returns the ",
  StyleBox["r", "MR"],
  "-fusion of words ",
  StyleBox["u", "MR"],
  " and ",
  StyleBox["v", "MR"],
  ". "
}], "Usage",
  CellTags->"WordFusion"],

Cell[TextData[{
  "Returns ",
  StyleBox["Null", "MR"],
  " if the fusion of the two input words is undefined."
}], "Notes",
  CellTags->"WordFusion"],

Cell[TextData[{
  "The input must have length at least ",
  StyleBox["r", "MR"],
  " (default ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  "). "
}], "Notes",
  CellTags->"WordFusion"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordFusion"],

Cell[TextData[{
  "Fusion overlaps a suffix of ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " and a prefix of ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ". "
}], "ExampleText",
  CellTags->"WordFusion"],

Cell[CellGroupData[{

Cell["WordFusion[ aabb, bbcc, 2 ]", "Input",
  CellLabel->"In[101]:=",
  CellTags->"WordFusion"],

Cell[BoxData[
    \("aabbcc"\)], "Output",
  CellLabel->"Out[101]=",
  CellTags->"WordFusion"]
}, Open  ]],

Cell["WordFusion[ aabb, ccbb, 2 ]", "Input",
  CellLabel->"In[102]:=",
  CellTags->"WordFusion"]
}, Closed]],

Cell["WordLength", "ObjectName",
  CellTags->"WordLength"],

Cell["Type: function", "Highlight",
  CellTags->"WordLength"],

Cell[TextData[{
  StyleBox["WordLength[w]", "MR"],
  "  returns the length of word ",
  StyleBox["w. ", "MR"]
}], "Usage",
  CellTags->"WordLength"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordLength"],

Cell[TextData[{
  StyleBox["WordLength", "MR"],
  " behaves very much like ",
  StyleBox["StringLength", "MR"],
  " but accepts symbols as input and treats the empty word \[Epsilon] \
properly."
}], "Notes",
  CellTags->"WordLength"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordLength"],

Cell[TextData[{
  StyleBox["WordLength", "MR"],
  " deals properly with epsilon."
}], "ExampleText",
  CellTags->"WordLength"],

Cell[CellGroupData[{

Cell["Words[-3]", "Input",
  CellLabel->"In[103]:=",
  CellTags->"WordLength"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "aa", "ab", "ba", "bb", "aaa", "aab", "aba", 
      "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[103]=",
  CellTags->"WordLength"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordLength[%]\)], "Input",
  CellLabel->"In[104]:=",
  CellTags->"WordLength"],

Cell[BoxData[
    \({0, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3}\)], "Output",
  CellLabel->"Out[104]=",
  CellTags->"WordLength"]
}, Open  ]]
}, Closed]],

Cell["WordOrder", "ObjectName",
  CellTags->"WordOrder"],

Cell["Type: function", "Highlight",
  CellTags->"WordOrder"],

Cell[TextData[{
  StyleBox["WordOrder[u,v]", "MR"],
  "  returns -1, 0, +1 depending on the position of ",
  StyleBox["u", "MR"],
  " and ",
  StyleBox["v", "MR"],
  " in the length-lex order"
}], "Usage",
  CellTags->"WordOrder"],

Cell[TextData[{
  "This order is used in many algorithms and in particular in the semimodule \
generation algorithm, see ",
  StyleBox["GenerateCSM", "MR"],
  "."
}], "Notes",
  CellTags->"WordOrder"],

Cell[TextData[{
  " ",
  StyleBox["u", "MR"],
  " is less than ",
  StyleBox["v", "MR"],
  " in the length-lex order if the length of ",
  StyleBox["u", "MR"],
  " is less than the length of ",
  StyleBox["v", "MR"],
  ", or if ",
  StyleBox["u", "MR"],
  " and ",
  StyleBox["v", "MR"],
  " have the same length but ",
  StyleBox["u", "MR"],
  " precedes ",
  StyleBox["v", "MR"],
  " lexicographically. "
}], "Notes",
  CellTags->"WordOrder"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordOrder"],

Cell["All comparisons between words of length at most 2.", "ExampleText",
  CellTags->"WordOrder"],

Cell[CellGroupData[{

Cell["W = Words[-2]", "Input",
  CellLabel->"In[107]:=",
  CellTags->"WordOrder"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "aa", "ab", "ba", "bb"}\)], "Output",
  CellLabel->"Out[107]=",
  CellTags->"WordOrder"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Apply[\ WordOrder, \ 
      CartesianProduct[W, W], {1}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[110]:=",
  CellTags->"WordOrder"],

Cell[BoxData[
    \({0, 1, 1, 1, 1, 1, 1, \(-1\), 0, 1, 1, 1, 1, 1, \(-1\), \(-1\), 0, 1, 
      1, 1, 1, \(-1\), \(-1\), \(-1\), 0, 1, 1, 
      1, \(-1\), \(-1\), \(-1\), \(-1\), 0, 1, 
      1, \(-1\), \(-1\), \(-1\), \(-1\), \(-1\), 0, 
      1, \(-1\), \(-1\), \(-1\), \(-1\), \(-1\), \(-1\), 0}\)], "Output",
  CellLabel->"Out[110]=",
  CellTags->"WordOrder"]
}, Open  ]]
}, Closed]],

Cell["WordPower", "ObjectName",
  CellTags->"WordPower"],

Cell["Type: function", "Highlight",
  CellTags->"WordPower"],

Cell[TextData[{
  StyleBox["WordPower[w,r]", "MR"],
  "  returns word ",
  Cell[BoxData[
      \(TraditionalForm\`w\[VeryThinSpace]w\ \[Ellipsis]\ w\)]],
  " (r times)."
}], "Usage",
  CellTags->"WordPower"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordPower"],

Cell[TextData[{
  "See also ",
  ButtonBox["PrimitiveQ",
    ButtonData:>"PrimitiveQ",
    ButtonStyle->"AddOnsLink"],
  " ,  ",
  ButtonBox["PrimitiveCount",
    ButtonData:>"PrimitiveCount",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"WordPower"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordPower"],

Cell["\<\
The words that fail to be powers of shorter words are primitive. \
\
\>", "ExampleText",
  CellTags->"WordPower"],

Cell[CellGroupData[{

Cell[BoxData[
    \(W = Complement[Words[8], Select[Words[8], PrimitiveQ]]\)], "Input",
  CellLabel->"In[118]:=",
  CellTags->"WordPower"],

Cell[BoxData[
    \({"aaaaaaaa", "aaabaaab", "aabaaaba", "aabbaabb", "abaaabaa", 
      "abababab", "abbaabba", "abbbabbb", "baaabaaa", "baabbaab", "babababa", 
      "babbbabb", "bbaabbaa", "bbabbbab", "bbbabbba", "bbbbbbbb"}\)], "Output",\

  CellLabel->"Out[118]=",
  CellTags->"WordPower"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(W1 = WordPower[Words[2], 4]\)], "Input",
  CellLabel->"In[119]:=",
  CellTags->"WordPower"],

Cell[BoxData[
    \({"aaaaaaaa", "abababab", "babababa", "bbbbbbbb"}\)], "Output",
  CellLabel->"Out[119]=",
  CellTags->"WordPower"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(W2 = WordPower[Words[4], 2]\)], "Input",
  CellLabel->"In[120]:=",
  CellTags->"WordPower"],

Cell[BoxData[
    \({"aaaaaaaa", "aaabaaab", "aabaaaba", "aabbaabb", "abaaabaa", 
      "abababab", "abbaabba", "abbbabbb", "baaabaaa", "baabbaab", "babababa", 
      "babbbabb", "bbaabbaa", "bbabbbab", "bbbabbba", "bbbbbbbb"}\)], "Output",\

  CellLabel->"Out[120]=",
  CellTags->"WordPower"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Union[W1, W2] === \ W\)], "Input",
  CellLabel->"In[121]:=",
  CellTags->"WordPower"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[121]=",
  CellTags->"WordPower"]
}, Open  ]]
}, Closed]],

Cell["WordPrefixes", "ObjectName",
  CellTags->"WordPrefixes"],

Cell["Type: function", "Highlight",
  CellTags->"WordPrefixes"],

Cell[TextData[{
  StyleBox["WordPrefixes[w]", "MR"],
  "  generates all prefixes of w, ",
  "in length-lex order. "
}], "Usage",
  CellTags->"WordPrefixes"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordPrefixes"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordSuffixes",
    ButtonData:>"WordSuffixes",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["WordFactors",
    ButtonData:>"WordFactors",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"WordPrefixes"],

Cell[TextData[{
  "See also ",
  StyleBox["ProperPrefixes", "MR"],
  "."
}], "Notes",
  CellTags->"WordPrefixes"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordPrefixes"],

Cell[TextData[{
  "The output list has length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\(+1\)\)\)]],
  "."
}], "ExampleText",
  CellTags->"WordPrefixes"],

Cell[CellGroupData[{

Cell[" WordPrefixes[abcabc]", "Input",
  CellLabel->"In[82]:=",
  CellTags->"WordPrefixes"],

Cell[BoxData[
    \({\[Epsilon], "a", "ab", "abc", "abca", "abcab", "abcabc"}\)], "Output",
  CellLabel->"Out[82]=",
  CellTags->"WordPrefixes"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" WordPrefixes[{abc,cba}]", "Input",
  CellLabel->"In[81]:=",
  CellTags->"WordPrefixes"],

Cell[BoxData[
    \({{\[Epsilon], "a", "ab", "abc"}, {\[Epsilon], "c", "cb", 
        "cba"}}\)], "Output",
  CellLabel->"Out[81]=",
  CellTags->"WordPrefixes"]
}, Open  ]]
}, Closed]],

Cell["WordReverse", "ObjectName",
  CellTags->"WordReverse"],

Cell["Type: function", "Highlight",
  CellTags->"WordReverse"],

Cell[TextData[{
  StyleBox["WordReverse[w]", "MR"],
  "  reverses the word w like ",
  StyleBox["StringReverse", "MR"],
  " but accepts symbols as input and treats \[Epsilon] properly."
}], "Usage",
  CellTags->"WordReverse"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordReverse"],

Cell["noteworthy", "Notes",
  CellTags->"WordReverse"],

Cell["noteworthy", "Notes",
  CellTags->"WordReverse"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordReverse"],

Cell["Nothing at all.", "ExampleText",
  CellTags->"WordReverse"],

Cell[CellGroupData[{

Cell["5", "Input",
  CellLabel->"In[1]:=",
  CellTags->"WordReverse"],

Cell[BoxData[
    \(5\)], "Output",
  CellLabel->"Out[1]=",
  CellTags->"WordReverse"]
}, Open  ]]
}, Closed]],

Cell["WordRoot", "ObjectName",
  CellTags->"WordRoot"],

Cell["Type: function", "Highlight",
  CellTags->"WordRoot"],

Cell[TextData[{
  StyleBox["WordRoot[w]", "MR"],
  "  computes the root of a word ",
  StyleBox["w", "MR"],
  ", i.e., the shortest word ",
  StyleBox["u", "MR"],
  " such that ",
  StyleBox["w", "MR"],
  " is a power of ",
  StyleBox["u", "MR"],
  "."
}], "Usage",
  CellTags->"WordRoot"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordRoot"],

Cell[TextData[{
  "See also ",
  ButtonBox["PrimitiveQ",
    ButtonData:>"PrimitiveQ",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PrimitiveCount",
    ButtonData:>"PrimitiveCount",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["WordPower",
    ButtonData:>"WordPower",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"WordRoot"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordRoot"],

Cell["All roots of non-primitive words of length 8.", "ExampleText",
  CellTags->"WordRoot"],

Cell[CellGroupData[{

Cell["W = Select[Words[8],!PrimitiveQ[#]&]", "Input",
  CellLabel->"In[135]:=",
  CellTags->"WordRoot"],

Cell[BoxData[
    \({"aaaaaaaa", "aaabaaab", "aabaaaba", "aabbaabb", "abaaabaa", 
      "abababab", "abbaabba", "abbbabbb", "baaabaaa", "baabbaab", "babababa", 
      "babbbabb", "bbaabbaa", "bbabbbab", "bbbabbba", "bbbbbbbb"}\)], "Output",\

  CellLabel->"Out[135]=",
  CellTags->"WordRoot"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordRoot[W]\)], "Input",
  CellLabel->"In[136]:=",
  CellTags->"WordRoot"],

Cell[BoxData[
    \({"a", "aaab", "aaba", "aabb", "abaa", "ab", "abba", "abbb", "baaa", 
      "baab", "ba", "babb", "bbaa", "bbab", "bbba", "b"}\)], "Output",
  CellLabel->"Out[136]=",
  CellTags->"WordRoot"]
}, Open  ]]
}, Closed]],

Cell["WordRotate", "ObjectName",
  CellTags->"WordRotate"],

Cell["Type: function", "Highlight",
  CellTags->"WordRotate"],

Cell[TextData[{
  StyleBox["WordRotate[w,n]", "MR"],
  "  rotates the word ",
  StyleBox["w", "MR"],
  " by ",
  StyleBox["n", "MR"],
  " places to the left.  "
}], "Usage",
  CellTags->"WordRotate"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordRotate"],

Cell[TextData[{
  StyleBox["n", "MR"],
  " has default 1."
}], "Notes",
  CellTags->"WordRotate"],

Cell["Treats epsilon properly. ", "Notes",
  CellTags->"WordRotate"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordConjugateQ",
    ButtonData:>"WordConjugateQ",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["WordConjugates",
    ButtonData:>"WordConjugates",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"WordRotate"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordRotate"],

Cell["All rotations of a word.", "ExampleText",
  CellTags->"WordRotate"],

Cell[CellGroupData[{

Cell["Table[ WordRotate[aaaab,n],{n,0,4}]", "Input",
  CellLabel->"In[142]:=",
  CellTags->"WordRotate"],

Cell[BoxData[
    \({"aaaab", "aaaba", "aabaa", "abaaa", "baaaa"}\)], "Output",
  CellLabel->"Out[142]=",
  CellTags->"WordRotate"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordConjugateQ[aaaab, %]\)], "Input",
  CellLabel->"In[143]:=",
  CellTags->"WordRotate"],

Cell[BoxData[
    \({True, True, True, True, True}\)], "Output",
  CellLabel->"Out[143]=",
  CellTags->"WordRotate"]
}, Open  ]]
}, Closed]],

Cell["WordShuffle", "ObjectName",
  CellTags->"WordShuffle"],

Cell["Type: function", "Highlight",
  CellTags->"WordShuffle"],

Cell[TextData[{
  StyleBox["WordShuffle[u,v]", "MR"],
  "  generates the shuffle language ",
  Cell[BoxData[
      \(TraditionalForm\`u\  || \ v\)]],
  ". "
}], "Usage",
  CellTags->"WordShuffle"],

Cell["Also accepts lists of words as input.", "Notes",
  CellTags->"WordShuffle"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordShuffle"],

Cell["\<\
The size of the output depends on the input words, not just their \
lengths.\
\>", "ExampleText",
  CellTags->"WordShuffle"],

Cell[CellGroupData[{

Cell["WordShuffle[ aaa, aaa ]", "Input",
  CellLabel->"In[144]:=",
  CellTags->"WordShuffle"],

Cell[BoxData[
    \({"aaaaaa"}\)], "Output",
  CellLabel->"Out[144]=",
  CellTags->"WordShuffle"]
}, Open  ]],

Cell[CellGroupData[{

Cell["WordShuffle[ aaa, bbb ]", "Input",
  CellLabel->"In[145]:=",
  CellTags->"WordShuffle"],

Cell[BoxData[
    \({"aaabbb", "aababb", "aabbab", "aabbba", "abaabb", "ababab", "ababba", 
      "abbaab", "abbaba", "abbbaa", "baaabb", "baabab", "baabba", "babaab", 
      "bababa", "babbaa", "bbaaab", "bbaaba", "bbabaa", "bbbaaa"}\)], "Output",\

  CellLabel->"Out[145]=",
  CellTags->"WordShuffle"]
}, Open  ]]
}, Closed]],

Cell["WordSort", "ObjectName",
  CellTags->"WordSort"],

Cell["Type: function", "Highlight",
  CellTags->"WordSort"],

Cell[TextData[{
  StyleBox["WordSort[L]", "MR"],
  "  sorts a list ",
  StyleBox["L", "MR"],
  " of words in length-lex order: first by length, then lexicographically. "
}], "Usage",
  CellTags->"WordSort"],

Cell[TextData[{
  "For example, on alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " the order is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Epsilon]\)\(,\)\(\ \)\(a\)\(,\)\(\ \
\)\(b\)\(,\)\(\ \)\(a\[VeryThinSpace]a\)\(,\)\(\ \
\)\(a\[VeryThinSpace]b\)\(,\)\(\ \)\(b\[VeryThinSpace]a\)\(,\)\(\ \)\(b\
\[VeryThinSpace]b\)\(,\)\(\ \)\(a\[VeryThinSpace]a\[VeryThinSpace]a\)\(,\)\(\ \
\)\(a\[VeryThinSpace]a\[VeryThinSpace]b\)\(\ \)\(,\)\(\[Ellipsis]\)\(\ \
\)\)\)]]
}], "Notes",
  CellTags->"WordSort"],

Cell["\<\
For inductive methods this order is preferable over the standard \
lexicographic order.\
\>", "Notes",
  CellTags->"WordSort"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordOrder",
    ButtonData:>"WordOrder",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"WordSort"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordSort"],

Cell["\<\
The built-in sorting algorithm produces undesirable results when \
applied to sets of words.\
\>", "ExampleText",
  CellTags->"WordSort"],

Cell[CellGroupData[{

Cell[" Sort[ Words[-3]]", "Input",
  CellLabel->"In[146]:=",
  CellTags->"WordSort"],

Cell[BoxData[
    \({"a", "aa", "aaa", "aab", "ab", "aba", "abb", "b", "ba", "baa", "bab", 
      "bb", "bba", "bbb", \[Epsilon]}\)], "Output",
  CellLabel->"Out[146]=",
  CellTags->"WordSort"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordSort[%]\)], "Input",
  CellLabel->"In[147]:=",
  CellTags->"WordSort"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "aa", "ab", "ba", "bb", "aaa", "aab", "aba", 
      "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[147]=",
  CellTags->"WordSort"]
}, Open  ]]
}, Closed]],

Cell["WordSuffixes", "ObjectName",
  CellTags->"WordSuffixes"],

Cell["Type: function", "Highlight",
  CellTags->"WordSuffixes"],

Cell[TextData[{
  StyleBox["WordSuffixes[w]", "MR"],
  "  generates all suffixes of ",
  StyleBox["w", "MR"],
  ", ",
  "in length-lex order. "
}], "Usage",
  CellTags->"WordSuffixes"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"WordSuffixes"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordPrefixes",
    ButtonData:>"WordPrefixes",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["WordFactors",
    ButtonData:>"WordFactors",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"WordSuffixes"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordSuffixes"],

Cell[TextData[{
  "The output list has length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(w\)\(|\)\(+1\)\)\)]],
  "."
}], "ExampleText",
  CellTags->"WordSuffixes"],

Cell[CellGroupData[{

Cell[" WordSuffixes[abcabc]", "Input",
  CellLabel->"In[79]:=",
  CellTags->"WordSuffixes"],

Cell[BoxData[
    \({\[Epsilon], "c", "bc", "abc", "cabc", "bcabc", "abcabc"}\)], "Output",
  CellLabel->"Out[79]=",
  CellTags->"WordSuffixes"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" WordSuffixes[{abc,cba}]", "Input",
  CellLabel->"In[80]:=",
  CellTags->"WordSuffixes"],

Cell[BoxData[
    \({{\[Epsilon], "c", "bc", "abc"}, {\[Epsilon], "a", "ba", 
        "cba"}}\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"WordSuffixes"]
}, Open  ]]
}, Closed]],

Cell["Words", "ObjectName",
  CellTags->"Words"],

Cell["Type: function", "Highlight",
  CellTags->"Words"],

Cell[TextData[{
  StyleBox["Words[r,K]", "MR"],
  "  produces a list of words of length ",
  StyleBox["r", "MR"],
  " over alphabet ",
  StyleBox["K", "MR"],
  ". For negative ",
  StyleBox["r", "MR"],
  " all words up to length ",
  StyleBox["-r", "MR"],
  " are generated. "
}], "Usage",
  CellTags->"Words"],

Cell["One symbol alphabets produce a flattened list.", "Notes",
  CellTags->"Words"],

Cell[TextData[{
  "The defaultvalue for  ",
  StyleBox["K", "MR"],
  "  is ",
  StyleBox["$alphabet", "MR"],
  "."
}], "Notes",
  CellTags->"Words"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Words"],

Cell["Default alphabet and user selected alphabets.", "ExampleText",
  CellTags->"Words"],

Cell[CellGroupData[{

Cell[" Words[3]", "Input",
  CellLabel->"In[69]:=",
  CellTags->"Words"],

Cell[BoxData[
    \({"aaa", "aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[69]=",
  CellTags->"Words"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Words[\(-3\)]\)], "Input",
  CellLabel->"In[70]:=",
  CellTags->"Words"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "aa", "ab", "ba", "bb", "aaa", "aab", "aba", 
      "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[70]=",
  CellTags->"Words"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Words[3, \(-2\)]\)], "Input",
  CellLabel->"In[72]:=",
  CellTags->"Words"],

Cell[BoxData[
    \({"000", "001", "010", "011", "100", "101", "110", "111"}\)], "Output",
  CellLabel->"Out[72]=",
  CellTags->"Words"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Words[3, {"\<x\>", "\<y\>"}]\)], "Input",
  CellLabel->"In[71]:=",
  CellTags->"Words"],

Cell[BoxData[
    \({"xxx", "xxy", "xyx", "xyy", "yxx", "yxy", "yyx", "yyy"}\)], "Output",
  CellLabel->"Out[71]=",
  CellTags->"Words"]
}, Open  ]]
}, Closed]],

Cell["Alphabetic", "ObjectName",
  CellTags->"Alphabetic"],

Cell["Type: option", "Highlight",
  CellTags->"Alphabetic"],

Cell[TextData[{
  StyleBox["Alphabetic", "MR"],
  "  is an option for ",
  StyleBox["FunctionToSA", "MR"],
  " and ",
  StyleBox["FunctionToDFA", "MR"],
  "."
}], "Usage",
  CellTags->"Alphabetic"],

Cell[TextData[{
  "Option ",
  StyleBox["Alphabetic->False", "MR"],
  StyleBox[" uses index notation for letters of the alphabet rather than \
characters.", "Text"]
}], "Notes",
  CellTags->"Alphabetic"],

Cell[TextData[{
  "See also ",
  ButtonBox["FunctionToSA",
    ButtonData:>"FunctionToSA",
    ButtonStyle->"AddOnsLink"],
  " , ",
  ButtonBox["FunctionToDFA",
    ButtonData:>"FunctionToDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Alphabetic"],

Cell["Boundary", "ObjectName",
  CellTags->"Boundary"],

Cell["Type: option", "Highlight",
  CellTags->"Boundary"],

Cell[TextData[{
  StyleBox["Boundary", "MR"],
  "  is an option for ",
  StyleBox["ToBlocks", "MR"],
  ". "
}], "Usage",
  CellTags->"Boundary"],

Cell[TextData[{
  "Acceptable values are ",
  StyleBox["Cyclic", "MR"],
  ", ",
  StyleBox["Fixed", "MR"],
  " and ",
  StyleBox["None", "MR"],
  "."
}], "Notes",
  CellTags->"Boundary"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToBlocks",
    ButtonData:>"ToBlocks",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OrbitCA",
    ButtonData:>"OrbitCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Boundary"],

Cell["Cyclic", "ObjectName",
  CellTags->"Cyclic"],

Cell["Type: option", "Highlight",
  CellTags->"Cyclic"],

Cell[TextData[{
  StyleBox["Cyclic", "MR"],
  "  is a possible value for option ",
  StyleBox["Boundary", "MR"],
  " in ",
  StyleBox["ToBlocks", "MR"],
  " and various operations on cellular automata."
}], "Usage",
  CellTags->"Cyclic"],

Cell[TextData[{
  "See ",
  ButtonBox["ToBlocks",
    ButtonData:>"ToBlocks",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OrbitCA",
    ButtonData:>"OrbitCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Cyclic"],

Cell["EdgeLU", "ObjectName",
  CellTags->"EdgeLU"],

Cell["Type: option", "Highlight",
  CellTags->"EdgeLU"],

Cell[TextData[{
  StyleBox["EdgeLU", "MR"],
  "  is an option for ",
  StyleBox["LocalUniversalFA", "MR"],
  "."
}], "Usage",
  CellTags->"EdgeLU"],

Cell["Determines the choice of edges in the de Bruijn automaton. ", "Notes",
  CellTags->"EdgeLU"],

Cell[TextData[{
  "See ",
  ButtonBox["LocalUniversalFA",
    ButtonData:>"LocalUniversalFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"EdgeLU"],

Cell["Empty", "ObjectName",
  CellTags->"Empty"],

Cell["Type: option", "Highlight",
  CellTags->"Empty"],

Cell[TextData[{
  StyleBox["Empty", "MR"],
  "  is a regular expression that denotes the empty set."
}], "Usage",
  CellTags->"Empty"],

Cell[TextData[{
  "See also ",
  ButtonBox["RegularExpressionToFA",
    ButtonData:>"RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Empty"],

Cell["EpsElim", "ObjectName",
  CellTags->"EpsElim"],

Cell["Type: option", "Highlight",
  CellTags->"EpsElim"],

Cell[TextData[{
  StyleBox["EpsElim", "MR"],
  "  is an option for ",
  StyleBox["StarFA", "MR"],
  " and ",
  StyleBox["RegularExpressionToFA", "MR"],
  ". "
}], "Usage",
  CellTags->"EpsElim"],

Cell[TextData[{
  "Opition ",
  StyleBox["EpsElim->False", "MR"],
  " supresses epsilon elimination and returns an FA with epsilon moves."
}], "Notes",
  CellTags->"EpsElim"],

Cell[TextData[{
  "See also  ",
  ButtonBox["StarFA",
    ButtonData:>"StarFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RegularExpressionToFA",
    ButtonData:>"RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"EpsElim"],

Cell["FinLU", "ObjectName",
  CellTags->"FinLU"],

Cell["Type: option", "Highlight",
  CellTags->"FinLU"],

Cell[TextData[{
  StyleBox["FinLU", "MR"],
  "  is an option for ",
  StyleBox["LocalUniversalFA", "MR"],
  "."
}], "Usage",
  CellTags->"FinLU"],

Cell["Determines the choic of final states. ", "Notes",
  CellTags->"FinLU"],

Cell[TextData[{
  "See ",
  ButtonBox["LocalUniversalFA",
    ButtonData:>"LocalUniversalFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FinLU"],

Cell["Fixed", "ObjectName",
  CellTags->"Fixed"],

Cell["Type: option", "Highlight",
  CellTags->"Fixed"],

Cell[TextData[{
  StyleBox["Fixed", "MR"],
  "  is an option for ",
  StyleBox["ToBlocks", "MR"],
  "."
}], "Usage",
  CellTags->"Fixed"],

Cell["Causes fixed boundary conditions to be used.", "Notes",
  CellTags->"Fixed"],

Cell[TextData[{
  "See ",
  ButtonBox["ToBlocks",
    ButtonData:>"ToBlocks",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Fixed"],

Cell["FLBound", "ObjectName",
  CellTags->"FLBound"],

Cell["Type: option", "Highlight",
  CellTags->"FLBound"],

Cell[TextData[{
  StyleBox["FLBound", "MR"],
  "  is an option for LanguageFA"
}], "Usage",
  CellTags->"FLBound"],

Cell[" Default valueis 50, limits the fixed point computation.", "Notes",
  CellTags->"FLBound"],

Cell[TextData[{
  " Only applies in mode ",
  StyleBox["Full->True", "MR"],
  ". "
}], "Notes",
  CellTags->"FLBound"],

Cell[TextData[{
  "See ",
  ButtonBox["LanguageFA",
    ButtonData:>"LanguageFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FLBound"],

Cell["Hopcroft", "ObjectName",
  CellTags->"Hopcroft"],

Cell["Type: option", "Highlight",
  CellTags->"Hopcroft"],

Cell[TextData[{
  StyleBox["Hopcroft", "MR"],
  " Hopcroft is an option for ",
  StyleBox["StateMergeDFA", "MR"],
  ", "
}], "Usage",
  CellTags->"Hopcroft"],

Cell[TextData[{
  "Causes Hopcroft's ",
  Cell[BoxData[
      \(TraditionalForm\`O(n\ lg\ n)\)]],
  " algorithm to be used. "
}], "Notes",
  CellTags->"Hopcroft"],

Cell["\<\
Note that in the internal implementation, the quadratic standard \
algorithm is actually faster.\
\>", "Notes",
  CellTags->"Hopcroft"],

Cell["Implementation", "ObjectName",
  CellTags->"Implementation"],

Cell["Type: option", "Highlight",
  CellTags->"Implementation"],

Cell[TextData[{
  StyleBox["Implementation", "MR"],
  " Implementation is an option for ",
  StyleBox["LanguageFA", "MR"],
  ". "
}], "Usage",
  CellTags->"Implementation"],

Cell["Allows selection of one of three algorithms.", "Notes",
  CellTags->"Implementation"],

Cell[TextData[{
  "See ",
  ButtonBox["LanguageFA",
    ButtonData:>"LanguageFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Implementation"],

Cell["IniLU", "ObjectName",
  CellTags->"IniLU"],

Cell["Type: option", "Highlight",
  CellTags->"IniLU"],

Cell[TextData[{
  StyleBox["IniLU", "MR"],
  "  is an option for ",
  StyleBox["LocalUniversalFA", "MR"],
  StyleBox[".", "Text"]
}], "Usage",
  CellTags->"IniLU"],

Cell["Determines the choice of initial states. ", "Notes",
  CellTags->"IniLU"],

Cell[TextData[{
  "See ",
  ButtonBox["LocalUniversalFA",
    ButtonData:>"LocalUniversalFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IniLU"],

Cell["ListAble", "ObjectName",
  CellTags->"ListAble"],

Cell["Type: option", "Highlight",
  CellTags->"ListAble"],

Cell[TextData[{
  StyleBox["ListAble", "MR"],
  "  is an option for ",
  StyleBox["MakeHomomorphism", "MR"],
  "."
}], "Usage",
  CellTags->"ListAble"],

Cell[TextData[{
  "See also ",
  ButtonBox["MakeHomomorphism",
    ButtonData:>"MakeHomomorphism",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ListAble"],

Cell["MakeTrim", "ObjectName",
  CellTags->"MakeTrim"],

Cell["Type: option", "Highlight",
  CellTags->"MakeTrim"],

Cell[TextData[{
  StyleBox["MakeTrim", "MR"],
  " MakeTrim is an option for ",
  StyleBox["LanguageFA", "MR"],
  ". "
}], "Usage",
  CellTags->"MakeTrim"],

Cell["\<\
Causes the input automaton to be replaced with its trim version \
before the language is computed.\
\>", "Notes",
  CellTags->"MakeTrim"],

Cell[TextData[{
  "See also ",
  ButtonBox["LanguageFA",
    ButtonData:>"LanguageFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MakeTrim"],

Cell["RegExpSimp", "ObjectName",
  CellTags->"RegExpSimp"],

Cell["Type: option", "Highlight",
  CellTags->"RegExpSimp"],

Cell[TextData[{
  StyleBox["RegExpSimp", "MR"],
  "  is an option for ",
  StyleBox["ToRegularExpressionFA", "MR"],
  ". "
}], "Usage",
  CellTags->"RegExpSimp"],

Cell["\<\
Forces Kleene's algorithm to be used without simplification. Do not \
use on machines with more than about 6 states.\
\>", "Notes",
  CellTags->"RegExpSimp"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToRegularExpressionFA",
    ButtonData:>"ToRegularExpressionFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"RegExpSimp"],

Cell["ShowAll", "ObjectName",
  CellTags->"ShowAll"],

Cell["Type: option", "Highlight",
  CellTags->"ShowAll"],

Cell[TextData[{
  StyleBox["ShowAll", "MR"],
  "   is an option for ",
  StyleBox["PlotComputationFA", "MR"],
  ", "
}], "Usage",
  CellTags->"ShowAll"],

Cell["Causes a display of all potential paths in the computation. ", "Notes",
  CellTags->"ShowAll"],

Cell[TextData[{
  "If set to ",
  StyleBox["False", "MR"],
  " only persistent paths are shown."
}], "Notes",
  CellTags->"ShowAll"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotComputationFA",
    ButtonData:>"PlotComputationFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ShowAll"],

Cell["ShowEdges", "ObjectName",
  CellTags->"ShowEdges"],

Cell["Type: option", "Highlight",
  CellTags->"ShowEdges"],

Cell[TextData[{
  StyleBox["ShowEdges", "MR"],
  "  is an option for ",
  StyleBox["PlotComputationFA", "MR"],
  ","
}], "Usage",
  CellTags->"ShowEdges"],

Cell["\<\
 Causes the edges of the computation graph rather than a graphics \
object to be returned.\
\>", "Notes",
  CellTags->"ShowEdges"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotComputationFA",
    ButtonData:>"PlotComputationFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ShowEdges"],

Cell["SizeOnly", "ObjectName",
  CellTags->"SizeOnly"],

Cell["Type: option", "Highlight",
  CellTags->"SizeOnly"],

Cell[TextData[{
  StyleBox["SizeOnly", "MR"],
  "  is an option in ",
  StyleBox["RegularExpressionToFA", "MR"]
}], "Usage",
  CellTags->"SizeOnly"],

Cell[TextData[{
  "Option ",
  StyleBox["SizeOnly->True", "MR"],
  " in  ",
  StyleBox["LanguageFA", "MR"],
  "  causes a list of the first ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " values of the growth function of the language to be returned."
}], "Notes",
  CellTags->"SizeOnly"],

Cell[TextData[{
  " Option ",
  StyleBox["SizeOnly->True", "MR"],
  " in ",
  StyleBox["RegularExpressionToFA", "MR"],
  " causes  only the size of the FA to be returned. "
}], "Notes",
  CellTags->"SizeOnly"],

Cell[TextData[{
  "See also ",
  ButtonBox["LanguageFA",
    ButtonData:>"LanguageFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RegularExpressionToFA",
    ButtonData:>"RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SizeOnly"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SizeOnly"],

Cell["The usual suspect.", "ExampleText",
  CellTags->"SizeOnly"],

Cell[BoxData[
    \(\(m = 
        FA[4, 2, {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[106]:=",
  CellTags->"SizeOnly"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[\ m, \ \(-10\), \ SizeOnly \[Rule] True\ ]\)], "Input",
  CellLabel->"In[107]:=",
  CellTags->"SizeOnly"],

Cell[BoxData[
    \({0, 0, 0, 4, 8, 16, 32, 64, 128, 256, 512}\)], "Output",
  CellLabel->"Out[107]=",
  CellTags->"SizeOnly"]
}, Open  ]]
}, Closed]],

Cell["Some", "ObjectName",
  CellTags->"Some"],

Cell["Type: option", "Highlight",
  CellTags->"Some"],

Cell[TextData[{
  StyleBox["Some", "MR"],
  "  is an option for ",
  StyleBox["FormatAutomata", "MR"],
  "."
}], "Usage",
  CellTags->"Some"],

Cell[TextData[{
  "See ",
  ButtonBox["FormatAutomata",
    ButtonData:>"FormatAutomata",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Some"],

Cell["Thompson", "ObjectName",
  CellTags->"Thompson"],

Cell["Type: option", "Highlight",
  CellTags->"Thompson"],

Cell[TextData[{
  StyleBox["Thompson", "MR"],
  "  is an option in ",
  StyleBox["RegularExpressionToFA", "MR"],
  ". "
}], "Usage",
  CellTags->"Thompson"],

Cell[TextData[{
  "By default, ",
  StyleBox["Thompson", "MR"],
  " has value ",
  StyleBox["False", "MR"],
  " and a McNaughton-Yamada type machine is used in the conversion."
}], "Notes",
  CellTags->"Thompson"],

Cell[TextData[{
  "See also ",
  ButtonBox["RegularExpressionToFA",
    ButtonData:>"RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Thompson"],

Cell["ToMatrix", "ObjectName",
  CellTags->"ToMatrix"],

Cell["Type: option", "Highlight",
  CellTags->"ToMatrix"],

Cell[TextData[{
  StyleBox["ToMatrix", "MR"],
  "  is an option for ",
  StyleBox["ConvertToFA", "MR"],
  ". "
}], "Usage",
  CellTags->"ToMatrix"],

Cell["\<\
Translates a list of transitions into a transition matrix, as \
needed for DFAs and NFAs.\
\>", "Notes",
  CellTags->"ToMatrix"],

Cell[TextData[{
  "See also ",
  ButtonBox["ConvertToFA",
    ButtonData:>"ConvertToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToMatrix"],

Cell["TransOnly", "ObjectName",
  CellTags->"TransOnly"],

Cell["Type: option", "Highlight",
  CellTags->"TransOnly"],

Cell[TextData[{
  StyleBox["TransOnly", "MR"],
  "  is an option for ",
  StyleBox["PrintFA", "MR"],
  ", "
}], "Usage",
  CellTags->"TransOnly"],

Cell[TextData[{
  "Option ",
  StyleBox["TransOnly->True", "MR"],
  "  causes only the transitions to be printed."
}], "Notes",
  CellTags->"TransOnly"],

Cell[TextData[{
  "See also ",
  ButtonBox["PrintFA",
    ButtonData:>"PrintFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TransOnly"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransOnly"],

Cell["Printing a semiautomaton.", "ExampleText",
  CellTags->"TransOnly"],

Cell[BoxData[
    \(\(m = 
        SA[4, 2, {{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 1}, {3, 
              1, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[103]:=",
  CellTags->"TransOnly"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintFA[m]\)], "Input",
  CellLabel->"In[104]:=",
  CellTags->"TransOnly"],

Cell[BoxData[
    InterpretationBox[\("no. of states:   "\[InvisibleSpace]4\),
      SequenceForm[ "no. of states:   ", 4],
      Editable->False]], "Print",
  CellLabel->"From In[104]:=",
  CellTags->"TransOnly"],

Cell[BoxData[
    InterpretationBox[\("no. transitions: "\[InvisibleSpace]8\),
      SequenceForm[ "no. transitions: ", 8],
      Editable->False]], "Print",
  CellLabel->"From In[104]:=",
  CellTags->"TransOnly"],

Cell[BoxData[
    InterpretationBox[\("alphabet:        "\[InvisibleSpace]{"a", "b"}\),
      SequenceForm[ "alphabet:        ", {"a", "b"}],
      Editable->False]], "Print",
  CellLabel->"From In[104]:=",
  CellTags->"TransOnly"],

Cell[BoxData[
    \("initial states: -all-"\)], "Print",
  CellLabel->"From In[104]:=",
  CellTags->"TransOnly"],

Cell[BoxData[
    \("final states:   -all-"\)], "Print",
  CellLabel->"From In[104]:=",
  CellTags->"TransOnly"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"1"},
                {"\<\"a\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"\<\"b\"\>"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"a\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"b\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"\<\"a\"\>"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"\<\"b\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"4"},
                {"\<\"a\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"4"},
                {"\<\"b\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{1, "a", 1}, {1, "b", 2}, {2, "a", 3}, {2, "b", 4}, {3, 
        "a", 2}, {3, "b", 1}, {4, "a", 4}, {4, "b", 3}}}, TableSpacing -> {1, 
        1}]]], "Output",
  CellLabel->"Out[104]//TableForm=",
  CellTags->"TransOnly"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintFA[m, TransOnly \[Rule] True]\)], "Input",
  CellLabel->"In[105]:=",
  CellTags->"TransOnly"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"1"},
                {"\<\"a\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"\<\"b\"\>"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"a\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"b\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"\<\"a\"\>"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"\<\"b\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"4"},
                {"\<\"a\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"4"},
                {"\<\"b\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{1, "a", 1}, {1, "b", 2}, {2, "a", 3}, {2, "b", 4}, {3, 
        "a", 2}, {3, "b", 1}, {4, "a", 4}, {4, "b", 3}}}, TableSpacing -> {1, 
        1}]]], "Output",
  CellLabel->"Out[105]//TableForm=",
  CellTags->"TransOnly"]
}, Open  ]]
}, Closed]],

Cell["Tropical", "ObjectName",
  CellTags->"Tropical"],

Cell["Type: option", "Highlight",
  CellTags->"Tropical"],

Cell[TextData[{
  StyleBox["Tropical", "MR"],
  "  is an option for ",
  StyleBox["TransitionMatrixFA", "MR"],
  ", "
}], "Usage",
  CellTags->"Tropical"],

Cell["\<\
Causes the matrix to be generated over the tropical semiring.\
\>", \
"Notes",
  CellTags->"Tropical"],

Cell[TextData[{
  " See also ",
  ButtonBox["LoopAutomatonFA",
    ButtonData:>"LoopAutomatonFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["TransitionMatrixFA, Tropical",
    ButtonData:>"TransitionMatrixFA, Tropical",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"Tropical"],

Cell["Unlabeled", "ObjectName",
  CellTags->"Unlabeled"],

Cell["Type: option", "Highlight",
  CellTags->"Unlabeled"],

Cell[TextData[{
  StyleBox["Unlabeled", "MR"],
  "   is an option for ",
  StyleBox["ToGraphFA", "MR"],
  ", causes an unlabeled graph to be generated."
}], "Usage",
  CellTags->"Unlabeled"],

Cell[TextData[{
  "Default value is ",
  StyleBox["True", "MR"],
  "."
}], "Notes",
  CellTags->"Unlabeled"],

Cell[TextData[{
  "See ",
  ButtonBox["ToGraphFA",
    ButtonData:>"ToGraphFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Unlabeled"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Unlabeled"],

Cell["Converting a machine into a graph.", "ExampleText",
  CellTags->"Unlabeled"],

Cell[BoxData[
    \(\(m = 
        FA[4, 2, {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[100]:=",
  CellTags->"Unlabeled"],

Cell[CellGroupData[{

Cell["ToGraphFA[m]", "Input",
  CellLabel->"In[101]:=",
  CellTags->"Unlabeled"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"4", ",", "4", ",", "1", ",", 
          TagBox[\({{1, 1}, {1, 2}, {2, 3}, {3, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[101]=",
  CellTags->"Unlabeled"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToGraphFA[m, Unlabeled \[Rule] False]\)], "Input",
  CellLabel->"In[102]:=",
  CellTags->"Unlabeled"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"4", ",", "7", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[102]=",
  CellTags->"Unlabeled"]
}, Open  ]]
}, Closed]],

Cell["WordMap", "ObjectName",
  CellTags->"WordMap"],

Cell["Type: option", "Highlight",
  CellTags->"WordMap"],

Cell[TextData[{
  StyleBox["WordMap", "MR"],
  "  is an option for an number of functions dealing with cellular automata."
}], "Usage",
  CellTags->"WordMap"],

Cell[TextData[{
  "Associated Functions:\n",
  StyleBox["GlobalMapCA", "MR"],
  "\n",
  StyleBox["LocalMapCA", "MR"],
  "\n",
  StyleBox["OrbitCA", "MR"],
  "\n",
  StyleBox["ToRulesCA", "MR"]
}], "Notes",
  CellTags->"WordMap"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordMap"],

Cell["\<\
The local map of a CA usually operates sequences of integers, but \
can be made to work on strings instead.\
\>", "ExampleText",
  CellTags->"WordMap"],

Cell[BoxData[
    \(LocalMapCA[f, CA[90], WordMap \[Rule] True]\)], "Input",
  CellLabel->"In[150]:=",
  CellTags->"WordMap"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?f\)\)], "Input",
  CellLabel->"In[151]:=",
  CellTags->"WordMap"],

Cell["Global`f", "Print",
  CellTags->"WordMap"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(f["000"] = "0"\)},
                {" "},
                {\(f["001"] = "1"\)},
                {" "},
                {\(f["010"] = "0"\)},
                {" "},
                {\(f["011"] = "1"\)},
                {" "},
                {\(f["100"] = "1"\)},
                {" "},
                {\(f["101"] = "0"\)},
                {" "},
                {\(f["110"] = "1"\)},
                {" "},
                {\(f["111"] = "0"\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "f"],
      Editable->False]], "Print",
  CellTags->"WordMap"]
}, Open  ]]
}, Closed]],

Cell["BEFA", "ObjectName",
  CellTags->"BEFA"],

Cell["Type: header", "Highlight",
  CellTags->"BEFA"],

Cell[TextData[{
  StyleBox["BEFA[n,T]", "MR"],
  "  denotes a begin-exit automaton, a special type of nondeterminisitc \
automaton that has exactly one initial state (begin) and one final state \
(exit).  Moreover, no transitions end at the begin and no transitions start \
at the exit. "
}], "Usage",
  CellTags->"BEFA"],

Cell[TextData[{
  "By convention, 1 is the initial state (begin) and ",
  StyleBox["n", "MR"],
  " is the final state (exit) of  ",
  StyleBox["BEFA[n,T]", "MR"],
  "."
}], "Notes",
  CellTags->"BEFA"],

Cell[TextData[{
  "T is a list of transitions ",
  StyleBox["{p,a,q}", "Input"],
  " where the states are in positional notation but the symbol is a \
character. "
}], "Notes",
  CellTags->"BEFA"],

Cell["Used only in the conversion of regular expressions to FAs.", "Notes",
  CellTags->"BEFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BEFA"],

Cell[TextData[{
  "A BEFA for the language  ",
  Cell[BoxData[
      \(TraditionalForm\`a\ \(\((a + b)\)\^*\)\)]],
  ".  Note the \[Epsilon] transitions."
}], "ExampleText",
  CellTags->"BEFA"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(RegularExpressionToBEFA[\ RET[a, RES[REP[a, b]]]]\)], "Input",
  CellLabel->"In[60]:="]], "Input",
  CellLabel->"In[61]:=",
  CellTags->"BEFA"],

Cell[BoxData[
    \(BEFA[
      5, {{1, "a", 2}, {2, \[Epsilon], 3}, {3, "a", 4}, {3, "b", 
          4}, {3, \[Epsilon], 5}, {4, \[Epsilon], 3}}]\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->"BEFA"]
}, Open  ]]
}, Closed]],

Cell["CA", "ObjectName",
  CellTags->"CA"],

Cell["Type: header", "Highlight",
  CellTags->"CA"],

Cell[TextData[{
  StyleBox["CA[r,w,k]", "MR"],
  "  denotes a linear cellular automaton with width ",
  StyleBox["w", "MR"],
  ", alphabet ",
  StyleBox["k", "MR"],
  " and local rule given by the rule number r. "
}], "Usage",
  CellTags->"CA"],

Cell[TextData[{
  "For elementary cellular automata it suffices to specify only the rule \
number ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0\  \[LessEqual] \ r\  < \ 256\)]],
  ". "
}], "Notes",
  CellTags->"CA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CA"],

Cell["\<\
Elementary cellular automata automatically supply the width and \
alphabet field.\
\>", "ExampleText",
  CellTags->"CA"],

Cell[CellGroupData[{

Cell[" CA[110]", "Input",
  CellLabel->"In[57]:=",
  CellTags->"CA"],

Cell[BoxData[
    \(CA[110, 3, \(-2\)]\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->"CA"]
}, Open  ]],

Cell["In all other cases they must be given explicitely.", "ExampleText",
  CellTags->"CA"],

Cell[CellGroupData[{

Cell[" CA[ 12345, 4, -2 ]", "Input",
  CellLabel->"In[58]:=",
  CellTags->"CA"],

Cell[BoxData[
    \(CA[12345, 4, \(-2\)]\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"CA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintCA[%]\)], "Input",
  CellLabel->"In[59]:=",
  CellTags->"CA"],

Cell[BoxData[
    TagBox[GridBox[{
          {\("0000" \[Rule] "1"\), \("0100" \[Rule] "1"\), \("1000" \[Rule] 
              "0"\), \("1100" \[Rule] "1"\)},
          {\("0001" \[Rule] "0"\), \("0101" \[Rule] "1"\), \("1001" \[Rule] 
              "0"\), \("1101" \[Rule] "1"\)},
          {\("0010" \[Rule] "0"\), \("0110" \[Rule] "0"\), \("1010" \[Rule] 
              "0"\), \("1110" \[Rule] "0"\)},
          {\("0011" \[Rule] "1"\), \("0111" \[Rule] "0"\), \("1011" \[Rule] 
              "0"\), \("1111" \[Rule] "0"\)}
          },
        RowSpacings->1,
        ColumnSpacings->2,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableSpacing -> {1, 2}]]]], "Output",
  CellLabel->"Out[59]//TableForm=",
  CellTags->"CA"]
}, Open  ]]
}, Closed]],

Cell["DFA", "ObjectName",
  CellTags->"DFA"],

Cell["Type: header", "Highlight",
  CellTags->"DFA"],

Cell[TextData[{
  StyleBox["DFA[n,k,T,q0,F]", "MR"],
  "  denotes a deterministic complete finite automaton. "
}], "Usage",
  CellTags->"DFA"],

Cell[TextData[{
  StyleBox["n", "MR"],
  " is the number of states, ",
  StyleBox["k", "MR"],
  " the size of the alphabet, ",
  StyleBox["T", "MR"],
  " the transition matrix, ",
  StyleBox["q0", "MR"],
  " the initial state, and ",
  StyleBox["F", "MR"],
  " the set of final states. "
}], "Notes",
  CellTags->"DFA"],

Cell[TextData[{
  "The entries in ",
  StyleBox["T", "MR"],
  ", ",
  StyleBox["q0", "MR"],
  " and ",
  StyleBox["F", "MR"],
  " are always in positional notation."
}], "Notes",
  CellTags->"DFA"],

Cell[TextData[{
  "The transition matrix ",
  StyleBox["T", "MR"],
  " has dimensions ",
  Cell[BoxData[
      \(TraditionalForm\`k\ \[Cross]\ n\)]],
  ". "
}], "Notes",
  CellTags->"DFA"],

Cell[TextData[{
  " Additional hidden fields may hold a structured state set ",
  StyleBox["Q", "MR"],
  ", an arbitrary list of objects of length ",
  StyleBox["n", "MR"],
  ", and the alphabet, a list of characters of length ",
  StyleBox["k", "MR"],
  ".  The display of these fields depends on the formatting level."
}], "Notes",
  CellTags->"DFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["FormatAutomata",
    ButtonData:>"FormatAutomata",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DFA"],

Cell[TextData[{
  "A simple DFA.  The alphabet is assumed to be ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " and the state set is assumed to be ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], 7}\)]],
  ".  Note how the missing state and alphabet fields are added automatically. \
"
}], "ExampleText",
  CellTags->"DFA"],

Cell[BoxData[
    \(FormatAutomata[None]\)], "Input",
  CellLabel->"In[166]:=",
  CellTags->"DFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(m\)\(\ \ \)\(=\)\(\ \)\(DFA[7, 
        2, {{2, 4, 5, 7, 5, 5, 5}, {3, 5, 6, 5, 5, 7, 5}}, 
        1, {7}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[168]:=",
  CellTags->"DFA"],

Cell[BoxData[
    \(DFA[7, 2, {{2, 4, 5, 7, 5, 5, 5}, {3, 5, 6, 5, 5, 7, 5}}, 
      1, {7}, {}, {}]\)], "Output",
  CellLabel->"Out[168]=",
  CellTags->"DFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(States[m]\), "\n", 
    \(Alphabet[m]\)}], "Input",
  CellLabel->"In[169]:=",
  CellTags->"DFA"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7}\)], "Output",
  CellLabel->"Out[169]=",
  CellTags->"DFA"],

Cell[BoxData[
    \({"a", "b"}\)], "Output",
  CellLabel->"Out[170]=",
  CellTags->"DFA"]
}, Open  ]]
}, Closed]],

Cell["FA", "ObjectName",
  CellTags->"FA"],

Cell["Type: header", "Highlight",
  CellTags->"FA"],

Cell[TextData[{
  StyleBox["FA[n,k,T,I,F]", "MR"],
  "  denotes a general finite automaton. "
}], "Usage",
  CellTags->"FA"],

Cell[TextData[{
  StyleBox["n", "MR"],
  " is the number of states, ",
  StyleBox["k", "MR"],
  " the alphabet size, ",
  StyleBox["T", "MR"],
  " a list of transitions ",
  StyleBox["{p,a,q}.", "MR"]
}], "Notes",
  CellTags->"FA"],

Cell[TextData[{
  "The  initial states are given by ",
  StyleBox["I", "MR"],
  " and the final states by ",
  StyleBox["F", "MR"],
  "."
}], "Notes",
  CellTags->"FA"],

Cell[TextData[{
  StyleBox["The entries in ", "Text"],
  StyleBox["T", "MR"],
  StyleBox[", ", "Text"],
  StyleBox["I", "MR"],
  StyleBox[" and ", "Text"],
  StyleBox["F", "MR"],
  StyleBox["  are in positional notation.", "Text"]
}], "Notes",
  CellTags->"FA"],

Cell[TextData[{
  "There are hidden fields ",
  StyleBox["K", "MR"],
  " for the alphabet and ",
  StyleBox["Q", "MR"],
  " for a structured state set."
}], "Notes",
  CellTags->"FA"],

Cell[TextData[{
  "See also ",
  ButtonBox["FA",
    ButtonData:>"FA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NFA",
    ButtonData:>"NFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DFA",
    ButtonData:>"DFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FA"],

Cell["A small FA.", "ExampleText",
  CellTags->"FA"],

Cell[BoxData[
    \(\(m = 
        FA[4, 2, {{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 3}, {3, 
              1, 4}, {3, 2, 4}}, {1}, {4}];\)\)], "Input",
  CellLabel->"In[101]:=",
  CellTags->"FA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Initial[m]\), "\n", 
    \(Final[m]\), "\n", 
    \(Alphabet[m]\)}], "Input",
  CellLabel->"In[102]:=",
  CellTags->"FA"],

Cell[BoxData[
    \({1}\)], "Output",
  CellLabel->"Out[102]=",
  CellTags->"FA"],

Cell[BoxData[
    \({4}\)], "Output",
  CellLabel->"Out[103]=",
  CellTags->"FA"],

Cell[BoxData[
    \({"a", "b"}\)], "Output",
  CellLabel->"Out[104]=",
  CellTags->"FA"]
}, Open  ]]
}, Closed]],

Cell["NFA", "ObjectName",
  CellTags->"NFA"],

Cell["Type: header", "Highlight",
  CellTags->"NFA"],

Cell[TextData[{
  StyleBox["NFA[n,k,A,I,F]", "MR"],
  "  denotes a non-deterministic finite automaton. "
}], "Usage",
  CellTags->"NFA"],

Cell[TextData[{
  StyleBox["n", "MR"],
  " is the number of states, ",
  StyleBox["k", "MR"],
  " the alphabet size, ",
  StyleBox["A", "MR"],
  " a  ",
  Cell[BoxData[
      \(TraditionalForm\`k\ \[Cross]\ n\)]],
  " matrix of sets of states."
}], "Notes",
  CellTags->"NFA"],

Cell[TextData[{
  "The  initial states are given by ",
  StyleBox["I", "MR"],
  " and the final states by ",
  StyleBox["F", "MR"],
  "."
}], "Notes",
  CellTags->"NFA"],

Cell[TextData[{
  StyleBox["The entries in ", "Text"],
  StyleBox["A", "MR"],
  StyleBox[", ", "Text"],
  StyleBox["I", "MR"],
  StyleBox[" and ", "Text"],
  StyleBox["F", "MR"],
  StyleBox["  are in positional notation.", "Text"]
}], "Notes",
  CellTags->"NFA"],

Cell[TextData[{
  "There are hidden fields ",
  StyleBox["K", "MR"],
  " for the alphabet and ",
  StyleBox["Q", "MR"],
  " for a structured state set."
}], "Notes",
  CellTags->"NFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["FA",
    ButtonData:>"FA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SA",
    ButtonData:>"SA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DFA",
    ButtonData:>"DFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NFA"],

Cell["A small NFA.", "ExampleText",
  CellTags->"NFA"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ 
      NFA[4, 2, {{{1}, {3}, {4}, {}}, {{1, 
              2}, {3}, {4}, {}}}, {1}, {4}]\)], "Input",
  CellLabel->"In[89]:=",
  CellTags->"NFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"NFA", "[", 
        RowBox[{"4", ",", "2", ",", 
          TagBox[\({{{1}, {3}, {4}, {}}, {{1, 2}, {3}, {4}, {}}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[89]=",
  CellTags->"NFA"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transitions[m]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[91]:=",
  CellTags->"NFA"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1}\), \({3}\), \({4}\), \({}\)},
            {\({1, 2}\), \({3}\), \({4}\), \({}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[91]//MatrixForm=",
  CellTags->"NFA"]
}, Open  ]]
}, Closed]],

Cell["NNFA", "ObjectName",
  CellTags->"NNFA"],

Cell["Type: header", "Highlight",
  CellTags->"NNFA"],

Cell[TextData[{
  StyleBox["NNFA[n,E,L,I,F,e]", "MR"],
  "  denotes the tail of a McNaughton-Yamada type finite automaton. "
}], "Usage",
  CellTags->"NNFA"],

Cell["\<\
Meaning of the fields: n: number of states (other than the virtual \
initial states), E: edges in the diagram, L: labels of the nodes, I: states \
at distance 1 from the initial state, F: final states, e: bit indicating \
whether Eps is accepted.\
\>", "Notes",
  CellTags->"NNFA"],

Cell[TextData[{
  "See ",
  ButtonBox["RegularExpressionToNNFA",
    ButtonData:>"RegularExpressionToNNFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NNFAToFA",
    ButtonData:>"NNFAToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NNFA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NNFA"],

Cell["A small NNFA.", "ExampleText",
  CellTags->"NNFA"],

Cell[CellGroupData[{

Cell["RegularExpressionToNNFA[ RES[REP[aa,bb]] ]", "Input",
  CellLabel->"In[84]:=",
  CellTags->"NNFA"],

Cell[BoxData[
    \(NNFA[
      4, {{1, 2}, {2, 1}, {2, 3}, {3, 4}, {4, 1}, {4, 3}}, {"a", "a", "b", 
        "b"}, {1, 3}, {2, 4}, 1]\)], "Output",
  CellLabel->"Out[84]=",
  CellTags->"NNFA"]
}, Open  ]]
}, Closed]],

Cell["REP", "ObjectName",
  CellTags->"REP"],

Cell["Type: header", "Highlight",
  CellTags->"REP"],

Cell[TextData[{
  StyleBox["REP", "MR"],
  "  is a header for regular expressions, denotes union."
}], "Usage",
  CellTags->"REP"],

Cell[TextData[{
  " ",
  StyleBox["REP", "MR"],
  " is polyadic."
}], "Notes",
  CellTags->"REP"],

Cell[TextData[{
  "See also ",
  ButtonBox["RET",
    ButtonData:>"RET",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RES",
    ButtonData:>"RES",
    ButtonStyle->"AddOnsLink"],
  StyleBox[",", "Text"],
  ButtonBox[" RegularExpressionToFA",
    ButtonData:>" RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"REP"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"REP"],

Cell[TextData[{
  "A slightly complicated regular expression for the language of all words \
containing an even number of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s."
}], "ExampleText",
  CellTags->"REP"],

Cell[CellGroupData[{

Cell["\<\
roo = REP[ab,ba]
ree = RES[ REP[aa,bb,RET[roo,RES[REP[aa,bb]],roo]]]\
\>", "Input",
  CellLabel->"In[80]:=",
  CellTags->"REP"],

Cell[BoxData[
    \(REP[ab, ba]\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"REP"],

Cell[BoxData[
    \(RES[
      REP[aa, bb, 
        RET[REP[ab, ba], RES[REP[aa, bb]], REP[ab, ba]]]]\)], "Output",
  CellLabel->"Out[81]=",
  CellTags->"REP"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ RegularExpressionToFA[ree]\)], "Input",
  CellLabel->"In[82]:=",
  CellTags->"REP"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"17", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 4}, {1, 1, 6}, {1, 2, 8}, {2, 1, 
                3}, {3, 1, 2}, \[LeftSkeleton]33\[RightSkeleton], {16, 1, 
                17}, {17, 1, 2}, {17, 2, 4}, {17, 1, 6}, {17, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 3, 5, 15, 17}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[82]=",
  CellTags->"REP"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-6\)]\)], "Input",
  CellLabel->"In[83]:=",
  CellTags->"REP"],

Cell[BoxData[
    \({{\[Epsilon]}, {}, {"aa", "bb"}, {}, {"aaaa", "aabb", "abab", "abba", 
        "baab", "baba", "bbaa", "bbbb"}, {}, {"aaaaaa", "aaaabb", "aaabab", 
        "aaabba", "aabaab", "aababa", "aabbaa", "aabbbb", "abaaab", "abaaba", 
        "ababaa", "ababbb", "abbaaa", "abbabb", "abbbab", "abbbba", "baaaab", 
        "baaaba", "baabaa", "baabbb", "babaaa", "bababb", "babbab", "babbba", 
        "bbaaaa", "bbaabb", "bbabab", "bbabba", "bbbaab", "bbbaba", "bbbbaa", 
        "bbbbbb"}}\)], "Output",
  CellLabel->"Out[83]=",
  CellTags->"REP"]
}, Open  ]]
}, Closed]],

Cell["RES", "ObjectName",
  CellTags->"RES"],

Cell["Type: header", "Highlight",
  CellTags->"RES"],

Cell[TextData[{
  StyleBox["RES", "MR"],
  "  is a header for regular expressions, denotes Kleene star."
}], "Usage",
  CellTags->"RES"],

Cell[TextData[{
  " ",
  StyleBox["RES", "MR"],
  " is unary."
}], "Notes",
  CellTags->"RES"],

Cell[TextData[{
  "See also ",
  ButtonBox["REP",
    ButtonData:>"REP",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RET",
    ButtonData:>"RET",
    ButtonStyle->"AddOnsLink"],
  StyleBox[",", "Text"],
  ButtonBox[" RegularExpressionToFA",
    ButtonData:>" RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"RES"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RES"],

Cell[TextData[{
  "A slightly complicated regular expression for the language of all words \
containing an even number of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s."
}], "ExampleText",
  CellTags->"RES"],

Cell[CellGroupData[{

Cell["\<\
roo = REP[ab,ba]
ree = RES[ REP[aa,bb,RET[roo,RES[REP[aa,bb]],roo]]]\
\>", "Input",
  CellLabel->"In[80]:=",
  CellTags->"RES"],

Cell[BoxData[
    \(REP[ab, ba]\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"RES"],

Cell[BoxData[
    \(RES[
      REP[aa, bb, 
        RET[REP[ab, ba], RES[REP[aa, bb]], REP[ab, ba]]]]\)], "Output",
  CellLabel->"Out[81]=",
  CellTags->"RES"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ RegularExpressionToFA[ree]\)], "Input",
  CellLabel->"In[82]:=",
  CellTags->"RES"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"17", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 4}, {1, 1, 6}, {1, 2, 8}, {2, 1, 
                3}, {3, 1, 2}, \[LeftSkeleton]33\[RightSkeleton], {16, 1, 
                17}, {17, 1, 2}, {17, 2, 4}, {17, 1, 6}, {17, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 3, 5, 15, 17}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[82]=",
  CellTags->"RES"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-6\)]\)], "Input",
  CellLabel->"In[83]:=",
  CellTags->"RES"],

Cell[BoxData[
    \({{\[Epsilon]}, {}, {"aa", "bb"}, {}, {"aaaa", "aabb", "abab", "abba", 
        "baab", "baba", "bbaa", "bbbb"}, {}, {"aaaaaa", "aaaabb", "aaabab", 
        "aaabba", "aabaab", "aababa", "aabbaa", "aabbbb", "abaaab", "abaaba", 
        "ababaa", "ababbb", "abbaaa", "abbabb", "abbbab", "abbbba", "baaaab", 
        "baaaba", "baabaa", "baabbb", "babaaa", "bababb", "babbab", "babbba", 
        "bbaaaa", "bbaabb", "bbabab", "bbabba", "bbbaab", "bbbaba", "bbbbaa", 
        "bbbbbb"}}\)], "Output",
  CellLabel->"Out[83]=",
  CellTags->"RES"]
}, Open  ]]
}, Closed]],

Cell["RET", "ObjectName",
  CellTags->"RET"],

Cell["Type: header", "Highlight",
  CellTags->"RET"],

Cell[TextData[{
  StyleBox["RET", "MR"],
  "  is a header for regular expressions, denotes concatenation."
}], "Usage",
  CellTags->"RET"],

Cell[TextData[{
  " ",
  StyleBox["RET", "MR"],
  " is polyadic."
}], "Notes",
  CellTags->"RET"],

Cell[TextData[{
  "See also ",
  ButtonBox["REP",
    ButtonData:>"REP",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RES",
    ButtonData:>"RES",
    ButtonStyle->"AddOnsLink"],
  StyleBox[",", "Text"],
  ButtonBox[" RegularExpressionToFA",
    ButtonData:>" RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"RET"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RET"],

Cell[TextData[{
  "A slightly complicated regular expression for the language of all words \
containing an even number of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "'s."
}], "ExampleText",
  CellTags->"RET"],

Cell[CellGroupData[{

Cell["\<\
roo = REP[ab,ba]
ree = RES[ REP[aa,bb,RET[roo,RES[REP[aa,bb]],roo]]]\
\>", "Input",
  CellLabel->"In[80]:=",
  CellTags->"RET"],

Cell[BoxData[
    \(REP[ab, ba]\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"RET"],

Cell[BoxData[
    \(RES[
      REP[aa, bb, 
        RET[REP[ab, ba], RES[REP[aa, bb]], REP[ab, ba]]]]\)], "Output",
  CellLabel->"Out[81]=",
  CellTags->"RET"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m\  = \ RegularExpressionToFA[ree]\)], "Input",
  CellLabel->"In[82]:=",
  CellTags->"RET"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"17", ",", "2", ",", 
          
          TagBox[\({{1, 1, 2}, {1, 2, 4}, {1, 1, 6}, {1, 2, 8}, {2, 1, 
                3}, {3, 1, 2}, \[LeftSkeleton]33\[RightSkeleton], {16, 1, 
                17}, {17, 1, 2}, {17, 2, 4}, {17, 1, 6}, {17, 2, 8}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1, 3, 5, 15, 17}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[82]=",
  CellTags->"RET"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[m, \(-6\)]\)], "Input",
  CellLabel->"In[83]:=",
  CellTags->"RET"],

Cell[BoxData[
    \({{\[Epsilon]}, {}, {"aa", "bb"}, {}, {"aaaa", "aabb", "abab", "abba", 
        "baab", "baba", "bbaa", "bbbb"}, {}, {"aaaaaa", "aaaabb", "aaabab", 
        "aaabba", "aabaab", "aababa", "aabbaa", "aabbbb", "abaaab", "abaaba", 
        "ababaa", "ababbb", "abbaaa", "abbabb", "abbbab", "abbbba", "baaaab", 
        "baaaba", "baabaa", "baabbb", "babaaa", "bababb", "babbab", "babbba", 
        "bbaaaa", "bbaabb", "bbabab", "bbabba", "bbbaab", "bbbaba", "bbbbaa", 
        "bbbbbb"}}\)], "Output",
  CellLabel->"Out[83]=",
  CellTags->"RET"]
}, Open  ]]
}, Closed]],

Cell["SA", "ObjectName",
  CellTags->"SA"],

Cell["Type: header", "Highlight",
  CellTags->"SA"],

Cell[TextData[{
  StyleBox["SA[n,k,T]", "MR"],
  "  denotes a semiautomaton. "
}], "Usage",
  CellTags->"SA"],

Cell[TextData[{
  StyleBox["n", "MR"],
  " is the number of states, ",
  StyleBox["k", "MR"],
  " the alphabet size, ",
  StyleBox["T", "MR"],
  " a list of transitions ",
  StyleBox["{p,a,q}.", "MR"]
}], "Notes",
  CellTags->"SA"],

Cell[TextData[{
  StyleBox["The entries in ", "Text"],
  StyleBox["T", "MR"],
  StyleBox[" are always in positional notation.", "Text"]
}], "Notes",
  CellTags->"SA"],

Cell["All states are considered initial and final.", "Notes",
  CellTags->"SA"],

Cell[TextData[{
  "There are hidden fields ",
  StyleBox["K", "MR"],
  " for the alphabet and ",
  StyleBox["Q", "MR"],
  " for a structured state set."
}], "Notes",
  CellTags->"SA"],

Cell[TextData[{
  "See also ",
  ButtonBox["FA",
    ButtonData:>"FA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NFA",
    ButtonData:>"NFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DFA",
    ButtonData:>"DFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SA"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SA"],

Cell["A small semiautomaton.", "ExampleText",
  CellTags->"SA"],

Cell[BoxData[
    \(\(m = 
        SA[4, \(-2\), {{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 
              1}, {3, 1, 2}, {4, 2, 3}, {4, 1, 4}}];\)\)], "Input",
  CellLabel->"In[70]:=",
  CellTags->"SA"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Initial[m]\), "\n", 
    \(Final[m]\), "\n", 
    \(Alphabet[m]\)}], "Input",
  CellLabel->"In[71]:=",
  CellTags->"SA"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[71]=",
  CellTags->"SA"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[72]=",
  CellTags->"SA"],

Cell[BoxData[
    \({"0", "1"}\)], "Output",
  CellLabel->"Out[73]=",
  CellTags->"SA"]
}, Open  ]]
}, Closed]],

Cell["TS", "ObjectName",
  CellTags->"TS"],

Cell["Type: header", "Highlight",
  CellTags->"TS"],

Cell[TextData[{
  StyleBox["TS[x]", "MR"],
  "  denotes an element in the tropical semiring; x is a non-negative integer \
or ",
  StyleBox["Infinity", "MR"],
  ". "
}], "Usage",
  CellTags->"TS"],

Cell[TextData[{
  "The display format of ",
  StyleBox["TS[Infinity]", "MR"],
  " is \[Infinity], and ",
  StyleBox["TS[x]", "MR"],
  " is displayed as ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " for all natural numbers ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Notes",
  CellTags->"TS"],

Cell[TextData[{
  "The arithmetic operations ",
  StyleBox["Plus", "MR"],
  ", ",
  StyleBox["Times", "MR"],
  " and ",
  StyleBox["Power", "MR"],
  " work as usual but their interpretation now is min, + and \[CenterDot]."
}], "Notes",
  CellTags->"TS"],

Cell[TextData[{
  "See ",
  ButtonBox["LoopAutomatonFA",
    ButtonData:>"LoopAutomatonFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Tropical",
    ButtonData:>"Tropical",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TropicalIdentityMatrix",
    ButtonData:>"TropicalIdentityMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TS"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TS"],

Cell["Arithmetic over the tropical semiring.", "ExampleText",
  CellTags->"TS"],

Cell[CellGroupData[{

Cell["TS[1] + TS[3]", "Input",
  CellLabel->"In[60]:=",
  CellTags->"TS"],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[60]=",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TS[1] * TS[3]", "Input",
  CellLabel->"In[61]:=",
  CellTags->"TS"],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TS[2]^3", "Input",
  CellLabel->"In[63]:=",
  CellTags->"TS"],

Cell[BoxData[
    \(6\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TS[1] + TS[Infinity]", "Input",
  CellLabel->"In[64]:=",
  CellTags->"TS"],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[64]=",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TS[1] * TS[Infinity]", "Input",
  CellLabel->"In[65]:=",
  CellTags->"TS"],

Cell[BoxData[
    InterpretationBox["\[Infinity]",
      DirectedInfinity[ 1]]], "Output",
  CellLabel->"Out[65]=",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TS[Infinity]^3", "Input",
  CellLabel->"In[66]:=",
  CellTags->"TS"],

Cell[BoxData[
    InterpretationBox["\[Infinity]",
      DirectedInfinity[ 1]]], "Output",
  CellLabel->"Out[66]=",
  CellTags->"TS"]
}, Open  ]]
}, Closed]],

Cell["$alphabet", "ObjectName",
  CellTags->"alphabet"],

Cell["Type: sysvar", "Highlight",
  CellTags->"alphabet"],

Cell[TextData[{
  StyleBox["$alphabet", "MR"],
  "  is the default alphabet used in commands that require an alphabet as \
part of their input. "
}], "Usage",
  CellTags->"alphabet"],

Cell[TextData[{
  "The default value is 2, which represents standard alphabet ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  ". "
}], "Notes",
  CellTags->"alphabet"],

Cell["\<\
Can be changed by user, but note that sizes of languages and \
machines may increase drastically.\
\>", "Notes",
  CellTags->"alphabet"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"alphabet"],

Cell["We can change the default locally.", "ExampleText",
  CellTags->"alphabet"],

Cell[CellGroupData[{

Cell["Words[-2]", "Input",
  CellLabel->"In[57]:=",
  CellTags->"alphabet"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "aa", "ab", "ba", "bb"}\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->"alphabet"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{$alphabet = 3}, Words[\(-2\)]]\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->"alphabet"],

Cell[BoxData[
    \({\[Epsilon], "a", "b", "c", "aa", "ab", "ac", "ba", "bb", "bc", "ca", 
      "cb", "cc"}\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"alphabet"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{$alphabet = {"\<x\>", "\<y\>"}}, Words[\(-2\)]]\)], "Input",
  CellLabel->"In[59]:=",
  CellTags->"alphabet"],

Cell[BoxData[
    \({\[Epsilon], "x", "y", "xx", "xy", "yx", "yy"}\)], "Output",
  CellLabel->"Out[59]=",
  CellTags->"alphabet"]
}, Open  ]]
}, Closed]],

Cell["$automataReleaseNumber", "ObjectName",
  CellTags->"automataReleaseNumber"],

Cell["Type: sysvar", "Highlight",
  CellTags->"automataReleaseNumber"],

Cell[TextData[{
  StyleBox["$automataReleaseNumber", "MR"],
  "  is the release number of the loaded automata package."
}], "Usage",
  CellTags->"automataReleaseNumber"],

Cell["Currently a slightly random number. ", "Notes",
  CellTags->"automataReleaseNumber"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"automataReleaseNumber"],

Cell["The current version:", "ExampleText",
  CellTags->"automataReleaseNumber"],

Cell[CellGroupData[{

Cell["$automataReleaseNumber", "Input",
  CellLabel->"In[56]:=",
  CellTags->"automataReleaseNumber"],

Cell[BoxData[
    \("4.5"\)], "Output",
  CellLabel->"Out[56]=",
  CellTags->"automataReleaseNumber"]
}, Open  ]]
}, Closed]],

Cell["$bottom", "ObjectName",
  CellTags->"bottom"],

Cell["Type: sysvar", "Highlight",
  CellTags->"bottom"],

Cell[TextData[{
  StyleBox["$bottom", "MR"],
  "   is the default object used for the trap state added to machines by ",
  StyleBox["CompleteFA", "MR"],
  ". "
}], "Usage",
  CellTags->"bottom"],

Cell["Default value is -1.", "Notes",
  CellTags->"bottom"],

Cell["\<\
Is only used when the input machine has a structured state set. \
\
\>", "Notes",
  CellTags->"bottom"],

Cell[TextData[{
  "See also ",
  ButtonBox["CompleteFA",
    ButtonData:>"CompleteFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"bottom"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"bottom"],

Cell["A machine with a structured state set and its completion.", \
"ExampleText",
  CellTags->"bottom"],

Cell[BoxData[
    \(\(m\  = \ SuffixFA[abc, 3, Normalize \[Rule] 1];\)\)], "Input",
  CellLabel->"In[54]:=",
  CellTags->"bottom"],

Cell[CellGroupData[{

Cell[BoxData[
    \(States[m]\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"bottom"],

Cell[BoxData[
    \({\[Epsilon], "a", "ab", "abc"}\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"bottom"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CompleteFA[m]\), "\n", 
    \(States[%]\)}], "Input",
  CellLabel->"In[44]:=",
  CellTags->"bottom"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "3", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 3, 1}, {1, 1, 2}, {2, 2, 
                3}, \[LeftSkeleton]6\[RightSkeleton], {2, 3, 5}, {4, 3, 
                5}, {5, 1, 5}, {5, 2, 5}, {5, 3, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[44]=",
  CellTags->"bottom"],

Cell[BoxData[
    \({\[Epsilon], "a", "ab", "abc", \(-1\)}\)], "Output",
  CellLabel->"Out[45]=",
  CellTags->"bottom"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Block[{\ $bottom\  = \ "\<\[UpTee]\>"}, CompleteFA[m]]\), "\n", 
    \(States[%]\)}], "Input",
  CellLabel->"In[51]:=",
  CellTags->"bottom"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "3", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 3, 1}, {1, 1, 2}, {2, 2, 
                3}, \[LeftSkeleton]6\[RightSkeleton], {2, 3, 5}, {4, 3, 
                5}, {5, 1, 5}, {5, 2, 5}, {5, 3, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({4}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[51]=",
  CellTags->"bottom"],

Cell[BoxData[
    \({\[Epsilon], "a", "ab", "abc", "\[UpTee]"}\)], "Output",
  CellLabel->"Out[52]=",
  CellTags->"bottom"]
}, Open  ]]
}, Closed]],

Cell["$defaultnormalize", "ObjectName",
  CellTags->"defaultnormalize"],

Cell["Type: sysvar", "Highlight",
  CellTags->"defaultnormalize"],

Cell[TextData[{
  StyleBox["$defaultnormalize", "MR"],
  "  is the default value used for all commands with option ",
  StyleBox["Normalize", "MR"],
  "."
}], "Usage",
  CellTags->"defaultnormalize"],

Cell[TextData[{
  "The default setting for ",
  StyleBox["$defaultnormalize", "MR"],
  " is 0, meaning that all machines are normalized."
}], "Notes",
  CellTags->"defaultnormalize"],

Cell[TextData[{
  "A normalized machine has as state set ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], n}\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the size of the machine. Needless to say, this list is not stored in \
the machine."
}], "Notes",
  CellTags->"defaultnormalize"],

Cell[TextData[{
  "Setting ",
  StyleBox["$defaultnormalize = 1", "MR"],
  " will produce state sets whose type determined by the operation performed, \
but the input machines are all treated as if their state sets were \
normalized. For example, ",
  StyleBox["ToDFA", "MR"],
  " will produce a subset of the power set of ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\)]],
  " as state set."
}], "Notes",
  CellTags->"defaultnormalize"],

Cell[TextData[{
  "Setting ",
  StyleBox["$defaultnormalize = 2", "MR"],
  " ",
  "will not only preserve the state structure with respect to the last \
operation, but also the state sets of the input machines. "
}], "Notes",
  CellTags->"defaultnormalize"],

Cell[TextData[{
  "Note that the memory requirement of non-normalized machines may be \
significantly larger than for their normalized counterparts. This true in \
particular for machines produced by command pipelines like ",
  StyleBox["ProductSA[m1,m2] // ToDFA // MinimizeFA", "MR"],
  "."
}], "Notes",
  CellTags->"defaultnormalize"],

Cell[TextData[{
  "See also ",
  ButtonBox["Normalize",
    ButtonData:>"Normalize",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NormalizeFA",
    ButtonData:>"NormalizeFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"defaultnormalize"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"defaultnormalize"],

Cell["By default all machines are normalized.", "ExampleText",
  CellTags->"defaultnormalize"],

Cell[CellGroupData[{

Cell["ToDFA[ IthSymbolFA[b,-3] ] // States", "Input",
  CellLabel->"In[150]:=",
  CellTags->"defaultnormalize"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8}\)], "Output",
  CellLabel->"Out[150]=",
  CellTags->"defaultnormalize"]
}, Open  ]],

Cell["We can override locally.", "ExampleText",
  CellTags->"defaultnormalize"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{$defaultnormalize = 1}, 
      States[ToDFA[IthSymbolFA[b, \(-3\)]]]]\)], "Input",
  CellLabel->"In[152]:=",
  CellTags->"defaultnormalize"],

Cell[BoxData[
    \({{1}, {1, 2}, {1, 3}, {1, 2, 3}, {1, 4}, {1, 2, 4}, {1, 3, 4}, {1, 2, 
        3, 4}}\)], "Output",
  CellLabel->"Out[152]=",
  CellTags->"defaultnormalize"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToDFA[IthSymbolFA[b, \(-3\)], Normalize \[Rule] 1]\  // \ 
      States\)], "Input",
  CellLabel->"In[155]:=",
  CellTags->"defaultnormalize"],

Cell[BoxData[
    \({{1}, {1, 2}, {1, 3}, {1, 2, 3}, {1, 4}, {1, 2, 4}, {1, 3, 4}, {1, 2, 
        3, 4}}\)], "Output",
  CellLabel->"Out[155]=",
  CellTags->"defaultnormalize"]
}, Open  ]]
}, Closed]],

Cell["$LLL", "ObjectName",
  CellTags->"LLL"],

Cell["Type: sysvar", "Highlight",
  CellTags->"LLL"],

Cell[TextData[{
  StyleBox["$LLL", "MR"],
  "   is a global parameter for the recursive language map in command ",
  StyleBox["LanguageFA", "MR"],
  " with option ",
  StyleBox["Implementation\[Rule]3", "MR"],
  " .  "
}], "Usage",
  CellTags->"LLL"],

Cell["This works only for DFAs. ", "Notes",
  CellTags->"LLL"],

Cell[TextData[{
  StyleBox["$LLL[s,p,q]", "MR"],
  " is the collection of all words of length ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " leading from state ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " to state ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  ". "
}], "Notes",
  CellTags->"LLL"],

Cell["Can be used to produce a trace of the algorithm.", "Notes",
  CellTags->"LLL"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LLL"],

Cell[TextData[{
  "A DFA for the language \"3rd symbol from the end is an ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "\". "
}], "ExampleText",
  CellTags->"LLL"],

Cell[BoxData[
    \(\(M\  = \ 
        DFA[8, 2, {{2, 3, 4, 4, 6, 3, 6, 2}, {1, 7, 5, 5, 8, 7, 8, 1}}, 
          1, {4, 5, 6, 8}];\)\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"LLL"],

Cell["The acceptance language up to words of length 3.", "ExampleText",
  CellTags->"LLL"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LanguageFA[M, \(-4\), Implementation \[Rule] 3]\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"LLL"],

Cell[BoxData[
    \({{}, {}, {}, {"aaa", "aab", "aba", "abb"}, {"aaaa", "aaab", "aaba", 
        "aabb", "baaa", "baab", "baba", "babb"}}\)], "Output",
  CellLabel->"Out[9]=",
  CellTags->"LLL"]
}, Closed]],

Cell[TextData[{
  "At level 1, ",
  StyleBox["$LLL", "MR"],
  " is essentially just the transition matrix of the automaton."
}], "ExampleText",
  CellTags->"LLL"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[$LLL[1, p, q], {p, 8}, {q, 8}]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->"LLL"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({"b"}\), \({"a"}\), \({}\), \({}\), \({}\), \({}\), \({}\), \
\({}\)},
            {\({}\), \({}\), \({"a"}\), \({}\), \({}\), \({}\), \({"b"}\), \
\({}\)},
            {\({}\), \({}\), \({}\), \({"a"}\), \({"b"}\), \({}\), \({}\), \
\({}\)},
            {\({}\), \({}\), \({}\), \({"a"}\), \({"b"}\), \({}\), \({}\), \
\({}\)},
            {\({}\), \({}\), \({}\), \({}\), \({}\), \({"a"}\), \({}\), \
\({"b"}\)},
            {\({}\), \({}\), \({"a"}\), \({}\), \({}\), \({}\), \({"b"}\), \
\({}\)},
            {\({}\), \({}\), \({}\), \({}\), \({}\), \({"a"}\), \({}\), \
\({"b"}\)},
            {\({"b"}\), \({"a"}\), \({}\), \({}\), \({}\), \({}\), \({}\), \
\({}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[14]//MatrixForm=",
  CellTags->"LLL"]
}, Closed]],

Cell[TextData[{
  "At level 4, ",
  StyleBox["$LLL", "MR"],
  " we get the transfer sequences of length 4, here from state 1 to any \
target state. "
}], "ExampleText",
  CellTags->"LLL"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[$LLL[4, 1, p], {p, 8}]\  // \ TableForm\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->"LLL"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"abbb\"\>", "\<\"bbbb\"\>"},
          {"\<\"abba\"\>", "\<\"bbba\"\>"},
          {"\<\"abaa\"\>", "\<\"bbaa\"\>"},
          {"\<\"aaaa\"\>", "\<\"baaa\"\>"},
          {"\<\"aaab\"\>", "\<\"baab\"\>"},
          {"\<\"aaba\"\>", "\<\"baba\"\>"},
          {"\<\"abab\"\>", "\<\"bbab\"\>"},
          {"\<\"aabb\"\>", "\<\"babb\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[15]//TableForm=",
  CellTags->"LLL"]
}, Closed]]
}, Closed]],

Cell["$regexrules", "ObjectName",
  CellTags->"regexrules"],

Cell["Type: sysvar", "Highlight",
  CellTags->"regexrules"],

Cell[TextData[{
  StyleBox["$regexrules", "MR"],
  "   is a set of simplification rules for regular expressions. Used \
automatically in ",
  StyleBox["ToRegExp", "MR"],
  "."
}], "Usage",
  CellTags->"regexrules"],

Cell["\<\
The rules can be augmented by the user. Make sure not to introduce \
any cycles, though. \
\>", "Notes",
  CellTags->"regexrules"],

Cell["\<\
Simplification PSPACE hard, so one should not expect great effects \
from a simple collection of rewrite rules. \
\>", "Notes",
  CellTags->"regexrules"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"regexrules"],

Cell["\<\
The rules in $regexrules perform some simplification of regular \
expressions. \
\>", "ExampleText",
  CellTags->"regexrules"],

Cell[CellGroupData[{

Cell["REP[REP[a,b],c] /. $regexrules", "Input",
  CellLabel->"In[105]:=",
  CellTags->"regexrules"],

Cell[BoxData[
    \(REP[a, b, c]\)], "Output",
  CellLabel->"Out[105]=",
  CellTags->"regexrules"]
}, Open  ]],

Cell[CellGroupData[{

Cell["REP[RES[a],Eps] //. $regexrules", "Input",
  CellLabel->"In[108]:=",
  CellTags->"regexrules"],

Cell[BoxData[
    \(RES[a]\)], "Output",
  CellLabel->"Out[108]=",
  CellTags->"regexrules"]
}, Open  ]]
}, Closed]],

Cell["$shortlines", "ObjectName",
  CellTags->"shortlines"],

Cell["Type: sysvar", "Highlight",
  CellTags->"shortlines"],

Cell[TextData[{
  StyleBox["$shortlines", "MR"],
  "  is controls the size of expression printed inside machines when \
formatting is turned on. "
}], "Usage",
  CellTags->"shortlines"],

Cell[TextData[{
  "Formatting applies   ",
  StyleBox["$Short[#,$shortlines]& ", "MR"],
  " to potentially long expressions."
}], "Notes",
  CellTags->"shortlines"],

Cell["Default value is 4. ", "Notes",
  CellTags->"shortlines"],

Cell[TextData[{
  "See also ",
  ButtonBox["FormatAutomata",
    ButtonData:>"FormatAutomata",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"shortlines"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"shortlines"],

Cell["The value can be adjusted locally.", "ExampleText",
  CellTags->"shortlines"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = IthSymbolFA[b, \(-10\)]\)], "Input",
  CellLabel->"In[127]:=",
  CellTags->"shortlines"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"11", ",", "2", ",", 
          TagBox[\(\[LeftSkeleton]1\[RightSkeleton]\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({11}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[127]=",
  CellTags->"shortlines"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($shortlines = 10;\)\), "\n", 
    \(m\)}], "Input",
  CellLabel->"In[137]:=",
  CellTags->"shortlines"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"11", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}, {4, 1, 5}, {4, 2, 5}, {5, 1, 
                6}, {5, 2, 6}, {6, 1, 7}, {6, 2, 7}, {7, 1, 8}, {7, 2, 
                8}, {8, 1, 9}, {8, 2, 9}, {9, 1, 10}, {9, 2, 10}, {10, 1, 
                11}, {10, 2, 11}}\),
            (Short[ #, 10]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 10]&)], ",", 
          TagBox[\({11}\),
            (Short[ #, 10]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[138]=",
  CellTags->"shortlines"]
}, Open  ]],

Cell[BoxData[
    \(\($shortlines = 4;\)\)], "Input",
  CellLabel->"In[136]:=",
  CellTags->"shortlines"]
}, Open  ]],

Cell["$transdispwidth", "ObjectName",
  CellTags->"transdispwidth"],

Cell["Type: sysvar", "Highlight",
  CellTags->"transdispwidth"],

Cell[TextData[{
  StyleBox["$transdispwidth", "MR"],
  "   controls the number of transitions displayed in one row in ",
  StyleBox["PrintFA", "MR"],
  ". "
}], "Usage",
  CellTags->"transdispwidth"],

Cell["Default is 20.", "Notes",
  CellTags->"transdispwidth"],

Cell[TextData[{
  "See ",
  ButtonBox["PrintFA",
    ButtonData:>"PrintFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"transdispwidth"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"transdispwidth"],

Cell["The value can be adjusted locally.", "ExampleText",
  CellTags->"transdispwidth"],

Cell[CellGroupData[{

Cell["m = IthSymbolFA[b,-10]", "Input",
  CellLabel->"In[127]:=",
  CellTags->"transdispwidth"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"11", ",", "2", ",", 
          TagBox[\(\[LeftSkeleton]1\[RightSkeleton]\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({11}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[127]=",
  CellTags->"transdispwidth"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Block[{$transdispwidth = 6}, PrintFA[m]]\)], "Input",
  CellLabel->"In[130]:=",
  CellTags->"transdispwidth"],

Cell[BoxData[
    InterpretationBox[\("no. of states:   "\[InvisibleSpace]11\),
      SequenceForm[ "no. of states:   ", 11],
      Editable->False]], "Print",
  CellLabel->"From In[130]:=",
  CellTags->"transdispwidth"],

Cell[BoxData[
    InterpretationBox[\("no. transitions: "\[InvisibleSpace]21\),
      SequenceForm[ "no. transitions: ", 21],
      Editable->False]], "Print",
  CellLabel->"From In[130]:=",
  CellTags->"transdispwidth"],

Cell[BoxData[
    InterpretationBox[\("alphabet:        "\[InvisibleSpace]{"a", "b"}\),
      SequenceForm[ "alphabet:        ", {"a", "b"}],
      Editable->False]], "Print",
  CellLabel->"From In[130]:=",
  CellTags->"transdispwidth"],

Cell[BoxData[
    InterpretationBox[\("initial states:  "\[InvisibleSpace]{1}\),
      SequenceForm[ "initial states:  ", {1}],
      Editable->False]], "Print",
  CellLabel->"From In[130]:=",
  CellTags->"transdispwidth"],

Cell[BoxData[
    InterpretationBox[\("final states:    "\[InvisibleSpace]{11}\),
      SequenceForm[ "final states:    ", {11}],
      Editable->False]], "Print",
  CellLabel->"From In[130]:=",
  CellTags->"transdispwidth"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {"1"},
                {"\<\"a\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"\<\"b\"\>"},
                {"1"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"1"},
                {"\<\"b\"\>"},
                {"2"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"a\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"2"},
                {"\<\"b\"\>"},
                {"3"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"3"},
                {"\<\"a\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"3"},
                {"\<\"b\"\>"},
                {"4"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"4"},
                {"\<\"a\"\>"},
                {"5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"4"},
                {"\<\"b\"\>"},
                {"5"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"5"},
                {"\<\"a\"\>"},
                {"6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"5"},
                {"\<\"b\"\>"},
                {"6"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"6"},
                {"\<\"a\"\>"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"6"},
                {"\<\"b\"\>"},
                {"7"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"7"},
                {"\<\"a\"\>"},
                {"8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"7"},
                {"\<\"b\"\>"},
                {"8"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"8"},
                {"\<\"a\"\>"},
                {"9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"8"},
                {"\<\"b\"\>"},
                {"9"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"9"},
                {"\<\"a\"\>"},
                {"10"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {"9"},
                {"\<\"b\"\>"},
                {"10"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"10"},
                {"\<\"a\"\>"},
                {"11"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {"10"},
                {"\<\"b\"\>"},
                {"11"}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{1, "a", 1}, {1, "b", 1}, {1, "b", 2}, {2, "a", 3}, {2, 
        "b", 3}, {3, "a", 4}}, {{3, "b", 4}, {4, "a", 5}, {4, "b", 5}, {5, 
        "a", 6}, {5, "b", 6}, {6, "a", 7}}, {{6, "b", 7}, {7, "a", 8}, {7, 
        "b", 8}, {8, "a", 9}, {8, "b", 9}, {9, "a", 10}}, {{9, "b", 10}, {10, 
        "a", 11}, {10, "b", 11}}}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[130]//TableForm=",
  CellTags->"transdispwidth"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{844, 728},
WindowMargins->{{Automatic, 48}, {56, Automatic}},
LanguageCategory->"Mathematica",
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "AcceptQFA"->{
    Cell[1754, 51, 56, 1, 42, "ObjectName",
      CellTags->"AcceptQFA"],
    Cell[1813, 54, 60, 1, 74, "Highlight",
      CellTags->"AcceptQFA"],
    Cell[1876, 57, 137, 4, 43, "Usage",
      CellTags->"AcceptQFA"],
    Cell[2016, 63, 281, 10, 80, "Notes",
      CellTags->"AcceptQFA"],
    Cell[2300, 75, 144, 5, 33, "Notes",
      CellTags->"AcceptQFA"],
    Cell[2447, 82, 161, 5, 33, "Notes",
      CellTags->"AcceptQFA"],
    Cell[2633, 91, 67, 1, 59, "ExampleSection",
      CellTags->"AcceptQFA"],
    Cell[2703, 94, 169, 6, 70, "ExampleText",
      CellTags->"AcceptQFA"],
    Cell[2897, 104, 87, 2, 70, "Input",
      CellTags->"AcceptQFA"],
    Cell[2987, 108, 378, 12, 70, "Output",
      CellTags->"AcceptQFA"],
    Cell[3402, 125, 103, 3, 70, "Input",
      CellTags->"AcceptQFA"],
    Cell[3508, 130, 89, 3, 70, "Output",
      CellTags->"AcceptQFA"],
    Cell[3634, 138, 125, 3, 70, "Input",
      CellTags->"AcceptQFA"],
    Cell[3762, 143, 103, 3, 70, "Output",
      CellTags->"AcceptQFA"],
    Cell[3880, 149, 79, 1, 70, "ExampleText",
      CellTags->"AcceptQFA"],
    Cell[3984, 154, 123, 3, 70, "Input",
      CellTags->"AcceptQFA"],
    Cell[4110, 159, 133, 3, 70, "Output",
      CellTags->"AcceptQFA"]},
  "AccessibleFA"->{
    Cell[4270, 166, 62, 1, 31, "ObjectName",
      CellTags->"AccessibleFA"],
    Cell[4335, 169, 63, 1, 74, "Highlight",
      CellTags->"AccessibleFA"],
    Cell[4401, 172, 171, 6, 43, "Usage",
      CellTags->"AccessibleFA"],
    Cell[4575, 180, 319, 10, 82, "Notes",
      CellTags->"AccessibleFA"],
    Cell[4897, 192, 92, 1, 33, "Notes",
      CellTags->"AccessibleFA"],
    Cell[4992, 195, 129, 4, 33, "Notes",
      CellTags->"AccessibleFA"],
    Cell[5124, 201, 264, 11, 33, "Notes",
      CellTags->"AccessibleFA"],
    Cell[5413, 216, 70, 1, 59, "ExampleSection",
      CellTags->"AccessibleFA"],
    Cell[5486, 219, 180, 4, 70, "MathCaption",
      CellTags->"AccessibleFA"],
    Cell[5691, 227, 204, 5, 70, "Input",
      CellTags->"AccessibleFA"],
    Cell[5898, 234, 398, 12, 70, "Output",
      CellTags->"AccessibleFA"],
    Cell[6333, 251, 149, 4, 70, "Input",
      CellTags->"AccessibleFA"],
    Cell[6485, 257, 377, 12, 70, "Output",
      CellTags->"AccessibleFA"],
    Cell[6865, 271, 91, 3, 70, "Output",
      CellTags->"AccessibleFA"],
    Cell[6971, 277, 106, 1, 70, "MathCaption",
      CellTags->"AccessibleFA"],
    Cell[7102, 282, 136, 3, 70, "Input",
      CellTags->"AccessibleFA"],
    Cell[7241, 287, 96, 3, 70, "Output",
      CellTags->"AccessibleFA"],
    Cell[7374, 295, 136, 3, 70, "Input",
      CellTags->"AccessibleFA"],
    Cell[7513, 300, 96, 3, 70, "Output",
      CellTags->"AccessibleFA"]},
  "AddTransitionFA"->{
    Cell[7636, 307, 68, 1, 31, "ObjectName",
      CellTags->"AddTransitionFA"],
    Cell[7707, 310, 66, 1, 74, "Highlight",
      CellTags->"AddTransitionFA"],
    Cell[7776, 313, 399, 14, 64, "Usage",
      CellTags->"AddTransitionFA"],
    Cell[8178, 329, 131, 4, 33, "Notes",
      CellTags->"AddTransitionFA"],
    Cell[8312, 335, 184, 7, 33, "Notes",
      CellTags->"AddTransitionFA"],
    Cell[8521, 346, 73, 1, 59, "ExampleSection",
      CellTags->"AddTransitionFA"],
    Cell[8597, 349, 94, 1, 70, "ExampleText",
      CellTags->"AddTransitionFA"],
    Cell[8716, 354, 204, 5, 70, "Input",
      CellTags->"AddTransitionFA"],
    Cell[8923, 361, 392, 12, 70, "Output",
      CellTags->"AddTransitionFA"],
    Cell[9318, 375, 120, 3, 70, "Output",
      CellTags->"AddTransitionFA"],
    Cell[9453, 381, 158, 6, 70, "ExampleText",
      CellTags->"AddTransitionFA"],
    Cell[9636, 391, 172, 4, 70, "Input",
      CellTags->"AddTransitionFA"],
    Cell[9811, 397, 403, 12, 70, "Output",
      CellTags->"AddTransitionFA"],
    Cell[10217, 411, 212, 4, 70, "Output",
      CellTags->"AddTransitionFA"],
    Cell[10444, 418, 161, 6, 70, "ExampleText",
      CellTags->"AddTransitionFA"],
    Cell[10630, 428, 178, 4, 70, "Input",
      CellTags->"AddTransitionFA"],
    Cell[10811, 434, 739, 13, 70, "Output",
      CellTags->"AddTransitionFA"]},
  "AllDFA"->{
    Cell[11577, 451, 50, 1, 31, "ObjectName",
      CellTags->"AllDFA"],
    Cell[11630, 454, 57, 1, 74, "Highlight",
      CellTags->"AllDFA"],
    Cell[11690, 457, 172, 6, 43, "Usage",
      CellTags->"AllDFA"],
    Cell[11865, 465, 225, 9, 58, "Notes",
      CellTags->"AllDFA"],
    Cell[12093, 476, 148, 5, 33, "Notes",
      CellTags->"AllDFA"],
    Cell[12266, 485, 64, 1, 59, "ExampleSection",
      CellTags->"AllDFA"],
    Cell[12333, 488, 179, 6, 70, "ExampleText",
      CellTags->"AllDFA"],
    Cell[12537, 498, 118, 3, 70, "Input",
      CellTags->"AllDFA"],
    Cell[12658, 503, 371, 12, 70, "Output",
      CellTags->"AllDFA"],
    Cell[13066, 520, 102, 3, 70, "Input",
      CellTags->"AllDFA"],
    Cell[13171, 525, 386, 7, 70, "Output",
      CellTags->"AllDFA"]},
  "AlphabetSize"->{
    Cell[13584, 536, 62, 1, 31, "ObjectName",
      CellTags->"AlphabetSize"],
    Cell[13649, 539, 63, 1, 74, "Highlight",
      CellTags->"AlphabetSize"],
    Cell[13715, 542, 164, 6, 43, "Usage",
      CellTags->"AlphabetSize"],
    Cell[13882, 550, 73, 1, 33, "Notes",
      CellTags->"AlphabetSize"],
    Cell[13958, 553, 264, 11, 33, "Notes",
      CellTags->"AlphabetSize"],
    Cell[14247, 568, 70, 1, 59, "ExampleSection",
      CellTags->"AlphabetSize"],
    Cell[14320, 571, 89, 1, 70, "ExampleText",
      CellTags->"AlphabetSize"],
    Cell[14434, 576, 207, 8, 70, "Input",
      CellTags->"AlphabetSize"],
    Cell[14644, 586, 89, 3, 70, "Output",
      CellTags->"AlphabetSize"],
    Cell[14748, 592, 76, 1, 70, "ExampleText",
      CellTags->"AlphabetSize"],
    Cell[14849, 597, 110, 3, 70, "Input",
      CellTags->"AlphabetSize"],
    Cell[14962, 602, 89, 3, 70, "Output",
      CellTags->"AlphabetSize"],
    Cell[15088, 610, 107, 3, 70, "Input",
      CellTags->"AlphabetSize"],
    Cell[15198, 615, 89, 3, 70, "Output",
      CellTags->"AlphabetSize"]},
  "Alphabet"->{
    Cell[15314, 622, 54, 1, 31, "ObjectName",
      CellTags->"Alphabet"],
    Cell[15371, 625, 59, 1, 74, "Highlight",
      CellTags->"Alphabet"],
    Cell[15433, 628, 161, 6, 43, "Usage",
      CellTags->"Alphabet"],
    Cell[15597, 636, 131, 4, 33, "Notes",
      CellTags->"Alphabet"],
    Cell[15731, 642, 82, 1, 33, "Notes",
      CellTags->"Alphabet"],
    Cell[15816, 645, 269, 11, 33, "Notes",
      CellTags->"Alphabet"],
    Cell[16110, 660, 66, 1, 59, "ExampleSection",
      CellTags->"Alphabet"],
    Cell[16179, 663, 84, 1, 70, "ExampleText",
      CellTags->"Alphabet"],
    Cell[16288, 668, 199, 8, 70, "Input",
      CellTags->"Alphabet"],
    Cell[16490, 678, 99, 3, 70, "Output",
      CellTags->"Alphabet"],
    Cell[16626, 686, 187, 7, 70, "Input",
      CellTags->"Alphabet"],
    Cell[16816, 695, 99, 3, 70, "Output",
      CellTags->"Alphabet"],
    Cell[16930, 701, 70, 1, 70, "ExampleText",
      CellTags->"Alphabet"],
    Cell[17025, 706, 86, 2, 70, "Input",
      CellTags->"Alphabet"],
    Cell[17114, 710, 104, 3, 70, "Output",
      CellTags->"Alphabet"]},
  "AmbiguousQFA"->{
    Cell[17245, 717, 62, 1, 31, "ObjectName",
      CellTags->"AmbiguousQFA"],
    Cell[17310, 720, 63, 1, 74, "Highlight",
      CellTags->"AmbiguousQFA"],
    Cell[17376, 723, 167, 6, 43, "Usage",
      CellTags->"AmbiguousQFA"],
    Cell[17546, 731, 295, 10, 80, "Notes",
      CellTags->"AmbiguousQFA"],
    Cell[17844, 743, 205, 6, 54, "Notes",
      CellTags->"AmbiguousQFA"],
    Cell[18052, 751, 134, 4, 33, "Notes",
      CellTags->"AmbiguousQFA"],
    Cell[18211, 759, 70, 1, 59, "ExampleSection",
      CellTags->"AmbiguousQFA"],
    Cell[18284, 762, 81, 1, 70, "ExampleText",
      CellTags->"AmbiguousQFA"],
    Cell[18390, 767, 219, 8, 70, "Input",
      CellTags->"AmbiguousQFA"],
    Cell[18612, 777, 90, 3, 70, "Output",
      CellTags->"AmbiguousQFA"],
    Cell[18717, 783, 104, 1, 70, "ExampleText",
      CellTags->"AmbiguousQFA"],
    Cell[18846, 788, 145, 4, 70, "Input",
      CellTags->"AmbiguousQFA"],
    Cell[18994, 794, 92, 3, 70, "Output",
      CellTags->"AmbiguousQFA"]},
  "Arden"->{
    Cell[19113, 801, 48, 1, 31, "ObjectName",
      CellTags->"Arden"],
    Cell[19164, 804, 56, 1, 74, "Highlight",
      CellTags->"Arden"],
    Cell[19223, 807, 310, 8, 64, "Usage",
      CellTags->"Arden"],
    Cell[19536, 817, 117, 5, 33, "Notes",
      CellTags->"Arden"],
    Cell[19656, 824, 203, 5, 54, "Notes",
      CellTags->"Arden"],
    Cell[19884, 833, 63, 1, 59, "ExampleSection",
      CellTags->"Arden"],
    Cell[19950, 836, 266, 9, 70, "ExampleText",
      CellTags->"Arden"],
    Cell[20241, 849, 136, 3, 70, "Input",
      CellTags->"Arden"],
    Cell[20380, 854, 373, 12, 70, "Output",
      CellTags->"Arden"],
    Cell[20790, 871, 267, 6, 70, "Input",
      CellTags->"Arden"],
    Cell[21060, 879, 1533, 40, 70, "Output",
      CellTags->"Arden"],
    Cell[22608, 922, 273, 12, 70, "ExampleText",
      CellTags->"Arden"],
    Cell[22906, 938, 133, 4, 70, "Input",
      CellTags->"Arden"],
    Cell[23042, 944, 177, 4, 70, "Output",
      CellTags->"Arden"],
    Cell[23234, 951, 296, 12, 70, "ExampleText",
      CellTags->"Arden"],
    Cell[23555, 967, 133, 4, 70, "Input",
      CellTags->"Arden"],
    Cell[23691, 973, 171, 5, 70, "Output",
      CellTags->"Arden"],
    Cell[23899, 983, 120, 4, 70, "Input",
      CellTags->"Arden"],
    Cell[24022, 989, 154, 4, 70, "Output",
      CellTags->"Arden"],
    Cell[24191, 996, 116, 4, 70, "ExampleText",
      CellTags->"Arden"],
    Cell[24332, 1004, 129, 4, 70, "Input",
      CellTags->"Arden"],
    Cell[24464, 1010, 350, 7, 70, "Output",
      CellTags->"Arden"],
    Cell[24851, 1022, 120, 4, 70, "Input",
      CellTags->"Arden"],
    Cell[24974, 1028, 286, 7, 70, "Output",
      CellTags->"Arden"],
    Cell[25275, 1038, 192, 5, 70, "ExampleText",
      CellTags->"Arden"],
    Cell[25492, 1047, 183, 5, 70, "Input",
      CellTags->"Arden"],
    Cell[25678, 1054, 148, 4, 70, "Output",
      CellTags->"Arden"],
    Cell[25841, 1061, 122, 4, 70, "ExampleText",
      CellTags->"Arden"],
    Cell[25988, 1069, 224, 5, 70, "Input",
      CellTags->"Arden"],
    Cell[26215, 1076, 84, 3, 70, "Output",
      CellTags->"Arden"]},
  "BehaviorFA"->{
    Cell[26326, 1083, 58, 1, 31, "ObjectName",
      CellTags->"BehaviorFA"],
    Cell[26387, 1086, 61, 1, 74, "Highlight",
      CellTags->"BehaviorFA"],
    Cell[26451, 1089, 409, 14, 64, "Usage",
      CellTags->"BehaviorFA"],
    Cell[26863, 1105, 186, 7, 33, "Notes",
      CellTags->"BehaviorFA"],
    Cell[27052, 1114, 164, 7, 33, "Notes",
      CellTags->"BehaviorFA"],
    Cell[27241, 1125, 68, 1, 59, "ExampleSection",
      CellTags->"BehaviorFA"],
    Cell[27312, 1128, 199, 6, 70, "ExampleText",
      CellTags->"BehaviorFA"],
    Cell[27536, 1138, 92, 2, 70, "Input",
      CellTags->"BehaviorFA"],
    Cell[27631, 1142, 372, 12, 70, "Output",
      CellTags->"BehaviorFA"],
    Cell[28018, 1157, 132, 4, 70, "ExampleText",
      CellTags->"BehaviorFA"],
    Cell[28175, 1165, 108, 3, 70, "Input",
      CellTags->"BehaviorFA"],
    Cell[28286, 1170, 184, 4, 70, "Output",
      CellTags->"BehaviorFA"],
    Cell[28485, 1177, 187, 6, 70, "ExampleText",
      CellTags->"BehaviorFA"],
    Cell[28697, 1187, 108, 3, 70, "Input",
      CellTags->"BehaviorFA"],
    Cell[28808, 1192, 181, 4, 70, "Output",
      CellTags->"BehaviorFA"]},
  "BFunctionToCA"->{
    Cell[29016, 1200, 64, 1, 31, "ObjectName",
      CellTags->"BFunctionToCA"],
    Cell[29083, 1203, 64, 1, 74, "Highlight",
      CellTags->"BFunctionToCA"],
    Cell[29150, 1206, 458, 16, 64, "Usage",
      CellTags->"BFunctionToCA"],
    Cell[29611, 1224, 226, 10, 33, "Notes",
      CellTags->"BFunctionToCA"],
    Cell[29840, 1236, 269, 10, 33, "Notes",
      CellTags->"BFunctionToCA"],
    Cell[30112, 1248, 156, 7, 33, "Notes",
      CellTags->"BFunctionToCA"],
    Cell[30293, 1259, 71, 1, 59, "ExampleSection",
      CellTags->"BFunctionToCA"],
    Cell[30367, 1262, 136, 4, 70, "ExampleText",
      CellTags->"BFunctionToCA"],
    Cell[30528, 1270, 118, 5, 70, "Input",
      CellTags->"BFunctionToCA"],
    Cell[30649, 1277, 105, 3, 70, "Output",
      CellTags->"BFunctionToCA"],
    Cell[30757, 1282, 560, 14, 70, "Output",
      CellTags->"BFunctionToCA"],
    Cell[31332, 1299, 74, 1, 70, "ExampleText",
      CellTags->"BFunctionToCA"],
    Cell[31431, 1304, 119, 5, 70, "Input",
      CellTags->"BFunctionToCA"],
    Cell[31553, 1311, 106, 3, 70, "Output",
      CellTags->"BFunctionToCA"],
    Cell[31662, 1316, 560, 14, 70, "Output",
      CellTags->"BFunctionToCA"]},
  "BuildBEFA"->{
    Cell[32249, 1334, 56, 1, 31, "ObjectName",
      CellTags->"BuildBEFA"],
    Cell[32308, 1337, 60, 1, 74, "Highlight",
      CellTags->"BuildBEFA"],
    Cell[32371, 1340, 197, 7, 43, "Usage",
      CellTags->"BuildBEFA"],
    Cell[32571, 1349, 117, 5, 33, "Notes",
      CellTags->"BuildBEFA"],
    Cell[32691, 1356, 134, 4, 33, "Notes",
      CellTags->"BuildBEFA"],
    Cell[32850, 1364, 67, 1, 59, "ExampleSection",
      CellTags->"BuildBEFA"],
    Cell[32920, 1367, 231, 7, 70, "ExampleText",
      CellTags->"BuildBEFA"],
    Cell[33176, 1378, 84, 2, 70, "Input",
      CellTags->"BuildBEFA"],
    Cell[33263, 1382, 152, 4, 70, "Output",
      CellTags->"BuildBEFA"]},
  "BuildDFA"->{
    Cell[33442, 1390, 54, 1, 31, "ObjectName",
      CellTags->"BuildDFA"],
    Cell[33499, 1393, 59, 1, 74, "Highlight",
      CellTags->"BuildDFA"],
    Cell[33561, 1396, 347, 11, 67, "Usage",
      CellTags->"BuildDFA"],
    Cell[33911, 1409, 248, 9, 58, "Notes",
      CellTags->"BuildDFA"],
    Cell[34162, 1420, 257, 8, 54, "Notes",
      CellTags->"BuildDFA"],
    Cell[34422, 1430, 164, 7, 33, "Notes",
      CellTags->"BuildDFA"],
    Cell[34611, 1441, 66, 1, 59, "ExampleSection",
      CellTags->"BuildDFA"],
    Cell[34680, 1444, 75, 1, 70, "ExampleText",
      CellTags->"BuildDFA"],
    Cell[34780, 1449, 151, 4, 70, "Input",
      CellTags->"BuildDFA"],
    Cell[34934, 1455, 388, 12, 70, "Output",
      CellTags->"BuildDFA"],
    Cell[35325, 1469, 127, 3, 70, "Output",
      CellTags->"BuildDFA"],
    Cell[35467, 1475, 86, 1, 70, "ExampleText",
      CellTags->"BuildDFA"],
    Cell[35578, 1480, 183, 5, 70, "Input",
      CellTags->"BuildDFA"],
    Cell[35764, 1487, 210, 4, 70, "Output",
      CellTags->"BuildDFA"],
    Cell[35977, 1493, 434, 14, 70, "Output",
      CellTags->"BuildDFA"],
    Cell[36414, 1509, 247, 5, 70, "Output",
      CellTags->"BuildDFA"]},
  "BuildNNFA"->{
    Cell[36688, 1518, 56, 1, 31, "ObjectName",
      CellTags->"BuildNNFA"],
    Cell[36747, 1521, 60, 1, 74, "Highlight",
      CellTags->"BuildNNFA"],
    Cell[36810, 1524, 213, 6, 64, "Usage",
      CellTags->"BuildNNFA"],
    Cell[37026, 1532, 117, 5, 33, "Notes",
      CellTags->"BuildNNFA"],
    Cell[37146, 1539, 145, 4, 33, "Notes",
      CellTags->"BuildNNFA"],
    Cell[37316, 1547, 67, 1, 59, "ExampleSection",
      CellTags->"BuildNNFA"],
    Cell[37386, 1550, 73, 1, 70, "ExampleText",
      CellTags->"BuildNNFA"],
    Cell[37484, 1555, 81, 2, 70, "Input",
      CellTags->"BuildNNFA"],
    Cell[37568, 1559, 139, 3, 70, "Output",
      CellTags->"BuildNNFA"]},
  "BuildStarDFA"->{
    Cell[37734, 1566, 62, 1, 31, "ObjectName",
      CellTags->"BuildStarDFA"],
    Cell[37799, 1569, 63, 1, 74, "Highlight",
      CellTags->"BuildStarDFA"],
    Cell[37865, 1572, 202, 7, 43, "Usage",
      CellTags->"BuildStarDFA"],
    Cell[38070, 1581, 91, 1, 33, "Notes",
      CellTags->"BuildStarDFA"],
    Cell[38186, 1586, 70, 1, 59, "ExampleSection",
      CellTags->"BuildStarDFA"],
    Cell[38259, 1589, 261, 9, 70, "ExampleText",
      CellTags->"BuildStarDFA"],
    Cell[38545, 1602, 90, 2, 70, "Input",
      CellTags->"BuildStarDFA"],
    Cell[38638, 1606, 403, 12, 70, "Output",
      CellTags->"BuildStarDFA"]},
  "CirculantSA"->{
    Cell[39068, 1622, 60, 1, 31, "ObjectName",
      CellTags->"CirculantSA"],
    Cell[39131, 1625, 62, 1, 74, "Highlight",
      CellTags->"CirculantSA"],
    Cell[39196, 1628, 318, 10, 64, "Usage",
      CellTags->"CirculantSA"],
    Cell[39517, 1640, 132, 5, 33, "Notes",
      CellTags->"CirculantSA"],
    Cell[39652, 1647, 167, 7, 33, "Notes",
      CellTags->"CirculantSA"],
    Cell[39822, 1656, 172, 7, 33, "Notes",
      CellTags->"CirculantSA"],
    Cell[40019, 1667, 69, 1, 59, "ExampleSection",
      CellTags->"CirculantSA"],
    Cell[40091, 1670, 245, 9, 70, "ExampleText",
      CellTags->"CirculantSA"],
    Cell[40361, 1683, 138, 3, 70, "Input",
      CellTags->"CirculantSA"],
    Cell[40502, 1688, 369, 10, 70, "Output",
      CellTags->"CirculantSA"],
    Cell[40908, 1703, 102, 3, 70, "Input",
      CellTags->"CirculantSA"],
    Cell[41013, 1708, 226, 5, 70, "Output",
      CellTags->"CirculantSA"]},
  "ClassifyCA"->{
    Cell[41266, 1717, 58, 1, 31, "ObjectName",
      CellTags->"ClassifyCA"],
    Cell[41327, 1720, 61, 1, 74, "Highlight",
      CellTags->"ClassifyCA"],
    Cell[41391, 1723, 272, 6, 64, "Usage",
      CellTags->"ClassifyCA"],
    Cell[41666, 1731, 296, 10, 80, "Notes",
      CellTags->"ClassifyCA"],
    Cell[41965, 1743, 465, 17, 128, "Notes",
      CellTags->"ClassifyCA"],
    Cell[42433, 1762, 208, 6, 54, "Notes",
      CellTags->"ClassifyCA"],
    Cell[42644, 1770, 121, 4, 33, "Notes",
      CellTags->"ClassifyCA"],
    Cell[42768, 1776, 157, 4, 33, "Notes",
      CellTags->"ClassifyCA"],
    Cell[42950, 1784, 68, 1, 59, "ExampleSection",
      CellTags->"ClassifyCA"],
    Cell[43021, 1787, 83, 1, 70, "ExampleText",
      CellTags->"ClassifyCA"],
    Cell[43129, 1792, 88, 2, 70, "Input",
      CellTags->"ClassifyCA"],
    Cell[43220, 1796, 87, 3, 70, "Output",
      CellTags->"ClassifyCA"],
    Cell[43344, 1804, 87, 2, 70, "Input",
      CellTags->"ClassifyCA"],
    Cell[43434, 1808, 87, 3, 70, "Output",
      CellTags->"ClassifyCA"],
    Cell[43558, 1816, 87, 2, 70, "Input",
      CellTags->"ClassifyCA"],
    Cell[43648, 1820, 87, 3, 70, "Output",
      CellTags->"ClassifyCA"],
    Cell[43772, 1828, 87, 2, 70, "Input",
      CellTags->"ClassifyCA"],
    Cell[43862, 1832, 87, 3, 70, "Output",
      CellTags->"ClassifyCA"],
    Cell[43964, 1838, 89, 1, 70, "ExampleText",
      CellTags->"ClassifyCA"],
    Cell[44078, 1843, 121, 3, 70, "Input",
      CellTags->"ClassifyCA"],
    Cell[44202, 1848, 87, 3, 70, "Output",
      CellTags->"ClassifyCA"],
    Cell[44304, 1854, 68, 1, 70, "ExampleText",
      CellTags->"ClassifyCA"],
    Cell[44397, 1859, 177, 4, 70, "Input",
      CellTags->"ClassifyCA"],
    Cell[44577, 1865, 393, 14, 70, "Output",
      CellTags->"ClassifyCA"]},
  "CoAccessibleFA"->{
    Cell[44997, 1883, 66, 1, 31, "ObjectName",
      CellTags->"CoAccessibleFA"],
    Cell[45066, 1886, 65, 1, 74, "Highlight",
      CellTags->"CoAccessibleFA"],
    Cell[45134, 1889, 191, 6, 43, "Usage",
      CellTags->"CoAccessibleFA"],
    Cell[45328, 1897, 321, 10, 82, "Notes",
      CellTags->"CoAccessibleFA"],
    Cell[45652, 1909, 167, 5, 33, "Notes",
      CellTags->"CoAccessibleFA"],
    Cell[45822, 1916, 262, 11, 33, "Notes",
      CellTags->"CoAccessibleFA"],
    Cell[46109, 1931, 72, 1, 59, "ExampleSection",
      CellTags->"CoAccessibleFA"],
    Cell[46184, 1934, 125, 4, 70, "MathCaption",
      CellTags->"CoAccessibleFA"],
    Cell[46334, 1942, 193, 5, 70, "Input",
      CellTags->"CoAccessibleFA"],
    Cell[46530, 1949, 389, 12, 70, "Output",
      CellTags->"CoAccessibleFA"],
    Cell[46956, 1966, 143, 4, 70, "Input",
      CellTags->"CoAccessibleFA"],
    Cell[47102, 1972, 378, 12, 70, "Output",
      CellTags->"CoAccessibleFA"],
    Cell[47483, 1986, 92, 3, 70, "Output",
      CellTags->"CoAccessibleFA"],
    Cell[47590, 1992, 108, 1, 70, "MathCaption",
      CellTags->"CoAccessibleFA"],
    Cell[47723, 1997, 139, 3, 70, "Input",
      CellTags->"CoAccessibleFA"],
    Cell[47865, 2002, 97, 3, 70, "Output",
      CellTags->"CoAccessibleFA"],
    Cell[47999, 2010, 139, 3, 70, "Input",
      CellTags->"CoAccessibleFA"],
    Cell[48141, 2015, 378, 12, 70, "Output",
      CellTags->"CoAccessibleFA"],
    Cell[48522, 2029, 97, 3, 70, "Output",
      CellTags->"CoAccessibleFA"]},
  "CodeterministicQFA"->{
    Cell[48646, 2036, 74, 1, 31, "ObjectName",
      CellTags->"CodeterministicQFA"],
    Cell[48723, 2039, 69, 1, 74, "Highlight",
      CellTags->"CodeterministicQFA"],
    Cell[48795, 2042, 186, 5, 64, "Usage",
      CellTags->"CodeterministicQFA"],
    Cell[48984, 2049, 237, 9, 58, "Notes",
      CellTags->"CodeterministicQFA"],
    Cell[49224, 2060, 425, 17, 54, "Notes",
      CellTags->"CodeterministicQFA"],
    Cell[49652, 2079, 183, 7, 33, "Notes",
      CellTags->"CodeterministicQFA"],
    Cell[49860, 2090, 76, 1, 59, "ExampleSection",
      CellTags->"CodeterministicQFA"],
    Cell[49939, 2093, 141, 4, 70, "ExampleText",
      CellTags->"CodeterministicQFA"],
    Cell[50105, 2101, 149, 4, 70, "Input",
      CellTags->"CodeterministicQFA"],
    Cell[50257, 2107, 357, 10, 70, "Output",
      CellTags->"CodeterministicQFA"],
    Cell[50617, 2119, 98, 3, 70, "Output",
      CellTags->"CodeterministicQFA"]},
  "ComplementFA"->{
    Cell[50742, 2126, 62, 1, 31, "ObjectName",
      CellTags->"ComplementFA"],
    Cell[50807, 2129, 63, 1, 74, "Highlight",
      CellTags->"ComplementFA"],
    Cell[50873, 2132, 187, 5, 64, "Usage",
      CellTags->"ComplementFA"],
    Cell[51063, 2139, 252, 5, 54, "Notes",
      CellTags->"ComplementFA"],
    Cell[51318, 2146, 151, 4, 33, "Notes",
      CellTags->"ComplementFA"],
    Cell[51494, 2154, 70, 1, 59, "ExampleSection",
      CellTags->"ComplementFA"],
    Cell[51567, 2157, 134, 4, 70, "ExampleText",
      CellTags->"ComplementFA"],
    Cell[51726, 2165, 98, 2, 70, "Input",
      CellTags->"ComplementFA"],
    Cell[51827, 2169, 393, 12, 70, "Output",
      CellTags->"ComplementFA"],
    Cell[52257, 2186, 111, 3, 70, "Input",
      CellTags->"ComplementFA"],
    Cell[52371, 2191, 405, 12, 70, "Output",
      CellTags->"ComplementFA"],
    Cell[52813, 2208, 134, 3, 70, "Input",
      CellTags->"ComplementFA"],
    Cell[52950, 2213, 121, 3, 70, "Output",
      CellTags->"ComplementFA"],
    Cell[53108, 2221, 100, 2, 70, "Input",
      CellTags->"ComplementFA"],
    Cell[53211, 2225, 414, 12, 70, "Output",
      CellTags->"ComplementFA"],
    Cell[53640, 2240, 110, 2, 70, "ExampleText",
      CellTags->"ComplementFA"],
    Cell[53775, 2246, 121, 3, 70, "Input",
      CellTags->"ComplementFA"],
    Cell[53899, 2251, 411, 12, 70, "Output",
      CellTags->"ComplementFA"],
    Cell[54347, 2268, 134, 3, 70, "Input",
      CellTags->"ComplementFA"],
    Cell[54484, 2273, 116, 3, 70, "Output",
      CellTags->"ComplementFA"]},
  "CompleteFA"->{
    Cell[54627, 2280, 58, 1, 31, "ObjectName",
      CellTags->"CompleteFA"],
    Cell[54688, 2283, 61, 1, 74, "Highlight",
      CellTags->"CompleteFA"],
    Cell[54752, 2286, 158, 4, 43, "Usage",
      CellTags->"CompleteFA"],
    Cell[54913, 2292, 126, 4, 33, "Notes",
      CellTags->"CompleteFA"],
    Cell[55064, 2300, 68, 1, 59, "ExampleSection",
      CellTags->"CompleteFA"],
    Cell[55135, 2303, 102, 1, 70, "ExampleText",
      CellTags->"CompleteFA"],
    Cell[55262, 2308, 97, 2, 70, "Input",
      CellTags->"CompleteFA"],
    Cell[55362, 2312, 364, 12, 70, "Output",
      CellTags->"CompleteFA"],
    Cell[55763, 2329, 97, 3, 70, "Input",
      CellTags->"CompleteFA"],
    Cell[55863, 2334, 447, 14, 70, "Output",
      CellTags->"CompleteFA"],
    Cell[56347, 2353, 104, 3, 70, "Input",
      CellTags->"CompleteFA"],
    Cell[56454, 2358, 89, 3, 70, "Output",
      CellTags->"CompleteFA"]},
  "CompleteQFA"->{
    Cell[56570, 2365, 60, 1, 31, "ObjectName",
      CellTags->"CompleteQFA"],
    Cell[56633, 2368, 62, 1, 74, "Highlight",
      CellTags->"CompleteQFA"],
    Cell[56698, 2371, 179, 6, 43, "Usage",
      CellTags->"CompleteQFA"],
    Cell[56880, 2379, 160, 4, 33, "Notes",
      CellTags->"CompleteQFA"],
    Cell[57043, 2385, 99, 1, 33, "Notes",
      CellTags->"CompleteQFA"],
    Cell[57167, 2390, 69, 1, 59, "ExampleSection",
      CellTags->"CompleteQFA"],
    Cell[57239, 2393, 96, 1, 70, "ExampleText",
      CellTags->"CompleteQFA"],
    Cell[57360, 2398, 122, 5, 70, "Input",
      CellTags->"CompleteQFA"],
    Cell[57485, 2405, 252, 8, 70, "Output",
      CellTags->"CompleteQFA"],
    Cell[57740, 2415, 90, 3, 70, "Output",
      CellTags->"CompleteQFA"],
    Cell[57845, 2421, 112, 2, 70, "ExampleText",
      CellTags->"CompleteQFA"],
    Cell[57982, 2427, 102, 2, 70, "Input",
      CellTags->"CompleteQFA"],
    Cell[58087, 2431, 91, 3, 70, "Output",
      CellTags->"CompleteQFA"]},
  "ComposeCA"->{
    Cell[58205, 2438, 56, 1, 31, "ObjectName",
      CellTags->"ComposeCA"],
    Cell[58264, 2441, 60, 1, 74, "Highlight",
      CellTags->"ComposeCA"],
    Cell[58327, 2444, 257, 8, 64, "Usage",
      CellTags->"ComposeCA"],
    Cell[58587, 2454, 247, 9, 58, "Notes",
      CellTags->"ComposeCA"],
    Cell[58837, 2465, 284, 9, 54, "Notes",
      CellTags->"ComposeCA"],
    Cell[59124, 2476, 168, 6, 33, "Notes",
      CellTags->"ComposeCA"],
    Cell[59317, 2486, 67, 1, 59, "ExampleSection",
      CellTags->"ComposeCA"],
    Cell[59387, 2489, 103, 1, 70, "ExampleText",
      CellTags->"ComposeCA"],
    Cell[59515, 2494, 109, 2, 70, "Input",
      CellTags->"ComposeCA"],
    Cell[59627, 2498, 109, 3, 70, "Output",
      CellTags->"ComposeCA"],
    Cell[59751, 2504, 111, 3, 70, "Input",
      CellTags->"ComposeCA"]},
  "ComputationFA"->{
    Cell[59877, 2510, 64, 1, 31, "ObjectName",
      CellTags->"ComputationFA"],
    Cell[59944, 2513, 64, 1, 74, "Highlight",
      CellTags->"ComputationFA"],
    Cell[60011, 2516, 251, 8, 64, "Usage",
      CellTags->"ComputationFA"],
    Cell[60265, 2526, 231, 9, 58, "Notes",
      CellTags->"ComputationFA"],
    Cell[60499, 2537, 195, 5, 54, "Notes",
      CellTags->"ComputationFA"],
    Cell[60697, 2544, 148, 4, 33, "Notes",
      CellTags->"ComputationFA"],
    Cell[60848, 2550, 295, 11, 33, "Notes",
      CellTags->"ComputationFA"],
    Cell[61168, 2565, 71, 1, 59, "ExampleSection",
      CellTags->"ComputationFA"],
    Cell[61242, 2568, 202, 7, 70, "ExampleText",
      CellTags->"ComputationFA"],
    Cell[61469, 2579, 113, 3, 70, "Input",
      CellTags->"ComputationFA"],
    Cell[61585, 2584, 483, 14, 70, "Output",
      CellTags->"ComputationFA"],
    Cell[62105, 2603, 117, 3, 70, "Input",
      CellTags->"ComputationFA"],
    Cell[62225, 2608, 327, 6, 70, "Output",
      CellTags->"ComputationFA"],
    Cell[62589, 2619, 116, 3, 70, "Input",
      CellTags->"ComputationFA"],
    Cell[62708, 2624, 133, 3, 70, "Output",
      CellTags->"ComputationFA"],
    Cell[62878, 2632, 136, 3, 70, "Input",
      CellTags->"ComputationFA"],
    Cell[63017, 2637, 191, 4, 70, "Output",
      CellTags->"ComputationFA"]},
  "ComputationGraphFA"->{
    Cell[63235, 2645, 74, 1, 31, "ObjectName",
      CellTags->"ComputationGraphFA"],
    Cell[63312, 2648, 69, 1, 74, "Highlight",
      CellTags->"ComputationGraphFA"],
    Cell[63384, 2651, 253, 8, 64, "Usage",
      CellTags->"ComputationGraphFA"],
    Cell[63640, 2661, 280, 9, 33, "Notes",
      CellTags->"ComputationGraphFA"],
    Cell[63923, 2672, 290, 11, 33, "Notes",
      CellTags->"ComputationGraphFA"],
    Cell[64238, 2687, 76, 1, 59, "ExampleSection",
      CellTags->"ComputationGraphFA"],
    Cell[64317, 2690, 207, 7, 70, "ExampleText",
      CellTags->"ComputationGraphFA"],
    Cell[64549, 2701, 118, 3, 70, "Input",
      CellTags->"ComputationGraphFA"],
    Cell[64670, 2706, 488, 14, 70, "Output",
      CellTags->"ComputationGraphFA"],
    Cell[65195, 2725, 120, 3, 70, "Input",
      CellTags->"ComputationGraphFA"],
    Cell[65318, 2730, 440, 11, 70, "Output",
      CellTags->"ComputationGraphFA"]},
  "ConcatenateFA"->{
    Cell[65785, 2745, 64, 1, 31, "ObjectName",
      CellTags->"ConcatenateFA"],
    Cell[65852, 2748, 64, 1, 74, "Highlight",
      CellTags->"ConcatenateFA"],
    Cell[65919, 2751, 202, 5, 64, "Usage",
      CellTags->"ConcatenateFA"],
    Cell[66124, 2758, 300, 10, 80, "Notes",
      CellTags->"ConcatenateFA"],
    Cell[66427, 2770, 193, 6, 33, "Notes",
      CellTags->"ConcatenateFA"],
    Cell[66623, 2778, 285, 9, 33, "Notes",
      CellTags->"ConcatenateFA"],
    Cell[66911, 2789, 110, 4, 33, "Notes",
      CellTags->"ConcatenateFA"],
    Cell[67046, 2797, 71, 1, 59, "ExampleSection",
      CellTags->"ConcatenateFA"],
    Cell[67120, 2800, 103, 1, 70, "ExampleText",
      CellTags->"ConcatenateFA"],
    Cell[67248, 2805, 100, 2, 70, "Input",
      CellTags->"ConcatenateFA"],
    Cell[67351, 2809, 382, 12, 70, "Output",
      CellTags->"ConcatenateFA"],
    Cell[67770, 2826, 118, 3, 70, "Input",
      CellTags->"ConcatenateFA"],
    Cell[67891, 2831, 546, 15, 70, "Output",
      CellTags->"ConcatenateFA"],
    Cell[68474, 2851, 141, 3, 70, "Input",
      CellTags->"ConcatenateFA"],
    Cell[68618, 2856, 117, 3, 70, "Output",
      CellTags->"ConcatenateFA"]},
  "ConvertToFA"->{
    Cell[68762, 2863, 60, 1, 31, "ObjectName",
      CellTags->"ConvertToFA"],
    Cell[68825, 2866, 62, 1, 74, "Highlight",
      CellTags->"ConvertToFA"],
    Cell[68890, 2869, 206, 5, 64, "Usage",
      CellTags->"ConvertToFA"],
    Cell[69099, 2876, 300, 10, 80, "Notes",
      CellTags->"ConvertToFA"],
    Cell[69402, 2888, 218, 6, 54, "Notes",
      CellTags->"ConvertToFA"],
    Cell[69623, 2896, 54, 1, 33, "Notes",
      CellTags->"ConvertToFA"],
    Cell[69702, 2901, 69, 1, 59, "ExampleSection",
      CellTags->"ConvertToFA"],
    Cell[69774, 2904, 166, 4, 70, "ExampleText",
      CellTags->"ConvertToFA"],
    Cell[69965, 2912, 252, 7, 70, "Input",
      CellTags->"ConvertToFA"],
    Cell[70220, 2921, 388, 12, 70, "Output",
      CellTags->"ConvertToFA"],
    Cell[70645, 2938, 107, 3, 70, "Input",
      CellTags->"ConvertToFA"],
    Cell[70755, 2943, 133, 3, 70, "Output",
      CellTags->"ConvertToFA"]},
  "CounterDFA"->{
    Cell[70915, 2950, 58, 1, 31, "ObjectName",
      CellTags->"CounterDFA"],
    Cell[70976, 2953, 61, 1, 74, "Highlight",
      CellTags->"CounterDFA"],
    Cell[71040, 2956, 270, 6, 64, "Usage",
      CellTags->"CounterDFA"],
    Cell[71313, 2964, 250, 9, 58, "Notes",
      CellTags->"CounterDFA"],
    Cell[71566, 2975, 170, 7, 33, "Notes",
      CellTags->"CounterDFA"],
    Cell[71761, 2986, 68, 1, 59, "ExampleSection",
      CellTags->"CounterDFA"],
    Cell[71832, 2989, 84, 1, 70, "ExampleText",
      CellTags->"CounterDFA"],
    Cell[71941, 2994, 105, 3, 70, "Input",
      CellTags->"CounterDFA"],
    Cell[72049, 2999, 385, 12, 70, "Output",
      CellTags->"CounterDFA"],
    Cell[72471, 3016, 112, 3, 70, "Input",
      CellTags->"CounterDFA"],
    Cell[72586, 3021, 251, 5, 70, "Output",
      CellTags->"CounterDFA"]},
  "CoverQDFA"->{
    Cell[72864, 3030, 56, 1, 31, "ObjectName",
      CellTags->"CoverQDFA"],
    Cell[72923, 3033, 60, 1, 74, "Highlight",
      CellTags->"CoverQDFA"],
    Cell[72986, 3036, 139, 4, 43, "Usage",
      CellTags->"CoverQDFA"],
    Cell[73128, 3042, 228, 9, 58, "Notes",
      CellTags->"CoverQDFA"],
    Cell[73359, 3053, 97, 1, 33, "Notes",
      CellTags->"CoverQDFA"],
    Cell[73459, 3056, 259, 10, 33, "Notes",
      CellTags->"CoverQDFA"],
    Cell[73721, 3068, 147, 5, 33, "Notes",
      CellTags->"CoverQDFA"],
    Cell[73893, 3077, 67, 1, 59, "ExampleSection",
      CellTags->"CoverQDFA"],
    Cell[73963, 3080, 132, 4, 70, "ExampleText",
      CellTags->"CoverQDFA"],
    Cell[74120, 3088, 148, 4, 70, "Input",
      CellTags->"CoverQDFA"],
    Cell[74271, 3094, 519, 15, 70, "Output",
      CellTags->"CoverQDFA"],
    Cell[74793, 3111, 411, 12, 70, "Output",
      CellTags->"CoverQDFA"],
    Cell[75241, 3128, 100, 3, 70, "Input",
      CellTags->"CoverQDFA"],
    Cell[75344, 3133, 89, 3, 70, "Output",
      CellTags->"CoverQDFA"],
    Cell[75470, 3141, 122, 3, 70, "Input",
      CellTags->"CoverQDFA"],
    Cell[75595, 3146, 222, 5, 70, "Output",
      CellTags->"CoverQDFA"]},
  "DeBruijnEdges"->{
    Cell[75844, 3155, 64, 1, 31, "ObjectName",
      CellTags->"DeBruijnEdges"],
    Cell[75911, 3158, 64, 1, 74, "Highlight",
      CellTags->"DeBruijnEdges"],
    Cell[75978, 3161, 180, 5, 43, "Usage",
      CellTags->"DeBruijnEdges"],
    Cell[76161, 3168, 230, 9, 58, "Notes",
      CellTags->"DeBruijnEdges"],
    Cell[76394, 3179, 155, 6, 33, "Notes",
      CellTags->"DeBruijnEdges"],
    Cell[76552, 3187, 209, 7, 33, "Notes",
      CellTags->"DeBruijnEdges"],
    Cell[76764, 3196, 172, 7, 33, "Notes",
      CellTags->"DeBruijnEdges"],
    Cell[76961, 3207, 71, 1, 59, "ExampleSection",
      CellTags->"DeBruijnEdges"],
    Cell[77035, 3210, 175, 6, 70, "ExampleText",
      CellTags->"DeBruijnEdges"],
    Cell[77235, 3220, 112, 3, 70, "Input",
      CellTags->"DeBruijnEdges"],
    Cell[77350, 3225, 381, 7, 70, "Output",
      CellTags->"DeBruijnEdges"],
    Cell[77746, 3235, 84, 1, 70, "ExampleText",
      CellTags->"DeBruijnEdges"],
    Cell[77855, 3240, 133, 3, 70, "Input",
      CellTags->"DeBruijnEdges"],
    Cell[77991, 3245, 235, 5, 70, "Output",
      CellTags->"DeBruijnEdges"]},
  "DeBruijnGraph"->{
    Cell[78253, 3254, 64, 1, 31, "ObjectName",
      CellTags->"DeBruijnGraph"],
    Cell[78320, 3257, 64, 1, 74, "Highlight",
      CellTags->"DeBruijnGraph"],
    Cell[78387, 3260, 161, 4, 43, "Usage",
      CellTags->"DeBruijnGraph"],
    Cell[78551, 3266, 230, 9, 58, "Notes",
      CellTags->"DeBruijnGraph"],
    Cell[78784, 3277, 155, 6, 33, "Notes",
      CellTags->"DeBruijnGraph"],
    Cell[78942, 3285, 839, 30, 75, "Notes",
      CellTags->"DeBruijnGraph"],
    Cell[79784, 3317, 172, 7, 33, "Notes",
      CellTags->"DeBruijnGraph"],
    Cell[79981, 3328, 71, 1, 59, "ExampleSection",
      CellTags->"DeBruijnGraph"],
    Cell[80055, 3331, 165, 6, 70, "ExampleText",
      CellTags->"DeBruijnGraph"],
    Cell[80245, 3341, 141, 3, 70, "Input",
      CellTags->"DeBruijnGraph"],
    Cell[80389, 3346, 420, 11, 70, "Output",
      CellTags->"DeBruijnGraph"],
    Cell[80846, 3362, 100, 3, 70, "Input",
      CellTags->"DeBruijnGraph"],
    Cell[80949, 3367, 145, 3, 70, "Output",
      CellTags->"DeBruijnGraph"],
    Cell[81109, 3373, 150, 4, 70, "ExampleText",
      CellTags->"DeBruijnGraph"],
    Cell[81284, 3381, 176, 4, 70, "Input",
      CellTags->"DeBruijnGraph"],
    Cell[81463, 3387, 678, 15, 70, "Output",
      CellTags->"DeBruijnGraph"]},
  "DefiniteQFA"->{
    Cell[82168, 3406, 60, 1, 31, "ObjectName",
      CellTags->"DefiniteQFA"],
    Cell[82231, 3409, 62, 1, 74, "Highlight",
      CellTags->"DefiniteQFA"],
    Cell[82296, 3412, 261, 6, 91, "Usage",
      CellTags->"DefiniteQFA"],
    Cell[82560, 3420, 294, 10, 80, "Notes",
      CellTags->"DefiniteQFA"],
    Cell[82857, 3432, 164, 5, 33, "Notes",
      CellTags->"DefiniteQFA"],
    Cell[83024, 3439, 170, 4, 54, "Notes",
      CellTags->"DefiniteQFA"],
    Cell[83197, 3445, 162, 7, 33, "Notes",
      CellTags->"DefiniteQFA"],
    Cell[83384, 3456, 69, 1, 59, "ExampleSection",
      CellTags->"DefiniteQFA"],
    Cell[83456, 3459, 71, 1, 70, "ExampleText",
      CellTags->"DefiniteQFA"],
    Cell[83552, 3464, 179, 5, 70, "Input",
      CellTags->"DefiniteQFA"],
    Cell[83734, 3471, 520, 15, 70, "Output",
      CellTags->"DefiniteQFA"],
    Cell[84257, 3488, 90, 3, 70, "Output",
      CellTags->"DefiniteQFA"],
    Cell[84362, 3494, 105, 1, 70, "ExampleText",
      CellTags->"DefiniteQFA"],
    Cell[84492, 3499, 118, 3, 70, "Input",
      CellTags->"DefiniteQFA"],
    Cell[84613, 3504, 87, 3, 70, "Output",
      CellTags->"DefiniteQFA"],
    Cell[84715, 3510, 118, 3, 70, "Input",
      CellTags->"DefiniteQFA"],
    Cell[84858, 3517, 124, 3, 70, "Input",
      CellTags->"DefiniteQFA"],
    Cell[84985, 3522, 153, 4, 70, "Output",
      CellTags->"DefiniteQFA"],
    Cell[85175, 3531, 124, 3, 70, "Input",
      CellTags->"DefiniteQFA"],
    Cell[85302, 3536, 131, 3, 70, "Output",
      CellTags->"DefiniteQFA"]},
  "DegreesFA"->{
    Cell[85460, 3543, 56, 1, 31, "ObjectName",
      CellTags->"DegreesFA"],
    Cell[85519, 3546, 60, 1, 74, "Highlight",
      CellTags->"DegreesFA"],
    Cell[85582, 3549, 373, 15, 64, "Usage",
      CellTags->"DegreesFA"],
    Cell[85958, 3566, 155, 4, 33, "Notes",
      CellTags->"DegreesFA"],
    Cell[86138, 3574, 67, 1, 59, "ExampleSection",
      CellTags->"DegreesFA"],
    Cell[86208, 3577, 135, 4, 70, "ExampleText",
      CellTags->"DegreesFA"],
    Cell[86368, 3585, 96, 2, 70, "Input",
      CellTags->"DegreesFA"],
    Cell[86467, 3589, 490, 14, 70, "Output",
      CellTags->"DegreesFA"],
    Cell[86994, 3608, 113, 3, 70, "Input",
      CellTags->"DegreesFA"],
    Cell[87110, 3613, 343, 10, 70, "Output",
      CellTags->"DegreesFA"]},
  "DeleteStateFA"->{
    Cell[87480, 3627, 64, 1, 31, "ObjectName",
      CellTags->"DeleteStateFA"],
    Cell[87547, 3630, 64, 1, 74, "Highlight",
      CellTags->"DeleteStateFA"],
    Cell[87614, 3633, 134, 4, 43, "Usage",
      CellTags->"DeleteStateFA"],
    Cell[87751, 3639, 230, 9, 58, "Notes",
      CellTags->"DeleteStateFA"],
    Cell[87984, 3650, 84, 1, 33, "Notes",
      CellTags->"DeleteStateFA"],
    Cell[88071, 3653, 97, 1, 33, "Notes",
      CellTags->"DeleteStateFA"],
    Cell[88193, 3658, 71, 1, 59, "ExampleSection",
      CellTags->"DeleteStateFA"],
    Cell[88267, 3661, 129, 4, 70, "ExampleText",
      CellTags->"DeleteStateFA"],
    Cell[88421, 3669, 314, 7, 70, "Input",
      CellTags->"DeleteStateFA"],
    Cell[88738, 3678, 287, 8, 70, "Output",
      CellTags->"DeleteStateFA"],
    Cell[89028, 3688, 276, 8, 70, "Output",
      CellTags->"DeleteStateFA"],
    Cell[89341, 3701, 276, 5, 70, "Input",
      CellTags->"DeleteStateFA"],
    Cell[89620, 3708, 123, 3, 70, "Output",
      CellTags->"DeleteStateFA"],
    Cell[89746, 3713, 122, 3, 70, "Output",
      CellTags->"DeleteStateFA"],
    Cell[89871, 3718, 117, 3, 70, "Output",
      CellTags->"DeleteStateFA"]},
  "DependencyCA"->{
    Cell[90015, 3725, 62, 1, 31, "ObjectName",
      CellTags->"DependencyCA"],
    Cell[90080, 3728, 63, 1, 74, "Highlight",
      CellTags->"DependencyCA"],
    Cell[90146, 3731, 207, 5, 64, "Usage",
      CellTags->"DependencyCA"],
    Cell[90356, 3738, 165, 7, 33, "Notes",
      CellTags->"DependencyCA"],
    Cell[90546, 3749, 70, 1, 59, "ExampleSection",
      CellTags->"DependencyCA"],
    Cell[90619, 3752, 160, 4, 70, "ExampleText",
      CellTags->"DependencyCA"],
    Cell[90804, 3760, 144, 4, 70, "Input",
      CellTags->"DependencyCA"],
    Cell[90951, 3766, 107, 3, 70, "Output",
      CellTags->"DependencyCA"],
    Cell[91061, 3771, 93, 3, 70, "Output",
      CellTags->"DependencyCA"],
    Cell[91191, 3779, 96, 3, 70, "Input",
      CellTags->"DependencyCA"],
    Cell[91290, 3784, 819, 18, 70, "Output",
      CellTags->"DependencyCA"]},
  "DeterministicQFA"->{
    Cell[92136, 3806, 70, 1, 31, "ObjectName",
      CellTags->"DeterministicQFA"],
    Cell[92209, 3809, 67, 1, 74, "Highlight",
      CellTags->"DeterministicQFA"],
    Cell[92279, 3812, 178, 4, 43, "Usage",
      CellTags->"DeterministicQFA"],
    Cell[92460, 3818, 235, 9, 58, "Notes",
      CellTags->"DeterministicQFA"],
    Cell[92698, 3829, 419, 17, 54, "Notes",
      CellTags->"DeterministicQFA"],
    Cell[93120, 3848, 185, 7, 33, "Notes",
      CellTags->"DeterministicQFA"],
    Cell[93330, 3859, 74, 1, 59, "ExampleSection",
      CellTags->"DeterministicQFA"],
    Cell[93407, 3862, 137, 4, 70, "ExampleText",
      CellTags->"DeterministicQFA"],
    Cell[93569, 3870, 145, 4, 70, "Input",
      CellTags->"DeterministicQFA"],
    Cell[93717, 3876, 355, 10, 70, "Output",
      CellTags->"DeterministicQFA"],
    Cell[94075, 3888, 93, 3, 70, "Output",
      CellTags->"DeterministicQFA"],
    Cell[94183, 3894, 151, 4, 70, "ExampleText",
      CellTags->"DeterministicQFA"],
    Cell[94359, 3902, 164, 4, 70, "Input",
      CellTags->"DeterministicQFA"],
    Cell[94526, 3908, 355, 10, 70, "Output",
      CellTags->"DeterministicQFA"],
    Cell[94884, 3920, 93, 3, 70, "Output",
      CellTags->"DeterministicQFA"]},
  "EmptyDFA"->{
    Cell[95004, 3927, 54, 1, 31, "ObjectName",
      CellTags->"EmptyDFA"],
    Cell[95061, 3930, 59, 1, 74, "Highlight",
      CellTags->"EmptyDFA"],
    Cell[95123, 3933, 157, 4, 43, "Usage",
      CellTags->"EmptyDFA"],
    Cell[95305, 3941, 66, 1, 59, "ExampleSection",
      CellTags->"EmptyDFA"],
    Cell[95374, 3944, 79, 1, 70, "ExampleText",
      CellTags->"EmptyDFA"],
    Cell[95478, 3949, 82, 2, 70, "Input",
      CellTags->"EmptyDFA"],
    Cell[95563, 3953, 363, 12, 70, "Output",
      CellTags->"EmptyDFA"],
    Cell[95963, 3970, 104, 3, 70, "Input",
      CellTags->"EmptyDFA"],
    Cell[96070, 3975, 108, 3, 70, "Output",
      CellTags->"EmptyDFA"]},
  "EmptyQFA"->{
    Cell[96205, 3982, 54, 1, 31, "ObjectName",
      CellTags->"EmptyQFA"],
    Cell[96262, 3985, 59, 1, 74, "Highlight",
      CellTags->"EmptyQFA"],
    Cell[96324, 3988, 144, 4, 43, "Usage",
      CellTags->"EmptyQFA"],
    Cell[96471, 3994, 125, 4, 33, "Notes",
      CellTags->"EmptyQFA"],
    Cell[96621, 4002, 66, 1, 59, "ExampleSection",
      CellTags->"EmptyQFA"],
    Cell[96690, 4005, 102, 1, 70, "ExampleText",
      CellTags->"EmptyQFA"],
    Cell[96795, 4008, 174, 5, 70, "Input",
      CellTags->"EmptyQFA"],
    Cell[96972, 4015, 194, 5, 70, "Input",
      CellTags->"EmptyQFA"],
    Cell[97191, 4024, 175, 5, 70, "Input",
      CellTags->"EmptyQFA"],
    Cell[97369, 4031, 89, 3, 70, "Output",
      CellTags->"EmptyQFA"],
    Cell[97461, 4036, 89, 3, 70, "Output",
      CellTags->"EmptyQFA"],
    Cell[97553, 4041, 88, 3, 70, "Output",
      CellTags->"EmptyQFA"]},
  "EpsFreeQ"->{
    Cell[97668, 4048, 54, 1, 31, "ObjectName",
      CellTags->"EpsFreeQ"],
    Cell[97725, 4051, 59, 1, 74, "Highlight",
      CellTags->"EpsFreeQ"],
    Cell[97787, 4054, 132, 4, 43, "Usage",
      CellTags->"EpsFreeQ"],
    Cell[97922, 4060, 120, 5, 33, "Notes",
      CellTags->"EpsFreeQ"],
    Cell[98067, 4069, 66, 1, 59, "ExampleSection",
      CellTags->"EpsFreeQ"],
    Cell[98136, 4072, 130, 4, 70, "ExampleText",
      CellTags->"EpsFreeQ"],
    Cell[98291, 4080, 109, 2, 70, "Input",
      CellTags->"EpsFreeQ"],
    Cell[98403, 4084, 223, 5, 70, "Output",
      CellTags->"EpsFreeQ"],
    Cell[98663, 4094, 94, 3, 70, "Input",
      CellTags->"EpsFreeQ"],
    Cell[98760, 4099, 89, 3, 70, "Output",
      CellTags->"EpsFreeQ"]},
  "EpsilonEliminationFA"->{
    Cell[98876, 4106, 78, 1, 31, "ObjectName",
      CellTags->"EpsilonEliminationFA"],
    Cell[98957, 4109, 71, 1, 74, "Highlight",
      CellTags->"EpsilonEliminationFA"],
    Cell[99031, 4112, 178, 4, 43, "Usage",
      CellTags->"EpsilonEliminationFA"],
    Cell[99212, 4118, 375, 11, 106, "Notes",
      CellTags->"EpsilonEliminationFA"],
    Cell[99590, 4131, 837, 29, 75, "Notes",
      CellTags->"EpsilonEliminationFA"],
    Cell[100430, 4162, 186, 4, 54, "Notes",
      CellTags->"EpsilonEliminationFA"],
    Cell[100619, 4168, 187, 4, 54, "Notes",
      CellTags->"EpsilonEliminationFA"],
    Cell[100831, 4176, 78, 1, 59, "ExampleSection",
      CellTags->"EpsilonEliminationFA"],
    Cell[100912, 4179, 160, 4, 70, "ExampleText",
      CellTags->"EpsilonEliminationFA"],
    Cell[101075, 4185, 667, 11, 70, "Input",
      CellTags->"EpsilonEliminationFA"],
    Cell[101745, 4198, 132, 3, 70, "Input",
      CellTags->"EpsilonEliminationFA"],
    Cell[101902, 4205, 115, 3, 70, "Input",
      CellTags->"EpsilonEliminationFA"],
    Cell[102020, 4210, 100, 3, 70, "Output",
      CellTags->"EpsilonEliminationFA"],
    Cell[102135, 4216, 86, 1, 70, "ExampleText",
      CellTags->"EpsilonEliminationFA"],
    Cell[102224, 4219, 176, 4, 70, "Input",
      CellTags->"EpsilonEliminationFA"],
    Cell[102425, 4227, 97, 3, 70, "Input",
      CellTags->"EpsilonEliminationFA"],
    Cell[102525, 4232, 146, 3, 70, "Output",
      CellTags->"EpsilonEliminationFA"],
    Cell[102708, 4240, 96, 3, 70, "Input",
      CellTags->"EpsilonEliminationFA"],
    Cell[102807, 4245, 500, 8, 70, "Output",
      CellTags->"EpsilonEliminationFA"],
    Cell[103344, 4258, 97, 3, 70, "Input",
      CellTags->"EpsilonEliminationFA"],
    Cell[103444, 4263, 253, 5, 70, "Output",
      CellTags->"EpsilonEliminationFA"]},
  "EquivalentQFA"->{
    Cell[103724, 4272, 64, 1, 31, "ObjectName",
      CellTags->"EquivalentQFA"],
    Cell[103791, 4275, 64, 1, 74, "Highlight",
      CellTags->"EquivalentQFA"],
    Cell[103858, 4278, 155, 4, 43, "Usage",
      CellTags->"EquivalentQFA"],
    Cell[104016, 4284, 299, 10, 80, "Notes",
      CellTags->"EquivalentQFA"],
    Cell[104318, 4296, 617, 20, 75, "Notes",
      CellTags->"EquivalentQFA"],
    Cell[104938, 4318, 194, 5, 60, "Notes",
      CellTags->"EquivalentQFA"],
    Cell[105135, 4325, 216, 5, 54, "Notes",
      CellTags->"EquivalentQFA"],
    Cell[105376, 4334, 71, 1, 59, "ExampleSection",
      CellTags->"EquivalentQFA"],
    Cell[105450, 4337, 80, 1, 70, "ExampleText",
      CellTags->"EquivalentQFA"],
    Cell[105533, 4340, 223, 5, 70, "Input",
      CellTags->"EquivalentQFA"],
    Cell[105759, 4347, 280, 6, 70, "Input",
      CellTags->"EquivalentQFA"],
    Cell[106042, 4355, 202, 5, 70, "Input",
      CellTags->"EquivalentQFA"],
    Cell[106269, 4364, 115, 3, 70, "Input",
      CellTags->"EquivalentQFA"],
    Cell[106387, 4369, 93, 3, 70, "Output",
      CellTags->"EquivalentQFA"],
    Cell[106495, 4375, 96, 1, 70, "ExampleText",
      CellTags->"EquivalentQFA"],
    Cell[106616, 4380, 115, 3, 70, "Input",
      CellTags->"EquivalentQFA"],
    Cell[106734, 4385, 93, 3, 70, "Output",
      CellTags->"EquivalentQFA"],
    Cell[106842, 4391, 194, 5, 70, "ExampleText",
      CellTags->"EquivalentQFA"],
    Cell[107061, 4400, 165, 4, 70, "Input",
      CellTags->"EquivalentQFA"],
    Cell[107229, 4406, 256, 6, 70, "Output",
      CellTags->"EquivalentQFA"],
    Cell[107522, 4417, 121, 3, 70, "Input",
      CellTags->"EquivalentQFA"],
    Cell[107646, 4422, 143, 3, 70, "Output",
      CellTags->"EquivalentQFA"]},
  "EvolutionCA"->{
    Cell[107816, 4429, 60, 1, 31, "ObjectName",
      CellTags->"EvolutionCA"],
    Cell[107879, 4432, 62, 1, 74, "Highlight",
      CellTags->"EvolutionCA"],
    Cell[107944, 4435, 199, 5, 64, "Usage",
      CellTags->"EvolutionCA"],
    Cell[108146, 4442, 299, 10, 80, "Notes",
      CellTags->"EvolutionCA"],
    Cell[108448, 4454, 142, 5, 33, "Notes",
      CellTags->"EvolutionCA"],
    Cell[108593, 4461, 249, 9, 33, "Notes",
      CellTags->"EvolutionCA"],
    Cell[108845, 4472, 112, 5, 33, "Notes",
      CellTags->"EvolutionCA"],
    Cell[108960, 4479, 128, 5, 33, "Notes",
      CellTags->"EvolutionCA"],
    Cell[109091, 4486, 328, 13, 33, "Notes",
      CellTags->"EvolutionCA"],
    Cell[109444, 4503, 69, 1, 59, "ExampleSection",
      CellTags->"EvolutionCA"],
    Cell[109516, 4506, 88, 1, 70, "ExampleText",
      CellTags->"EvolutionCA"],
    Cell[109629, 4511, 90, 2, 70, "Input",
      CellTags->"EvolutionCA"],
    Cell[109722, 4515, 21368, 362, 70, 21189, 356, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"EvolutionCA"],
    Cell[131105, 4880, 197, 5, 70, "ExampleText",
      CellTags->"EvolutionCA"],
    Cell[131327, 4889, 236, 5, 70, "Input",
      CellTags->"EvolutionCA"],
    Cell[131566, 4896, 3123, 183, 70, 2943, 177, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"EvolutionCA"]},
  "FactorialQFA"->{
    Cell[134716, 5083, 62, 1, 31, "ObjectName",
      CellTags->"FactorialQFA"],
    Cell[134781, 5086, 63, 1, 74, "Highlight",
      CellTags->"FactorialQFA"],
    Cell[134847, 5089, 219, 6, 64, "Usage",
      CellTags->"FactorialQFA"],
    Cell[135069, 5097, 295, 10, 80, "Notes",
      CellTags->"FactorialQFA"],
    Cell[135367, 5109, 221, 6, 54, "Notes",
      CellTags->"FactorialQFA"],
    Cell[135613, 5119, 70, 1, 59, "ExampleSection",
      CellTags->"FactorialQFA"],
    Cell[135686, 5122, 81, 1, 70, "ExampleText",
      CellTags->"FactorialQFA"],
    Cell[135770, 5125, 187, 5, 70, "Input",
      CellTags->"FactorialQFA"],
    Cell[135982, 5134, 102, 3, 70, "Input",
      CellTags->"FactorialQFA"],
    Cell[136087, 5139, 92, 3, 70, "Output",
      CellTags->"FactorialQFA"],
    Cell[136194, 5145, 86, 1, 70, "ExampleText",
      CellTags->"FactorialQFA"],
    Cell[136305, 5150, 121, 3, 70, "Input",
      CellTags->"FactorialQFA"],
    Cell[136429, 5155, 262, 6, 70, "Output",
      CellTags->"FactorialQFA"]},
  "FinalVectorFA"->{
    Cell[136718, 5165, 64, 1, 31, "ObjectName",
      CellTags->"FinalVectorFA"],
    Cell[136785, 5168, 64, 1, 74, "Highlight",
      CellTags->"FinalVectorFA"],
    Cell[136852, 5171, 159, 4, 43, "Usage",
      CellTags->"FinalVectorFA"],
    Cell[137014, 5177, 92, 1, 33, "Notes",
      CellTags->"FinalVectorFA"],
    Cell[137109, 5180, 265, 11, 33, "Notes",
      CellTags->"FinalVectorFA"],
    Cell[137399, 5195, 71, 1, 59, "ExampleSection",
      CellTags->"FinalVectorFA"],
    Cell[137473, 5198, 96, 1, 70, "ExampleText",
      CellTags->"FinalVectorFA"],
    Cell[137594, 5203, 227, 6, 70, "Input",
      CellTags->"FinalVectorFA"],
    Cell[137824, 5211, 107, 3, 70, "Output",
      CellTags->"FinalVectorFA"]},
  "Final"->{
    Cell[137958, 5218, 48, 1, 31, "ObjectName",
      CellTags->"Final"],
    Cell[138009, 5221, 56, 1, 74, "Highlight",
      CellTags->"Final"],
    Cell[138068, 5224, 198, 6, 43, "Usage",
      CellTags->"Final"],
    Cell[138269, 5232, 257, 11, 33, "Notes",
      CellTags->"Final"],
    Cell[138551, 5247, 63, 1, 59, "ExampleSection",
      CellTags->"Final"],
    Cell[138617, 5250, 141, 4, 70, "ExampleText",
      CellTags->"Final"],
    Cell[138761, 5256, 151, 4, 70, "Input",
      CellTags->"Final"],
    Cell[138937, 5264, 88, 3, 70, "Input",
      CellTags->"Final"],
    Cell[139028, 5269, 95, 3, 70, "Output",
      CellTags->"Final"]},
  "FiniteComplementSA"->{
    Cell[139150, 5276, 74, 1, 31, "ObjectName",
      CellTags->"FiniteComplementSA"],
    Cell[139227, 5279, 69, 1, 74, "Highlight",
      CellTags->"FiniteComplementSA"],
    Cell[139299, 5282, 263, 7, 64, "Usage",
      CellTags->"FiniteComplementSA"],
    Cell[139565, 5291, 242, 9, 58, "Notes",
      CellTags->"FiniteComplementSA"],
    Cell[139810, 5302, 117, 4, 33, "Notes",
      CellTags->"FiniteComplementSA"],
    Cell[139952, 5310, 76, 1, 59, "ExampleSection",
      CellTags->"FiniteComplementSA"],
    Cell[140031, 5313, 104, 1, 70, "ExampleText",
      CellTags->"FiniteComplementSA"],
    Cell[140160, 5318, 104, 2, 70, "Input",
      CellTags->"FiniteComplementSA"],
    Cell[140267, 5322, 280, 8, 70, "Output",
      CellTags->"FiniteComplementSA"],
    Cell[140584, 5335, 112, 3, 70, "Input",
      CellTags->"FiniteComplementSA"],
    Cell[140699, 5340, 195, 4, 70, "Output",
      CellTags->"FiniteComplementSA"]},
  "FormatAutomata"->{
    Cell[140921, 5348, 66, 1, 31, "ObjectName",
      CellTags->"FormatAutomata"],
    Cell[140990, 5351, 65, 1, 74, "Highlight",
      CellTags->"FormatAutomata"],
    Cell[141058, 5354, 184, 5, 43, "Usage",
      CellTags->"FormatAutomata"],
    Cell[141245, 5361, 190, 5, 54, "Notes",
      CellTags->"FormatAutomata"],
    Cell[141438, 5368, 167, 5, 33, "Notes",
      CellTags->"FormatAutomata"],
    Cell[141608, 5375, 199, 6, 33, "Notes",
      CellTags->"FormatAutomata"],
    Cell[141810, 5383, 169, 6, 33, "Notes",
      CellTags->"FormatAutomata"],
    Cell[141982, 5391, 161, 4, 33, "Notes",
      CellTags->"FormatAutomata"],
    Cell[142146, 5397, 168, 7, 33, "Notes",
      CellTags->"FormatAutomata"],
    Cell[142339, 5408, 72, 1, 59, "ExampleSection",
      CellTags->"FormatAutomata"],
    Cell[142414, 5411, 101, 1, 70, "ExampleText",
      CellTags->"FormatAutomata"],
    Cell[142518, 5414, 149, 4, 70, "Input",
      CellTags->"FormatAutomata"],
    Cell[142692, 5422, 128, 4, 70, "Input",
      CellTags->"FormatAutomata"],
    Cell[142823, 5428, 940, 15, 70, "Output",
      CellTags->"FormatAutomata"],
    Cell[143800, 5448, 128, 4, 70, "Input",
      CellTags->"FormatAutomata"],
    Cell[143931, 5454, 504, 10, 70, "Output",
      CellTags->"FormatAutomata"],
    Cell[144472, 5469, 133, 4, 70, "Input",
      CellTags->"FormatAutomata"],
    Cell[144608, 5475, 641, 17, 70, "Output",
      CellTags->"FormatAutomata"],
    Cell[145286, 5497, 128, 4, 70, "Input",
      CellTags->"FormatAutomata"],
    Cell[145417, 5503, 96, 3, 70, "Output",
      CellTags->"FormatAutomata"],
    Cell[145528, 5509, 73, 1, 70, "ExampleText",
      CellTags->"FormatAutomata"],
    Cell[145604, 5512, 113, 3, 70, "Input",
      CellTags->"FormatAutomata"]},
  "FormatX"->{
    Cell[145732, 5518, 52, 1, 31, "ObjectName",
      CellTags->"FormatX"],
    Cell[145787, 5521, 58, 1, 74, "Highlight",
      CellTags->"FormatX"],
    Cell[145848, 5524, 196, 8, 43, "Usage",
      CellTags->"FormatX"],
    Cell[146047, 5534, 132, 4, 33, "Notes",
      CellTags->"FormatX"],
    Cell[146182, 5540, 140, 4, 33, "Notes",
      CellTags->"FormatX"],
    Cell[146325, 5546, 169, 7, 33, "Notes",
      CellTags->"FormatX"],
    Cell[146519, 5557, 65, 1, 59, "ExampleSection",
      CellTags->"FormatX"],
    Cell[146587, 5560, 90, 1, 70, "ExampleText",
      CellTags->"FormatX"],
    Cell[146702, 5565, 119, 2, 70, "Input",
      CellTags->"FormatX"],
    Cell[146824, 5569, 1174, 34, 70, "Output",
      CellTags->"FormatX"],
    Cell[148035, 5608, 169, 4, 70, "Input",
      CellTags->"FormatX"],
    Cell[148207, 5614, 1247, 33, 70, "Output",
      CellTags->"FormatX"]},
  "FrontierQ"->{
    Cell[149481, 5651, 56, 1, 31, "ObjectName",
      CellTags->"FrontierQ"],
    Cell[149540, 5654, 60, 1, 74, "Highlight",
      CellTags->"FrontierQ"],
    Cell[149603, 5657, 217, 8, 43, "Usage",
      CellTags->"FrontierQ"],
    Cell[149823, 5667, 120, 4, 33, "Notes",
      CellTags->"FrontierQ"],
    Cell[149946, 5673, 265, 11, 33, "Notes",
      CellTags->"FrontierQ"],
    Cell[150236, 5688, 67, 1, 59, "ExampleSection",
      CellTags->"FrontierQ"],
    Cell[150306, 5691, 74, 1, 70, "ExampleText",
      CellTags->"FrontierQ"],
    Cell[150405, 5696, 124, 3, 70, "Input",
      CellTags->"FrontierQ"],
    Cell[150532, 5701, 87, 3, 70, "Output",
      CellTags->"FrontierQ"],
    Cell[150634, 5707, 90, 1, 70, "ExampleText",
      CellTags->"FrontierQ"],
    Cell[150749, 5712, 124, 3, 70, "Input",
      CellTags->"FrontierQ"],
    Cell[150876, 5717, 88, 3, 70, "Output",
      CellTags->"FrontierQ"]},
  "FrontierToDFA"->{
    Cell[150991, 5724, 64, 1, 31, "ObjectName",
      CellTags->"FrontierToDFA"],
    Cell[151058, 5727, 64, 1, 74, "Highlight",
      CellTags->"FrontierToDFA"],
    Cell[151125, 5730, 209, 7, 43, "Usage",
      CellTags->"FrontierToDFA"],
    Cell[151337, 5739, 218, 8, 33, "Notes",
      CellTags->"FrontierToDFA"],
    Cell[151558, 5749, 389, 15, 33, "Notes",
      CellTags->"FrontierToDFA"],
    Cell[151972, 5768, 71, 1, 59, "ExampleSection",
      CellTags->"FrontierToDFA"],
    Cell[152046, 5771, 151, 4, 70, "ExampleText",
      CellTags->"FrontierToDFA"],
    Cell[152200, 5777, 107, 3, 70, "Input",
      CellTags->"FrontierToDFA"],
    Cell[152332, 5784, 287, 6, 70, "Input",
      CellTags->"FrontierToDFA"],
    Cell[152622, 5792, 92, 3, 70, "Output",
      CellTags->"FrontierToDFA"],
    Cell[152751, 5800, 161, 4, 70, "Input",
      CellTags->"FrontierToDFA"],
    Cell[152915, 5806, 387, 12, 70, "Output",
      CellTags->"FrontierToDFA"],
    Cell[153317, 5821, 172, 4, 70, "ExampleText",
      CellTags->"FrontierToDFA"],
    Cell[153514, 5829, 96, 3, 70, "Input",
      CellTags->"FrontierToDFA"],
    Cell[153613, 5834, 122, 3, 70, "Output",
      CellTags->"FrontierToDFA"],
    Cell[153750, 5840, 90, 1, 70, "ExampleText",
      CellTags->"FrontierToDFA"],
    Cell[153865, 5845, 114, 3, 70, "Input",
      CellTags->"FrontierToDFA"],
    Cell[153982, 5850, 570, 9, 70, "Output",
      CellTags->"FrontierToDFA"]},
  "FSMQ"->{
    Cell[154579, 5863, 46, 1, 31, "ObjectName",
      CellTags->"FSMQ"],
    Cell[154628, 5866, 55, 1, 74, "Highlight",
      CellTags->"FSMQ"],
    Cell[154686, 5869, 154, 6, 43, "Usage",
      CellTags->"FSMQ"],
    Cell[154843, 5877, 147, 5, 33, "Notes",
      CellTags->"FSMQ"],
    Cell[155015, 5886, 62, 1, 59, "ExampleSection",
      CellTags->"FSMQ"],
    Cell[155080, 5889, 91, 1, 70, "ExampleText",
      CellTags->"FSMQ"],
    Cell[155174, 5892, 97, 2, 70, "Input",
      CellTags->"FSMQ"],
    Cell[155296, 5898, 118, 3, 70, "Input",
      CellTags->"FSMQ"],
    Cell[155417, 5903, 406, 12, 70, "Output",
      CellTags->"FSMQ"],
    Cell[155860, 5920, 94, 3, 70, "Input",
      CellTags->"FSMQ"],
    Cell[155957, 5925, 98, 3, 70, "Output",
      CellTags->"FSMQ"]},
  "FSurjectiveCA"->{
    Cell[156082, 5932, 64, 1, 31, "ObjectName",
      CellTags->"FSurjectiveCA"],
    Cell[156149, 5935, 64, 1, 74, "Highlight",
      CellTags->"FSurjectiveCA"],
    Cell[156216, 5938, 187, 5, 43, "Usage",
      CellTags->"FSurjectiveCA"],
    Cell[156406, 5945, 150, 4, 33, "Notes",
      CellTags->"FSurjectiveCA"],
    Cell[156559, 5951, 281, 9, 54, "Notes",
      CellTags->"FSurjectiveCA"],
    Cell[156865, 5964, 71, 1, 59, "ExampleSection",
      CellTags->"FSurjectiveCA"],
    Cell[156939, 5967, 177, 4, 70, "ExampleText",
      CellTags->"FSurjectiveCA"],
    Cell[157119, 5973, 185, 4, 70, "Input",
      CellTags->"FSurjectiveCA"],
    Cell[157329, 5981, 133, 3, 70, "Input",
      CellTags->"FSurjectiveCA"],
    Cell[157465, 5986, 113, 3, 70, "Output",
      CellTags->"FSurjectiveCA"]},
  "FullAlphabet"->{
    Cell[157605, 5993, 62, 1, 31, "ObjectName",
      CellTags->"FullAlphabet"],
    Cell[157670, 5996, 63, 1, 74, "Highlight",
      CellTags->"FullAlphabet"],
    Cell[157736, 5999, 311, 12, 64, "Usage",
      CellTags->"FullAlphabet"],
    Cell[158050, 6013, 155, 4, 33, "Notes",
      CellTags->"FullAlphabet"],
    Cell[158208, 6019, 264, 11, 33, "Notes",
      CellTags->"FullAlphabet"],
    Cell[158497, 6034, 70, 1, 59, "ExampleSection",
      CellTags->"FullAlphabet"],
    Cell[158570, 6037, 82, 1, 70, "ExampleText",
      CellTags->"FullAlphabet"],
    Cell[158677, 6042, 220, 8, 70, "Input",
      CellTags->"FullAlphabet"],
    Cell[158900, 6052, 108, 3, 70, "Output",
      CellTags->"FullAlphabet"],
    Cell[159011, 6057, 280, 8, 70, "Output",
      CellTags->"FullAlphabet"],
    Cell[159328, 6070, 215, 8, 70, "Input",
      CellTags->"FullAlphabet"],
    Cell[159546, 6080, 103, 3, 70, "Output",
      CellTags->"FullAlphabet"],
    Cell[159652, 6085, 271, 8, 70, "Output",
      CellTags->"FullAlphabet"]},
  "FullTransitionMatrixFA"->{
    Cell[159950, 6097, 82, 1, 31, "ObjectName",
      CellTags->"FullTransitionMatrixFA"],
    Cell[160035, 6100, 73, 1, 74, "Highlight",
      CellTags->"FullTransitionMatrixFA"],
    Cell[160111, 6103, 231, 5, 64, "Usage",
      CellTags->"FullTransitionMatrixFA"],
    Cell[160345, 6110, 249, 8, 58, "Notes",
      CellTags->"FullTransitionMatrixFA"],
    Cell[160597, 6120, 164, 5, 33, "Notes",
      CellTags->"FullTransitionMatrixFA"],
    Cell[160786, 6129, 80, 1, 59, "ExampleSection",
      CellTags->"FullTransitionMatrixFA"],
    Cell[160869, 6132, 115, 1, 70, "ExampleText",
      CellTags->"FullTransitionMatrixFA"],
    Cell[161009, 6137, 107, 2, 70, "Input",
      CellTags->"FullTransitionMatrixFA"],
    Cell[161119, 6141, 408, 12, 70, "Output",
      CellTags->"FullTransitionMatrixFA"],
    Cell[161564, 6158, 172, 4, 70, "Input",
      CellTags->"FullTransitionMatrixFA"],
    Cell[161739, 6164, 597, 14, 70, "Output",
      CellTags->"FullTransitionMatrixFA"],
    Cell[162351, 6181, 141, 4, 70, "ExampleText",
      CellTags->"FullTransitionMatrixFA"],
    Cell[162517, 6189, 129, 3, 70, "Input",
      CellTags->"FullTransitionMatrixFA"],
    Cell[162649, 6194, 98, 3, 70, "Output",
      CellTags->"FullTransitionMatrixFA"]},
  "FullTransitions"->{
    Cell[162774, 6201, 68, 1, 31, "ObjectName",
      CellTags->"FullTransitions"],
    Cell[162845, 6204, 66, 1, 74, "Highlight",
      CellTags->"FullTransitions"],
    Cell[162914, 6207, 164, 4, 43, "Usage",
      CellTags->"FullTransitions"],
    Cell[163081, 6213, 383, 12, 54, "Notes",
      CellTags->"FullTransitions"],
    Cell[163467, 6227, 293, 11, 33, "Notes",
      CellTags->"FullTransitions"],
    Cell[163785, 6242, 73, 1, 59, "ExampleSection",
      CellTags->"FullTransitions"],
    Cell[163861, 6245, 107, 1, 70, "ExampleText",
      CellTags->"FullTransitions"],
    Cell[163993, 6250, 100, 2, 70, "Input",
      CellTags->"FullTransitions"],
    Cell[164096, 6254, 401, 12, 70, "Output",
      CellTags->"FullTransitions"],
    Cell[164534, 6271, 124, 3, 70, "Input",
      CellTags->"FullTransitions"],
    Cell[164661, 6276, 796, 24, 70, "Output",
      CellTags->"FullTransitions"]},
  "FunctionToCA"->{
    Cell[165484, 6304, 62, 1, 31, "ObjectName",
      CellTags->"FunctionToCA"],
    Cell[165549, 6307, 63, 1, 74, "Highlight",
      CellTags->"FunctionToCA"],
    Cell[165615, 6310, 323, 11, 64, "Usage",
      CellTags->"FunctionToCA"],
    Cell[165941, 6323, 235, 8, 54, "Notes",
      CellTags->"FunctionToCA"],
    Cell[166179, 6333, 276, 11, 33, "Notes",
      CellTags->"FunctionToCA"],
    Cell[166480, 6348, 70, 1, 59, "ExampleSection",
      CellTags->"FunctionToCA"],
    Cell[166553, 6351, 123, 4, 70, "ExampleText",
      CellTags->"FunctionToCA"],
    Cell[166701, 6359, 134, 3, 70, "Input",
      CellTags->"FunctionToCA"],
    Cell[166838, 6364, 116, 3, 70, "Output",
      CellTags->"FunctionToCA"],
    Cell[166969, 6370, 89, 1, 70, "ExampleText",
      CellTags->"FunctionToCA"],
    Cell[167083, 6375, 100, 3, 70, "Input",
      CellTags->"FunctionToCA"],
    Cell[167186, 6380, 89, 3, 70, "Output",
      CellTags->"FunctionToCA"],
    Cell[167312, 6388, 110, 3, 70, "Input",
      CellTags->"FunctionToCA"],
    Cell[167425, 6393, 32526, 534, 70, 32345, 528, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"FunctionToCA"]},
  "FunctionToDFA"->{
    Cell[199978, 6931, 64, 1, 31, "ObjectName",
      CellTags->"FunctionToDFA"],
    Cell[200045, 6934, 64, 1, 74, "Highlight",
      CellTags->"FunctionToDFA"],
    Cell[200112, 6937, 186, 4, 64, "Usage",
      CellTags->"FunctionToDFA"],
    Cell[200301, 6943, 303, 10, 80, "Notes",
      CellTags->"FunctionToDFA"],
    Cell[200607, 6955, 316, 10, 33, "Notes",
      CellTags->"FunctionToDFA"],
    Cell[200926, 6967, 287, 10, 54, "Notes",
      CellTags->"FunctionToDFA"],
    Cell[201216, 6979, 311, 13, 33, "Notes",
      CellTags->"FunctionToDFA"],
    Cell[201552, 6996, 71, 1, 59, "ExampleSection",
      CellTags->"FunctionToDFA"],
    Cell[201626, 6999, 105, 1, 70, "ExampleText",
      CellTags->"FunctionToDFA"],
    Cell[201756, 7004, 121, 3, 70, "Input",
      CellTags->"FunctionToDFA"],
    Cell[201880, 7009, 217, 4, 70, "Output",
      CellTags->"FunctionToDFA"],
    Cell[202112, 7016, 145, 3, 70, "Input",
      CellTags->"FunctionToDFA"],
    Cell[202282, 7023, 156, 4, 70, "Input",
      CellTags->"FunctionToDFA"],
    Cell[202441, 7029, 488, 14, 70, "Output",
      CellTags->"FunctionToDFA"],
    Cell[202966, 7048, 114, 3, 70, "Input",
      CellTags->"FunctionToDFA"],
    Cell[203083, 7053, 219, 4, 70, "Output",
      CellTags->"FunctionToDFA"]},
  "FunctionToSA"->{
    Cell[203329, 7061, 62, 1, 31, "ObjectName",
      CellTags->"FunctionToSA"],
    Cell[203394, 7064, 63, 1, 74, "Highlight",
      CellTags->"FunctionToSA"],
    Cell[203460, 7067, 245, 10, 43, "Usage",
      CellTags->"FunctionToSA"],
    Cell[203708, 7079, 302, 10, 80, "Notes",
      CellTags->"FunctionToSA"],
    Cell[204013, 7091, 249, 7, 33, "Notes",
      CellTags->"FunctionToSA"],
    Cell[204265, 7100, 150, 5, 33, "Notes",
      CellTags->"FunctionToSA"],
    Cell[204418, 7107, 349, 13, 33, "Notes",
      CellTags->"FunctionToSA"],
    Cell[204792, 7124, 70, 1, 59, "ExampleSection",
      CellTags->"FunctionToSA"],
    Cell[204865, 7127, 142, 4, 70, "ExampleText",
      CellTags->"FunctionToSA"],
    Cell[205010, 7133, 253, 6, 70, "Input",
      CellTags->"FunctionToSA"],
    Cell[205288, 7143, 172, 5, 70, "Input",
      CellTags->"FunctionToSA"],
    Cell[205463, 7150, 359, 10, 70, "Output",
      CellTags->"FunctionToSA"],
    Cell[205837, 7163, 83, 1, 70, "ExampleText",
      CellTags->"FunctionToSA"],
    Cell[205945, 7168, 124, 3, 70, "Input",
      CellTags->"FunctionToSA"],
    Cell[206072, 7173, 483, 14, 70, "Output",
      CellTags->"FunctionToSA"],
    Cell[206592, 7192, 134, 3, 70, "Input",
      CellTags->"FunctionToSA"],
    Cell[206729, 7197, 120, 3, 70, "Output",
      CellTags->"FunctionToSA"]},
  "GenerateDFA"->{
    Cell[206876, 7204, 60, 1, 31, "ObjectName",
      CellTags->"GenerateDFA"],
    Cell[206939, 7207, 62, 1, 74, "Highlight",
      CellTags->"GenerateDFA"],
    Cell[207004, 7210, 287, 8, 64, "Usage",
      CellTags->"GenerateDFA"],
    Cell[207294, 7220, 278, 7, 54, "Notes",
      CellTags->"GenerateDFA"],
    Cell[207575, 7229, 300, 9, 54, "Notes",
      CellTags->"GenerateDFA"],
    Cell[207878, 7240, 221, 9, 33, "Notes",
      CellTags->"GenerateDFA"],
    Cell[208124, 7253, 69, 1, 59, "ExampleSection",
      CellTags->"GenerateDFA"],
    Cell[208196, 7256, 229, 7, 70, "ExampleText",
      CellTags->"GenerateDFA"],
    Cell[208428, 7265, 201, 4, 70, "Input",
      CellTags->"GenerateDFA"],
    Cell[208654, 7273, 173, 5, 70, "Input",
      CellTags->"GenerateDFA"],
    Cell[208830, 7280, 716, 19, 70, "Output",
      CellTags->"GenerateDFA"],
    Cell[209561, 7302, 254, 7, 70, "ExampleText",
      CellTags->"GenerateDFA"],
    Cell[209840, 7313, 124, 3, 70, "Input",
      CellTags->"GenerateDFA"],
    Cell[209967, 7318, 605, 16, 70, "Output",
      CellTags->"GenerateDFA"],
    Cell[210609, 7339, 157, 4, 70, "Input",
      CellTags->"GenerateDFA"],
    Cell[210769, 7345, 123, 3, 70, "Output",
      CellTags->"GenerateDFA"]},
  "GenerateQuotients"->{
    Cell[210919, 7352, 72, 1, 31, "ObjectName",
      CellTags->"GenerateQuotients"],
    Cell[210994, 7355, 68, 1, 74, "Highlight",
      CellTags->"GenerateQuotients"],
    Cell[211065, 7358, 232, 8, 43, "Usage",
      CellTags->"GenerateQuotients"],
    Cell[211300, 7368, 173, 5, 33, "Notes",
      CellTags->"GenerateQuotients"],
    Cell[211476, 7375, 476, 19, 33, "Notes",
      CellTags->"GenerateQuotients"],
    Cell[211977, 7398, 75, 1, 59, "ExampleSection",
      CellTags->"GenerateQuotients"],
    Cell[212055, 7401, 146, 4, 70, "ExampleText",
      CellTags->"GenerateQuotients"],
    Cell[212226, 7409, 94, 2, 70, "Input",
      CellTags->"GenerateQuotients"],
    Cell[212323, 7413, 142, 3, 70, "Output",
      CellTags->"GenerateQuotients"],
    Cell[212502, 7421, 115, 3, 70, "Input",
      CellTags->"GenerateQuotients"],
    Cell[212620, 7426, 245, 5, 70, "Output",
      CellTags->"GenerateQuotients"]},
  "GlobalMapCA"->{
    Cell[212892, 7435, 60, 1, 31, "ObjectName",
      CellTags->"GlobalMapCA"],
    Cell[212955, 7438, 62, 1, 74, "Highlight",
      CellTags->"GlobalMapCA"],
    Cell[213020, 7441, 310, 10, 64, "Usage",
      CellTags->"GlobalMapCA"],
    Cell[213333, 7453, 274, 9, 80, "Notes",
      CellTags->"GlobalMapCA"],
    Cell[213610, 7464, 112, 5, 33, "Notes",
      CellTags->"GlobalMapCA"],
    Cell[213725, 7471, 142, 5, 33, "Notes",
      CellTags->"GlobalMapCA"],
    Cell[213870, 7478, 189, 6, 33, "Notes",
      CellTags->"GlobalMapCA"],
    Cell[214062, 7486, 164, 7, 33, "Notes",
      CellTags->"GlobalMapCA"],
    Cell[214251, 7497, 69, 1, 59, "ExampleSection",
      CellTags->"GlobalMapCA"],
    Cell[214323, 7500, 100, 1, 70, "ExampleText",
      CellTags->"GlobalMapCA"],
    Cell[214426, 7503, 108, 3, 70, "Input",
      CellTags->"GlobalMapCA"],
    Cell[214559, 7510, 148, 4, 70, "Input",
      CellTags->"GlobalMapCA"],
    Cell[214710, 7516, 367, 6, 70, "Output",
      CellTags->"GlobalMapCA"],
    Cell[215114, 7527, 127, 3, 70, "Input",
      CellTags->"GlobalMapCA"],
    Cell[215244, 7532, 844, 21, 70, "Output",
      CellTags->"GlobalMapCA"],
    Cell[216103, 7556, 89, 1, 70, "ExampleText",
      CellTags->"GlobalMapCA"],
    Cell[216217, 7561, 264, 5, 70, "Input",
      CellTags->"GlobalMapCA"],
    Cell[216484, 7568, 91, 3, 70, "Output",
      CellTags->"GlobalMapCA"]},
  "HomomorphismFA"->{
    Cell[216602, 7575, 66, 1, 31, "ObjectName",
      CellTags->"HomomorphismFA"],
    Cell[216671, 7578, 65, 1, 74, "Highlight",
      CellTags->"HomomorphismFA"],
    Cell[216739, 7581, 257, 8, 64, "Usage",
      CellTags->"HomomorphismFA"],
    Cell[216999, 7591, 164, 5, 33, "Notes",
      CellTags->"HomomorphismFA"],
    Cell[217166, 7598, 163, 5, 33, "Notes",
      CellTags->"HomomorphismFA"],
    Cell[217332, 7605, 179, 7, 33, "Notes",
      CellTags->"HomomorphismFA"],
    Cell[217536, 7616, 72, 1, 59, "ExampleSection",
      CellTags->"HomomorphismFA"],
    Cell[217611, 7619, 303, 12, 70, "ExampleText",
      CellTags->"HomomorphismFA"],
    Cell[217939, 7635, 221, 5, 70, "Input",
      CellTags->"HomomorphismFA"],
    Cell[218163, 7642, 495, 14, 70, "Output",
      CellTags->"HomomorphismFA"],
    Cell[218661, 7658, 571, 15, 70, "Output",
      CellTags->"HomomorphismFA"],
    Cell[219269, 7678, 110, 3, 70, "Input",
      CellTags->"HomomorphismFA"],
    Cell[219382, 7683, 229, 5, 70, "Output",
      CellTags->"HomomorphismFA"]},
  "HurwitzProduct"->{
    Cell[219638, 7692, 66, 1, 31, "ObjectName",
      CellTags->"HurwitzProduct"],
    Cell[219707, 7695, 65, 1, 74, "Highlight",
      CellTags->"HurwitzProduct"],
    Cell[219775, 7698, 164, 4, 43, "Usage",
      CellTags->"HurwitzProduct"],
    Cell[219942, 7704, 84, 1, 33, "Notes",
      CellTags->"HurwitzProduct"],
    Cell[220029, 7707, 418, 15, 33, "Notes",
      CellTags->"HurwitzProduct"],
    Cell[220472, 7726, 72, 1, 59, "ExampleSection",
      CellTags->"HurwitzProduct"],
    Cell[220547, 7729, 114, 2, 70, "ExampleText",
      CellTags->"HurwitzProduct"],
    Cell[220686, 7735, 142, 6, 70, "Input",
      CellTags->"HurwitzProduct"],
    Cell[220831, 7743, 232, 5, 70, "Output",
      CellTags->"HurwitzProduct"],
    Cell[221100, 7753, 160, 6, 70, "Input",
      CellTags->"HurwitzProduct"],
    Cell[221263, 7761, 325, 6, 70, "Output",
      CellTags->"HurwitzProduct"],
    Cell[221625, 7772, 112, 3, 70, "Input",
      CellTags->"HurwitzProduct"],
    Cell[221740, 7777, 315, 6, 70, "Output",
      CellTags->"HurwitzProduct"],
    Cell[222070, 7786, 196, 6, 70, "ExampleText",
      CellTags->"HurwitzProduct"],
    Cell[222291, 7796, 229, 5, 70, "Input",
      CellTags->"HurwitzProduct"],
    Cell[222523, 7803, 834, 26, 70, "Output",
      CellTags->"HurwitzProduct"]},
  "IdealBaseFA"->{
    Cell[223384, 7833, 60, 1, 31, "ObjectName",
      CellTags->"IdealBaseFA"],
    Cell[223447, 7836, 62, 1, 74, "Highlight",
      CellTags->"IdealBaseFA"],
    Cell[223512, 7839, 177, 6, 43, "Usage",
      CellTags->"IdealBaseFA"],
    Cell[223692, 7847, 255, 9, 54, "Notes",
      CellTags->"IdealBaseFA"],
    Cell[223950, 7858, 450, 19, 33, "Notes",
      CellTags->"IdealBaseFA"],
    Cell[224425, 7881, 69, 1, 59, "ExampleSection",
      CellTags->"IdealBaseFA"],
    Cell[224497, 7884, 98, 1, 70, "ExampleText",
      CellTags->"IdealBaseFA"],
    Cell[224620, 7889, 127, 3, 70, "Input",
      CellTags->"IdealBaseFA"],
    Cell[224750, 7894, 379, 12, 70, "Output",
      CellTags->"IdealBaseFA"],
    Cell[225166, 7911, 96, 3, 70, "Input",
      CellTags->"IdealBaseFA"],
    Cell[225265, 7916, 90, 3, 70, "Output",
      CellTags->"IdealBaseFA"],
    Cell[225392, 7924, 109, 3, 70, "Input",
      CellTags->"IdealBaseFA"],
    Cell[225504, 7929, 386, 12, 70, "Output",
      CellTags->"IdealBaseFA"],
    Cell[225905, 7944, 269, 9, 70, "ExampleText",
      CellTags->"IdealBaseFA"],
    Cell[226199, 7957, 112, 3, 70, "Input",
      CellTags->"IdealBaseFA"],
    Cell[226314, 7962, 206, 4, 70, "Output",
      CellTags->"IdealBaseFA"]},
  "IdealQFA"->{
    Cell[226547, 7970, 54, 1, 31, "ObjectName",
      CellTags->"IdealQFA"],
    Cell[226604, 7973, 59, 1, 74, "Highlight",
      CellTags->"IdealQFA"],
    Cell[226666, 7976, 168, 6, 43, "Usage",
      CellTags->"IdealQFA"],
    Cell[226837, 7984, 147, 5, 33, "Notes",
      CellTags->"IdealQFA"],
    Cell[226987, 7991, 163, 7, 33, "Notes",
      CellTags->"IdealQFA"],
    Cell[227175, 8002, 66, 1, 59, "ExampleSection",
      CellTags->"IdealQFA"],
    Cell[227244, 8005, 95, 1, 70, "ExampleText",
      CellTags->"IdealQFA"],
    Cell[227364, 8010, 124, 3, 70, "Input",
      CellTags->"IdealQFA"],
    Cell[227491, 8015, 376, 12, 70, "Output",
      CellTags->"IdealQFA"],
    Cell[227904, 8032, 93, 3, 70, "Input",
      CellTags->"IdealQFA"],
    Cell[228000, 8037, 87, 3, 70, "Output",
      CellTags->"IdealQFA"]},
  "IdentityCA"->{
    Cell[228114, 8044, 58, 1, 31, "ObjectName",
      CellTags->"IdentityCA"],
    Cell[228175, 8047, 61, 1, 74, "Highlight",
      CellTags->"IdentityCA"],
    Cell[228239, 8050, 167, 4, 43, "Usage",
      CellTags->"IdentityCA"],
    Cell[228409, 8056, 99, 1, 33, "Notes",
      CellTags->"IdentityCA"],
    Cell[228511, 8059, 262, 11, 33, "Notes",
      CellTags->"IdentityCA"],
    Cell[228798, 8074, 68, 1, 59, "ExampleSection",
      CellTags->"IdentityCA"],
    Cell[228869, 8077, 82, 1, 70, "ExampleText",
      CellTags->"IdentityCA"],
    Cell[228976, 8082, 153, 4, 70, "Input",
      CellTags->"IdentityCA"],
    Cell[229132, 8088, 103, 3, 70, "Output",
      CellTags->"IdentityCA"],
    Cell[229238, 8093, 106, 3, 70, "Output",
      CellTags->"IdentityCA"],
    Cell[229359, 8099, 123, 4, 70, "ExampleText",
      CellTags->"IdentityCA"],
    Cell[229507, 8107, 100, 3, 70, "Input",
      CellTags->"IdentityCA"],
    Cell[229610, 8112, 92, 3, 70, "Output",
      CellTags->"IdentityCA"],
    Cell[229739, 8120, 96, 3, 70, "Input",
      CellTags->"IdentityCA"],
    Cell[229838, 8125, 103, 3, 70, "Output",
      CellTags->"IdentityCA"]},
  "InfiniteQFA"->{
    Cell[229968, 8132, 60, 1, 31, "ObjectName",
      CellTags->"InfiniteQFA"],
    Cell[230031, 8135, 62, 1, 74, "Highlight",
      CellTags->"InfiniteQFA"],
    Cell[230096, 8138, 181, 6, 43, "Usage",
      CellTags->"InfiniteQFA"],
    Cell[230280, 8146, 130, 5, 33, "Notes",
      CellTags->"InfiniteQFA"],
    Cell[230413, 8153, 157, 7, 33, "Notes",
      CellTags->"InfiniteQFA"],
    Cell[230595, 8164, 69, 1, 59, "ExampleSection",
      CellTags->"InfiniteQFA"],
    Cell[230667, 8167, 83, 1, 70, "ExampleText",
      CellTags->"InfiniteQFA"],
    Cell[230775, 8172, 100, 2, 70, "Input",
      CellTags->"InfiniteQFA"],
    Cell[230878, 8176, 412, 12, 70, "Output",
      CellTags->"InfiniteQFA"],
    Cell[231327, 8193, 100, 3, 70, "Input",
      CellTags->"InfiniteQFA"],
    Cell[231430, 8198, 92, 3, 70, "Output",
      CellTags->"InfiniteQFA"],
    Cell[231537, 8204, 100, 1, 70, "ExampleText",
      CellTags->"InfiniteQFA"],
    Cell[231662, 8209, 84, 2, 70, "Input",
      CellTags->"InfiniteQFA"],
    Cell[231749, 8213, 548, 15, 70, "Output",
      CellTags->"InfiniteQFA"],
    Cell[232334, 8233, 101, 3, 70, "Input",
      CellTags->"InfiniteQFA"],
    Cell[232438, 8238, 91, 3, 70, "Output",
      CellTags->"InfiniteQFA"]},
  "InfixFA"->{
    Cell[232556, 8245, 52, 1, 31, "ObjectName",
      CellTags->"InfixFA"],
    Cell[232611, 8248, 58, 1, 74, "Highlight",
      CellTags->"InfixFA"],
    Cell[232672, 8251, 192, 6, 43, "Usage",
      CellTags->"InfixFA"],
    Cell[232867, 8259, 247, 9, 58, "Notes",
      CellTags->"InfixFA"],
    Cell[233117, 8270, 254, 11, 33, "Notes",
      CellTags->"InfixFA"],
    Cell[233396, 8285, 65, 1, 59, "ExampleSection",
      CellTags->"InfixFA"],
    Cell[233464, 8288, 71, 1, 70, "ExampleText",
      CellTags->"InfixFA"],
    Cell[233560, 8293, 83, 2, 70, "Input",
      CellTags->"InfixFA"],
    Cell[233646, 8297, 477, 14, 70, "Output",
      CellTags->"InfixFA"],
    Cell[234160, 8316, 102, 3, 70, "Input",
      CellTags->"InfixFA"],
    Cell[234265, 8321, 443, 8, 70, "Output",
      CellTags->"InfixFA"]},
  "InitialVectorFA"->{
    Cell[234735, 8333, 68, 1, 31, "ObjectName",
      CellTags->"InitialVectorFA"],
    Cell[234806, 8336, 66, 1, 74, "Highlight",
      CellTags->"InitialVectorFA"],
    Cell[234875, 8339, 167, 4, 43, "Usage",
      CellTags->"InitialVectorFA"],
    Cell[235045, 8345, 94, 1, 33, "Notes",
      CellTags->"InitialVectorFA"],
    Cell[235142, 8348, 267, 11, 33, "Notes",
      CellTags->"InitialVectorFA"],
    Cell[235434, 8363, 73, 1, 59, "ExampleSection",
      CellTags->"InitialVectorFA"],
    Cell[235510, 8366, 151, 4, 70, "ExampleText",
      CellTags->"InitialVectorFA"],
    Cell[235664, 8372, 161, 4, 70, "Input",
      CellTags->"InitialVectorFA"],
    Cell[235850, 8380, 108, 3, 70, "Input",
      CellTags->"InitialVectorFA"],
    Cell[235961, 8385, 139, 3, 70, "Output",
      CellTags->"InitialVectorFA"]},
  "Initial"->{
    Cell[236127, 8392, 52, 1, 31, "ObjectName",
      CellTags->"Initial"],
    Cell[236182, 8395, 58, 1, 74, "Highlight",
      CellTags->"Initial"],
    Cell[236243, 8398, 178, 5, 43, "Usage",
      CellTags->"Initial"],
    Cell[236424, 8405, 259, 11, 33, "Notes",
      CellTags->"Initial"],
    Cell[236708, 8420, 65, 1, 59, "ExampleSection",
      CellTags->"Initial"],
    Cell[236776, 8423, 143, 4, 70, "ExampleText",
      CellTags->"Initial"],
    Cell[236922, 8429, 153, 4, 70, "Input",
      CellTags->"Initial"],
    Cell[237100, 8437, 92, 3, 70, "Input",
      CellTags->"Initial"],
    Cell[237195, 8442, 96, 3, 70, "Output",
      CellTags->"Initial"]},
  "IntersectionFA"->{
    Cell[237318, 8449, 66, 1, 31, "ObjectName",
      CellTags->"IntersectionFA"],
    Cell[237387, 8452, 65, 1, 74, "Highlight",
      CellTags->"IntersectionFA"],
    Cell[237455, 8455, 271, 9, 64, "Usage",
      CellTags->"IntersectionFA"],
    Cell[237729, 8466, 299, 10, 80, "Notes",
      CellTags->"IntersectionFA"],
    Cell[238031, 8478, 141, 5, 33, "Notes",
      CellTags->"IntersectionFA"],
    Cell[238175, 8485, 202, 8, 33, "Notes",
      CellTags->"IntersectionFA"],
    Cell[238380, 8495, 83, 1, 33, "Notes",
      CellTags->"IntersectionFA"],
    Cell[238466, 8498, 59, 1, 33, "Notes",
      CellTags->"IntersectionFA"],
    Cell[238528, 8501, 341, 15, 33, "Notes",
      CellTags->"IntersectionFA"],
    Cell[238894, 8520, 72, 1, 59, "ExampleSection",
      CellTags->"IntersectionFA"],
    Cell[238969, 8523, 205, 5, 70, "ExampleText",
      CellTags->"IntersectionFA"],
    Cell[239199, 8532, 167, 4, 70, "Input",
      CellTags->"IntersectionFA"],
    Cell[239369, 8538, 365, 12, 70, "Output",
      CellTags->"IntersectionFA"],
    Cell[239737, 8552, 368, 12, 70, "Output",
      CellTags->"IntersectionFA"],
    Cell[240120, 8567, 133, 4, 70, "ExampleText",
      CellTags->"IntersectionFA"],
    Cell[240278, 8575, 182, 4, 70, "Input",
      CellTags->"IntersectionFA"],
    Cell[240463, 8581, 396, 12, 70, "Output",
      CellTags->"IntersectionFA"],
    Cell[240862, 8595, 174, 4, 70, "Output",
      CellTags->"IntersectionFA"]},
  "InverseCA"->{
    Cell[241063, 8603, 56, 1, 31, "ObjectName",
      CellTags->"InverseCA"],
    Cell[241122, 8606, 60, 1, 74, "Highlight",
      CellTags->"InverseCA"],
    Cell[241185, 8609, 180, 6, 43, "Usage",
      CellTags->"InverseCA"],
    Cell[241368, 8617, 247, 9, 58, "Notes",
      CellTags->"InverseCA"],
    Cell[241618, 8628, 113, 4, 33, "Notes",
      CellTags->"InverseCA"],
    Cell[241756, 8636, 67, 1, 59, "ExampleSection",
      CellTags->"InverseCA"],
    Cell[241826, 8639, 80, 1, 70, "ExampleText",
      CellTags->"InverseCA"],
    Cell[241931, 8644, 170, 5, 70, "Input",
      CellTags->"InverseCA"],
    Cell[242104, 8651, 86, 3, 70, "Output",
      CellTags->"InverseCA"],
    Cell[242227, 8659, 201, 6, 70, "Input",
      CellTags->"InverseCA"],
    Cell[242431, 8667, 139, 3, 70, "Output",
      CellTags->"InverseCA"],
    Cell[242573, 8672, 101, 3, 70, "Output",
      CellTags->"InverseCA"]},
  "IrreducibleFA"->{
    Cell[242701, 8679, 64, 1, 31, "ObjectName",
      CellTags->"IrreducibleFA"],
    Cell[242768, 8682, 64, 1, 74, "Highlight",
      CellTags->"IrreducibleFA"],
    Cell[242835, 8685, 292, 10, 64, "Usage",
      CellTags->"IrreducibleFA"],
    Cell[243130, 8697, 298, 10, 80, "Notes",
      CellTags->"IrreducibleFA"],
    Cell[243431, 8709, 401, 15, 54, "Notes",
      CellTags->"IrreducibleFA"],
    Cell[243835, 8726, 146, 5, 33, "Notes",
      CellTags->"IrreducibleFA"],
    Cell[243984, 8733, 167, 7, 33, "Notes",
      CellTags->"IrreducibleFA"],
    Cell[244176, 8744, 71, 1, 59, "ExampleSection",
      CellTags->"IrreducibleFA"],
    Cell[244250, 8747, 221, 9, 70, "ExampleText",
      CellTags->"IrreducibleFA"],
    Cell[244474, 8758, 82, 2, 70, "Input",
      CellTags->"IrreducibleFA"],
    Cell[244581, 8764, 114, 3, 70, "Input",
      CellTags->"IrreducibleFA"],
    Cell[244698, 8769, 406, 12, 70, "Output",
      CellTags->"IrreducibleFA"],
    Cell[245141, 8786, 114, 3, 70, "Input",
      CellTags->"IrreducibleFA"],
    Cell[245258, 8791, 191, 4, 70, "Output",
      CellTags->"IrreducibleFA"],
    Cell[245464, 8798, 96, 1, 70, "ExampleText",
      CellTags->"IrreducibleFA"],
    Cell[245585, 8803, 142, 3, 70, "Input",
      CellTags->"IrreducibleFA"],
    Cell[245730, 8808, 121, 3, 70, "Output",
      CellTags->"IrreducibleFA"]},
  "IsomorphicQDFA"->{
    Cell[245878, 8815, 66, 1, 31, "ObjectName",
      CellTags->"IsomorphicQDFA"],
    Cell[245947, 8818, 65, 1, 74, "Highlight",
      CellTags->"IsomorphicQDFA"],
    Cell[246015, 8821, 157, 4, 43, "Usage",
      CellTags->"IsomorphicQDFA"],
    Cell[246175, 8827, 300, 10, 80, "Notes",
      CellTags->"IsomorphicQDFA"],
    Cell[246478, 8839, 150, 4, 33, "Notes",
      CellTags->"IsomorphicQDFA"],
    Cell[246631, 8845, 167, 5, 33, "Notes",
      CellTags->"IsomorphicQDFA"],
    Cell[246801, 8852, 163, 4, 33, "Notes",
      CellTags->"IsomorphicQDFA"],
    Cell[246989, 8860, 72, 1, 59, "ExampleSection",
      CellTags->"IsomorphicQDFA"],
    Cell[247064, 8863, 77, 1, 70, "ExampleText",
      CellTags->"IsomorphicQDFA"],
    Cell[247144, 8866, 336, 8, 70, "Input",
      CellTags->"IsomorphicQDFA"],
    Cell[247505, 8878, 111, 3, 70, "Input",
      CellTags->"IsomorphicQDFA"],
    Cell[247619, 8883, 94, 3, 70, "Output",
      CellTags->"IsomorphicQDFA"],
    Cell[247750, 8891, 133, 3, 70, "Input",
      CellTags->"IsomorphicQDFA"],
    Cell[247886, 8896, 163, 4, 70, "Output",
      CellTags->"IsomorphicQDFA"]},
  "IterateCA"->{
    Cell[248076, 8904, 56, 1, 31, "ObjectName",
      CellTags->"IterateCA"],
    Cell[248135, 8907, 60, 1, 74, "Highlight",
      CellTags->"IterateCA"],
    Cell[248198, 8910, 166, 4, 43, "Usage",
      CellTags->"IterateCA"],
    Cell[248367, 8916, 249, 9, 58, "Notes",
      CellTags->"IterateCA"],
    Cell[248619, 8927, 322, 12, 54, "Notes",
      CellTags->"IterateCA"],
    Cell[248966, 8943, 67, 1, 59, "ExampleSection",
      CellTags->"IterateCA"],
    Cell[249036, 8946, 98, 1, 70, "ExampleText",
      CellTags->"IterateCA"],
    Cell[249159, 8951, 93, 2, 70, "Input",
      CellTags->"IterateCA"],
    Cell[249255, 8955, 138, 3, 70, "Output",
      CellTags->"IterateCA"],
    Cell[249430, 8963, 143, 4, 70, "Input",
      CellTags->"IterateCA"],
    Cell[249576, 8969, 85, 3, 70, "Output",
      CellTags->"IterateCA"]},
  "IthSymbolDFA"->{
    Cell[249688, 8976, 62, 1, 31, "ObjectName",
      CellTags->"IthSymbolDFA"],
    Cell[249753, 8979, 63, 1, 74, "Highlight",
      CellTags->"IthSymbolDFA"],
    Cell[249819, 8982, 200, 5, 64, "Usage",
      CellTags->"IthSymbolDFA"],
    Cell[250022, 8989, 252, 9, 58, "Notes",
      CellTags->"IthSymbolDFA"],
    Cell[250277, 9000, 82, 1, 33, "Notes",
      CellTags->"IthSymbolDFA"],
    Cell[250362, 9003, 167, 7, 33, "Notes",
      CellTags->"IthSymbolDFA"],
    Cell[250554, 9014, 70, 1, 59, "ExampleSection",
      CellTags->"IthSymbolDFA"],
    Cell[250627, 9017, 180, 6, 70, "ExampleText",
      CellTags->"IthSymbolDFA"],
    Cell[250832, 9027, 117, 3, 70, "Input",
      CellTags->"IthSymbolDFA"],
    Cell[250952, 9032, 524, 15, 70, "Output",
      CellTags->"IthSymbolDFA"],
    Cell[251513, 9052, 114, 3, 70, "Input",
      CellTags->"IthSymbolDFA"],
    Cell[251630, 9057, 369, 6, 70, "Output",
      CellTags->"IthSymbolDFA"],
    Cell[252014, 9066, 89, 1, 70, "ExampleText",
      CellTags->"IthSymbolDFA"],
    Cell[252128, 9071, 112, 3, 70, "Input",
      CellTags->"IthSymbolDFA"],
    Cell[252243, 9076, 89, 3, 70, "Output",
      CellTags->"IthSymbolDFA"]},
  "IthSymbolFA"->{
    Cell[252359, 9083, 60, 1, 31, "ObjectName",
      CellTags->"IthSymbolFA"],
    Cell[252422, 9086, 62, 1, 74, "Highlight",
      CellTags->"IthSymbolFA"],
    Cell[252487, 9089, 226, 7, 64, "Usage",
      CellTags->"IthSymbolFA"],
    Cell[252716, 9098, 251, 9, 58, "Notes",
      CellTags->"IthSymbolFA"],
    Cell[252970, 9109, 125, 5, 33, "Notes",
      CellTags->"IthSymbolFA"],
    Cell[253098, 9116, 166, 7, 33, "Notes",
      CellTags->"IthSymbolFA"],
    Cell[253289, 9127, 69, 1, 59, "ExampleSection",
      CellTags->"IthSymbolFA"],
    Cell[253361, 9130, 179, 6, 70, "ExampleText",
      CellTags->"IthSymbolFA"],
    Cell[253565, 9140, 115, 3, 70, "Input",
      CellTags->"IthSymbolFA"],
    Cell[253683, 9145, 460, 14, 70, "Output",
      CellTags->"IthSymbolFA"],
    Cell[254180, 9164, 113, 3, 70, "Input",
      CellTags->"IthSymbolFA"],
    Cell[254296, 9169, 368, 6, 70, "Output",
      CellTags->"IthSymbolFA"]},
  "JoinSA"->{
    Cell[254691, 9179, 50, 1, 31, "ObjectName",
      CellTags->"JoinSA"],
    Cell[254744, 9182, 57, 1, 74, "Highlight",
      CellTags->"JoinSA"],
    Cell[254804, 9185, 190, 6, 43, "Usage",
      CellTags->"JoinSA"],
    Cell[254997, 9193, 246, 9, 58, "Notes",
      CellTags->"JoinSA"],
    Cell[255246, 9204, 158, 5, 33, "Notes",
      CellTags->"JoinSA"],
    Cell[255407, 9211, 149, 7, 33, "Notes",
      CellTags->"JoinSA"],
    Cell[255581, 9222, 64, 1, 59, "ExampleSection",
      CellTags->"JoinSA"],
    Cell[255648, 9225, 79, 1, 70, "ExampleText",
      CellTags->"JoinSA"],
    Cell[255730, 9228, 183, 4, 70, "Input",
      CellTags->"JoinSA"],
    Cell[255938, 9236, 118, 3, 70, "Input",
      CellTags->"JoinSA"],
    Cell[256059, 9241, 269, 8, 70, "Output",
      CellTags->"JoinSA"],
    Cell[256365, 9254, 131, 3, 70, "Input",
      CellTags->"JoinSA"],
    Cell[256499, 9259, 185, 4, 70, "Output",
      CellTags->"JoinSA"]},
  "LabelToCodeCA"->{
    Cell[256711, 9267, 64, 1, 31, "ObjectName",
      CellTags->"LabelToCodeCA"],
    Cell[256778, 9270, 64, 1, 74, "Highlight",
      CellTags->"LabelToCodeCA"],
    Cell[256845, 9273, 149, 4, 43, "Usage",
      CellTags->"LabelToCodeCA"],
    Cell[256997, 9279, 147, 4, 33, "Notes",
      CellTags->"LabelToCodeCA"],
    Cell[257147, 9285, 125, 4, 33, "Notes",
      CellTags->"LabelToCodeCA"],
    Cell[257297, 9293, 71, 1, 59, "ExampleSection",
      CellTags->"LabelToCodeCA"],
    Cell[257371, 9296, 85, 1, 70, "ExampleText",
      CellTags->"LabelToCodeCA"],
    Cell[257481, 9301, 148, 3, 70, "Input",
      CellTags->"LabelToCodeCA"],
    Cell[257632, 9306, 106, 3, 70, "Output",
      CellTags->"LabelToCodeCA"]},
  "LanguageFA"->{
    Cell[257765, 9313, 58, 1, 31, "ObjectName",
      CellTags->"LanguageFA"],
    Cell[257826, 9316, 61, 1, 74, "Highlight",
      CellTags->"LanguageFA"],
    Cell[257890, 9319, 207, 8, 43, "Usage",
      CellTags->"LanguageFA"],
    Cell[258100, 9329, 473, 14, 176, "Notes",
      CellTags->"LanguageFA"],
    Cell[258576, 9345, 181, 7, 33, "Notes",
      CellTags->"LanguageFA"],
    Cell[258760, 9354, 211, 7, 33, "Notes",
      CellTags->"LanguageFA"],
    Cell[258974, 9363, 183, 5, 33, "Notes",
      CellTags->"LanguageFA"],
    Cell[259160, 9370, 156, 5, 33, "Notes",
      CellTags->"LanguageFA"],
    Cell[259319, 9377, 345, 10, 54, "Notes",
      CellTags->"LanguageFA"],
    Cell[259667, 9389, 398, 14, 54, "Notes",
      CellTags->"LanguageFA"],
    Cell[260068, 9405, 205, 7, 33, "Notes",
      CellTags->"LanguageFA"],
    Cell[260298, 9416, 68, 1, 59, "ExampleSection",
      CellTags->"LanguageFA"],
    Cell[260369, 9419, 134, 4, 70, "ExampleText",
      CellTags->"LanguageFA"],
    Cell[260506, 9425, 193, 5, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[260724, 9434, 105, 3, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[260832, 9439, 366, 6, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[261235, 9450, 154, 4, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[261392, 9456, 127, 3, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[261534, 9462, 110, 2, 70, "ExampleText",
      CellTags->"LanguageFA"],
    Cell[261647, 9466, 218, 5, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[261890, 9475, 175, 4, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[262068, 9481, 366, 6, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[262437, 9489, 127, 3, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[262579, 9495, 124, 4, 70, "ExampleText",
      CellTags->"LanguageFA"],
    Cell[262728, 9503, 127, 3, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[262858, 9508, 336, 6, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[263209, 9517, 144, 4, 70, "ExampleText",
      CellTags->"LanguageFA"],
    Cell[263356, 9523, 224, 5, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[263605, 9532, 128, 3, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[263736, 9537, 119, 3, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[263892, 9545, 127, 3, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[264022, 9550, 320, 6, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[264357, 9559, 85, 1, 70, "ExampleText",
      CellTags->"LanguageFA"],
    Cell[264467, 9564, 114, 3, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[264584, 9569, 384, 12, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[265005, 9586, 128, 3, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[265136, 9591, 106, 3, 70, "Output",
      CellTags->"LanguageFA"],
    Cell[265279, 9599, 116, 3, 70, "Input",
      CellTags->"LanguageFA"],
    Cell[265398, 9604, 141, 3, 70, "Output",
      CellTags->"LanguageFA"]},
  "LanguageSort"->{
    Cell[265566, 9611, 62, 1, 31, "ObjectName",
      CellTags->"LanguageSort"],
    Cell[265631, 9614, 63, 1, 74, "Highlight",
      CellTags->"LanguageSort"],
    Cell[265697, 9617, 207, 6, 43, "Usage",
      CellTags->"LanguageSort"],
    Cell[265907, 9625, 145, 5, 33, "Notes",
      CellTags->"LanguageSort"],
    Cell[266055, 9632, 178, 7, 33, "Notes",
      CellTags->"LanguageSort"],
    Cell[266258, 9643, 70, 1, 59, "ExampleSection",
      CellTags->"LanguageSort"],
    Cell[266331, 9646, 171, 4, 70, "ExampleText",
      CellTags->"LanguageSort"],
    Cell[266505, 9652, 220, 6, 70, "Input",
      CellTags->"LanguageSort"],
    Cell[266750, 9662, 204, 5, 70, "Input",
      CellTags->"LanguageSort"],
    Cell[266957, 9669, 841, 17, 70, "Output",
      CellTags->"LanguageSort"]},
  "LanguageToSeries"->{
    Cell[267825, 9690, 70, 1, 31, "ObjectName",
      CellTags->"LanguageToSeries"],
    Cell[267898, 9693, 67, 1, 74, "Highlight",
      CellTags->"LanguageToSeries"],
    Cell[267968, 9696, 175, 6, 43, "Usage",
      CellTags->"LanguageToSeries"],
    Cell[268146, 9704, 156, 5, 33, "Notes",
      CellTags->"LanguageToSeries"],
    Cell[268305, 9711, 269, 11, 33, "Notes",
      CellTags->"LanguageToSeries"],
    Cell[268599, 9726, 74, 1, 59, "ExampleSection",
      CellTags->"LanguageToSeries"],
    Cell[268676, 9729, 77, 1, 70, "ExampleText",
      CellTags->"LanguageToSeries"],
    Cell[268778, 9734, 83, 2, 70, "Input",
      CellTags->"LanguageToSeries"],
    Cell[268864, 9738, 148, 3, 70, "Output",
      CellTags->"LanguageToSeries"],
    Cell[269049, 9746, 110, 3, 70, "Input",
      CellTags->"LanguageToSeries"],
    Cell[269162, 9751, 197, 4, 70, "Output",
      CellTags->"LanguageToSeries"],
    Cell[269396, 9760, 102, 3, 70, "Input",
      CellTags->"LanguageToSeries"],
    Cell[269501, 9765, 177, 4, 70, "Output",
      CellTags->"LanguageToSeries"]},
  "LeftQuotient"->{
    Cell[269705, 9773, 62, 1, 31, "ObjectName",
      CellTags->"LeftQuotient"],
    Cell[269770, 9776, 63, 1, 74, "Highlight",
      CellTags->"LeftQuotient"],
    Cell[269836, 9779, 231, 8, 43, "Usage",
      CellTags->"LeftQuotient"],
    Cell[270070, 9789, 182, 7, 33, "Notes",
      CellTags->"LeftQuotient"],
    Cell[270255, 9798, 481, 19, 33, "Notes",
      CellTags->"LeftQuotient"],
    Cell[270761, 9821, 70, 1, 59, "ExampleSection",
      CellTags->"LeftQuotient"],
    Cell[270834, 9824, 145, 4, 70, "ExampleText",
      CellTags->"LeftQuotient"],
    Cell[271004, 9832, 89, 2, 70, "Input",
      CellTags->"LeftQuotient"],
    Cell[271096, 9836, 137, 3, 70, "Output",
      CellTags->"LeftQuotient"],
    Cell[271270, 9844, 105, 3, 70, "Input",
      CellTags->"LeftQuotient"],
    Cell[271378, 9849, 106, 3, 70, "Output",
      CellTags->"LeftQuotient"],
    Cell[271521, 9857, 106, 3, 70, "Input",
      CellTags->"LeftQuotient"],
    Cell[271630, 9862, 93, 3, 70, "Output",
      CellTags->"LeftQuotient"],
    Cell[271760, 9870, 107, 3, 70, "Input",
      CellTags->"LeftQuotient"],
    Cell[271870, 9875, 90, 3, 70, "Output",
      CellTags->"LeftQuotient"],
    Cell[271997, 9883, 106, 3, 70, "Input",
      CellTags->"LeftQuotient"],
    Cell[272106, 9888, 98, 3, 70, "Output",
      CellTags->"LeftQuotient"]},
  "LeftShiftCA"->{
    Cell[272231, 9895, 60, 1, 31, "ObjectName",
      CellTags->"LeftShiftCA"],
    Cell[272294, 9898, 62, 1, 74, "Highlight",
      CellTags->"LeftShiftCA"],
    Cell[272359, 9901, 162, 4, 43, "Usage",
      CellTags->"LeftShiftCA"],
    Cell[272524, 9907, 168, 7, 33, "Notes",
      CellTags->"LeftShiftCA"],
    Cell[272717, 9918, 69, 1, 59, "ExampleSection",
      CellTags->"LeftShiftCA"],
    Cell[272789, 9921, 60, 1, 70, "ExampleText",
      CellTags->"LeftShiftCA"],
    Cell[272874, 9926, 84, 2, 70, "Input",
      CellTags->"LeftShiftCA"],
    Cell[272961, 9930, 104, 3, 70, "Output",
      CellTags->"LeftShiftCA"],
    Cell[273102, 9938, 139, 3, 70, "Input",
      CellTags->"LeftShiftCA"],
    Cell[273244, 9943, 106, 3, 70, "Output",
      CellTags->"LeftShiftCA"],
    Cell[273387, 9951, 96, 3, 70, "Input",
      CellTags->"LeftShiftCA"],
    Cell[273486, 9956, 102, 3, 70, "Output",
      CellTags->"LeftShiftCA"]},
  "LengthDFA"->{
    Cell[273615, 9963, 56, 1, 31, "ObjectName",
      CellTags->"LengthDFA"],
    Cell[273674, 9966, 60, 1, 74, "Highlight",
      CellTags->"LengthDFA"],
    Cell[273737, 9969, 228, 8, 43, "Usage",
      CellTags->"LengthDFA"],
    Cell[273968, 9979, 249, 9, 58, "Notes",
      CellTags->"LengthDFA"],
    Cell[274220, 9990, 113, 4, 33, "Notes",
      CellTags->"LengthDFA"],
    Cell[274336, 9996, 161, 5, 33, "Notes",
      CellTags->"LengthDFA"],
    Cell[274522, 10005, 67, 1, 59, "ExampleSection",
      CellTags->"LengthDFA"],
    Cell[274592, 10008, 92, 1, 70, "ExampleText",
      CellTags->"LengthDFA"],
    Cell[274709, 10013, 132, 3, 70, "Input",
      CellTags->"LengthDFA"],
    Cell[274844, 10018, 402, 12, 70, "Output",
      CellTags->"LengthDFA"],
    Cell[275283, 10035, 136, 3, 70, "Input",
      CellTags->"LengthDFA"],
    Cell[275422, 10040, 113, 3, 70, "Output",
      CellTags->"LengthDFA"],
    Cell[275550, 10046, 94, 1, 70, "ExampleText",
      CellTags->"LengthDFA"],
    Cell[275647, 10049, 133, 3, 70, "Input",
      CellTags->"LengthDFA"],
    Cell[275805, 10056, 136, 3, 70, "Input",
      CellTags->"LengthDFA"],
    Cell[275944, 10061, 113, 3, 70, "Output",
      CellTags->"LengthDFA"]},
  "LocalMapCA"->{
    Cell[276084, 10068, 58, 1, 31, "ObjectName",
      CellTags->"LocalMapCA"],
    Cell[276145, 10071, 61, 1, 74, "Highlight",
      CellTags->"LocalMapCA"],
    Cell[276209, 10074, 213, 8, 43, "Usage",
      CellTags->"LocalMapCA"],
    Cell[276425, 10084, 229, 9, 58, "Notes",
      CellTags->"LocalMapCA"],
    Cell[276657, 10095, 111, 5, 33, "Notes",
      CellTags->"LocalMapCA"],
    Cell[276771, 10102, 141, 5, 33, "Notes",
      CellTags->"LocalMapCA"],
    Cell[276915, 10109, 188, 6, 33, "Notes",
      CellTags->"LocalMapCA"],
    Cell[277106, 10117, 165, 7, 33, "Notes",
      CellTags->"LocalMapCA"],
    Cell[277296, 10128, 68, 1, 59, "ExampleSection",
      CellTags->"LocalMapCA"],
    Cell[277367, 10131, 99, 1, 70, "ExampleText",
      CellTags->"LocalMapCA"],
    Cell[277469, 10134, 105, 3, 70, "Input",
      CellTags->"LocalMapCA"],
    Cell[277599, 10141, 122, 3, 70, "Input",
      CellTags->"LocalMapCA"],
    Cell[277724, 10146, 109, 3, 70, "Output",
      CellTags->"LocalMapCA"],
    Cell[277848, 10152, 176, 4, 70, "ExampleText",
      CellTags->"LocalMapCA"],
    Cell[278049, 10160, 177, 4, 70, "Input",
      CellTags->"LocalMapCA"],
    Cell[278229, 10166, 106, 3, 70, "Output",
      CellTags->"LocalMapCA"]},
  "LocalUniversalFA"->{
    Cell[278362, 10173, 70, 1, 31, "ObjectName",
      CellTags->"LocalUniversalFA"],
    Cell[278435, 10176, 67, 1, 74, "Highlight",
      CellTags->"LocalUniversalFA"],
    Cell[278505, 10179, 227, 7, 43, "Usage",
      CellTags->"LocalUniversalFA"],
    Cell[278735, 10188, 437, 12, 128, "Notes",
      CellTags->"LocalUniversalFA"],
    Cell[279175, 10202, 292, 11, 54, "Notes",
      CellTags->"LocalUniversalFA"],
    Cell[279470, 10215, 83, 1, 33, "Notes",
      CellTags->"LocalUniversalFA"],
    Cell[279556, 10218, 175, 7, 33, "Notes",
      CellTags->"LocalUniversalFA"],
    Cell[279756, 10229, 74, 1, 59, "ExampleSection",
      CellTags->"LocalUniversalFA"],
    Cell[279833, 10232, 335, 9, 70, "ExampleText",
      CellTags->"LocalUniversalFA"],
    Cell[280193, 10245, 296, 7, 70, "Input",
      CellTags->"LocalUniversalFA"],
    Cell[280492, 10254, 558, 15, 70, "Output",
      CellTags->"LocalUniversalFA"],
    Cell[281087, 10274, 100, 3, 70, "Input",
      CellTags->"LocalUniversalFA"],
    Cell[281190, 10279, 148, 3, 70, "Output",
      CellTags->"LocalUniversalFA"],
    Cell[281353, 10285, 173, 6, 70, "ExampleText",
      CellTags->"LocalUniversalFA"],
    Cell[281551, 10295, 118, 3, 70, "Input",
      CellTags->"LocalUniversalFA"],
    Cell[281672, 10300, 373, 6, 70, "Output",
      CellTags->"LocalUniversalFA"]},
  "LoopAutomatonFA"->{
    Cell[282072, 10310, 68, 1, 31, "ObjectName",
      CellTags->"LoopAutomatonFA"],
    Cell[282143, 10313, 66, 1, 74, "Highlight",
      CellTags->"LoopAutomatonFA"],
    Cell[282212, 10316, 172, 6, 43, "Usage",
      CellTags->"LoopAutomatonFA"],
    Cell[282387, 10324, 104, 1, 33, "Notes",
      CellTags->"LoopAutomatonFA"],
    Cell[282494, 10327, 271, 11, 33, "Notes",
      CellTags->"LoopAutomatonFA"],
    Cell[282790, 10342, 73, 1, 59, "ExampleSection",
      CellTags->"LoopAutomatonFA"],
    Cell[282866, 10345, 176, 4, 70, "ExampleText",
      CellTags->"LoopAutomatonFA"],
    Cell[283067, 10353, 197, 4, 70, "Input",
      CellTags->"LoopAutomatonFA"],
    Cell[283267, 10359, 301, 6, 70, "Output",
      CellTags->"LoopAutomatonFA"],
    Cell[283583, 10368, 121, 3, 70, "Input",
      CellTags->"LoopAutomatonFA"],
    Cell[283707, 10373, 219, 6, 70, "ExampleText",
      CellTags->"LoopAutomatonFA"],
    Cell[283951, 10383, 190, 4, 70, "Input",
      CellTags->"LoopAutomatonFA"],
    Cell[284144, 10389, 2403, 58, 70, "Output",
      CellTags->"LoopAutomatonFA"],
    Cell[286562, 10450, 128, 4, 70, "ExampleText",
      CellTags->"LoopAutomatonFA"],
    Cell[286715, 10458, 167, 4, 70, "Input",
      CellTags->"LoopAutomatonFA"],
    Cell[286885, 10464, 4509, 108, 70, "Output",
      CellTags->"LoopAutomatonFA"]},
  "MakeHomoDFA"->{
    Cell[291421, 10576, 60, 1, 31, "ObjectName",
      CellTags->"MakeHomoDFA"],
    Cell[291484, 10579, 62, 1, 74, "Highlight",
      CellTags->"MakeHomoDFA"],
    Cell[291549, 10582, 273, 10, 64, "Usage",
      CellTags->"MakeHomoDFA"],
    Cell[291825, 10594, 177, 7, 33, "Notes",
      CellTags->"MakeHomoDFA"],
    Cell[292005, 10603, 165, 7, 33, "Notes",
      CellTags->"MakeHomoDFA"],
    Cell[292195, 10614, 69, 1, 59, "ExampleSection",
      CellTags->"MakeHomoDFA"],
    Cell[292267, 10617, 90, 1, 70, "ExampleText",
      CellTags->"MakeHomoDFA"],
    Cell[292382, 10622, 120, 5, 70, "Input",
      CellTags->"MakeHomoDFA"],
    Cell[292505, 10629, 521, 15, 70, "Output",
      CellTags->"MakeHomoDFA"],
    Cell[293029, 10646, 413, 12, 70, "Output",
      CellTags->"MakeHomoDFA"],
    Cell[293457, 10661, 132, 4, 70, "ExampleText",
      CellTags->"MakeHomoDFA"],
    Cell[293614, 10669, 119, 3, 70, "Input",
      CellTags->"MakeHomoDFA"],
    Cell[293736, 10674, 91, 3, 70, "Output",
      CellTags->"MakeHomoDFA"],
    Cell[293842, 10680, 161, 4, 70, "Input",
      CellTags->"MakeHomoDFA"],
    Cell[294028, 10688, 178, 4, 70, "Input",
      CellTags->"MakeHomoDFA"],
    Cell[294209, 10694, 132, 3, 70, "Output",
      CellTags->"MakeHomoDFA"],
    Cell[294344, 10699, 132, 3, 70, "Output",
      CellTags->"MakeHomoDFA"]},
  "MakeHomomorphism"->{
    Cell[294503, 10706, 70, 1, 31, "ObjectName",
      CellTags->"MakeHomomorphism"],
    Cell[294576, 10709, 67, 1, 74, "Highlight",
      CellTags->"MakeHomomorphism"],
    Cell[294646, 10712, 267, 10, 64, "Usage",
      CellTags->"MakeHomomorphism"],
    Cell[294916, 10724, 236, 9, 58, "Notes",
      CellTags->"MakeHomomorphism"],
    Cell[295155, 10735, 191, 7, 33, "Notes",
      CellTags->"MakeHomomorphism"],
    Cell[295349, 10744, 117, 5, 33, "Notes",
      CellTags->"MakeHomomorphism"],
    Cell[295469, 10751, 208, 8, 33, "Notes",
      CellTags->"MakeHomomorphism"],
    Cell[295680, 10761, 177, 7, 33, "Notes",
      CellTags->"MakeHomomorphism"],
    Cell[295882, 10772, 74, 1, 59, "ExampleSection",
      CellTags->"MakeHomomorphism"],
    Cell[295959, 10775, 101, 1, 70, "ExampleText",
      CellTags->"MakeHomomorphism"],
    Cell[296085, 10780, 107, 2, 70, "Input",
      CellTags->"MakeHomomorphism"],
    Cell[296195, 10784, 126, 3, 70, "Output",
      CellTags->"MakeHomomorphism"],
    Cell[296358, 10792, 184, 5, 70, "Input",
      CellTags->"MakeHomomorphism"],
    Cell[296545, 10799, 840, 21, 70, "Output",
      CellTags->"MakeHomomorphism"],
    Cell[297400, 10823, 132, 2, 70, "ExampleText",
      Evaluatable->False,
      CellTags->"MakeHomomorphism"],
    Cell[297557, 10829, 104, 3, 70, "Input",
      CellTags->"MakeHomomorphism"],
    Cell[297664, 10834, 125, 3, 70, "Output",
      CellTags->"MakeHomomorphism"]},
  "MakeWord"->{
    Cell[297816, 10841, 54, 1, 31, "ObjectName",
      CellTags->"MakeWord"],
    Cell[297873, 10844, 59, 1, 74, "Highlight",
      CellTags->"MakeWord"],
    Cell[297935, 10847, 231, 7, 45, "Usage",
      CellTags->"MakeWord"],
    Cell[298169, 10856, 76, 1, 33, "Notes",
      CellTags->"MakeWord"],
    Cell[298248, 10859, 159, 7, 33, "Notes",
      CellTags->"MakeWord"],
    Cell[298432, 10870, 66, 1, 59, "ExampleSection",
      CellTags->"MakeWord"],
    Cell[298501, 10873, 68, 1, 70, "ExampleText",
      CellTags->"MakeWord"],
    Cell[298594, 10878, 86, 2, 70, "Input",
      CellTags->"MakeWord"],
    Cell[298683, 10882, 113, 3, 70, "Output",
      CellTags->"MakeWord"]},
  "MatrixToTransitions"->{
    Cell[298823, 10889, 76, 1, 31, "ObjectName",
      CellTags->"MatrixToTransitions"],
    Cell[298902, 10892, 70, 1, 74, "Highlight",
      CellTags->"MatrixToTransitions"],
    Cell[298975, 10895, 282, 8, 64, "Usage",
      CellTags->"MatrixToTransitions"],
    Cell[299260, 10905, 280, 11, 33, "Notes",
      CellTags->"MatrixToTransitions"],
    Cell[299565, 10920, 77, 1, 59, "ExampleSection",
      CellTags->"MatrixToTransitions"],
    Cell[299645, 10923, 130, 4, 70, "ExampleText",
      CellTags->"MatrixToTransitions"],
    Cell[299800, 10931, 118, 2, 70, "Input",
      CellTags->"MatrixToTransitions"],
    Cell[299921, 10935, 116, 3, 70, "Output",
      CellTags->"MatrixToTransitions"],
    Cell[300074, 10943, 101, 2, 70, "Input",
      CellTags->"MatrixToTransitions"],
    Cell[300178, 10947, 169, 4, 70, "Output",
      CellTags->"MatrixToTransitions"]},
  "MinimalFischerFA"->{
    Cell[300374, 10955, 70, 1, 31, "ObjectName",
      CellTags->"MinimalFischerFA"],
    Cell[300447, 10958, 67, 1, 74, "Highlight",
      CellTags->"MinimalFischerFA"],
    Cell[300517, 10961, 165, 4, 43, "Usage",
      CellTags->"MinimalFischerFA"],
    Cell[300685, 10967, 368, 11, 106, "Notes",
      CellTags->"MinimalFischerFA"],
    Cell[301056, 10980, 250, 8, 54, "Notes",
      CellTags->"MinimalFischerFA"],
    Cell[301309, 10990, 218, 6, 54, "Notes",
      CellTags->"MinimalFischerFA"],
    Cell[301552, 11000, 74, 1, 59, "ExampleSection",
      CellTags->"MinimalFischerFA"],
    Cell[301629, 11003, 106, 1, 70, "ExampleText",
      CellTags->"MinimalFischerFA"],
    Cell[301760, 11008, 93, 2, 70, "Input",
      CellTags->"MinimalFischerFA"],
    Cell[301856, 11012, 355, 10, 70, "Output",
      CellTags->"MinimalFischerFA"],
    Cell[302248, 11027, 119, 3, 70, "Input",
      CellTags->"MinimalFischerFA"],
    Cell[302370, 11032, 426, 11, 70, "Output",
      CellTags->"MinimalFischerFA"],
    Cell[302833, 11048, 111, 3, 70, "Input",
      CellTags->"MinimalFischerFA"],
    Cell[302947, 11053, 96, 3, 70, "Output",
      CellTags->"MinimalFischerFA"],
    Cell[303080, 11061, 115, 3, 70, "Input",
      CellTags->"MinimalFischerFA"],
    Cell[303198, 11066, 96, 3, 70, "Output",
      CellTags->"MinimalFischerFA"]},
  "MinimizeDFA"->{
    Cell[303321, 11073, 60, 1, 31, "ObjectName",
      CellTags->"MinimizeDFA"],
    Cell[303384, 11076, 62, 1, 74, "Highlight",
      CellTags->"MinimizeDFA"],
    Cell[303449, 11079, 141, 4, 43, "Usage",
      CellTags->"MinimizeDFA"],
    Cell[303593, 11085, 348, 11, 104, "Notes",
      CellTags->"MinimizeDFA"],
    Cell[303944, 11098, 305, 9, 54, "Notes",
      CellTags->"MinimizeDFA"],
    Cell[304252, 11109, 146, 5, 33, "Notes",
      CellTags->"MinimizeDFA"],
    Cell[304401, 11116, 272, 8, 54, "Notes",
      CellTags->"MinimizeDFA"],
    Cell[304676, 11126, 269, 11, 33, "Notes",
      CellTags->"MinimizeDFA"],
    Cell[304970, 11141, 69, 1, 59, "ExampleSection",
      CellTags->"MinimizeDFA"],
    Cell[305042, 11144, 78, 1, 70, "ExampleText",
      CellTags->"MinimizeDFA"],
    Cell[305145, 11149, 120, 3, 70, "Input",
      CellTags->"MinimizeDFA"],
    Cell[305268, 11154, 523, 15, 70, "Output",
      CellTags->"MinimizeDFA"],
    Cell[305828, 11174, 286, 8, 70, "Input",
      CellTags->"MinimizeDFA"],
    Cell[306117, 11184, 413, 12, 70, "Output",
      CellTags->"MinimizeDFA"],
    Cell[306533, 11198, 163, 4, 70, "Output",
      CellTags->"MinimizeDFA"],
    Cell[306699, 11204, 11936, 380, 70, "Output",
      CellTags->"MinimizeDFA"]},
  "MinimizeFA"->{
    Cell[318662, 11588, 58, 1, 31, "ObjectName",
      CellTags->"MinimizeFA"],
    Cell[318723, 11591, 61, 1, 74, "Highlight",
      CellTags->"MinimizeFA"],
    Cell[318787, 11594, 232, 6, 64, "Usage",
      CellTags->"MinimizeFA"],
    Cell[319022, 11602, 365, 11, 106, "Notes",
      CellTags->"MinimizeFA"],
    Cell[319390, 11615, 222, 6, 54, "Notes",
      CellTags->"MinimizeFA"],
    Cell[319615, 11623, 209, 6, 54, "Notes",
      CellTags->"MinimizeFA"],
    Cell[319827, 11631, 362, 15, 33, "Notes",
      CellTags->"MinimizeFA"],
    Cell[320214, 11650, 68, 1, 59, "ExampleSection",
      CellTags->"MinimizeFA"],
    Cell[320285, 11653, 158, 4, 70, "ExampleText",
      CellTags->"MinimizeFA"],
    Cell[320468, 11661, 115, 5, 70, "Input",
      CellTags->"MinimizeFA"],
    Cell[320586, 11668, 522, 15, 70, "Output",
      CellTags->"MinimizeFA"],
    Cell[321111, 11685, 412, 12, 70, "Output",
      CellTags->"MinimizeFA"],
    Cell[321560, 11702, 147, 4, 70, "Input",
      CellTags->"MinimizeFA"],
    Cell[321710, 11708, 117, 3, 70, "Output",
      CellTags->"MinimizeFA"]},
  "ModCounterDFA"->{
    Cell[321854, 11715, 64, 1, 31, "ObjectName",
      CellTags->"ModCounterDFA"],
    Cell[321921, 11718, 64, 1, 74, "Highlight",
      CellTags->"ModCounterDFA"],
    Cell[321988, 11721, 232, 5, 64, "Usage",
      CellTags->"ModCounterDFA"],
    Cell[322223, 11728, 253, 9, 58, "Notes",
      CellTags->"ModCounterDFA"],
    Cell[322479, 11739, 168, 7, 33, "Notes",
      CellTags->"ModCounterDFA"],
    Cell[322672, 11750, 71, 1, 59, "ExampleSection",
      CellTags->"ModCounterDFA"],
    Cell[322746, 11753, 121, 4, 70, "ExampleText",
      CellTags->"ModCounterDFA"],
    Cell[322892, 11761, 114, 3, 70, "Input",
      CellTags->"ModCounterDFA"],
    Cell[323009, 11766, 376, 12, 70, "Output",
      CellTags->"ModCounterDFA"],
    Cell[323422, 11783, 115, 3, 70, "Input",
      CellTags->"ModCounterDFA"],
    Cell[323540, 11788, 289, 5, 70, "Output",
      CellTags->"ModCounterDFA"],
    Cell[323844, 11796, 135, 4, 70, "ExampleText",
      CellTags->"ModCounterDFA"],
    Cell[324004, 11804, 159, 4, 70, "Input",
      CellTags->"ModCounterDFA"],
    Cell[324166, 11810, 98, 3, 70, "Output",
      CellTags->"ModCounterDFA"]},
  "NNFAToFA"->{
    Cell[324291, 11817, 54, 1, 31, "ObjectName",
      CellTags->"NNFAToFA"],
    Cell[324348, 11820, 59, 1, 74, "Highlight",
      CellTags->"NNFAToFA"],
    Cell[324410, 11823, 177, 6, 43, "Usage",
      CellTags->"NNFAToFA"],
    Cell[324590, 11831, 140, 4, 33, "Notes",
      CellTags->"NNFAToFA"],
    Cell[324733, 11837, 187, 7, 33, "Notes",
      CellTags->"NNFAToFA"],
    Cell[324945, 11848, 66, 1, 59, "ExampleSection",
      CellTags->"NNFAToFA"],
    Cell[325014, 11851, 242, 7, 70, "ExampleText",
      CellTags->"NNFAToFA"],
    Cell[325281, 11862, 110, 2, 70, "Input",
      CellTags->"NNFAToFA"],
    Cell[325394, 11866, 127, 3, 70, "Output",
      CellTags->"NNFAToFA"],
    Cell[325558, 11874, 109, 3, 70, "Input",
      CellTags->"NNFAToFA"],
    Cell[325670, 11879, 274, 6, 70, "Output",
      CellTags->"NNFAToFA"],
    Cell[325959, 11888, 67, 1, 70, "ExampleText",
      CellTags->"NNFAToFA"],
    Cell[326051, 11893, 77, 2, 70, "Input",
      CellTags->"NNFAToFA"],
    Cell[326131, 11897, 543, 15, 70, "Output",
      CellTags->"NNFAToFA"],
    Cell[326711, 11917, 103, 3, 70, "Input",
      CellTags->"NNFAToFA"],
    Cell[326817, 11922, 364, 6, 70, "Output",
      CellTags->"NNFAToFA"]},
  "NoFactorFA"->{
    Cell[327208, 11932, 58, 1, 31, "ObjectName",
      CellTags->"NoFactorFA"],
    Cell[327269, 11935, 61, 1, 74, "Highlight",
      CellTags->"NoFactorFA"],
    Cell[327333, 11938, 390, 15, 67, "Usage",
      CellTags->"NoFactorFA"],
    Cell[327726, 11955, 250, 9, 58, "Notes",
      CellTags->"NoFactorFA"],
    Cell[327979, 11966, 358, 15, 33, "Notes",
      CellTags->"NoFactorFA"],
    Cell[328362, 11985, 68, 1, 59, "ExampleSection",
      CellTags->"NoFactorFA"],
    Cell[328433, 11988, 159, 6, 70, "ExampleText",
      CellTags->"NoFactorFA"],
    Cell[328617, 11998, 108, 3, 70, "Input",
      CellTags->"NoFactorFA"],
    Cell[328728, 12003, 385, 12, 70, "Output",
      CellTags->"NoFactorFA"],
    Cell[329150, 12020, 111, 3, 70, "Input",
      CellTags->"NoFactorFA"],
    Cell[329264, 12025, 557, 15, 70, "Output",
      CellTags->"NoFactorFA"],
    Cell[329836, 12043, 250, 9, 70, "ExampleText",
      CellTags->"NoFactorFA"],
    Cell[330111, 12056, 107, 3, 70, "Input",
      CellTags->"NoFactorFA"],
    Cell[330221, 12061, 205, 4, 70, "Output",
      CellTags->"NoFactorFA"]},
  "NoPrefixFA"->{
    Cell[330453, 12069, 58, 1, 31, "ObjectName",
      CellTags->"NoPrefixFA"],
    Cell[330514, 12072, 61, 1, 74, "Highlight",
      CellTags->"NoPrefixFA"],
    Cell[330578, 12075, 437, 16, 64, "Usage",
      CellTags->"NoPrefixFA"],
    Cell[331018, 12093, 250, 9, 58, "Notes",
      CellTags->"NoPrefixFA"],
    Cell[331271, 12104, 357, 15, 33, "Notes",
      CellTags->"NoPrefixFA"],
    Cell[331653, 12123, 68, 1, 59, "ExampleSection",
      CellTags->"NoPrefixFA"],
    Cell[331724, 12126, 159, 6, 70, "ExampleText",
      CellTags->"NoPrefixFA"],
    Cell[331908, 12136, 108, 3, 70, "Input",
      CellTags->"NoPrefixFA"],
    Cell[332019, 12141, 385, 12, 70, "Output",
      CellTags->"NoPrefixFA"],
    Cell[332441, 12158, 111, 3, 70, "Input",
      CellTags->"NoPrefixFA"],
    Cell[332555, 12163, 470, 14, 70, "Output",
      CellTags->"NoPrefixFA"],
    Cell[333040, 12180, 241, 9, 70, "ExampleText",
      CellTags->"NoPrefixFA"],
    Cell[333306, 12193, 107, 3, 70, "Input",
      CellTags->"NoPrefixFA"],
    Cell[333416, 12198, 318, 6, 70, "Output",
      CellTags->"NoPrefixFA"]},
  "NormalizeControl"->{
    Cell[333761, 12208, 70, 1, 31, "ObjectName",
      CellTags->"NormalizeControl"],
    Cell[333834, 12211, 67, 1, 74, "Highlight",
      CellTags->"NormalizeControl"],
    Cell[333904, 12214, 158, 4, 43, "Usage",
      CellTags->"NormalizeControl"],
    Cell[334065, 12220, 176, 5, 33, "Notes",
      CellTags->"NormalizeControl"],
    Cell[334244, 12227, 154, 5, 33, "Notes",
      CellTags->"NormalizeControl"],
    Cell[334401, 12234, 163, 4, 33, "Notes",
      CellTags->"NormalizeControl"],
    Cell[334589, 12242, 74, 1, 59, "ExampleSection",
      CellTags->"NormalizeControl"],
    Cell[334666, 12245, 157, 4, 70, "ExampleText",
      CellTags->"NormalizeControl"],
    Cell[334848, 12253, 152, 4, 70, "Input",
      CellTags->"NormalizeControl"],
    Cell[335003, 12259, 115, 3, 70, "Output",
      CellTags->"NormalizeControl"],
    Cell[335155, 12267, 173, 4, 70, "Input",
      CellTags->"NormalizeControl"],
    Cell[335331, 12273, 176, 4, 70, "Output",
      CellTags->"NormalizeControl"],
    Cell[335522, 12280, 128, 4, 70, "ExampleText",
      CellTags->"NormalizeControl"],
    Cell[335675, 12288, 187, 5, 70, "Input",
      CellTags->"NormalizeControl"],
    Cell[335865, 12295, 189, 4, 70, "Message",
      CellTags->"NormalizeControl"],
    Cell[336057, 12301, 176, 4, 70, "Output",
      CellTags->"NormalizeControl"]},
  "NormalizeFA"->{
    Cell[336260, 12309, 60, 1, 31, "ObjectName",
      CellTags->"NormalizeFA"],
    Cell[336323, 12312, 62, 1, 74, "Highlight",
      CellTags->"NormalizeFA"],
    Cell[336388, 12315, 160, 6, 43, "Usage",
      CellTags->"NormalizeFA"],
    Cell[336551, 12323, 291, 9, 54, "Notes",
      CellTags->"NormalizeFA"],
    Cell[336845, 12334, 139, 4, 33, "Notes",
      CellTags->"NormalizeFA"],
    Cell[336987, 12340, 185, 7, 33, "Notes",
      CellTags->"NormalizeFA"],
    Cell[337197, 12351, 69, 1, 59, "ExampleSection",
      CellTags->"NormalizeFA"],
    Cell[337269, 12354, 133, 4, 70, "ExampleText",
      CellTags->"NormalizeFA"],
    Cell[337427, 12362, 171, 4, 70, "Input",
      CellTags->"NormalizeFA"],
    Cell[337601, 12368, 413, 12, 70, "Output",
      CellTags->"NormalizeFA"],
    Cell[338017, 12382, 172, 4, 70, "Output",
      CellTags->"NormalizeFA"],
    Cell[338226, 12391, 138, 4, 70, "Input",
      CellTags->"NormalizeFA"],
    Cell[338367, 12397, 413, 12, 70, "Output",
      CellTags->"NormalizeFA"],
    Cell[338783, 12411, 111, 3, 70, "Output",
      CellTags->"NormalizeFA"]},
  "NoSuffix"->{
    Cell[338921, 12418, 56, 1, 31, "ObjectName",
      CellTags->"NoSuffix"],
    Cell[338980, 12421, 59, 1, 74, "Highlight",
      CellTags->"NoSuffix"],
    Cell[339042, 12424, 439, 16, 64, "Usage",
      CellTags->"NoSuffix"],
    Cell[339484, 12442, 248, 9, 58, "Notes",
      CellTags->"NoSuffix"],
    Cell[339735, 12453, 355, 15, 33, "Notes",
      CellTags->"NoSuffix"],
    Cell[340115, 12472, 66, 1, 59, "ExampleSection",
      CellTags->"NoSuffix"],
    Cell[340184, 12475, 157, 6, 70, "ExampleText",
      CellTags->"NoSuffix"],
    Cell[340366, 12485, 106, 3, 70, "Input",
      CellTags->"NoSuffix"],
    Cell[340475, 12490, 383, 12, 70, "Output",
      CellTags->"NoSuffix"],
    Cell[340895, 12507, 109, 3, 70, "Input",
      CellTags->"NoSuffix"],
    Cell[341007, 12512, 468, 14, 70, "Output",
      CellTags->"NoSuffix"],
    Cell[341490, 12529, 241, 9, 70, "ExampleText",
      CellTags->"NoSuffix"],
    Cell[341756, 12542, 105, 3, 70, "Input",
      CellTags->"NoSuffix"],
    Cell[341864, 12547, 316, 6, 70, "Output",
      CellTags->"NoSuffix"]},
  "NumberOfCA"->{
    Cell[342207, 12557, 58, 1, 31, "ObjectName",
      CellTags->"NumberOfCA"],
    Cell[342268, 12560, 61, 1, 74, "Highlight",
      CellTags->"NumberOfCA"],
    Cell[342332, 12563, 234, 8, 43, "Usage",
      CellTags->"NumberOfCA"],
    Cell[342569, 12573, 132, 6, 37, "Notes",
      CellTags->"NumberOfCA"],
    Cell[342704, 12581, 183, 7, 33, "Notes",
      CellTags->"NumberOfCA"],
    Cell[342912, 12592, 68, 1, 59, "ExampleSection",
      CellTags->"NumberOfCA"],
    Cell[342983, 12595, 75, 1, 70, "ExampleText",
      CellTags->"NumberOfCA"],
    Cell[343083, 12600, 116, 2, 70, "Input",
      CellTags->"NumberOfCA"],
    Cell[343202, 12604, 427, 15, 70, "Output",
      CellTags->"NumberOfCA"]},
  "NumberOfDFA"->{
    Cell[343656, 12623, 60, 1, 31, "ObjectName",
      CellTags->"NumberOfDFA"],
    Cell[343719, 12626, 62, 1, 74, "Highlight",
      CellTags->"NumberOfDFA"],
    Cell[343784, 12629, 210, 8, 43, "Usage",
      CellTags->"NumberOfDFA"],
    Cell[343997, 12639, 135, 4, 33, "Notes",
      CellTags->"NumberOfDFA"],
    Cell[344135, 12645, 354, 15, 33, "Notes",
      CellTags->"NumberOfDFA"],
    Cell[344514, 12664, 69, 1, 59, "ExampleSection",
      CellTags->"NumberOfDFA"],
    Cell[344586, 12667, 91, 1, 70, "ExampleText",
      CellTags->"NumberOfDFA"],
    Cell[344702, 12672, 115, 2, 70, "Input",
      CellTags->"NumberOfDFA"],
    Cell[344820, 12676, 567, 18, 70, "Output",
      CellTags->"NumberOfDFA"]},
  "NumberOfTotalisticCA"->{
    Cell[345414, 12698, 78, 1, 31, "ObjectName",
      CellTags->"NumberOfTotalisticCA"],
    Cell[345495, 12701, 71, 1, 74, "Highlight",
      CellTags->"NumberOfTotalisticCA"],
    Cell[345569, 12704, 268, 8, 64, "Usage",
      CellTags->"NumberOfTotalisticCA"],
    Cell[345840, 12714, 150, 6, 35, "Notes",
      CellTags->"NumberOfTotalisticCA"],
    Cell[345993, 12722, 401, 15, 33, "Notes",
      CellTags->"NumberOfTotalisticCA"],
    Cell[346419, 12741, 78, 1, 59, "ExampleSection",
      CellTags->"NumberOfTotalisticCA"],
    Cell[346500, 12744, 79, 1, 70, "ExampleText",
      CellTags->"NumberOfTotalisticCA"],
    Cell[346604, 12749, 136, 2, 70, "Input",
      CellTags->"NumberOfTotalisticCA"],
    Cell[346743, 12753, 436, 15, 70, "Output",
      CellTags->"NumberOfTotalisticCA"]},
  "NumTransitions"->{
    Cell[347206, 12772, 66, 1, 31, "ObjectName",
      CellTags->"NumTransitions"],
    Cell[347275, 12775, 65, 1, 74, "Highlight",
      CellTags->"NumTransitions"],
    Cell[347343, 12778, 179, 6, 43, "Usage",
      CellTags->"NumTransitions"],
    Cell[347525, 12786, 155, 7, 33, "Notes",
      CellTags->"NumTransitions"],
    Cell[347705, 12797, 72, 1, 59, "ExampleSection",
      CellTags->"NumTransitions"],
    Cell[347780, 12800, 109, 1, 70, "ExampleText",
      CellTags->"NumTransitions"],
    Cell[347892, 12803, 209, 5, 70, "Input",
      CellTags->"NumTransitions"],
    Cell[348126, 12812, 106, 3, 70, "Input",
      CellTags->"NumTransitions"],
    Cell[348235, 12817, 91, 3, 70, "Output",
      CellTags->"NumTransitions"]},
  "OrbitCA"->{
    Cell[348353, 12824, 52, 1, 31, "ObjectName",
      CellTags->"OrbitCA"],
    Cell[348408, 12827, 58, 1, 74, "Highlight",
      CellTags->"OrbitCA"],
    Cell[348469, 12830, 211, 5, 64, "Usage",
      CellTags->"OrbitCA"],
    Cell[348683, 12837, 295, 10, 80, "Notes",
      CellTags->"OrbitCA"],
    Cell[348981, 12849, 138, 5, 33, "Notes",
      CellTags->"OrbitCA"],
    Cell[349122, 12856, 148, 4, 33, "Notes",
      CellTags->"OrbitCA"],
    Cell[349273, 12862, 263, 11, 33, "Notes",
      CellTags->"OrbitCA"],
    Cell[349561, 12877, 65, 1, 59, "ExampleSection",
      CellTags->"OrbitCA"],
    Cell[349629, 12880, 128, 4, 70, "ExampleText",
      CellTags->"OrbitCA"],
    Cell[349760, 12886, 147, 5, 70, "Input",
      CellTags->"OrbitCA"],
    Cell[349932, 12895, 103, 3, 70, "Input",
      CellTags->"OrbitCA"],
    Cell[350038, 12900, 92, 3, 70, "Output",
      CellTags->"OrbitCA"],
    Cell[350145, 12906, 117, 4, 70, "ExampleText",
      CellTags->"OrbitCA"],
    Cell[350287, 12914, 113, 3, 70, "Input",
      CellTags->"OrbitCA"],
    Cell[350403, 12919, 105, 3, 70, "Output",
      CellTags->"OrbitCA"]},
  "ParikhVector"->{
    Cell[350535, 12926, 62, 1, 31, "ObjectName",
      CellTags->"ParikhVector"],
    Cell[350600, 12929, 63, 1, 74, "Highlight",
      CellTags->"ParikhVector"],
    Cell[350666, 12932, 155, 4, 43, "Usage",
      CellTags->"ParikhVector"],
    Cell[350824, 12938, 75, 1, 33, "Notes",
      CellTags->"ParikhVector"],
    Cell[350924, 12943, 70, 1, 59, "ExampleSection",
      CellTags->"ParikhVector"],
    Cell[350997, 12946, 95, 1, 70, "ExampleText",
      CellTags->"ParikhVector"],
    Cell[351117, 12951, 98, 2, 70, "Input",
      CellTags->"ParikhVector"],
    Cell[351218, 12955, 234, 5, 70, "Output",
      CellTags->"ParikhVector"]},
  "PermutationSA"->{
    Cell[351479, 12964, 64, 1, 31, "ObjectName",
      CellTags->"PermutationSA"],
    Cell[351546, 12967, 64, 1, 74, "Highlight",
      CellTags->"PermutationSA"],
    Cell[351613, 12970, 212, 6, 64, "Usage",
      CellTags->"PermutationSA"],
    Cell[351828, 12978, 150, 4, 33, "Notes",
      CellTags->"PermutationSA"],
    Cell[352003, 12986, 71, 1, 59, "ExampleSection",
      CellTags->"PermutationSA"],
    Cell[352077, 12989, 87, 1, 70, "ExampleText",
      CellTags->"PermutationSA"],
    Cell[352189, 12994, 114, 2, 70, "Input",
      CellTags->"PermutationSA"],
    Cell[352306, 12998, 349, 10, 70, "Output",
      CellTags->"PermutationSA"],
    Cell[352670, 13011, 131, 4, 70, "ExampleText",
      CellTags->"PermutationSA"],
    Cell[352826, 13019, 174, 5, 70, "Input",
      CellTags->"PermutationSA"],
    Cell[353003, 13026, 488, 9, 70, "Output",
      CellTags->"PermutationSA"],
    Cell[353494, 13037, 91, 3, 70, "Output",
      CellTags->"PermutationSA"]},
  "PermuteFA"->{
    Cell[353612, 13044, 56, 1, 31, "ObjectName",
      CellTags->"PermuteFA"],
    Cell[353671, 13047, 60, 1, 74, "Highlight",
      CellTags->"PermuteFA"],
    Cell[353734, 13050, 215, 8, 43, "Usage",
      CellTags->"PermuteFA"],
    Cell[353952, 13060, 211, 7, 33, "Notes",
      CellTags->"PermuteFA"],
    Cell[354188, 13071, 67, 1, 59, "ExampleSection",
      CellTags->"PermuteFA"],
    Cell[354258, 13074, 104, 1, 48, "ExampleText",
      CellTags->"PermuteFA"],
    Cell[354387, 13079, 100, 2, 40, "Input",
      CellTags->"PermuteFA"],
    Cell[354490, 13083, 372, 12, 30, "Output",
      CellTags->"PermuteFA"],
    Cell[354899, 13100, 122, 3, 37, "Input",
      CellTags->"PermuteFA"],
    Cell[355024, 13105, 372, 12, 30, "Output",
      CellTags->"PermuteFA"],
    Cell[355433, 13122, 105, 3, 37, "Input",
      CellTags->"PermuteFA"],
    Cell[355541, 13127, 89, 3, 30, "Output",
      CellTags->"PermuteFA"]},
  "PlotComputationFA"->{
    Cell[355657, 13134, 72, 1, 42, "ObjectName",
      CellTags->"PlotComputationFA"],
    Cell[355732, 13137, 68, 1, 74, "Highlight",
      CellTags->"PlotComputationFA"],
    Cell[355803, 13140, 222, 8, 43, "Usage",
      CellTags->"PlotComputationFA"],
    Cell[356028, 13150, 378, 12, 128, "Notes",
      CellTags->"PlotComputationFA"],
    Cell[356409, 13164, 161, 5, 33, "Notes",
      CellTags->"PlotComputationFA"],
    Cell[356573, 13171, 151, 5, 33, "Notes",
      CellTags->"PlotComputationFA"],
    Cell[356727, 13178, 293, 11, 33, "Notes",
      CellTags->"PlotComputationFA"],
    Cell[357045, 13193, 75, 1, 59, "ExampleSection",
      CellTags->"PlotComputationFA"],
    Cell[357123, 13196, 206, 7, 70, "ExampleText",
      CellTags->"PlotComputationFA"],
    Cell[357354, 13207, 117, 3, 70, "Input",
      CellTags->"PlotComputationFA"],
    Cell[357474, 13212, 487, 14, 70, "Output",
      CellTags->"PlotComputationFA"],
    Cell[357976, 13229, 155, 4, 70, "ExampleText",
      CellTags->"PlotComputationFA"],
    Cell[358156, 13237, 126, 3, 70, "Input",
      CellTags->"PlotComputationFA"],
    Cell[358285, 13242, 2413, 168, 70, 2227, 162, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PlotComputationFA"],
    Cell[360735, 13415, 184, 4, 70, "Input",
      CellTags->"PlotComputationFA"],
    Cell[360922, 13421, 1899, 105, 70, 1713, 99, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PlotComputationFA"]},
  "PolynomialToCA"->{
    Cell[362848, 13530, 66, 1, 31, "ObjectName",
      CellTags->"PolynomialToCA"],
    Cell[362917, 13533, 65, 1, 74, "Highlight",
      CellTags->"PolynomialToCA"],
    Cell[362985, 13536, 303, 9, 64, "Usage",
      CellTags->"PolynomialToCA"],
    Cell[363291, 13547, 270, 11, 33, "Notes",
      CellTags->"PolynomialToCA"],
    Cell[363564, 13560, 277, 11, 33, "Notes",
      CellTags->"PolynomialToCA"],
    Cell[363866, 13575, 72, 1, 59, "ExampleSection",
      CellTags->"PolynomialToCA"],
    Cell[363941, 13578, 146, 4, 70, "ExampleText",
      CellTags->"PolynomialToCA"],
    Cell[364112, 13586, 123, 5, 70, "Input",
      CellTags->"PolynomialToCA"],
    Cell[364238, 13593, 106, 3, 70, "Output",
      CellTags->"PolynomialToCA"],
    Cell[364347, 13598, 561, 14, 70, "Output",
      CellTags->"PolynomialToCA"]},
  "PrefixDFA"->{
    Cell[364935, 13616, 56, 1, 31, "ObjectName",
      CellTags->"PrefixDFA"],
    Cell[364994, 13619, 60, 1, 74, "Highlight",
      CellTags->"PrefixDFA"],
    Cell[365057, 13622, 175, 5, 43, "Usage",
      CellTags->"PrefixDFA"],
    Cell[365235, 13629, 249, 9, 58, "Notes",
      CellTags->"PrefixDFA"],
    Cell[365509, 13642, 67, 1, 59, "ExampleSection",
      CellTags->"PrefixDFA"],
    Cell[365579, 13645, 89, 1, 70, "ExampleText",
      CellTags->"PrefixDFA"],
    Cell[365693, 13650, 103, 3, 70, "Input",
      CellTags->"PrefixDFA"],
    Cell[365799, 13655, 390, 12, 70, "Output",
      CellTags->"PrefixDFA"],
    Cell[366226, 13672, 100, 3, 70, "Input",
      CellTags->"PrefixDFA"],
    Cell[366329, 13677, 125, 3, 70, "Output",
      CellTags->"PrefixDFA"]},
  "PrefixQ"->{
    Cell[366481, 13684, 52, 1, 31, "ObjectName",
      CellTags->"PrefixQ"],
    Cell[366536, 13687, 58, 1, 74, "Highlight",
      CellTags->"PrefixQ"],
    Cell[366597, 13690, 191, 8, 43, "Usage",
      CellTags->"PrefixQ"],
    Cell[366791, 13700, 90, 1, 33, "Notes",
      CellTags->"PrefixQ"],
    Cell[366884, 13703, 150, 7, 33, "Notes",
      CellTags->"PrefixQ"],
    Cell[367059, 13714, 65, 1, 59, "ExampleSection",
      CellTags->"PrefixQ"],
    Cell[367127, 13717, 87, 1, 70, "ExampleText",
      CellTags->"PrefixQ"],
    Cell[367239, 13722, 96, 3, 70, "Input",
      CellTags->"PrefixQ"],
    Cell[367338, 13727, 86, 3, 70, "Output",
      CellTags->"PrefixQ"],
    Cell[367461, 13735, 96, 3, 70, "Input",
      CellTags->"PrefixQ"],
    Cell[367560, 13740, 87, 3, 70, "Output",
      CellTags->"PrefixQ"],
    Cell[367684, 13748, 105, 3, 70, "Input",
      CellTags->"PrefixQ"],
    Cell[367792, 13753, 86, 3, 70, "Output",
      CellTags->"PrefixQ"],
    Cell[367915, 13761, 122, 3, 70, "Input",
      CellTags->"PrefixQ"],
    Cell[368040, 13766, 118, 3, 70, "Output",
      CellTags->"PrefixQ"]},
  "PrimitiveCount"->{
    Cell[368185, 13773, 66, 1, 31, "ObjectName",
      CellTags->"PrimitiveCount"],
    Cell[368254, 13776, 65, 1, 74, "Highlight",
      CellTags->"PrimitiveCount"],
    Cell[368322, 13779, 238, 8, 43, "Usage",
      CellTags->"PrimitiveCount"],
    Cell[368563, 13789, 114, 5, 33, "Notes",
      CellTags->"PrimitiveCount"],
    Cell[368680, 13796, 82, 1, 33, "Notes",
      CellTags->"PrimitiveCount"],
    Cell[368765, 13799, 355, 15, 33, "Notes",
      CellTags->"PrimitiveCount"],
    Cell[369145, 13818, 72, 1, 59, "ExampleSection",
      CellTags->"PrimitiveCount"],
    Cell[369220, 13821, 78, 1, 70, "ExampleText",
      CellTags->"PrimitiveCount"],
    Cell[369323, 13826, 127, 2, 70, "Input",
      CellTags->"PrimitiveCount"],
    Cell[369453, 13830, 600, 20, 70, "Output",
      CellTags->"PrimitiveCount"]},
  "PrimitiveQ"->{
    Cell[370080, 13854, 58, 1, 31, "ObjectName",
      CellTags->"PrimitiveQ"],
    Cell[370141, 13857, 61, 1, 74, "Highlight",
      CellTags->"PrimitiveQ"],
    Cell[370205, 13860, 254, 8, 64, "Usage",
      CellTags->"PrimitiveQ"],
    Cell[370462, 13870, 110, 5, 33, "Notes",
      CellTags->"PrimitiveQ"],
    Cell[370575, 13877, 136, 5, 33, "Notes",
      CellTags->"PrimitiveQ"],
    Cell[370714, 13884, 361, 15, 33, "Notes",
      CellTags->"PrimitiveQ"],
    Cell[371100, 13903, 68, 1, 59, "ExampleSection",
      CellTags->"PrimitiveQ"],
    Cell[371171, 13906, 128, 4, 70, "ExampleText",
      CellTags->"PrimitiveQ"],
    Cell[371324, 13914, 125, 3, 70, "Input",
      CellTags->"PrimitiveQ"],
    Cell[371452, 13919, 89, 3, 70, "Output",
      CellTags->"PrimitiveQ"],
    Cell[371556, 13925, 132, 4, 70, "ExampleText",
      CellTags->"PrimitiveQ"],
    Cell[371713, 13933, 125, 3, 70, "Input",
      CellTags->"PrimitiveQ"],
    Cell[371841, 13938, 89, 3, 70, "Output",
      CellTags->"PrimitiveQ"]},
  "PrintCA"->{
    Cell[371957, 13945, 52, 1, 31, "ObjectName",
      CellTags->"PrintCA"],
    Cell[372012, 13948, 58, 1, 74, "Highlight",
      CellTags->"PrintCA"],
    Cell[372073, 13951, 181, 5, 43, "Usage",
      CellTags->"PrintCA"],
    Cell[372279, 13960, 65, 1, 59, "ExampleSection",
      CellTags->"PrintCA"],
    Cell[372347, 13963, 69, 1, 70, "ExampleText",
      CellTags->"PrintCA"],
    Cell[372441, 13968, 83, 2, 70, "Input",
      CellTags->"PrintCA"],
    Cell[372527, 13972, 554, 14, 70, "Output",
      CellTags->"PrintCA"],
    Cell[373118, 13991, 90, 2, 70, "Input",
      CellTags->"PrintCA"],
    Cell[373211, 13995, 814, 18, 70, "Output",
      CellTags->"PrintCA"]},
  "PrintFA"->{
    Cell[374052, 14017, 52, 1, 31, "ObjectName",
      CellTags->"PrintFA"],
    Cell[374107, 14020, 58, 1, 74, "Highlight",
      CellTags->"PrintFA"],
    Cell[374168, 14023, 158, 6, 43, "Usage",
      CellTags->"PrintFA"],
    Cell[374329, 14031, 273, 10, 80, "Notes",
      CellTags->"PrintFA"],
    Cell[374605, 14043, 144, 5, 33, "Notes",
      CellTags->"PrintFA"],
    Cell[374752, 14050, 135, 5, 33, "Notes",
      CellTags->"PrintFA"],
    Cell[374890, 14057, 79, 1, 33, "Notes",
      CellTags->"PrintFA"],
    Cell[374994, 14062, 65, 1, 59, "ExampleSection",
      CellTags->"PrintFA"],
    Cell[375062, 14065, 61, 1, 70, "ExampleText",
      CellTags->"PrintFA"],
    Cell[375148, 14070, 91, 2, 70, "Input",
      CellTags->"PrintFA"],
    Cell[375242, 14074, 399, 12, 70, "Output",
      CellTags->"PrintFA"],
    Cell[375678, 14091, 92, 3, 70, "Input",
      CellTags->"PrintFA"],
    Cell[375773, 14096, 209, 5, 70, "Print",
      CellTags->"PrintFA"],
    Cell[375985, 14103, 237, 5, 70, "Print",
      CellTags->"PrintFA"],
    Cell[376225, 14110, 213, 5, 70, "Print",
      CellTags->"PrintFA"],
    Cell[376441, 14117, 213, 5, 70, "Print",
      CellTags->"PrintFA"],
    Cell[376657, 14124, 606, 16, 70, "Output",
      CellTags->"PrintFA"],
    Cell[377278, 14143, 61, 1, 70, "ExampleText",
      CellTags->"PrintFA"],
    Cell[377364, 14148, 93, 2, 70, "Input",
      CellTags->"PrintFA"],
    Cell[377460, 14152, 489, 14, 70, "Output",
      CellTags->"PrintFA"],
    Cell[377986, 14171, 92, 3, 70, "Input",
      CellTags->"PrintFA"],
    Cell[378081, 14176, 211, 5, 70, "Print",
      CellTags->"PrintFA"],
    Cell[378295, 14183, 213, 5, 70, "Print",
      CellTags->"PrintFA"],
    Cell[378511, 14190, 246, 6, 70, "Print",
      CellTags->"PrintFA"],
    Cell[378760, 14198, 215, 5, 70, "Print",
      CellTags->"PrintFA"],
    Cell[378978, 14205, 215, 5, 70, "Print",
      CellTags->"PrintFA"],
    Cell[379196, 14212, 2964, 92, 70, "Output",
      CellTags->"PrintFA"]},
  "ProductFA"->{
    Cell[382187, 14308, 56, 1, 31, "ObjectName",
      CellTags->"ProductFA"],
    Cell[382246, 14311, 60, 1, 74, "Highlight",
      CellTags->"ProductFA"],
    Cell[382309, 14314, 199, 8, 43, "Usage",
      CellTags->"ProductFA"],
    Cell[382511, 14324, 350, 11, 104, "Notes",
      CellTags->"ProductFA"],
    Cell[382864, 14337, 226, 6, 60, "Notes",
      CellTags->"ProductFA"],
    Cell[383093, 14345, 235, 6, 54, "Notes",
      CellTags->"ProductFA"],
    Cell[383331, 14353, 446, 19, 33, "Notes",
      CellTags->"ProductFA"],
    Cell[383802, 14376, 67, 1, 59, "ExampleSection",
      CellTags->"ProductFA"],
    Cell[383872, 14379, 97, 1, 70, "ExampleText",
      CellTags->"ProductFA"],
    Cell[383994, 14384, 128, 5, 70, "Input",
      CellTags->"ProductFA"],
    Cell[384125, 14391, 377, 12, 70, "Output",
      CellTags->"ProductFA"],
    Cell[384505, 14405, 383, 12, 70, "Output",
      CellTags->"ProductFA"],
    Cell[384925, 14422, 108, 3, 70, "Input",
      CellTags->"ProductFA"],
    Cell[385036, 14427, 491, 14, 70, "Output",
      CellTags->"ProductFA"],
    Cell[385542, 14444, 244, 9, 70, "ExampleText",
      CellTags->"ProductFA"],
    Cell[385811, 14457, 104, 3, 70, "Input",
      CellTags->"ProductFA"],
    Cell[385918, 14462, 213, 4, 70, "Output",
      CellTags->"ProductFA"]},
  "ProductTransitions"->{
    Cell[386158, 14470, 74, 1, 31, "ObjectName",
      CellTags->"ProductTransitions"],
    Cell[386235, 14473, 69, 1, 74, "Highlight",
      CellTags->"ProductTransitions"],
    Cell[386307, 14476, 199, 5, 64, "Usage",
      CellTags->"ProductTransitions"],
    Cell[386509, 14483, 230, 9, 58, "Notes",
      CellTags->"ProductTransitions"],
    Cell[386742, 14494, 446, 16, 54, "Notes",
      CellTags->"ProductTransitions"],
    Cell[387191, 14512, 253, 11, 33, "Notes",
      CellTags->"ProductTransitions"],
    Cell[387447, 14525, 276, 11, 33, "Notes",
      CellTags->"ProductTransitions"],
    Cell[387726, 14538, 286, 12, 33, "Notes",
      CellTags->"ProductTransitions"],
    Cell[388037, 14554, 76, 1, 59, "ExampleSection",
      CellTags->"ProductTransitions"],
    Cell[388116, 14557, 112, 1, 70, "ExampleText",
      CellTags->"ProductTransitions"],
    Cell[388231, 14560, 203, 4, 70, "Input",
      CellTags->"ProductTransitions"],
    Cell[388459, 14568, 120, 3, 70, "Input",
      CellTags->"ProductTransitions"],
    Cell[388582, 14573, 907, 14, 70, "Output",
      CellTags->"ProductTransitions"],
    Cell[389526, 14592, 138, 3, 70, "Input",
      CellTags->"ProductTransitions"],
    Cell[389667, 14597, 598, 10, 70, "Output",
      CellTags->"ProductTransitions"],
    Cell[390302, 14612, 138, 3, 70, "Input",
      CellTags->"ProductTransitions"],
    Cell[390443, 14617, 310, 6, 70, "Output",
      CellTags->"ProductTransitions"]},
  "ProperPrefixes"->{
    Cell[390780, 14627, 66, 1, 31, "ObjectName",
      CellTags->"ProperPrefixes"],
    Cell[390849, 14630, 65, 1, 74, "Highlight",
      CellTags->"ProperPrefixes"],
    Cell[390917, 14633, 170, 4, 43, "Usage",
      CellTags->"ProperPrefixes"],
    Cell[391090, 14639, 148, 5, 33, "Notes",
      CellTags->"ProperPrefixes"],
    Cell[391241, 14646, 239, 7, 33, "Notes",
      CellTags->"ProperPrefixes"],
    Cell[391483, 14655, 186, 5, 33, "Notes",
      CellTags->"ProperPrefixes"],
    Cell[391672, 14662, 262, 11, 33, "Notes",
      CellTags->"ProperPrefixes"],
    Cell[391959, 14677, 72, 1, 59, "ExampleSection",
      CellTags->"ProperPrefixes"],
    Cell[392034, 14680, 96, 1, 70, "ExampleText",
      CellTags->"ProperPrefixes"],
    Cell[392155, 14685, 165, 4, 70, "Input",
      CellTags->"ProperPrefixes"],
    Cell[392323, 14691, 186, 4, 70, "Output",
      CellTags->"ProperPrefixes"],
    Cell[392546, 14700, 99, 2, 70, "Input",
      CellTags->"ProperPrefixes"],
    Cell[392648, 14704, 123, 3, 70, "Output",
      CellTags->"ProperPrefixes"]},
  "QuotientDFA"->{
    Cell[392798, 14711, 60, 1, 31, "ObjectName",
      CellTags->"QuotientDFA"],
    Cell[392861, 14714, 62, 1, 74, "Highlight",
      CellTags->"QuotientDFA"],
    Cell[392926, 14717, 228, 8, 43, "Usage",
      CellTags->"QuotientDFA"],
    Cell[393157, 14727, 251, 9, 58, "Notes",
      CellTags->"QuotientDFA"],
    Cell[393411, 14738, 74, 1, 33, "Notes",
      CellTags->"QuotientDFA"],
    Cell[393488, 14741, 580, 23, 54, "Notes",
      CellTags->"QuotientDFA"],
    Cell[394093, 14768, 69, 1, 59, "ExampleSection",
      CellTags->"QuotientDFA"],
    Cell[394165, 14771, 155, 4, 70, "ExampleText",
      CellTags->"QuotientDFA"],
    Cell[394345, 14779, 88, 2, 70, "Input",
      CellTags->"QuotientDFA"],
    Cell[394436, 14783, 136, 3, 70, "Output",
      CellTags->"QuotientDFA"],
    Cell[394609, 14791, 128, 3, 70, "Input",
      CellTags->"QuotientDFA"],
    Cell[394740, 14796, 398, 12, 70, "Output",
      CellTags->"QuotientDFA"],
    Cell[395175, 14813, 113, 3, 70, "Input",
      CellTags->"QuotientDFA"],
    Cell[395291, 14818, 641, 17, 70, "Output",
      CellTags->"QuotientDFA"],
    Cell[395947, 14838, 111, 2, 70, "ExampleText",
      CellTags->"QuotientDFA"],
    Cell[396083, 14844, 142, 4, 70, "Input",
      CellTags->"QuotientDFA"],
    Cell[396228, 14850, 105, 3, 70, "Output",
      CellTags->"QuotientDFA"],
    Cell[396336, 14855, 92, 3, 70, "Output",
      CellTags->"QuotientDFA"]},
  "QuotientMachineFA"->{
    Cell[396455, 14862, 72, 1, 31, "ObjectName",
      CellTags->"QuotientMachineFA"],
    Cell[396530, 14865, 68, 1, 74, "Highlight",
      CellTags->"QuotientMachineFA"],
    Cell[396601, 14868, 553, 19, 64, "Usage",
      CellTags->"QuotientMachineFA"],
    Cell[397157, 14889, 257, 9, 58, "Notes",
      CellTags->"QuotientMachineFA"],
    Cell[397417, 14900, 107, 1, 33, "Notes",
      CellTags->"QuotientMachineFA"],
    Cell[397527, 14903, 475, 19, 33, "Notes",
      CellTags->"QuotientMachineFA"],
    Cell[398027, 14926, 75, 1, 59, "ExampleSection",
      CellTags->"QuotientMachineFA"],
    Cell[398105, 14929, 378, 12, 70, "ExampleText",
      CellTags->"QuotientMachineFA"],
    Cell[398508, 14945, 174, 5, 70, "Input",
      CellTags->"QuotientMachineFA"],
    Cell[398685, 14952, 148, 3, 70, "Output",
      CellTags->"QuotientMachineFA"],
    Cell[398848, 14958, 143, 3, 70, "Input",
      CellTags->"QuotientMachineFA"],
    Cell[398994, 14963, 162, 4, 70, "Input",
      CellTags->"QuotientMachineFA"],
    Cell[399181, 14971, 107, 2, 70, "Input",
      CellTags->"QuotientMachineFA"],
    Cell[399291, 14975, 477, 14, 70, "Output",
      CellTags->"QuotientMachineFA"],
    Cell[399805, 14994, 119, 3, 70, "Input",
      CellTags->"QuotientMachineFA"],
    Cell[399927, 14999, 240, 5, 70, "Output",
      CellTags->"QuotientMachineFA"],
    Cell[400182, 15007, 103, 1, 70, "ExampleText",
      CellTags->"QuotientMachineFA"],
    Cell[400310, 15012, 118, 3, 70, "Input",
      CellTags->"QuotientMachineFA"],
    Cell[400431, 15017, 97, 3, 70, "Output",
      CellTags->"QuotientMachineFA"]},
  "RandomDFA"->{
    Cell[400555, 15024, 56, 1, 31, "ObjectName",
      CellTags->"RandomDFA"],
    Cell[400614, 15027, 60, 1, 74, "Highlight",
      CellTags->"RandomDFA"],
    Cell[400677, 15030, 147, 4, 43, "Usage",
      CellTags->"RandomDFA"],
    Cell[400827, 15036, 102, 1, 33, "Notes",
      CellTags->"RandomDFA"],
    Cell[400932, 15039, 356, 15, 33, "Notes",
      CellTags->"RandomDFA"],
    Cell[401313, 15058, 67, 1, 59, "ExampleSection",
      CellTags->"RandomDFA"],
    Cell[401383, 15061, 99, 1, 70, "ExampleText",
      CellTags->"RandomDFA"],
    Cell[401507, 15066, 82, 2, 70, "Input",
      CellTags->"RandomDFA"],
    Cell[401592, 15070, 410, 12, 70, "Output",
      CellTags->"RandomDFA"],
    Cell[402039, 15087, 82, 2, 70, "Input",
      CellTags->"RandomDFA"],
    Cell[402124, 15091, 407, 12, 70, "Output",
      CellTags->"RandomDFA"]},
  "RandomWord"->{
    Cell[402558, 15107, 58, 1, 31, "ObjectName",
      CellTags->"RandomWord"],
    Cell[402619, 15110, 61, 1, 74, "Highlight",
      CellTags->"RandomWord"],
    Cell[402683, 15113, 150, 4, 43, "Usage",
      CellTags->"RandomWord"],
    Cell[402836, 15119, 72, 1, 33, "Notes",
      CellTags->"RandomWord"],
    Cell[402911, 15122, 155, 7, 33, "Notes",
      CellTags->"RandomWord"],
    Cell[403091, 15133, 68, 1, 59, "ExampleSection",
      CellTags->"RandomWord"],
    Cell[403162, 15136, 62, 1, 70, "ExampleText",
      CellTags->"RandomWord"],
    Cell[403249, 15141, 85, 2, 70, "Input",
      CellTags->"RandomWord"],
    Cell[403337, 15145, 108, 3, 70, "Output",
      CellTags->"RandomWord"],
    Cell[403482, 15153, 86, 2, 70, "Input",
      CellTags->"RandomWord"],
    Cell[403571, 15157, 108, 3, 70, "Output",
      CellTags->"RandomWord"]},
  "RankOfDFA"->{
    Cell[403706, 15164, 56, 1, 31, "ObjectName",
      CellTags->"RankOfDFA"],
    Cell[403765, 15167, 60, 1, 74, "Highlight",
      CellTags->"RankOfDFA"],
    Cell[403828, 15170, 169, 5, 43, "Usage",
      CellTags->"RankOfDFA"],
    Cell[404000, 15177, 352, 15, 33, "Notes",
      CellTags->"RankOfDFA"],
    Cell[404377, 15196, 67, 1, 59, "ExampleSection",
      CellTags->"RankOfDFA"],
    Cell[404447, 15199, 66, 1, 70, "ExampleText",
      CellTags->"RankOfDFA"],
    Cell[404538, 15204, 90, 2, 70, "Input",
      CellTags->"RankOfDFA"],
    Cell[404631, 15208, 399, 12, 70, "Output",
      CellTags->"RankOfDFA"],
    Cell[405067, 15225, 100, 3, 70, "Input",
      CellTags->"RankOfDFA"],
    Cell[405170, 15230, 100, 3, 70, "Output",
      CellTags->"RankOfDFA"],
    Cell[405307, 15238, 110, 3, 70, "Input",
      CellTags->"RankOfDFA"],
    Cell[405420, 15243, 399, 12, 70, "Output",
      CellTags->"RankOfDFA"]},
  "RankToDFA"->{
    Cell[405846, 15259, 56, 1, 31, "ObjectName",
      CellTags->"RankToDFA"],
    Cell[405905, 15262, 60, 1, 74, "Highlight",
      CellTags->"RankToDFA"],
    Cell[405968, 15265, 194, 5, 64, "Usage",
      CellTags->"RankToDFA"],
    Cell[406165, 15272, 80, 1, 33, "Notes",
      CellTags->"RankToDFA"],
    Cell[406248, 15275, 369, 17, 33, "Notes",
      CellTags->"RankToDFA"],
    Cell[406642, 15296, 67, 1, 59, "ExampleSection",
      CellTags->"RankToDFA"],
    Cell[406712, 15299, 61, 1, 70, "ExampleText",
      CellTags->"RankToDFA"],
    Cell[406798, 15304, 133, 5, 70, "Input",
      CellTags->"RankToDFA"],
    Cell[406934, 15311, 95, 3, 70, "Output",
      CellTags->"RankToDFA"],
    Cell[407032, 15316, 390, 12, 70, "Output",
      CellTags->"RankToDFA"]},
  "REEpsQ"->{
    Cell[407449, 15332, 50, 1, 31, "ObjectName",
      CellTags->"REEpsQ"],
    Cell[407502, 15335, 57, 1, 74, "Highlight",
      CellTags->"REEpsQ"],
    Cell[407562, 15338, 197, 6, 43, "Usage",
      CellTags->"REEpsQ"],
    Cell[407762, 15346, 376, 14, 54, "Notes",
      CellTags->"REEpsQ"],
    Cell[408141, 15362, 155, 7, 33, "Notes",
      CellTags->"REEpsQ"],
    Cell[408321, 15373, 64, 1, 59, "ExampleSection",
      CellTags->"REEpsQ"],
    Cell[408388, 15376, 78, 1, 70, "ExampleText",
      CellTags->"REEpsQ"],
    Cell[408491, 15381, 85, 2, 70, "Input",
      CellTags->"REEpsQ"],
    Cell[408579, 15385, 87, 3, 70, "Output",
      CellTags->"REEpsQ"],
    Cell[408703, 15393, 90, 2, 70, "Input",
      CellTags->"REEpsQ"],
    Cell[408796, 15397, 86, 3, 70, "Output",
      CellTags->"REEpsQ"],
    Cell[408919, 15405, 97, 2, 70, "Input",
      CellTags->"REEpsQ"],
    Cell[409019, 15409, 87, 3, 70, "Output",
      CellTags->"REEpsQ"]},
  "RegularExpressionToBEFA"->{
    Cell[409133, 15416, 84, 1, 31, "ObjectName",
      CellTags->"RegularExpressionToBEFA"],
    Cell[409220, 15419, 74, 1, 74, "Highlight",
      CellTags->"RegularExpressionToBEFA"],
    Cell[409297, 15422, 197, 6, 43, "Usage",
      CellTags->"RegularExpressionToBEFA"],
    Cell[409497, 15430, 103, 1, 33, "Notes",
      CellTags->"RegularExpressionToBEFA"],
    Cell[409603, 15433, 131, 4, 33, "Notes",
      CellTags->"RegularExpressionToBEFA"],
    Cell[409737, 15439, 282, 11, 33, "Notes",
      CellTags->"RegularExpressionToBEFA"],
    Cell[410044, 15454, 81, 1, 59, "ExampleSection",
      CellTags->"RegularExpressionToBEFA"],
    Cell[410128, 15457, 257, 7, 70, "ExampleText",
      CellTags->"RegularExpressionToBEFA"],
    Cell[410410, 15468, 126, 2, 70, "Input",
      CellTags->"RegularExpressionToBEFA"],
    Cell[410539, 15472, 143, 3, 70, "Output",
      CellTags->"RegularExpressionToBEFA"],
    Cell[410719, 15480, 125, 3, 70, "Input",
      CellTags->"RegularExpressionToBEFA"],
    Cell[410847, 15485, 288, 6, 70, "Output",
      CellTags->"RegularExpressionToBEFA"]},
  "RegularExpressionToFA"->{
    Cell[411162, 15495, 80, 1, 31, "ObjectName",
      CellTags->"RegularExpressionToFA"],
    Cell[411245, 15498, 72, 1, 74, "Highlight",
      CellTags->"RegularExpressionToFA"],
    Cell[411320, 15501, 237, 8, 43, "Usage",
      CellTags->"RegularExpressionToFA"],
    Cell[411560, 15511, 337, 11, 104, "Notes",
      CellTags->"RegularExpressionToFA"],
    Cell[411900, 15524, 171, 5, 33, "Notes",
      CellTags->"RegularExpressionToFA"],
    Cell[412074, 15531, 180, 5, 33, "Notes",
      CellTags->"RegularExpressionToFA"],
    Cell[412257, 15538, 172, 5, 33, "Notes",
      CellTags->"RegularExpressionToFA"],
    Cell[412432, 15545, 245, 6, 33, "Notes",
      CellTags->"RegularExpressionToFA"],
    Cell[412702, 15555, 79, 1, 59, "ExampleSection",
      CellTags->"RegularExpressionToFA"],
    Cell[412784, 15558, 254, 7, 70, "ExampleText",
      CellTags->"RegularExpressionToFA"],
    Cell[413063, 15569, 124, 2, 70, "Input",
      CellTags->"RegularExpressionToFA"],
    Cell[413190, 15573, 141, 3, 70, "Output",
      CellTags->"RegularExpressionToFA"],
    Cell[413368, 15581, 129, 3, 70, "Input",
      CellTags->"RegularExpressionToFA"],
    Cell[413500, 15586, 557, 15, 70, "Output",
      CellTags->"RegularExpressionToFA"],
    Cell[414094, 15606, 117, 3, 70, "Input",
      CellTags->"RegularExpressionToFA"],
    Cell[414214, 15611, 378, 6, 70, "Output",
      CellTags->"RegularExpressionToFA"],
    Cell[414607, 15620, 146, 4, 70, "ExampleText",
      CellTags->"RegularExpressionToFA"],
    Cell[414778, 15628, 196, 5, 70, "Input",
      CellTags->"RegularExpressionToFA"],
    Cell[414977, 15635, 503, 14, 70, "Output",
      CellTags->"RegularExpressionToFA"]},
  "RegularExpressionToNNFA"->{
    Cell[415507, 15653, 84, 1, 31, "ObjectName",
      CellTags->"RegularExpressionToNNFA"],
    Cell[415594, 15656, 74, 1, 74, "Highlight",
      CellTags->"RegularExpressionToNNFA"],
    Cell[415671, 15659, 197, 6, 43, "Usage",
      CellTags->"RegularExpressionToNNFA"],
    Cell[415871, 15667, 138, 4, 33, "Notes",
      CellTags->"RegularExpressionToNNFA"],
    Cell[416012, 15673, 282, 11, 33, "Notes",
      CellTags->"RegularExpressionToNNFA"],
    Cell[416319, 15688, 81, 1, 59, "ExampleSection",
      CellTags->"RegularExpressionToNNFA"],
    Cell[416403, 15691, 257, 7, 70, "ExampleText",
      CellTags->"RegularExpressionToNNFA"],
    Cell[416685, 15702, 126, 2, 70, "Input",
      CellTags->"RegularExpressionToNNFA"],
    Cell[416814, 15706, 143, 3, 70, "Output",
      CellTags->"RegularExpressionToNNFA"],
    Cell[416994, 15714, 125, 3, 70, "Input",
      CellTags->"RegularExpressionToNNFA"],
    Cell[417122, 15719, 290, 6, 70, "Output",
      CellTags->"RegularExpressionToNNFA"]},
  "RemoveTransitionFA"->{
    Cell[417439, 15729, 74, 1, 31, "ObjectName",
      CellTags->"RemoveTransitionFA"],
    Cell[417516, 15732, 69, 1, 74, "Highlight",
      CellTags->"RemoveTransitionFA"],
    Cell[417588, 15735, 284, 10, 64, "Usage",
      CellTags->"RemoveTransitionFA"],
    Cell[417875, 15747, 243, 7, 54, "Notes",
      CellTags->"RemoveTransitionFA"],
    Cell[418121, 15756, 293, 11, 33, "Notes",
      CellTags->"RemoveTransitionFA"],
    Cell[418439, 15771, 76, 1, 59, "ExampleSection",
      CellTags->"RemoveTransitionFA"],
    Cell[418518, 15774, 96, 1, 70, "ExampleText",
      CellTags->"RemoveTransitionFA"],
    Cell[418617, 15777, 223, 5, 70, "Input",
      CellTags->"RemoveTransitionFA"],
    Cell[418865, 15786, 105, 3, 70, "Input",
      CellTags->"RemoveTransitionFA"],
    Cell[418973, 15791, 368, 12, 70, "Output",
      CellTags->"RemoveTransitionFA"],
    Cell[419356, 15806, 152, 4, 70, "ExampleText",
      CellTags->"RemoveTransitionFA"],
    Cell[419533, 15814, 131, 3, 70, "Input",
      CellTags->"RemoveTransitionFA"],
    Cell[419667, 15819, 342, 10, 70, "Output",
      CellTags->"RemoveTransitionFA"],
    Cell[420046, 15834, 106, 3, 70, "Input",
      CellTags->"RemoveTransitionFA"],
    Cell[420155, 15839, 567, 15, 70, "Output",
      CellTags->"RemoveTransitionFA"]},
  "REQ"->{
    Cell[420749, 15858, 44, 1, 31, "ObjectName",
      CellTags->"REQ"],
    Cell[420796, 15861, 54, 1, 74, "Highlight",
      CellTags->"REQ"],
    Cell[420853, 15864, 273, 7, 66, "Usage",
      CellTags->"REQ"],
    Cell[421129, 15873, 313, 7, 54, "Notes",
      CellTags->"REQ"],
    Cell[421445, 15882, 178, 7, 33, "Notes",
      CellTags->"REQ"],
    Cell[421648, 15893, 61, 1, 59, "ExampleSection",
      CellTags->"REQ"],
    Cell[421712, 15896, 148, 6, 70, "ExampleText",
      CellTags->"REQ"],
    Cell[421885, 15906, 84, 2, 70, "Input",
      CellTags->"REQ"],
    Cell[421972, 15910, 121, 3, 70, "Output",
      CellTags->"REQ"],
    Cell[422130, 15918, 90, 3, 70, "Input",
      CellTags->"REQ"],
    Cell[422223, 15923, 109, 3, 70, "Output",
      CellTags->"REQ"],
    Cell[422347, 15929, 189, 6, 70, "ExampleText",
      CellTags->"REQ"]},
  "RESimplify"->{
    Cell[422551, 15938, 58, 1, 31, "ObjectName",
      CellTags->"RESimplify"],
    Cell[422612, 15941, 61, 1, 74, "Highlight",
      CellTags->"RESimplify"],
    Cell[422676, 15944, 238, 8, 64, "Usage",
      CellTags->"RESimplify"],
    Cell[422917, 15954, 129, 4, 33, "Notes",
      CellTags->"RESimplify"],
    Cell[423049, 15960, 165, 7, 33, "Notes",
      CellTags->"RESimplify"],
    Cell[423239, 15971, 68, 1, 59, "ExampleSection",
      CellTags->"RESimplify"],
    Cell[423310, 15974, 85, 1, 70, "ExampleText",
      CellTags->"RESimplify"],
    Cell[423420, 15979, 95, 2, 70, "Input",
      CellTags->"RESimplify"],
    Cell[423518, 15983, 91, 3, 70, "Output",
      CellTags->"RESimplify"],
    Cell[423646, 15991, 104, 2, 70, "Input",
      CellTags->"RESimplify"],
    Cell[423753, 15995, 99, 3, 70, "Output",
      CellTags->"RESimplify"]},
  "ReverseFA"->{
    Cell[423879, 16002, 56, 1, 31, "ObjectName",
      CellTags->"ReverseFA"],
    Cell[423938, 16005, 60, 1, 74, "Highlight",
      CellTags->"ReverseFA"],
    Cell[424001, 16008, 207, 6, 43, "Usage",
      CellTags->"ReverseFA"],
    Cell[424211, 16016, 117, 4, 33, "Notes",
      CellTags->"ReverseFA"],
    Cell[424353, 16024, 67, 1, 59, "ExampleSection",
      CellTags->"ReverseFA"],
    Cell[424423, 16027, 178, 6, 70, "ExampleText",
      CellTags->"ReverseFA"],
    Cell[424626, 16037, 109, 3, 70, "Input",
      CellTags->"ReverseFA"],
    Cell[424738, 16042, 384, 12, 70, "Output",
      CellTags->"ReverseFA"],
    Cell[425159, 16059, 101, 3, 70, "Input",
      CellTags->"ReverseFA"],
    Cell[425263, 16064, 491, 14, 70, "Output",
      CellTags->"ReverseFA"],
    Cell[425791, 16083, 112, 3, 70, "Input",
      CellTags->"ReverseFA"],
    Cell[425906, 16088, 366, 6, 70, "Output",
      CellTags->"ReverseFA"]},
  "RightShiftCA"->{
    Cell[426299, 16098, 62, 1, 31, "ObjectName",
      CellTags->"RightShiftCA"],
    Cell[426364, 16101, 63, 1, 74, "Highlight",
      CellTags->"RightShiftCA"],
    Cell[426430, 16104, 165, 4, 43, "Usage",
      CellTags->"RightShiftCA"],
    Cell[426598, 16110, 167, 7, 33, "Notes",
      CellTags->"RightShiftCA"],
    Cell[426790, 16121, 70, 1, 59, "ExampleSection",
      CellTags->"RightShiftCA"],
    Cell[426863, 16124, 61, 1, 70, "ExampleText",
      CellTags->"RightShiftCA"],
    Cell[426949, 16129, 86, 2, 70, "Input",
      CellTags->"RightShiftCA"],
    Cell[427038, 16133, 104, 3, 70, "Output",
      CellTags->"RightShiftCA"],
    Cell[427179, 16141, 140, 3, 70, "Input",
      CellTags->"RightShiftCA"],
    Cell[427322, 16146, 107, 3, 70, "Output",
      CellTags->"RightShiftCA"],
    Cell[427466, 16154, 97, 3, 70, "Input",
      CellTags->"RightShiftCA"],
    Cell[427566, 16159, 103, 3, 70, "Output",
      CellTags->"RightShiftCA"]},
  "SelectFA"->{
    Cell[427696, 16166, 54, 1, 31, "ObjectName",
      CellTags->"SelectFA"],
    Cell[427753, 16169, 59, 1, 74, "Highlight",
      CellTags->"SelectFA"],
    Cell[427815, 16172, 208, 8, 43, "Usage",
      CellTags->"SelectFA"],
    Cell[428026, 16182, 225, 9, 58, "Notes",
      CellTags->"SelectFA"],
    Cell[428254, 16193, 91, 1, 33, "Notes",
      CellTags->"SelectFA"],
    Cell[428348, 16196, 114, 4, 33, "Notes",
      CellTags->"SelectFA"],
    Cell[428487, 16204, 66, 1, 59, "ExampleSection",
      CellTags->"SelectFA"],
    Cell[428556, 16207, 254, 7, 70, "ExampleText",
      CellTags->"SelectFA"],
    Cell[428813, 16216, 272, 6, 70, "Input",
      CellTags->"SelectFA"],
    Cell[429110, 16226, 151, 4, 70, "Input",
      CellTags->"SelectFA"],
    Cell[429264, 16232, 572, 15, 70, "Output",
      CellTags->"SelectFA"],
    Cell[429873, 16252, 93, 3, 70, "Input",
      CellTags->"SelectFA"],
    Cell[429969, 16257, 114, 3, 70, "Output",
      CellTags->"SelectFA"],
    Cell[430098, 16263, 138, 4, 70, "ExampleText",
      CellTags->"SelectFA"],
    Cell[430261, 16271, 115, 3, 70, "Input",
      CellTags->"SelectFA"],
    Cell[430379, 16276, 572, 15, 70, "Output",
      CellTags->"SelectFA"],
    Cell[430988, 16296, 103, 3, 70, "Input",
      CellTags->"SelectFA"],
    Cell[431094, 16301, 88, 3, 70, "Output",
      CellTags->"SelectFA"]},
  "SetFinalFA"->{
    Cell[431209, 16308, 58, 1, 31, "ObjectName",
      CellTags->"SetFinalFA"],
    Cell[431270, 16311, 61, 1, 74, "Highlight",
      CellTags->"SetFinalFA"],
    Cell[431334, 16314, 200, 8, 43, "Usage",
      CellTags->"SetFinalFA"],
    Cell[431537, 16324, 138, 5, 33, "Notes",
      CellTags->"SetFinalFA"],
    Cell[431678, 16331, 68, 1, 33, "Notes",
      CellTags->"SetFinalFA"],
    Cell[431749, 16334, 277, 11, 33, "Notes",
      CellTags->"SetFinalFA"],
    Cell[432051, 16349, 68, 1, 59, "ExampleSection",
      CellTags->"SetFinalFA"],
    Cell[432122, 16352, 259, 7, 50, "ExampleText",
      CellTags->"SetFinalFA"],
    Cell[432384, 16361, 215, 5, 60, "Input",
      CellTags->"SetFinalFA"],
    Cell[432624, 16370, 103, 3, 37, "Input",
      CellTags->"SetFinalFA"],
    Cell[432730, 16375, 459, 14, 53, "Output",
      CellTags->"SetFinalFA"],
    Cell[433226, 16394, 106, 3, 37, "Input",
      CellTags->"SetFinalFA"],
    Cell[433335, 16399, 386, 7, 99, "Output",
      CellTags->"SetFinalFA"]},
  "SetInitialFA"->{
    Cell[433748, 16410, 62, 1, 42, "ObjectName",
      CellTags->"SetInitialFA"],
    Cell[433813, 16413, 63, 1, 74, "Highlight",
      CellTags->"SetInitialFA"],
    Cell[433879, 16416, 210, 8, 43, "Usage",
      CellTags->"SetInitialFA"],
    Cell[434092, 16426, 140, 5, 33, "Notes",
      CellTags->"SetInitialFA"],
    Cell[434235, 16433, 70, 1, 33, "Notes",
      CellTags->"SetInitialFA"],
    Cell[434308, 16436, 275, 11, 33, "Notes",
      CellTags->"SetInitialFA"],
    Cell[434608, 16451, 70, 1, 59, "ExampleSection",
      CellTags->"SetInitialFA"],
    Cell[434681, 16454, 261, 7, 70, "ExampleText",
      CellTags->"SetInitialFA"],
    Cell[434945, 16463, 217, 5, 70, "Input",
      CellTags->"SetInitialFA"],
    Cell[435187, 16472, 107, 3, 70, "Input",
      CellTags->"SetInitialFA"],
    Cell[435297, 16477, 461, 14, 70, "Output",
      CellTags->"SetInitialFA"],
    Cell[435795, 16496, 108, 3, 70, "Input",
      CellTags->"SetInitialFA"],
    Cell[435906, 16501, 134, 3, 70, "Output",
      CellTags->"SetInitialFA"]},
  "SetInitialFinalFA"->{
    Cell[436067, 16508, 72, 1, 31, "ObjectName",
      CellTags->"SetInitialFinalFA"],
    Cell[436142, 16511, 68, 1, 74, "Highlight",
      CellTags->"SetInitialFinalFA"],
    Cell[436213, 16514, 276, 10, 64, "Usage",
      CellTags->"SetInitialFinalFA"],
    Cell[436492, 16526, 183, 7, 33, "Notes",
      CellTags->"SetInitialFinalFA"],
    Cell[436678, 16535, 75, 1, 33, "Notes",
      CellTags->"SetInitialFinalFA"],
    Cell[436756, 16538, 270, 11, 33, "Notes",
      CellTags->"SetInitialFinalFA"],
    Cell[437051, 16553, 75, 1, 59, "ExampleSection",
      CellTags->"SetInitialFinalFA"],
    Cell[437129, 16556, 156, 4, 70, "ExampleText",
      CellTags->"SetInitialFinalFA"],
    Cell[437288, 16562, 223, 5, 70, "Input",
      CellTags->"SetInitialFinalFA"],
    Cell[437536, 16571, 122, 3, 70, "Input",
      CellTags->"SetInitialFinalFA"],
    Cell[437661, 16576, 477, 14, 70, "Output",
      CellTags->"SetInitialFinalFA"],
    Cell[438175, 16595, 113, 3, 70, "Input",
      CellTags->"SetInitialFinalFA"],
    Cell[438291, 16600, 264, 5, 70, "Output",
      CellTags->"SetInitialFinalFA"]},
  "ShowAcceptQFA"->{
    Cell[438582, 16609, 64, 1, 31, "ObjectName",
      CellTags->"ShowAcceptQFA"],
    Cell[438649, 16612, 64, 1, 74, "Highlight",
      CellTags->"ShowAcceptQFA"],
    Cell[438716, 16615, 221, 7, 43, "Usage",
      CellTags->"ShowAcceptQFA"],
    Cell[438940, 16624, 114, 5, 33, "Notes",
      CellTags->"ShowAcceptQFA"],
    Cell[439079, 16633, 71, 1, 59, "ExampleSection",
      CellTags->"ShowAcceptQFA"],
    Cell[439153, 16636, 70, 1, 70, "ExampleText",
      CellTags->"ShowAcceptQFA"],
    Cell[439226, 16639, 218, 5, 70, "Input",
      CellTags->"ShowAcceptQFA"],
    Cell[439469, 16648, 134, 3, 70, "Input",
      CellTags->"ShowAcceptQFA"],
    Cell[439606, 16653, 441, 12, 70, "Output",
      CellTags->"ShowAcceptQFA"]},
  "ShrinkCA"->{
    Cell[440074, 16669, 54, 1, 31, "ObjectName",
      CellTags->"ShrinkCA"],
    Cell[440131, 16672, 59, 1, 74, "Highlight",
      CellTags->"ShrinkCA"],
    Cell[440193, 16675, 202, 5, 64, "Usage",
      CellTags->"ShrinkCA"],
    Cell[440398, 16682, 224, 9, 58, "Notes",
      CellTags->"ShrinkCA"],
    Cell[440625, 16693, 148, 5, 33, "Notes",
      CellTags->"ShrinkCA"],
    Cell[440798, 16702, 66, 1, 59, "ExampleSection",
      CellTags->"ShrinkCA"],
    Cell[440867, 16705, 166, 4, 70, "ExampleText",
      CellTags->"ShrinkCA"],
    Cell[441058, 16713, 179, 5, 70, "Input",
      CellTags->"ShrinkCA"],
    Cell[441240, 16720, 101, 3, 70, "Output",
      CellTags->"ShrinkCA"],
    Cell[441344, 16725, 104, 3, 70, "Output",
      CellTags->"ShrinkCA"],
    Cell[441451, 16730, 101, 3, 70, "Output",
      CellTags->"ShrinkCA"],
    Cell[441567, 16736, 134, 4, 70, "ExampleText",
      CellTags->"ShrinkCA"],
    Cell[441726, 16744, 245, 7, 70, "Input",
      CellTags->"ShrinkCA"],
    Cell[441974, 16753, 138, 3, 70, "Output",
      CellTags->"ShrinkCA"],
    Cell[442115, 16758, 100, 3, 70, "Output",
      CellTags->"ShrinkCA"],
    Cell[442252, 16766, 93, 3, 70, "Input",
      CellTags->"ShrinkCA"],
    Cell[442348, 16771, 385, 12, 70, "Output",
      CellTags->"ShrinkCA"]},
  "ShuffleProductFA"->{
    Cell[442760, 16787, 70, 1, 31, "ObjectName",
      CellTags->"ShuffleProductFA"],
    Cell[442833, 16790, 67, 1, 74, "Highlight",
      CellTags->"ShuffleProductFA"],
    Cell[442903, 16793, 282, 9, 64, "Usage",
      CellTags->"ShuffleProductFA"],
    Cell[443188, 16804, 256, 9, 58, "Notes",
      CellTags->"ShuffleProductFA"],
    Cell[443447, 16815, 107, 1, 33, "Notes",
      CellTags->"ShuffleProductFA"],
    Cell[443557, 16818, 171, 7, 33, "Notes",
      CellTags->"ShuffleProductFA"],
    Cell[443753, 16829, 74, 1, 59, "ExampleSection",
      CellTags->"ShuffleProductFA"],
    Cell[443830, 16832, 287, 9, 70, "ExampleText",
      CellTags->"ShuffleProductFA"],
    Cell[444142, 16845, 137, 5, 70, "Input",
      CellTags->"ShuffleProductFA"],
    Cell[444282, 16852, 373, 12, 70, "Output",
      CellTags->"ShuffleProductFA"],
    Cell[444658, 16866, 373, 12, 70, "Output",
      CellTags->"ShuffleProductFA"],
    Cell[445068, 16883, 124, 3, 70, "Input",
      CellTags->"ShuffleProductFA"],
    Cell[445195, 16888, 549, 15, 70, "Output",
      CellTags->"ShuffleProductFA"],
    Cell[445781, 16908, 138, 3, 70, "Input",
      CellTags->"ShuffleProductFA"],
    Cell[445922, 16913, 126, 3, 70, "Output",
      CellTags->"ShuffleProductFA"]},
  "SinkQDFA"->{
    Cell[446075, 16920, 54, 1, 31, "ObjectName",
      CellTags->"SinkQDFA"],
    Cell[446132, 16923, 59, 1, 74, "Highlight",
      CellTags->"SinkQDFA"],
    Cell[446194, 16926, 249, 8, 64, "Usage",
      CellTags->"SinkQDFA"],
    Cell[446446, 16936, 256, 11, 33, "Notes",
      CellTags->"SinkQDFA"],
    Cell[446705, 16949, 66, 1, 59, "ExampleSection",
      CellTags->"SinkQDFA"],
    Cell[446796, 16954, 66, 1, 59, "ExampleSection",
      CellTags->"SinkQDFA"],
    Cell[446865, 16957, 79, 1, 48, "ExampleText",
      CellTags->"SinkQDFA"],
    Cell[446947, 16960, 154, 4, 37, "Input",
      CellTags->"SinkQDFA"],
    Cell[447126, 16968, 93, 3, 37, "Input",
      CellTags->"SinkQDFA"],
    Cell[447222, 16973, 88, 3, 30, "Output",
      CellTags->"SinkQDFA"],
    Cell[447325, 16979, 97, 1, 48, "ExampleText",
      CellTags->"SinkQDFA"],
    Cell[447425, 16982, 139, 3, 37, "Input",
      CellTags->"SinkQDFA"],
    Cell[447589, 16989, 93, 3, 37, "Input",
      CellTags->"SinkQDFA"],
    Cell[447685, 16994, 87, 3, 30, "Output",
      CellTags->"SinkQDFA"]},
  "SinksDFA"->{
    Cell[447799, 17001, 54, 1, 42, "ObjectName",
      CellTags->"SinksDFA"],
    Cell[447856, 17004, 59, 1, 74, "Highlight",
      CellTags->"SinksDFA"],
    Cell[447918, 17007, 155, 4, 43, "Usage",
      CellTags->"SinksDFA"],
    Cell[448076, 17013, 256, 11, 33, "Notes",
      CellTags->"SinksDFA"],
    Cell[448357, 17028, 66, 1, 59, "ExampleSection",
      CellTags->"SinksDFA"],
    Cell[448426, 17031, 73, 1, 70, "ExampleText",
      CellTags->"SinksDFA"],
    Cell[448502, 17034, 144, 4, 70, "Input",
      CellTags->"SinksDFA"],
    Cell[448671, 17042, 107, 3, 70, "Input",
      CellTags->"SinksDFA"],
    Cell[448781, 17047, 89, 3, 70, "Output",
      CellTags->"SinksDFA"]},
  "Size"->{
    Cell[448897, 17054, 46, 1, 31, "ObjectName",
      CellTags->"Size"],
    Cell[448946, 17057, 55, 1, 74, "Highlight",
      CellTags->"Size"],
    Cell[449004, 17060, 126, 4, 43, "Usage",
      CellTags->"Size"],
    Cell[449133, 17066, 220, 9, 58, "Notes",
      CellTags->"Size"],
    Cell[449356, 17077, 104, 5, 33, "Notes",
      CellTags->"Size"],
    Cell[449485, 17086, 62, 1, 59, "ExampleSection",
      CellTags->"Size"],
    Cell[449550, 17089, 69, 1, 70, "ExampleText",
      CellTags->"Size"],
    Cell[449644, 17094, 90, 2, 70, "Input",
      CellTags->"Size"],
    Cell[449737, 17098, 81, 3, 70, "Output",
      CellTags->"Size"]},
  "SquareSA"->{
    Cell[449845, 17105, 54, 1, 31, "ObjectName",
      CellTags->"SquareSA"],
    Cell[449902, 17108, 59, 1, 74, "Highlight",
      CellTags->"SquareSA"],
    Cell[449964, 17111, 187, 6, 43, "Usage",
      CellTags->"SquareSA"],
    Cell[450154, 17119, 302, 10, 80, "Notes",
      CellTags->"SquareSA"],
    Cell[450459, 17131, 159, 5, 33, "Notes",
      CellTags->"SquareSA"],
    Cell[450621, 17138, 145, 5, 33, "Notes",
      CellTags->"SquareSA"],
    Cell[450769, 17145, 100, 1, 33, "Notes",
      CellTags->"SquareSA"],
    Cell[450872, 17148, 258, 11, 33, "Notes",
      CellTags->"SquareSA"],
    Cell[451155, 17163, 66, 1, 59, "ExampleSection",
      CellTags->"SquareSA"],
    Cell[451224, 17166, 78, 1, 70, "ExampleText",
      CellTags->"SquareSA"],
    Cell[451305, 17169, 213, 5, 70, "Input",
      CellTags->"SquareSA"],
    Cell[451543, 17178, 93, 3, 70, "Input",
      CellTags->"SquareSA"],
    Cell[451639, 17183, 416, 11, 70, "Output",
      CellTags->"SquareSA"],
    Cell[452092, 17199, 109, 3, 70, "Input",
      CellTags->"SquareSA"],
    Cell[452204, 17204, 421, 11, 70, "Output",
      CellTags->"SquareSA"],
    Cell[452662, 17220, 109, 3, 70, "Input",
      CellTags->"SquareSA"],
    Cell[452774, 17225, 354, 10, 70, "Output",
      CellTags->"SquareSA"]},
  "StarFA"->{
    Cell[453155, 17239, 50, 1, 31, "ObjectName",
      CellTags->"StarFA"],
    Cell[453208, 17242, 57, 1, 74, "Highlight",
      CellTags->"StarFA"],
    Cell[453268, 17245, 196, 7, 43, "Usage",
      CellTags->"StarFA"],
    Cell[453467, 17254, 305, 10, 80, "Notes",
      CellTags->"StarFA"],
    Cell[453775, 17266, 176, 5, 33, "Notes",
      CellTags->"StarFA"],
    Cell[453954, 17273, 438, 19, 33, "Notes",
      CellTags->"StarFA"],
    Cell[454417, 17296, 64, 1, 59, "ExampleSection",
      CellTags->"StarFA"],
    Cell[454484, 17299, 189, 6, 70, "ExampleText",
      CellTags->"StarFA"],
    Cell[454698, 17309, 84, 2, 70, "Input",
      CellTags->"StarFA"],
    Cell[454785, 17313, 369, 12, 70, "Output",
      CellTags->"StarFA"],
    Cell[455191, 17330, 99, 3, 70, "Input",
      CellTags->"StarFA"],
    Cell[455293, 17335, 491, 14, 70, "Output",
      CellTags->"StarFA"],
    Cell[455821, 17354, 134, 3, 70, "Input",
      CellTags->"StarFA"],
    Cell[455958, 17359, 116, 3, 70, "Output",
      CellTags->"StarFA"]},
  "StateMergeDFA"->{
    Cell[456101, 17366, 64, 1, 31, "ObjectName",
      CellTags->"StateMergeDFA"],
    Cell[456168, 17369, 64, 1, 74, "Highlight",
      CellTags->"StateMergeDFA"],
    Cell[456235, 17372, 227, 6, 64, "Usage",
      CellTags->"StateMergeDFA"],
    Cell[456465, 17380, 350, 11, 104, "Notes",
      CellTags->"StateMergeDFA"],
    Cell[456818, 17393, 228, 5, 54, "Notes",
      CellTags->"StateMergeDFA"],
    Cell[457049, 17400, 187, 7, 33, "Notes",
      CellTags->"StateMergeDFA"],
    Cell[457239, 17409, 202, 7, 33, "Notes",
      CellTags->"StateMergeDFA"],
    Cell[457466, 17420, 71, 1, 59, "ExampleSection",
      CellTags->"StateMergeDFA"],
    Cell[457540, 17423, 242, 7, 70, "ExampleText",
      CellTags->"StateMergeDFA"],
    Cell[457785, 17432, 202, 5, 70, "Input",
      CellTags->"StateMergeDFA"],
    Cell[457990, 17439, 105, 1, 70, "ExampleText",
      CellTags->"StateMergeDFA"],
    Cell[458120, 17444, 112, 3, 70, "Input",
      CellTags->"StateMergeDFA"],
    Cell[458235, 17449, 415, 12, 70, "Output",
      CellTags->"StateMergeDFA"],
    Cell[458687, 17466, 110, 3, 70, "Input",
      CellTags->"StateMergeDFA"],
    Cell[458800, 17471, 370, 6, 70, "Output",
      CellTags->"StateMergeDFA"]},
  "States"->{
    Cell[459197, 17481, 50, 1, 31, "ObjectName",
      CellTags->"States"],
    Cell[459250, 17484, 57, 1, 74, "Highlight",
      CellTags->"States"],
    Cell[459310, 17487, 164, 6, 43, "Usage",
      CellTags->"States"],
    Cell[459477, 17495, 196, 6, 33, "Notes",
      CellTags->"States"],
    Cell[459676, 17503, 255, 11, 33, "Notes",
      CellTags->"States"],
    Cell[459956, 17518, 64, 1, 59, "ExampleSection",
      CellTags->"States"],
    Cell[460023, 17521, 96, 1, 70, "ExampleText",
      CellTags->"States"],
    Cell[460122, 17524, 101, 3, 70, "Input",
      CellTags->"States"],
    Cell[460248, 17531, 89, 3, 70, "Input",
      CellTags->"States"],
    Cell[460340, 17536, 93, 3, 70, "Output",
      CellTags->"States"],
    Cell[460448, 17542, 122, 3, 70, "Input",
      CellTags->"States"],
    Cell[460595, 17549, 89, 3, 70, "Input",
      CellTags->"States"],
    Cell[460687, 17554, 111, 3, 70, "Output",
      CellTags->"States"]},
  "SubsetQFA"->{
    Cell[460825, 17561, 56, 1, 31, "ObjectName",
      CellTags->"SubsetQFA"],
    Cell[460884, 17564, 60, 1, 74, "Highlight",
      CellTags->"SubsetQFA"],
    Cell[460947, 17567, 244, 8, 64, "Usage",
      CellTags->"SubsetQFA"],
    Cell[461194, 17577, 247, 9, 58, "Notes",
      CellTags->"SubsetQFA"],
    Cell[461444, 17588, 198, 6, 54, "Notes",
      CellTags->"SubsetQFA"],
    Cell[461645, 17596, 168, 7, 33, "Notes",
      CellTags->"SubsetQFA"],
    Cell[461838, 17607, 67, 1, 59, "ExampleSection",
      CellTags->"SubsetQFA"],
    Cell[461908, 17610, 125, 4, 70, "ExampleText",
      CellTags->"SubsetQFA"],
    Cell[462058, 17618, 156, 4, 70, "Input",
      CellTags->"SubsetQFA"],
    Cell[462217, 17624, 399, 12, 70, "Output",
      CellTags->"SubsetQFA"],
    Cell[462619, 17638, 402, 12, 70, "Output",
      CellTags->"SubsetQFA"],
    Cell[463058, 17655, 103, 3, 70, "Input",
      CellTags->"SubsetQFA"],
    Cell[463164, 17660, 89, 3, 70, "Output",
      CellTags->"SubsetQFA"],
    Cell[463290, 17668, 103, 3, 70, "Input",
      CellTags->"SubsetQFA"],
    Cell[463396, 17673, 90, 3, 70, "Output",
      CellTags->"SubsetQFA"]},
  "Substitute"->{
    Cell[463513, 17680, 58, 1, 31, "ObjectName",
      CellTags->"Substitute"],
    Cell[463574, 17683, 61, 1, 74, "Highlight",
      CellTags->"Substitute"],
    Cell[463638, 17686, 229, 8, 43, "Usage",
      CellTags->"Substitute"],
    Cell[463870, 17696, 126, 5, 33, "Notes",
      CellTags->"Substitute"],
    Cell[463999, 17703, 257, 11, 33, "Notes",
      CellTags->"Substitute"],
    Cell[464281, 17718, 68, 1, 59, "ExampleSection",
      CellTags->"Substitute"],
    Cell[464352, 17721, 78, 1, 70, "ExampleText",
      CellTags->"Substitute"],
    Cell[464455, 17726, 111, 3, 70, "Input",
      CellTags->"Substitute"],
    Cell[464569, 17731, 378, 12, 70, "Output",
      CellTags->"Substitute"],
    Cell[464962, 17746, 129, 3, 70, "Input",
      CellTags->"Substitute"],
    Cell[465116, 17753, 117, 3, 70, "Input",
      CellTags->"Substitute"],
    Cell[465236, 17758, 1465, 42, 70, "Output",
      CellTags->"Substitute"],
    Cell[466738, 17805, 102, 3, 70, "Input",
      CellTags->"Substitute"],
    Cell[466843, 17810, 163, 5, 70, "Output",
      CellTags->"Substitute"]},
  "SubwordCounterDFA"->{
    Cell[467033, 17819, 72, 1, 31, "ObjectName",
      CellTags->"SubwordCounterDFA"],
    Cell[467108, 17822, 68, 1, 74, "Highlight",
      CellTags->"SubwordCounterDFA"],
    Cell[467179, 17825, 337, 11, 64, "Usage",
      CellTags->"SubwordCounterDFA"],
    Cell[467519, 17838, 257, 9, 58, "Notes",
      CellTags->"SubwordCounterDFA"],
    Cell[467779, 17849, 311, 11, 33, "Notes",
      CellTags->"SubwordCounterDFA"],
    Cell[468093, 17862, 198, 6, 35, "Notes",
      CellTags->"SubwordCounterDFA"],
    Cell[468294, 17870, 289, 11, 33, "Notes",
      CellTags->"SubwordCounterDFA"],
    Cell[468608, 17885, 75, 1, 59, "ExampleSection",
      CellTags->"SubwordCounterDFA"],
    Cell[468686, 17888, 138, 4, 70, "ExampleText",
      CellTags->"SubwordCounterDFA"],
    Cell[468849, 17896, 228, 6, 70, "Input",
      CellTags->"SubwordCounterDFA"],
    Cell[469080, 17904, 94, 3, 70, "Output",
      CellTags->"SubwordCounterDFA"],
    Cell[469177, 17909, 882, 13, 70, "Output",
      CellTags->"SubwordCounterDFA"],
    Cell[470096, 17927, 203, 5, 70, "Input",
      CellTags->"SubwordCounterDFA"],
    Cell[470302, 17934, 660, 21, 70, "Output",
      CellTags->"SubwordCounterDFA"]},
  "SubwordDFA"->{
    Cell[470989, 17959, 58, 1, 31, "ObjectName",
      CellTags->"SubwordDFA"],
    Cell[471050, 17962, 61, 1, 74, "Highlight",
      CellTags->"SubwordDFA"],
    Cell[471114, 17965, 234, 8, 43, "Usage",
      CellTags->"SubwordDFA"],
    Cell[471351, 17975, 250, 9, 58, "Notes",
      CellTags->"SubwordDFA"],
    Cell[471604, 17986, 142, 5, 33, "Notes",
      CellTags->"SubwordDFA"],
    Cell[471749, 17993, 296, 11, 33, "Notes",
      CellTags->"SubwordDFA"],
    Cell[472070, 18008, 68, 1, 59, "ExampleSection",
      CellTags->"SubwordDFA"],
    Cell[472141, 18011, 97, 1, 70, "ExampleText",
      CellTags->"SubwordDFA"],
    Cell[472263, 18016, 132, 3, 70, "Input",
      CellTags->"SubwordDFA"],
    Cell[472398, 18021, 378, 12, 70, "Output",
      CellTags->"SubwordDFA"],
    Cell[472813, 18038, 93, 3, 70, "Input",
      CellTags->"SubwordDFA"],
    Cell[472909, 18043, 115, 3, 70, "Output",
      CellTags->"SubwordDFA"],
    Cell[473061, 18051, 105, 3, 70, "Input",
      CellTags->"SubwordDFA"],
    Cell[473169, 18056, 321, 6, 70, "Output",
      CellTags->"SubwordDFA"],
    Cell[473527, 18067, 113, 3, 70, "Input",
      CellTags->"SubwordDFA"],
    Cell[473643, 18072, 158, 4, 70, "Output",
      CellTags->"SubwordDFA"]},
  "SubwordModCounterDFA"->{
    Cell[473828, 18080, 78, 1, 31, "ObjectName",
      CellTags->"SubwordModCounterDFA"],
    Cell[473909, 18083, 71, 1, 74, "Highlight",
      CellTags->"SubwordModCounterDFA"],
    Cell[473983, 18086, 326, 9, 64, "Usage",
      CellTags->"SubwordModCounterDFA"],
    Cell[474312, 18097, 260, 9, 58, "Notes",
      CellTags->"SubwordModCounterDFA"],
    Cell[474575, 18108, 317, 11, 33, "Notes",
      CellTags->"SubwordModCounterDFA"],
    Cell[474895, 18121, 201, 6, 35, "Notes",
      CellTags->"SubwordModCounterDFA"],
    Cell[475099, 18129, 286, 11, 33, "Notes",
      CellTags->"SubwordModCounterDFA"],
    Cell[475410, 18144, 78, 1, 59, "ExampleSection",
      CellTags->"SubwordModCounterDFA"],
    Cell[475491, 18147, 138, 4, 70, "ExampleText",
      CellTags->"SubwordModCounterDFA"],
    Cell[475654, 18155, 128, 3, 70, "Input",
      CellTags->"SubwordModCounterDFA"],
    Cell[475785, 18160, 452, 14, 70, "Output",
      CellTags->"SubwordModCounterDFA"],
    Cell[476274, 18179, 110, 3, 70, "Input",
      CellTags->"SubwordModCounterDFA"],
    Cell[476387, 18184, 235, 5, 70, "Output",
      CellTags->"SubwordModCounterDFA"],
    Cell[476659, 18194, 113, 3, 70, "Input",
      CellTags->"SubwordModCounterDFA"],
    Cell[476775, 18199, 137, 3, 70, "Output",
      CellTags->"SubwordModCounterDFA"]},
  "SuffixesFA"->{
    Cell[476939, 18206, 58, 1, 31, "ObjectName",
      CellTags->"SuffixesFA"],
    Cell[477000, 18209, 61, 1, 74, "Highlight",
      CellTags->"SuffixesFA"],
    Cell[477064, 18212, 225, 8, 43, "Usage",
      CellTags->"SuffixesFA"],
    Cell[477292, 18222, 250, 9, 58, "Notes",
      CellTags->"SuffixesFA"],
    Cell[477545, 18233, 159, 7, 33, "Notes",
      CellTags->"SuffixesFA"],
    Cell[477729, 18244, 68, 1, 59, "ExampleSection",
      CellTags->"SuffixesFA"],
    Cell[477800, 18247, 86, 1, 70, "ExampleText",
      CellTags->"SuffixesFA"],
    Cell[477911, 18252, 92, 2, 70, "Input",
      CellTags->"SuffixesFA"],
    Cell[478006, 18256, 466, 14, 70, "Output",
      CellTags->"SuffixesFA"],
    Cell[478509, 18275, 110, 3, 70, "Input",
      CellTags->"SuffixesFA"],
    Cell[478622, 18280, 163, 4, 70, "Output",
      CellTags->"SuffixesFA"]},
  "SuffixFA"->{
    Cell[478812, 18288, 54, 1, 31, "ObjectName",
      CellTags->"SuffixFA"],
    Cell[478869, 18291, 59, 1, 74, "Highlight",
      CellTags->"SuffixFA"],
    Cell[478931, 18294, 222, 8, 43, "Usage",
      CellTags->"SuffixFA"],
    Cell[479156, 18304, 248, 9, 58, "Notes",
      CellTags->"SuffixFA"],
    Cell[479407, 18315, 200, 6, 33, "Notes",
      CellTags->"SuffixFA"],
    Cell[479632, 18325, 66, 1, 59, "ExampleSection",
      CellTags->"SuffixFA"],
    Cell[479701, 18328, 85, 1, 48, "ExampleText",
      CellTags->"SuffixFA"],
    Cell[479811, 18333, 82, 2, 40, "Input",
      CellTags->"SuffixFA"],
    Cell[479896, 18337, 407, 12, 53, "Output",
      CellTags->"SuffixFA"],
    Cell[480340, 18354, 104, 3, 37, "Input",
      CellTags->"SuffixFA"],
    Cell[480447, 18359, 170, 4, 30, "Output",
      CellTags->"SuffixFA"]},
  "SumFA"->{
    Cell[480644, 18367, 48, 1, 42, "ObjectName",
      CellTags->"SumFA"],
    Cell[480695, 18370, 56, 1, 74, "Highlight",
      CellTags->"SumFA"],
    Cell[480754, 18373, 199, 8, 43, "Usage",
      CellTags->"SumFA"],
    Cell[480956, 18383, 147, 5, 33, "Notes",
      CellTags->"SumFA"],
    Cell[481106, 18390, 50, 1, 33, "Notes",
      CellTags->"SumFA"],
    Cell[481159, 18393, 142, 4, 33, "Notes",
      CellTags->"SumFA"],
    Cell[481304, 18399, 350, 15, 33, "Notes",
      CellTags->"SumFA"],
    Cell[481679, 18418, 63, 1, 59, "ExampleSection",
      CellTags->"SumFA"],
    Cell[481745, 18421, 142, 4, 70, "ExampleText",
      CellTags->"SumFA"],
    Cell[481912, 18429, 132, 6, 70, "Input",
      CellTags->"SumFA"],
    Cell[482047, 18437, 379, 12, 70, "Output",
      CellTags->"SumFA"],
    Cell[482429, 18451, 379, 12, 70, "Output",
      CellTags->"SumFA"],
    Cell[482811, 18465, 548, 15, 70, "Output",
      CellTags->"SumFA"],
    Cell[483396, 18485, 100, 3, 70, "Input",
      CellTags->"SumFA"],
    Cell[483499, 18490, 116, 3, 70, "Output",
      CellTags->"SumFA"],
    Cell[483630, 18496, 140, 4, 70, "ExampleText",
      CellTags->"SumFA"],
    Cell[483795, 18504, 105, 3, 70, "Input",
      CellTags->"SumFA"],
    Cell[483903, 18509, 400, 12, 70, "Output",
      CellTags->"SumFA"],
    Cell[484340, 18526, 99, 3, 70, "Input",
      CellTags->"SumFA"],
    Cell[484442, 18531, 84, 3, 70, "Output",
      CellTags->"SumFA"]},
  "SwitchTransitionFA"->{
    Cell[484553, 18538, 74, 1, 31, "ObjectName",
      CellTags->"SwitchTransitionFA"],
    Cell[484630, 18541, 69, 1, 74, "Highlight",
      CellTags->"SwitchTransitionFA"],
    Cell[484702, 18544, 347, 12, 64, "Usage",
      CellTags->"SwitchTransitionFA"],
    Cell[485052, 18558, 245, 7, 54, "Notes",
      CellTags->"SwitchTransitionFA"],
    Cell[485300, 18567, 296, 11, 33, "Notes",
      CellTags->"SwitchTransitionFA"],
    Cell[485621, 18582, 76, 1, 59, "ExampleSection",
      CellTags->"SwitchTransitionFA"],
    Cell[485700, 18585, 200, 5, 70, "ExampleText",
      CellTags->"SwitchTransitionFA"],
    Cell[485903, 18592, 224, 5, 70, "Input",
      CellTags->"SwitchTransitionFA"],
    Cell[486152, 18601, 129, 3, 70, "Input",
      CellTags->"SwitchTransitionFA"],
    Cell[486284, 18606, 354, 10, 70, "Output",
      CellTags->"SwitchTransitionFA"],
    Cell[486675, 18621, 114, 3, 70, "Input",
      CellTags->"SwitchTransitionFA"],
    Cell[486792, 18626, 96, 3, 70, "Output",
      CellTags->"SwitchTransitionFA"]},
  "SyntacticCongruence"->{
    Cell[486915, 18633, 76, 1, 31, "ObjectName",
      CellTags->"SyntacticCongruence"],
    Cell[486994, 18636, 70, 1, 74, "Highlight",
      CellTags->"SyntacticCongruence"],
    Cell[487067, 18639, 214, 6, 43, "Usage",
      CellTags->"SyntacticCongruence"],
    Cell[487284, 18647, 212, 7, 33, "Notes",
      CellTags->"SyntacticCongruence"],
    Cell[487499, 18656, 510, 19, 33, "Notes",
      CellTags->"SyntacticCongruence"],
    Cell[488034, 18679, 77, 1, 59, "ExampleSection",
      CellTags->"SyntacticCongruence"],
    Cell[488114, 18682, 146, 4, 70, "ExampleText",
      CellTags->"SyntacticCongruence"],
    Cell[488285, 18690, 104, 2, 70, "Input",
      CellTags->"SyntacticCongruence"],
    Cell[488392, 18694, 381, 12, 70, "Output",
      CellTags->"SyntacticCongruence"],
    Cell[488810, 18711, 127, 3, 70, "Input",
      CellTags->"SyntacticCongruence"],
    Cell[488940, 18716, 165, 4, 70, "Output",
      CellTags->"SyntacticCongruence"],
    Cell[489120, 18723, 117, 2, 70, "ExampleText",
      CellTags->"SyntacticCongruence"],
    Cell[489262, 18729, 162, 4, 70, "Input",
      CellTags->"SyntacticCongruence"],
    Cell[489427, 18735, 205, 4, 70, "Output",
      CellTags->"SyntacticCongruence"]},
  "SyntacticHomomorphism"->{
    Cell[489659, 18743, 80, 1, 31, "ObjectName",
      CellTags->"SyntacticHomomorphism"],
    Cell[489742, 18746, 72, 1, 74, "Highlight",
      CellTags->"SyntacticHomomorphism"],
    Cell[489817, 18749, 196, 6, 43, "Usage",
      CellTags->"SyntacticHomomorphism"],
    Cell[490016, 18757, 122, 5, 33, "Notes",
      CellTags->"SyntacticHomomorphism"],
    Cell[490141, 18764, 284, 9, 33, "Notes",
      CellTags->"SyntacticHomomorphism"],
    Cell[490428, 18775, 412, 15, 33, "Notes",
      CellTags->"SyntacticHomomorphism"],
    Cell[490865, 18794, 79, 1, 59, "ExampleSection",
      CellTags->"SyntacticHomomorphism"],
    Cell[490947, 18797, 110, 1, 70, "ExampleText",
      CellTags->"SyntacticHomomorphism"],
    Cell[491082, 18802, 106, 2, 70, "Input",
      CellTags->"SyntacticHomomorphism"],
    Cell[491191, 18806, 383, 12, 70, "Output",
      CellTags->"SyntacticHomomorphism"],
    Cell[491589, 18821, 122, 3, 70, "Input",
      CellTags->"SyntacticHomomorphism"],
    Cell[491736, 18828, 99, 3, 70, "Input",
      CellTags->"SyntacticHomomorphism"],
    Cell[491838, 18833, 106, 3, 70, "Output",
      CellTags->"SyntacticHomomorphism"],
    Cell[491981, 18841, 124, 4, 70, "Input",
      CellTags->"SyntacticHomomorphism"],
    Cell[492108, 18847, 106, 3, 70, "Output",
      CellTags->"SyntacticHomomorphism"],
    Cell[492217, 18852, 106, 3, 70, "Output",
      CellTags->"SyntacticHomomorphism"]},
  "SyntacticSG"->{
    Cell[492350, 18859, 60, 1, 31, "ObjectName",
      CellTags->"SyntacticSG"],
    Cell[492413, 18862, 62, 1, 74, "Highlight",
      CellTags->"SyntacticSG"],
    Cell[492478, 18865, 167, 6, 43, "Usage",
      CellTags->"SyntacticSG"],
    Cell[492648, 18873, 206, 7, 33, "Notes",
      CellTags->"SyntacticSG"],
    Cell[492857, 18882, 304, 11, 33, "Notes",
      CellTags->"SyntacticSG"],
    Cell[493186, 18897, 69, 1, 59, "ExampleSection",
      CellTags->"SyntacticSG"],
    Cell[493258, 18900, 135, 4, 70, "ExampleText",
      CellTags->"SyntacticSG"],
    Cell[493418, 18908, 96, 2, 70, "Input",
      CellTags->"SyntacticSG"],
    Cell[493517, 18912, 373, 12, 70, "Output",
      CellTags->"SyntacticSG"],
    Cell[493927, 18929, 99, 3, 70, "Input",
      CellTags->"SyntacticSG"],
    Cell[494029, 18934, 124, 3, 70, "Output",
      CellTags->"SyntacticSG"]},
  "TheInitial"->{
    Cell[494180, 18941, 58, 1, 31, "ObjectName",
      CellTags->"TheInitial"],
    Cell[494241, 18944, 61, 1, 74, "Highlight",
      CellTags->"TheInitial"],
    Cell[494305, 18947, 184, 6, 43, "Usage",
      CellTags->"TheInitial"],
    Cell[494492, 18955, 157, 7, 33, "Notes",
      CellTags->"TheInitial"],
    Cell[494674, 18966, 68, 1, 59, "ExampleSection",
      CellTags->"TheInitial"],
    Cell[494745, 18969, 103, 1, 70, "ExampleText",
      CellTags->"TheInitial"],
    Cell[494873, 18974, 94, 2, 70, "Input",
      CellTags->"TheInitial"],
    Cell[494970, 18978, 383, 12, 70, "Output",
      CellTags->"TheInitial"],
    Cell[495390, 18995, 97, 3, 70, "Input",
      CellTags->"TheInitial"],
    Cell[495490, 19000, 86, 3, 70, "Output",
      CellTags->"TheInitial"]},
  "TheSinkDFA"->{
    Cell[495603, 19007, 58, 1, 31, "ObjectName",
      CellTags->"TheSinkDFA"],
    Cell[495664, 19010, 61, 1, 74, "Highlight",
      CellTags->"TheSinkDFA"],
    Cell[495728, 19013, 192, 5, 43, "Usage",
      CellTags->"TheSinkDFA"],
    Cell[495923, 19020, 254, 11, 33, "Notes",
      CellTags->"TheSinkDFA"],
    Cell[496202, 19035, 68, 1, 59, "ExampleSection",
      CellTags->"TheSinkDFA"],
    Cell[496273, 19038, 75, 1, 70, "ExampleText",
      CellTags->"TheSinkDFA"],
    Cell[496351, 19041, 146, 4, 70, "Input",
      CellTags->"TheSinkDFA"],
    Cell[496522, 19049, 97, 3, 70, "Input",
      CellTags->"TheSinkDFA"],
    Cell[496622, 19054, 86, 3, 70, "Output",
      CellTags->"TheSinkDFA"]},
  "ToBlocks"->{
    Cell[496735, 19061, 54, 1, 31, "ObjectName",
      CellTags->"ToBlocks"],
    Cell[496792, 19064, 59, 1, 74, "Highlight",
      CellTags->"ToBlocks"],
    Cell[496854, 19067, 204, 6, 43, "Usage",
      CellTags->"ToBlocks"],
    Cell[497061, 19075, 284, 10, 58, "Notes",
      CellTags->"ToBlocks"],
    Cell[497348, 19087, 132, 5, 33, "Notes",
      CellTags->"ToBlocks"],
    Cell[497483, 19094, 192, 7, 33, "Notes",
      CellTags->"ToBlocks"],
    Cell[497678, 19103, 157, 5, 33, "Notes",
      CellTags->"ToBlocks"],
    Cell[497860, 19112, 66, 1, 59, "ExampleSection",
      CellTags->"ToBlocks"],
    Cell[497929, 19115, 75, 1, 70, "ExampleText",
      CellTags->"ToBlocks"],
    Cell[498029, 19120, 89, 2, 70, "Input",
      CellTags->"ToBlocks"],
    Cell[498121, 19124, 138, 3, 70, "Output",
      CellTags->"ToBlocks"],
    Cell[498296, 19132, 106, 2, 70, "Input",
      CellTags->"ToBlocks"],
    Cell[498405, 19136, 138, 3, 70, "Output",
      CellTags->"ToBlocks"],
    Cell[498558, 19142, 67, 1, 70, "ExampleText",
      CellTags->"ToBlocks"],
    Cell[498650, 19147, 91, 2, 70, "Input",
      CellTags->"ToBlocks"],
    Cell[498744, 19151, 118, 3, 70, "Output",
      CellTags->"ToBlocks"]},
  "ToCharacters"->{
    Cell[498889, 19158, 62, 1, 31, "ObjectName",
      CellTags->"ToCharacters"],
    Cell[498954, 19161, 63, 1, 74, "Highlight",
      CellTags->"ToCharacters"],
    Cell[499020, 19164, 160, 4, 43, "Usage",
      CellTags->"ToCharacters"],
    Cell[499183, 19170, 164, 5, 33, "Notes",
      CellTags->"ToCharacters"],
    Cell[499350, 19177, 86, 1, 33, "Notes",
      CellTags->"ToCharacters"],
    Cell[499461, 19182, 70, 1, 59, "ExampleSection",
      CellTags->"ToCharacters"],
    Cell[499534, 19185, 124, 4, 70, "ExampleText",
      CellTags->"ToCharacters"],
    Cell[499683, 19193, 110, 5, 70, "Input",
      CellTags->"ToCharacters"],
    Cell[499796, 19200, 107, 3, 70, "Output",
      CellTags->"ToCharacters"],
    Cell[499906, 19205, 279, 8, 70, "Output",
      CellTags->"ToCharacters"]},
  "ToDFA"->{
    Cell[500212, 19217, 48, 1, 31, "ObjectName",
      CellTags->"ToDFA"],
    Cell[500263, 19220, 56, 1, 74, "Highlight",
      CellTags->"ToDFA"],
    Cell[500322, 19223, 142, 4, 43, "Usage",
      CellTags->"ToDFA"],
    Cell[500467, 19229, 406, 12, 130, "Notes",
      CellTags->"ToDFA"],
    Cell[500876, 19243, 208, 8, 33, "Notes",
      CellTags->"ToDFA"],
    Cell[501087, 19253, 167, 5, 33, "Notes",
      CellTags->"ToDFA"],
    Cell[501257, 19260, 209, 5, 54, "Notes",
      CellTags->"ToDFA"],
    Cell[501469, 19267, 250, 8, 54, "Notes",
      CellTags->"ToDFA"],
    Cell[501722, 19277, 150, 5, 33, "Notes",
      CellTags->"ToDFA"],
    Cell[501875, 19284, 161, 4, 54, "Notes",
      CellTags->"ToDFA"],
    Cell[502039, 19290, 316, 15, 33, "Notes",
      CellTags->"ToDFA"],
    Cell[502380, 19309, 63, 1, 59, "ExampleSection",
      CellTags->"ToDFA"],
    Cell[502446, 19312, 147, 4, 70, "ExampleText",
      CellTags->"ToDFA"],
    Cell[502596, 19318, 105, 3, 70, "Input",
      CellTags->"ToDFA"],
    Cell[502726, 19325, 146, 4, 70, "Input",
      CellTags->"ToDFA"],
    Cell[502875, 19331, 620, 17, 70, "Output",
      CellTags->"ToDFA"],
    Cell[503498, 19350, 643, 17, 70, "Output",
      CellTags->"ToDFA"],
    Cell[504178, 19372, 100, 3, 70, "Input",
      CellTags->"ToDFA"],
    Cell[504281, 19377, 85, 3, 70, "Output",
      CellTags->"ToDFA"],
    Cell[504381, 19383, 105, 2, 70, "ExampleText",
      CellTags->"ToDFA"],
    Cell[504511, 19389, 201, 5, 70, "Input",
      CellTags->"ToDFA"],
    Cell[504715, 19396, 454, 14, 70, "Output",
      CellTags->"ToDFA"],
    Cell[505172, 19412, 166, 4, 70, "Output",
      CellTags->"ToDFA"]},
  "ToEquationsDFA"->{
    Cell[505365, 19420, 66, 1, 31, "ObjectName",
      CellTags->"ToEquationsDFA"],
    Cell[505434, 19423, 65, 1, 74, "Highlight",
      CellTags->"ToEquationsDFA"],
    Cell[505502, 19426, 175, 6, 43, "Usage",
      CellTags->"ToEquationsDFA"],
    Cell[505680, 19434, 173, 4, 54, "Notes",
      CellTags->"ToEquationsDFA"],
    Cell[505856, 19440, 251, 11, 33, "Notes",
      CellTags->"ToEquationsDFA"],
    Cell[506132, 19455, 72, 1, 59, "ExampleSection",
      CellTags->"ToEquationsDFA"],
    Cell[506207, 19458, 115, 2, 70, "ExampleText",
      CellTags->"ToEquationsDFA"],
    Cell[506347, 19464, 97, 2, 70, "Input",
      CellTags->"ToEquationsDFA"],
    Cell[506447, 19468, 376, 12, 70, "Output",
      CellTags->"ToEquationsDFA"],
    Cell[506860, 19485, 122, 3, 70, "Input",
      CellTags->"ToEquationsDFA"],
    Cell[506985, 19490, 1180, 34, 70, "Output",
      CellTags->"ToEquationsDFA"],
    Cell[508180, 19527, 82, 1, 70, "ExampleText",
      CellTags->"ToEquationsDFA"],
    Cell[508287, 19532, 193, 4, 70, "Input",
      CellTags->"ToEquationsDFA"],
    Cell[508483, 19538, 1253, 33, 70, "Output",
      CellTags->"ToEquationsDFA"]},
  "ToFA"->{
    Cell[509763, 19575, 46, 1, 31, "ObjectName",
      CellTags->"ToFA"],
    Cell[509812, 19578, 55, 1, 74, "Highlight",
      CellTags->"ToFA"],
    Cell[509870, 19581, 120, 4, 43, "Usage",
      CellTags->"ToFA"],
    Cell[509993, 19587, 244, 9, 58, "Notes",
      CellTags->"ToFA"],
    Cell[510240, 19598, 116, 4, 33, "Notes",
      CellTags->"ToFA"],
    Cell[510359, 19604, 123, 4, 33, "Notes",
      CellTags->"ToFA"],
    Cell[510485, 19610, 317, 15, 33, "Notes",
      CellTags->"ToFA"],
    Cell[510827, 19629, 62, 1, 59, "ExampleSection",
      CellTags->"ToFA"],
    Cell[510892, 19632, 69, 1, 70, "ExampleText",
      CellTags->"ToFA"],
    Cell[510964, 19635, 188, 5, 70, "Input",
      CellTags->"ToFA"],
    Cell[511177, 19644, 70, 2, 70, "Input",
      CellTags->"ToFA"],
    Cell[511250, 19648, 546, 15, 70, "Output",
      CellTags->"ToFA"],
    Cell[511833, 19668, 98, 3, 70, "Input",
      CellTags->"ToFA"],
    Cell[511934, 19673, 84, 3, 70, "Output",
      CellTags->"ToFA"],
    Cell[512033, 19679, 75, 1, 70, "ExampleText",
      CellTags->"ToFA"],
    Cell[512133, 19684, 92, 3, 70, "Input",
      CellTags->"ToFA"],
    Cell[512228, 19689, 485, 14, 70, "Output",
      CellTags->"ToFA"]},
  "ToFrontierDFA"->{
    Cell[512740, 19707, 64, 1, 31, "ObjectName",
      CellTags->"ToFrontierDFA"],
    Cell[512807, 19710, 64, 1, 74, "Highlight",
      CellTags->"ToFrontierDFA"],
    Cell[512874, 19713, 223, 7, 43, "Usage",
      CellTags->"ToFrontierDFA"],
    Cell[513100, 19722, 191, 7, 33, "Notes",
      CellTags->"ToFrontierDFA"],
    Cell[513294, 19731, 335, 13, 33, "Notes",
      CellTags->"ToFrontierDFA"],
    Cell[513654, 19748, 71, 1, 59, "ExampleSection",
      CellTags->"ToFrontierDFA"],
    Cell[513728, 19751, 251, 6, 70, "ExampleText",
      CellTags->"ToFrontierDFA"],
    Cell[513982, 19759, 148, 4, 70, "Input",
      CellTags->"ToFrontierDFA"],
    Cell[514155, 19767, 229, 6, 70, "Input",
      CellTags->"ToFrontierDFA"],
    Cell[514387, 19775, 820, 19, 70, "Output",
      CellTags->"ToFrontierDFA"],
    Cell[515210, 19796, 100, 3, 70, "Output",
      CellTags->"ToFrontierDFA"],
    Cell[515325, 19802, 143, 4, 70, "ExampleText",
      CellTags->"ToFrontierDFA"],
    Cell[515493, 19810, 173, 4, 70, "Input",
      CellTags->"ToFrontierDFA"],
    Cell[515669, 19816, 92, 3, 70, "Output",
      CellTags->"ToFrontierDFA"]},
  "ToGeneratorsFA"->{
    Cell[515788, 19823, 66, 1, 31, "ObjectName",
      CellTags->"ToGeneratorsFA"],
    Cell[515857, 19826, 65, 1, 74, "Highlight",
      CellTags->"ToGeneratorsFA"],
    Cell[515925, 19829, 216, 5, 64, "Usage",
      CellTags->"ToGeneratorsFA"],
    Cell[516144, 19836, 268, 11, 33, "Notes",
      CellTags->"ToGeneratorsFA"],
    Cell[516437, 19851, 72, 1, 59, "ExampleSection",
      CellTags->"ToGeneratorsFA"],
    Cell[516512, 19854, 92, 1, 70, "ExampleText",
      CellTags->"ToGeneratorsFA"],
    Cell[516607, 19857, 197, 5, 70, "Input",
      CellTags->"ToGeneratorsFA"],
    Cell[516829, 19866, 105, 3, 70, "Input",
      CellTags->"ToGeneratorsFA"],
    Cell[516937, 19871, 163, 5, 70, "Output",
      CellTags->"ToGeneratorsFA"],
    Cell[517137, 19881, 102, 3, 70, "Input",
      CellTags->"ToGeneratorsFA"],
    Cell[517242, 19886, 512, 9, 70, "Output",
      CellTags->"ToGeneratorsFA"]},
  "ToGraphFA"->{
    Cell[517781, 19899, 56, 1, 31, "ObjectName",
      CellTags->"ToGraphFA"],
    Cell[517840, 19902, 60, 1, 74, "Highlight",
      CellTags->"ToGraphFA"],
    Cell[517903, 19905, 206, 5, 64, "Usage",
      CellTags->"ToGraphFA"],
    Cell[518112, 19912, 303, 10, 80, "Notes",
      CellTags->"ToGraphFA"],
    Cell[518418, 19924, 140, 5, 33, "Notes",
      CellTags->"ToGraphFA"],
    Cell[518561, 19931, 197, 7, 33, "Notes",
      CellTags->"ToGraphFA"],
    Cell[518783, 19942, 67, 1, 59, "ExampleSection",
      CellTags->"ToGraphFA"],
    Cell[518853, 19945, 86, 1, 70, "ExampleText",
      CellTags->"ToGraphFA"],
    Cell[518942, 19948, 214, 5, 70, "Input",
      CellTags->"ToGraphFA"],
    Cell[519181, 19957, 103, 3, 70, "Input",
      CellTags->"ToGraphFA"],
    Cell[519287, 19962, 333, 10, 70, "Output",
      CellTags->"ToGraphFA"],
    Cell[519635, 19975, 76, 1, 70, "ExampleText",
      CellTags->"ToGraphFA"],
    Cell[519736, 19980, 113, 3, 70, "Input",
      CellTags->"ToGraphFA"],
    Cell[519852, 19985, 98, 3, 70, "Output",
      CellTags->"ToGraphFA"]},
  "ToIndex"->{
    Cell[519977, 19992, 52, 1, 31, "ObjectName",
      CellTags->"ToIndex"],
    Cell[520032, 19995, 58, 1, 74, "Highlight",
      CellTags->"ToIndex"],
    Cell[520093, 19998, 214, 8, 43, "Usage",
      CellTags->"ToIndex"],
    Cell[520310, 20008, 91, 1, 33, "Notes",
      CellTags->"ToIndex"],
    Cell[520404, 20011, 90, 1, 33, "Notes",
      CellTags->"ToIndex"],
    Cell[520497, 20014, 152, 7, 33, "Notes",
      CellTags->"ToIndex"],
    Cell[520674, 20025, 65, 1, 59, "ExampleSection",
      CellTags->"ToIndex"],
    Cell[520742, 20028, 79, 1, 70, "ExampleText",
      CellTags->"ToIndex"],
    Cell[520846, 20033, 85, 2, 70, "Input",
      CellTags->"ToIndex"],
    Cell[520934, 20037, 98, 3, 70, "Output",
      CellTags->"ToIndex"],
    Cell[521069, 20045, 100, 3, 70, "Input",
      CellTags->"ToIndex"],
    Cell[521172, 20050, 90, 3, 70, "Output",
      CellTags->"ToIndex"]},
  "ToKernelFA"->{
    Cell[521289, 20057, 58, 1, 31, "ObjectName",
      CellTags->"ToKernelFA"],
    Cell[521350, 20060, 61, 1, 74, "Highlight",
      CellTags->"ToKernelFA"],
    Cell[521414, 20063, 232, 8, 43, "Usage",
      CellTags->"ToKernelFA"],
    Cell[521649, 20073, 294, 10, 80, "Notes",
      CellTags->"ToKernelFA"],
    Cell[521946, 20085, 301, 12, 33, "Notes",
      CellTags->"ToKernelFA"],
    Cell[522250, 20099, 288, 11, 33, "Notes",
      CellTags->"ToKernelFA"],
    Cell[522541, 20112, 153, 7, 33, "Notes",
      CellTags->"ToKernelFA"],
    Cell[522719, 20123, 68, 1, 59, "ExampleSection",
      CellTags->"ToKernelFA"],
    Cell[522790, 20126, 120, 4, 70, "ExampleText",
      CellTags->"ToKernelFA"],
    Cell[522913, 20132, 220, 5, 70, "Input",
      CellTags->"ToKernelFA"],
    Cell[523158, 20141, 125, 4, 70, "Input",
      CellTags->"ToKernelFA"],
    Cell[523286, 20147, 421, 11, 70, "Output",
      CellTags->"ToKernelFA"],
    Cell[523710, 20160, 146, 4, 70, "Output",
      CellTags->"ToKernelFA"],
    Cell[523893, 20169, 130, 4, 70, "Input",
      CellTags->"ToKernelFA"],
    Cell[524026, 20175, 421, 11, 70, "Output",
      CellTags->"ToKernelFA"],
    Cell[524450, 20188, 134, 3, 70, "Output",
      CellTags->"ToKernelFA"],
    Cell[524599, 20194, 151, 5, 70, "ExampleText",
      CellTags->"ToKernelFA"],
    Cell[524775, 20203, 141, 4, 70, "Input",
      CellTags->"ToKernelFA"],
    Cell[524919, 20209, 421, 11, 70, "Output",
      CellTags->"ToKernelFA"],
    Cell[525343, 20222, 157, 4, 70, "Output",
      CellTags->"ToKernelFA"]},
  "ToLabelCA"->{
    Cell[525527, 20230, 56, 1, 31, "ObjectName",
      CellTags->"ToLabelCA"],
    Cell[525586, 20233, 60, 1, 74, "Highlight",
      CellTags->"ToLabelCA"],
    Cell[525649, 20236, 160, 4, 43, "Usage",
      CellTags->"ToLabelCA"],
    Cell[525812, 20242, 121, 4, 33, "Notes",
      CellTags->"ToLabelCA"],
    Cell[525958, 20250, 67, 1, 59, "ExampleSection",
      CellTags->"ToLabelCA"],
    Cell[526028, 20253, 74, 1, 70, "ExampleText",
      CellTags->"ToLabelCA"],
    Cell[526127, 20258, 108, 5, 70, "Input",
      CellTags->"ToLabelCA"],
    Cell[526238, 20265, 124, 3, 70, "Output",
      CellTags->"ToLabelCA"],
    Cell[526365, 20270, 314, 9, 70, "Output",
      CellTags->"ToLabelCA"]},
  "ToNFA"->{
    Cell[526706, 20283, 48, 1, 31, "ObjectName",
      CellTags->"ToNFA"],
    Cell[526757, 20286, 56, 1, 74, "Highlight",
      CellTags->"ToNFA"],
    Cell[526816, 20289, 150, 6, 43, "Usage",
      CellTags->"ToNFA"],
    Cell[526969, 20297, 117, 4, 33, "Notes",
      CellTags->"ToNFA"],
    Cell[527089, 20303, 317, 15, 33, "Notes",
      CellTags->"ToNFA"],
    Cell[527431, 20322, 63, 1, 59, "ExampleSection",
      CellTags->"ToNFA"],
    Cell[527497, 20325, 86, 1, 70, "ExampleText",
      CellTags->"ToNFA"],
    Cell[527586, 20328, 214, 5, 70, "Input",
      CellTags->"ToNFA"],
    Cell[527825, 20337, 87, 3, 70, "Input",
      CellTags->"ToNFA"],
    Cell[527915, 20342, 413, 12, 70, "Output",
      CellTags->"ToNFA"],
    Cell[528365, 20359, 111, 3, 70, "Input",
      CellTags->"ToNFA"],
    Cell[528479, 20364, 339, 9, 70, "Output",
      CellTags->"ToNFA"]},
  "ToPeriodicFrontierDFA"->{
    Cell[528845, 20377, 80, 1, 31, "ObjectName",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[528928, 20380, 72, 1, 74, "Highlight",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[529003, 20383, 216, 5, 64, "Usage",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[529222, 20390, 369, 12, 54, "Notes",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[529594, 20404, 64, 1, 33, "Notes",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[529661, 20407, 327, 13, 33, "Notes",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[530013, 20424, 79, 1, 59, "ExampleSection",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[530095, 20427, 259, 6, 70, "ExampleText",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[530357, 20435, 156, 4, 70, "Input",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[530538, 20443, 185, 5, 70, "Input",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[530726, 20450, 828, 19, 70, "Output",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[531569, 20472, 199, 5, 70, "ExampleText",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[531793, 20481, 241, 6, 70, "Input",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[532037, 20489, 943, 21, 70, "Output",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[532983, 20512, 115, 3, 70, "Output",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[533113, 20518, 151, 4, 70, "ExampleText",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[533289, 20526, 181, 4, 70, "Input",
      CellTags->"ToPeriodicFrontierDFA"],
    Cell[533473, 20532, 100, 3, 70, "Output",
      CellTags->"ToPeriodicFrontierDFA"]},
  "ToPrefixFA"->{
    Cell[533600, 20539, 58, 1, 31, "ObjectName",
      CellTags->"ToPrefixFA"],
    Cell[533661, 20542, 61, 1, 74, "Highlight",
      CellTags->"ToPrefixFA"],
    Cell[533725, 20545, 200, 5, 64, "Usage",
      CellTags->"ToPrefixFA"],
    Cell[533928, 20552, 53, 1, 33, "Notes",
      CellTags->"ToPrefixFA"],
    Cell[533984, 20555, 123, 4, 33, "Notes",
      CellTags->"ToPrefixFA"],
    Cell[534110, 20561, 163, 7, 33, "Notes",
      CellTags->"ToPrefixFA"],
    Cell[534298, 20572, 68, 1, 59, "ExampleSection",
      CellTags->"ToPrefixFA"],
    Cell[534369, 20575, 169, 6, 70, "ExampleText",
      CellTags->"ToPrefixFA"],
    Cell[534563, 20585, 111, 3, 70, "Input",
      CellTags->"ToPrefixFA"],
    Cell[534677, 20590, 378, 12, 70, "Output",
      CellTags->"ToPrefixFA"],
    Cell[535092, 20607, 106, 3, 70, "Input",
      CellTags->"ToPrefixFA"],
    Cell[535201, 20612, 384, 12, 70, "Output",
      CellTags->"ToPrefixFA"],
    Cell[535600, 20627, 159, 6, 70, "ExampleText",
      CellTags->"ToPrefixFA"],
    Cell[535784, 20637, 112, 3, 70, "Input",
      CellTags->"ToPrefixFA"],
    Cell[535899, 20642, 469, 8, 70, "Output",
      CellTags->"ToPrefixFA"],
    Cell[536405, 20655, 129, 3, 70, "Input",
      CellTags->"ToPrefixFA"],
    Cell[536537, 20660, 89, 3, 70, "Output",
      CellTags->"ToPrefixFA"]},
  "ToPrefix"->{
    Cell[536653, 20667, 54, 1, 31, "ObjectName",
      CellTags->"ToPrefix"],
    Cell[536710, 20670, 59, 1, 74, "Highlight",
      CellTags->"ToPrefix"],
    Cell[536772, 20673, 176, 5, 43, "Usage",
      CellTags->"ToPrefix"],
    Cell[536951, 20680, 156, 6, 33, "Notes",
      CellTags->"ToPrefix"],
    Cell[537110, 20688, 156, 5, 33, "Notes",
      CellTags->"ToPrefix"],
    Cell[537269, 20695, 268, 11, 33, "Notes",
      CellTags->"ToPrefix"],
    Cell[537562, 20710, 66, 1, 59, "ExampleSection",
      CellTags->"ToPrefix"],
    Cell[537631, 20713, 90, 1, 70, "ExampleText",
      CellTags->"ToPrefix"],
    Cell[537746, 20718, 185, 4, 70, "Input",
      CellTags->"ToPrefix"],
    Cell[537934, 20724, 117, 3, 70, "Output",
      CellTags->"ToPrefix"],
    Cell[538088, 20732, 77, 2, 70, "Input",
      CellTags->"ToPrefix"],
    Cell[538168, 20736, 123, 3, 70, "Output",
      CellTags->"ToPrefix"]},
  "ToRegExp"->{
    Cell[538318, 20743, 54, 1, 31, "ObjectName",
      CellTags->"ToRegExp"],
    Cell[538375, 20746, 59, 1, 74, "Highlight",
      CellTags->"ToRegExp"],
    Cell[538437, 20749, 365, 12, 64, "Usage",
      CellTags->"ToRegExp"],
    Cell[538805, 20763, 138, 4, 33, "Notes",
      CellTags->"ToRegExp"],
    Cell[538946, 20769, 432, 19, 33, "Notes",
      CellTags->"ToRegExp"],
    Cell[539403, 20792, 66, 1, 59, "ExampleSection",
      CellTags->"ToRegExp"],
    Cell[539472, 20795, 150, 4, 70, "ExampleText",
      CellTags->"ToRegExp"],
    Cell[539647, 20803, 111, 2, 70, "Input",
      CellTags->"ToRegExp"],
    Cell[539761, 20807, 152, 4, 70, "Output",
      CellTags->"ToRegExp"],
    Cell[539950, 20816, 94, 3, 70, "Input",
      CellTags->"ToRegExp"],
    Cell[540047, 20821, 165, 5, 70, "Output",
      CellTags->"ToRegExp"]},
  "ToRegularExpressionFA"->{
    Cell[540239, 20830, 80, 1, 31, "ObjectName",
      CellTags->"ToRegularExpressionFA"],
    Cell[540322, 20833, 72, 1, 74, "Highlight",
      CellTags->"ToRegularExpressionFA"],
    Cell[540397, 20836, 200, 5, 64, "Usage",
      CellTags->"ToRegularExpressionFA"],
    Cell[540600, 20843, 290, 10, 80, "Notes",
      CellTags->"ToRegularExpressionFA"],
    Cell[540893, 20855, 223, 6, 54, "Notes",
      CellTags->"ToRegularExpressionFA"],
    Cell[541119, 20863, 131, 4, 33, "Notes",
      CellTags->"ToRegularExpressionFA"],
    Cell[541253, 20869, 270, 11, 33, "Notes",
      CellTags->"ToRegularExpressionFA"],
    Cell[541548, 20884, 79, 1, 59, "ExampleSection",
      CellTags->"ToRegularExpressionFA"],
    Cell[541630, 20887, 93, 1, 70, "ExampleText",
      CellTags->"ToRegularExpressionFA"],
    Cell[541726, 20890, 225, 5, 70, "Input",
      CellTags->"ToRegularExpressionFA"],
    Cell[541976, 20899, 119, 3, 70, "Input",
      CellTags->"ToRegularExpressionFA"],
    Cell[542098, 20904, 203, 4, 70, "Output",
      CellTags->"ToRegularExpressionFA"],
    Cell[542338, 20913, 173, 4, 70, "Input",
      CellTags->"ToRegularExpressionFA"],
    Cell[542514, 20919, 212, 4, 70, "Output",
      CellTags->"ToRegularExpressionFA"],
    Cell[542741, 20926, 256, 7, 70, "ExampleText",
      CellTags->"ToRegularExpressionFA"]},
  "ToRulesCA"->{
    Cell[543012, 20936, 56, 1, 31, "ObjectName",
      CellTags->"ToRulesCA"],
    Cell[543071, 20939, 60, 1, 74, "Highlight",
      CellTags->"ToRulesCA"],
    Cell[543134, 20942, 200, 5, 64, "Usage",
      CellTags->"ToRulesCA"],
    Cell[543337, 20949, 227, 9, 58, "Notes",
      CellTags->"ToRulesCA"],
    Cell[543567, 20960, 164, 5, 33, "Notes",
      CellTags->"ToRulesCA"],
    Cell[543756, 20969, 67, 1, 59, "ExampleSection",
      CellTags->"ToRulesCA"],
    Cell[543826, 20972, 165, 6, 70, "ExampleText",
      CellTags->"ToRulesCA"],
    Cell[544016, 20982, 100, 3, 70, "Input",
      CellTags->"ToRulesCA"],
    Cell[544119, 20987, 664, 17, 70, "Output",
      CellTags->"ToRulesCA"],
    Cell[544798, 21007, 66, 1, 70, "ExampleText",
      CellTags->"ToRulesCA"],
    Cell[544889, 21012, 123, 3, 70, "Input",
      CellTags->"ToRulesCA"],
    Cell[545015, 21017, 699, 18, 70, "Output",
      CellTags->"ToRulesCA"]},
  "ToSA"->{
    Cell[545741, 21039, 46, 1, 31, "ObjectName",
      CellTags->"ToSA"],
    Cell[545790, 21042, 55, 1, 74, "Highlight",
      CellTags->"ToSA"],
    Cell[545848, 21045, 154, 4, 43, "Usage",
      CellTags->"ToSA"],
    Cell[546005, 21051, 244, 9, 58, "Notes",
      CellTags->"ToSA"],
    Cell[546252, 21062, 127, 4, 33, "Notes",
      CellTags->"ToSA"],
    Cell[546382, 21068, 137, 4, 33, "Notes",
      CellTags->"ToSA"],
    Cell[546522, 21074, 317, 15, 33, "Notes",
      CellTags->"ToSA"],
    Cell[546864, 21093, 62, 1, 59, "ExampleSection",
      CellTags->"ToSA"],
    Cell[546929, 21096, 89, 1, 70, "ExampleText",
      CellTags->"ToSA"],
    Cell[547043, 21101, 83, 2, 70, "Input",
      CellTags->"ToSA"],
    Cell[547129, 21105, 378, 12, 70, "Output",
      CellTags->"ToSA"],
    Cell[547544, 21122, 85, 3, 70, "Input",
      CellTags->"ToSA"],
    Cell[547632, 21127, 361, 10, 70, "Output",
      CellTags->"ToSA"],
    Cell[548030, 21142, 97, 3, 70, "Input",
      CellTags->"ToSA"],
    Cell[548130, 21147, 83, 3, 70, "Output",
      CellTags->"ToSA"]},
  "ToSeries"->{
    Cell[548240, 21154, 54, 1, 31, "ObjectName",
      CellTags->"ToSeries"],
    Cell[548297, 21157, 59, 1, 74, "Highlight",
      CellTags->"ToSeries"],
    Cell[548359, 21160, 223, 7, 64, "Usage",
      CellTags->"ToSeries"],
    Cell[548585, 21169, 141, 5, 33, "Notes",
      CellTags->"ToSeries"],
    Cell[548729, 21176, 256, 11, 33, "Notes",
      CellTags->"ToSeries"],
    Cell[549010, 21191, 66, 1, 59, "ExampleSection",
      CellTags->"ToSeries"],
    Cell[549079, 21194, 62, 1, 70, "ExampleText",
      CellTags->"ToSeries"],
    Cell[549144, 21197, 88, 2, 70, "Input",
      CellTags->"ToSeries"],
    Cell[549257, 21203, 131, 3, 70, "Input",
      CellTags->"ToSeries"],
    Cell[549391, 21208, 319, 6, 70, "Output",
      CellTags->"ToSeries"],
    Cell[549747, 21219, 93, 3, 70, "Input",
      CellTags->"ToSeries"],
    Cell[549843, 21224, 303, 6, 70, "Output",
      CellTags->"ToSeries"]},
  "ToSuffixFA"->{
    Cell[550173, 21234, 58, 1, 31, "ObjectName",
      CellTags->"ToSuffixFA"],
    Cell[550234, 21237, 61, 1, 74, "Highlight",
      CellTags->"ToSuffixFA"],
    Cell[550298, 21240, 200, 5, 64, "Usage",
      CellTags->"ToSuffixFA"],
    Cell[550501, 21247, 123, 4, 33, "Notes",
      CellTags->"ToSuffixFA"],
    Cell[550627, 21253, 163, 7, 33, "Notes",
      CellTags->"ToSuffixFA"],
    Cell[550815, 21264, 68, 1, 59, "ExampleSection",
      CellTags->"ToSuffixFA"],
    Cell[550886, 21267, 169, 6, 70, "ExampleText",
      CellTags->"ToSuffixFA"],
    Cell[551080, 21277, 111, 3, 70, "Input",
      CellTags->"ToSuffixFA"],
    Cell[551194, 21282, 378, 12, 70, "Output",
      CellTags->"ToSuffixFA"],
    Cell[551609, 21299, 106, 3, 70, "Input",
      CellTags->"ToSuffixFA"],
    Cell[551718, 21304, 478, 14, 70, "Output",
      CellTags->"ToSuffixFA"],
    Cell[552211, 21321, 159, 6, 70, "ExampleText",
      CellTags->"ToSuffixFA"],
    Cell[552395, 21331, 112, 3, 70, "Input",
      CellTags->"ToSuffixFA"],
    Cell[552510, 21336, 469, 8, 70, "Output",
      CellTags->"ToSuffixFA"],
    Cell[553016, 21349, 129, 3, 70, "Input",
      CellTags->"ToSuffixFA"],
    Cell[553148, 21354, 89, 3, 70, "Output",
      CellTags->"ToSuffixFA"]},
  "TotalisticRuleToCA"->{
    Cell[553264, 21361, 74, 1, 31, "ObjectName",
      CellTags->"TotalisticRuleToCA"],
    Cell[553341, 21364, 69, 1, 74, "Highlight",
      CellTags->"TotalisticRuleToCA"],
    Cell[553413, 21367, 184, 4, 43, "Usage",
      CellTags->"TotalisticRuleToCA"],
    Cell[553600, 21373, 176, 6, 33, "Notes",
      CellTags->"TotalisticRuleToCA"],
    Cell[553779, 21381, 187, 7, 33, "Notes",
      CellTags->"TotalisticRuleToCA"],
    Cell[553991, 21392, 76, 1, 59, "ExampleSection",
      CellTags->"TotalisticRuleToCA"],
    Cell[554070, 21395, 133, 4, 70, "ExampleText",
      CellTags->"TotalisticRuleToCA"],
    Cell[554228, 21403, 101, 2, 70, "Input",
      CellTags->"TotalisticRuleToCA"],
    Cell[554332, 21407, 95, 3, 70, "Output",
      CellTags->"TotalisticRuleToCA"],
    Cell[554464, 21415, 140, 3, 70, "Input",
      CellTags->"TotalisticRuleToCA"],
    Cell[554607, 21420, 442, 8, 70, "Output",
      CellTags->"TotalisticRuleToCA"]},
  "ToTotalisticRuleCA"->{
    Cell[555076, 21432, 74, 1, 31, "ObjectName",
      CellTags->"ToTotalisticRuleCA"],
    Cell[555153, 21435, 69, 1, 74, "Highlight",
      CellTags->"ToTotalisticRuleCA"],
    Cell[555225, 21438, 169, 4, 43, "Usage",
      CellTags->"ToTotalisticRuleCA"],
    Cell[555397, 21444, 103, 1, 33, "Notes",
      CellTags->"ToTotalisticRuleCA"],
    Cell[555503, 21447, 187, 7, 33, "Notes",
      CellTags->"ToTotalisticRuleCA"],
    Cell[555715, 21458, 76, 1, 59, "ExampleSection",
      CellTags->"ToTotalisticRuleCA"],
    Cell[555794, 21461, 80, 1, 70, "ExampleText",
      CellTags->"ToTotalisticRuleCA"],
    Cell[555899, 21466, 107, 2, 70, "Input",
      CellTags->"ToTotalisticRuleCA"],
    Cell[556009, 21470, 95, 3, 70, "Output",
      CellTags->"ToTotalisticRuleCA"]},
  "ToTransitions"->{
    Cell[556131, 21477, 64, 1, 31, "ObjectName",
      CellTags->"ToTransitions"],
    Cell[556198, 21480, 64, 1, 74, "Highlight",
      CellTags->"ToTransitions"],
    Cell[556265, 21483, 238, 5, 64, "Usage",
      CellTags->"ToTransitions"],
    Cell[556506, 21490, 117, 4, 33, "Notes",
      CellTags->"ToTransitions"],
    Cell[556648, 21498, 71, 1, 59, "ExampleSection",
      CellTags->"ToTransitions"],
    Cell[556722, 21501, 163, 4, 70, "ExampleText",
      CellTags->"ToTransitions"],
    Cell[556910, 21509, 114, 2, 70, "Input",
      CellTags->"ToTransitions"],
    Cell[557027, 21513, 111, 3, 70, "Output",
      CellTags->"ToTransitions"]},
  "ToWord"->{
    Cell[557165, 21520, 50, 1, 31, "ObjectName",
      CellTags->"ToWord"],
    Cell[557218, 21523, 57, 1, 74, "Highlight",
      CellTags->"ToWord"],
    Cell[557278, 21526, 196, 7, 43, "Usage",
      CellTags->"ToWord"],
    Cell[557477, 21535, 132, 5, 33, "Notes",
      CellTags->"ToWord"],
    Cell[557612, 21542, 118, 4, 33, "Notes",
      CellTags->"ToWord"],
    Cell[557755, 21550, 64, 1, 59, "ExampleSection",
      CellTags->"ToWord"],
    Cell[557822, 21553, 85, 1, 70, "ExampleText",
      CellTags->"ToWord"],
    Cell[557932, 21558, 84, 2, 70, "Input",
      CellTags->"ToWord"],
    Cell[558019, 21562, 89, 3, 70, "Output",
      CellTags->"ToWord"],
    Cell[558145, 21570, 99, 2, 70, "Input",
      CellTags->"ToWord"],
    Cell[558247, 21574, 92, 3, 70, "Output",
      CellTags->"ToWord"]},
  "TransferSequenceFA"->{
    Cell[558366, 21581, 74, 1, 31, "ObjectName",
      CellTags->"TransferSequenceFA"],
    Cell[558443, 21584, 69, 1, 74, "Highlight",
      CellTags->"TransferSequenceFA"],
    Cell[558515, 21587, 477, 16, 64, "Usage",
      CellTags->"TransferSequenceFA"],
    Cell[558995, 21605, 171, 7, 33, "Notes",
      CellTags->"TransferSequenceFA"],
    Cell[559169, 21614, 318, 9, 54, "Notes",
      CellTags->"TransferSequenceFA"],
    Cell[559512, 21627, 76, 1, 59, "ExampleSection",
      CellTags->"TransferSequenceFA"],
    Cell[559591, 21630, 90, 1, 48, "ExampleText",
      CellTags->"TransferSequenceFA"],
    Cell[559684, 21633, 207, 5, 60, "Input",
      CellTags->"TransferSequenceFA"],
    Cell[559916, 21642, 99, 2, 40, "Input",
      CellTags->"TransferSequenceFA"],
    Cell[560018, 21646, 123, 3, 30, "Output",
      CellTags->"TransferSequenceFA"],
    Cell[560178, 21654, 133, 2, 40, "Input",
      CellTags->"TransferSequenceFA"],
    Cell[560314, 21658, 1353, 27, 216, "Output",
      CellTags->"TransferSequenceFA"]},
  "TransitionFunctionFA"->{
    Cell[561694, 21689, 78, 1, 42, "ObjectName",
      CellTags->"TransitionFunctionFA"],
    Cell[561775, 21692, 71, 1, 74, "Highlight",
      CellTags->"TransitionFunctionFA"],
    Cell[561849, 21695, 317, 7, 64, "Usage",
      CellTags->"TransitionFunctionFA"],
    Cell[562169, 21704, 236, 9, 58, "Notes",
      CellTags->"TransitionFunctionFA"],
    Cell[562408, 21715, 120, 5, 33, "Notes",
      CellTags->"TransitionFunctionFA"],
    Cell[562531, 21722, 172, 5, 33, "Notes",
      CellTags->"TransitionFunctionFA"],
    Cell[562706, 21729, 176, 7, 33, "Notes",
      CellTags->"TransitionFunctionFA"],
    Cell[562907, 21740, 78, 1, 59, "ExampleSection",
      CellTags->"TransitionFunctionFA"],
    Cell[562988, 21743, 108, 1, 70, "ExampleText",
      CellTags->"TransitionFunctionFA"],
    Cell[563121, 21748, 215, 5, 70, "Input",
      CellTags->"TransitionFunctionFA"],
    Cell[563339, 21755, 97, 3, 70, "Output",
      CellTags->"TransitionFunctionFA"],
    Cell[563451, 21761, 107, 1, 70, "ExampleText",
      CellTags->"TransitionFunctionFA"],
    Cell[563583, 21766, 244, 6, 70, "Input",
      CellTags->"TransitionFunctionFA"],
    Cell[563830, 21774, 108, 3, 70, "Output",
      CellTags->"TransitionFunctionFA"],
    Cell[563941, 21779, 98, 3, 70, "Output",
      CellTags->"TransitionFunctionFA"],
    Cell[564054, 21785, 101, 1, 70, "ExampleText",
      CellTags->"TransitionFunctionFA"],
    Cell[564180, 21790, 215, 5, 70, "Input",
      CellTags->"TransitionFunctionFA"],
    Cell[564398, 21797, 134, 3, 70, "Output",
      CellTags->"TransitionFunctionFA"],
    Cell[564535, 21802, 115, 3, 70, "Output",
      CellTags->"TransitionFunctionFA"]},
  "TransitionMatrixFA"->{
    Cell[564677, 21809, 74, 1, 31, "ObjectName",
      CellTags->"TransitionMatrixFA"],
    Cell[564754, 21812, 69, 1, 74, "Highlight",
      CellTags->"TransitionMatrixFA"],
    Cell[564826, 21815, 493, 12, 85, "Usage",
      CellTags->"TransitionMatrixFA"],
    Cell[565322, 21829, 251, 9, 58, "Notes",
      CellTags->"TransitionMatrixFA"],
    Cell[565576, 21840, 118, 5, 33, "Notes",
      CellTags->"TransitionMatrixFA"],
    Cell[565697, 21847, 144, 5, 33, "Notes",
      CellTags->"TransitionMatrixFA"],
    Cell[565844, 21854, 147, 5, 33, "Notes",
      CellTags->"TransitionMatrixFA"],
    Cell[565994, 21861, 314, 11, 33, "Notes",
      CellTags->"TransitionMatrixFA"],
    Cell[566333, 21876, 76, 1, 59, "ExampleSection",
      CellTags->"TransitionMatrixFA"],
    Cell[566412, 21879, 185, 5, 70, "ExampleText",
      CellTags->"TransitionMatrixFA"],
    Cell[566600, 21886, 167, 4, 70, "Input",
      CellTags->"TransitionMatrixFA"],
    Cell[566792, 21894, 117, 3, 70, "Input",
      CellTags->"TransitionMatrixFA"],
    Cell[566912, 21899, 446, 12, 70, "Output",
      CellTags->"TransitionMatrixFA"],
    Cell[567395, 21916, 118, 3, 70, "Input",
      CellTags->"TransitionMatrixFA"],
    Cell[567516, 21921, 446, 12, 70, "Output",
      CellTags->"TransitionMatrixFA"]},
  "TransitionsToMatrix"->{
    Cell[567989, 21937, 76, 1, 31, "ObjectName",
      CellTags->"TransitionsToMatrix"],
    Cell[568068, 21940, 70, 1, 74, "Highlight",
      CellTags->"TransitionsToMatrix"],
    Cell[568141, 21943, 221, 5, 64, "Usage",
      CellTags->"TransitionsToMatrix"],
    Cell[568365, 21950, 252, 5, 54, "Notes",
      CellTags->"TransitionsToMatrix"],
    Cell[568642, 21959, 77, 1, 59, "ExampleSection",
      CellTags->"TransitionsToMatrix"],
    Cell[568722, 21962, 73, 1, 70, "ExampleText",
      CellTags->"TransitionsToMatrix"],
    Cell[568820, 21967, 77, 2, 70, "Input",
      CellTags->"TransitionsToMatrix"],
    Cell[568900, 21971, 94, 3, 70, "Output",
      CellTags->"TransitionsToMatrix"]},
  "Transitions"->{
    Cell[569021, 21978, 60, 1, 31, "ObjectName",
      CellTags->"Transitions"],
    Cell[569084, 21981, 62, 1, 74, "Highlight",
      CellTags->"Transitions"],
    Cell[569149, 21984, 214, 5, 64, "Usage",
      CellTags->"Transitions"],
    Cell[569366, 21991, 371, 12, 54, "Notes",
      CellTags->"Transitions"],
    Cell[569740, 22005, 293, 11, 33, "Notes",
      CellTags->"Transitions"],
    Cell[570058, 22020, 69, 1, 59, "ExampleSection",
      CellTags->"Transitions"],
    Cell[570130, 22023, 124, 4, 70, "ExampleText",
      CellTags->"Transitions"],
    Cell[570279, 22031, 120, 5, 70, "Input",
      CellTags->"Transitions"],
    Cell[570402, 22038, 132, 3, 70, "Output",
      CellTags->"Transitions"],
    Cell[570571, 22046, 114, 5, 70, "Input",
      CellTags->"Transitions"],
    Cell[570688, 22053, 172, 4, 70, "Output",
      CellTags->"Transitions"]},
  "TransitiveLangQFA"->{
    Cell[570887, 22061, 72, 1, 31, "ObjectName",
      CellTags->"TransitiveLangQFA"],
    Cell[570962, 22064, 68, 1, 74, "Highlight",
      CellTags->"TransitiveLangQFA"],
    Cell[571033, 22067, 194, 6, 43, "Usage",
      CellTags->"TransitiveLangQFA"],
    Cell[571230, 22075, 255, 9, 58, "Notes",
      CellTags->"TransitiveLangQFA"],
    Cell[571488, 22086, 110, 1, 33, "Notes",
      CellTags->"TransitiveLangQFA"],
    Cell[571601, 22089, 176, 7, 33, "Notes",
      CellTags->"TransitiveLangQFA"],
    Cell[571802, 22100, 75, 1, 59, "ExampleSection",
      CellTags->"TransitiveLangQFA"],
    Cell[571880, 22103, 129, 4, 70, "ExampleText",
      CellTags->"TransitiveLangQFA"],
    Cell[572034, 22111, 94, 2, 70, "Input",
      CellTags->"TransitiveLangQFA"],
    Cell[572131, 22115, 356, 10, 70, "Output",
      CellTags->"TransitiveLangQFA"],
    Cell[572524, 22130, 112, 3, 70, "Input",
      CellTags->"TransitiveLangQFA"],
    Cell[572639, 22135, 97, 3, 70, "Output",
      CellTags->"TransitiveLangQFA"]},
  "TransitiveQFA"->{
    Cell[572763, 22142, 64, 1, 31, "ObjectName",
      CellTags->"TransitiveQFA"],
    Cell[572830, 22145, 64, 1, 74, "Highlight",
      CellTags->"TransitiveQFA"],
    Cell[572897, 22148, 138, 4, 43, "Usage",
      CellTags->"TransitiveQFA"],
    Cell[573038, 22154, 299, 10, 80, "Notes",
      CellTags->"TransitiveQFA"],
    Cell[573340, 22166, 201, 6, 54, "Notes",
      CellTags->"TransitiveQFA"],
    Cell[573544, 22174, 180, 7, 33, "Notes",
      CellTags->"TransitiveQFA"],
    Cell[573749, 22185, 71, 1, 59, "ExampleSection",
      CellTags->"TransitiveQFA"],
    Cell[573823, 22188, 151, 4, 70, "ExampleText",
      CellTags->"TransitiveQFA"],
    Cell[573999, 22196, 90, 2, 70, "Input",
      CellTags->"TransitiveQFA"],
    Cell[574092, 22200, 352, 10, 70, "Output",
      CellTags->"TransitiveQFA"],
    Cell[574481, 22215, 104, 3, 70, "Input",
      CellTags->"TransitiveQFA"],
    Cell[574588, 22220, 93, 3, 70, "Output",
      CellTags->"TransitiveQFA"],
    Cell[574718, 22228, 126, 3, 70, "Input",
      CellTags->"TransitiveQFA"],
    Cell[574847, 22233, 103, 3, 70, "Output",
      CellTags->"TransitiveQFA"]},
  "TrimFA"->{
    Cell[574977, 22240, 50, 1, 31, "ObjectName",
      CellTags->"TrimFA"],
    Cell[575030, 22243, 57, 1, 74, "Highlight",
      CellTags->"TrimFA"],
    Cell[575090, 22246, 232, 5, 64, "Usage",
      CellTags->"TrimFA"],
    Cell[575325, 22253, 246, 9, 58, "Notes",
      CellTags->"TrimFA"],
    Cell[575574, 22264, 196, 5, 54, "Notes",
      CellTags->"TrimFA"],
    Cell[575773, 22271, 270, 11, 33, "Notes",
      CellTags->"TrimFA"],
    Cell[576068, 22286, 64, 1, 59, "ExampleSection",
      CellTags->"TrimFA"],
    Cell[576135, 22289, 157, 4, 70, "MathCaption",
      CellTags->"TrimFA"],
    Cell[576317, 22297, 181, 5, 70, "Input",
      CellTags->"TrimFA"],
    Cell[576501, 22304, 394, 12, 70, "Output",
      CellTags->"TrimFA"],
    Cell[576932, 22321, 138, 4, 70, "Input",
      CellTags->"TrimFA"],
    Cell[577073, 22327, 372, 12, 70, "Output",
      CellTags->"TrimFA"],
    Cell[577448, 22341, 86, 3, 70, "Output",
      CellTags->"TrimFA"]},
  "TropicalIdentityMatrix"->{
    Cell[577561, 22348, 82, 1, 31, "ObjectName",
      CellTags->"TropicalIdentityMatrix"],
    Cell[577646, 22351, 73, 1, 74, "Highlight",
      CellTags->"TropicalIdentityMatrix"],
    Cell[577722, 22354, 239, 8, 43, "Usage",
      CellTags->"TropicalIdentityMatrix"],
    Cell[577964, 22364, 357, 15, 33, "Notes",
      CellTags->"TropicalIdentityMatrix"],
    Cell[578346, 22383, 80, 1, 59, "ExampleSection",
      CellTags->"TropicalIdentityMatrix"],
    Cell[578429, 22386, 172, 6, 70, "ExampleText",
      CellTags->"TropicalIdentityMatrix"],
    Cell[578626, 22396, 120, 2, 70, "Input",
      CellTags->"TropicalIdentityMatrix"],
    Cell[578749, 22400, 1375, 35, 70, "Output",
      CellTags->"TropicalIdentityMatrix"]},
  "UnionFA"->{
    Cell[580151, 22439, 52, 1, 31, "ObjectName",
      CellTags->"UnionFA"],
    Cell[580206, 22442, 58, 1, 74, "Highlight",
      CellTags->"UnionFA"],
    Cell[580267, 22445, 250, 9, 64, "Usage",
      CellTags->"UnionFA"],
    Cell[580520, 22456, 292, 10, 80, "Notes",
      CellTags->"UnionFA"],
    Cell[580815, 22468, 134, 5, 33, "Notes",
      CellTags->"UnionFA"],
    Cell[580952, 22475, 195, 8, 33, "Notes",
      CellTags->"UnionFA"],
    Cell[581150, 22485, 134, 4, 33, "Notes",
      CellTags->"UnionFA"],
    Cell[581287, 22491, 52, 1, 33, "Notes",
      CellTags->"UnionFA"],
    Cell[581342, 22494, 348, 15, 33, "Notes",
      CellTags->"UnionFA"],
    Cell[581715, 22513, 65, 1, 59, "ExampleSection",
      CellTags->"UnionFA"],
    Cell[581783, 22516, 198, 5, 70, "ExampleText",
      CellTags->"UnionFA"],
    Cell[582006, 22525, 160, 4, 70, "Input",
      CellTags->"UnionFA"],
    Cell[582169, 22531, 358, 12, 70, "Output",
      CellTags->"UnionFA"],
    Cell[582530, 22545, 361, 12, 70, "Output",
      CellTags->"UnionFA"],
    Cell[582906, 22560, 123, 4, 70, "ExampleText",
      CellTags->"UnionFA"],
    Cell[583054, 22568, 168, 4, 70, "Input",
      CellTags->"UnionFA"],
    Cell[583225, 22574, 404, 12, 70, "Output",
      CellTags->"UnionFA"],
    Cell[583632, 22588, 167, 4, 70, "Output",
      CellTags->"UnionFA"]},
  "VerifyFA"->{
    Cell[583826, 22596, 54, 1, 31, "ObjectName",
      CellTags->"VerifyFA"],
    Cell[583883, 22599, 59, 1, 74, "Highlight",
      CellTags->"VerifyFA"],
    Cell[583945, 22602, 182, 5, 43, "Usage",
      CellTags->"VerifyFA"],
    Cell[584130, 22609, 143, 5, 33, "Notes",
      CellTags->"VerifyFA"],
    Cell[584276, 22616, 66, 1, 59, "ExampleSection",
      CellTags->"VerifyFA"]},
  "WelchCA"->{
    Cell[584345, 22619, 52, 1, 42, "ObjectName",
      CellTags->"WelchCA"],
    Cell[584400, 22622, 58, 1, 74, "Highlight",
      CellTags->"WelchCA"],
    Cell[584461, 22625, 155, 4, 43, "Usage",
      CellTags->"WelchCA"],
    Cell[584619, 22631, 290, 10, 80, "Notes",
      CellTags->"WelchCA"],
    Cell[584912, 22643, 142, 5, 33, "Notes",
      CellTags->"WelchCA"],
    Cell[585057, 22650, 142, 5, 33, "Notes",
      CellTags->"WelchCA"],
    Cell[585224, 22659, 65, 1, 59, "ExampleSection",
      CellTags->"WelchCA"],
    Cell[585292, 22662, 129, 4, 70, "ExampleText",
      CellTags->"WelchCA"],
    Cell[585424, 22668, 179, 4, 70, "Input",
      CellTags->"WelchCA"],
    Cell[585628, 22676, 101, 2, 70, "Input",
      CellTags->"WelchCA"],
    Cell[585732, 22680, 703, 25, 70, "Output",
      CellTags->"WelchCA"],
    Cell[586450, 22708, 82, 1, 70, "ExampleText",
      CellTags->"WelchCA"],
    Cell[586557, 22713, 116, 3, 70, "Input",
      CellTags->"WelchCA"],
    Cell[586676, 22718, 685, 18, 70, "Output",
      CellTags->"WelchCA"],
    Cell[587398, 22741, 102, 3, 70, "Input",
      CellTags->"WelchCA"],
    Cell[587503, 22746, 88, 3, 70, "Output",
      CellTags->"WelchCA"]},
  "WidthCA"->{
    Cell[587618, 22753, 52, 1, 31, "ObjectName",
      CellTags->"WidthCA"],
    Cell[587673, 22756, 58, 1, 74, "Highlight",
      CellTags->"WidthCA"],
    Cell[587734, 22759, 134, 4, 43, "Usage",
      CellTags->"WidthCA"],
    Cell[587893, 22767, 65, 1, 59, "ExampleSection",
      CellTags->"WidthCA"],
    Cell[587961, 22770, 83, 1, 70, "ExampleText",
      CellTags->"WidthCA"],
    Cell[588069, 22775, 91, 5, 70, "Input",
      CellTags->"WidthCA"],
    Cell[588163, 22782, 100, 3, 70, "Output",
      CellTags->"WidthCA"],
    Cell[588266, 22787, 83, 3, 70, "Output",
      CellTags->"WidthCA"]},
  "WordBinomial"->{
    Cell[588376, 22794, 62, 1, 31, "ObjectName",
      CellTags->"WordBinomial"],
    Cell[588441, 22797, 63, 1, 74, "Highlight",
      CellTags->"WordBinomial"],
    Cell[588507, 22800, 242, 9, 64, "Usage",
      CellTags->"WordBinomial"],
    Cell[588752, 22811, 231, 9, 58, "Notes",
      CellTags->"WordBinomial"],
    Cell[588986, 22822, 207, 9, 33, "Notes",
      CellTags->"WordBinomial"],
    Cell[589196, 22833, 55, 1, 33, "Notes",
      CellTags->"WordBinomial"],
    Cell[589276, 22838, 70, 1, 59, "ExampleSection",
      CellTags->"WordBinomial"],
    Cell[589349, 22841, 154, 4, 70, "ExampleText",
      CellTags->"WordBinomial"],
    Cell[589528, 22849, 142, 4, 70, "Input",
      CellTags->"WordBinomial"],
    Cell[589673, 22855, 89, 3, 70, "Output",
      CellTags->"WordBinomial"],
    Cell[589765, 22860, 89, 3, 70, "Output",
      CellTags->"WordBinomial"],
    Cell[589891, 22868, 109, 3, 70, "Input",
      CellTags->"WordBinomial"],
    Cell[590003, 22873, 88, 3, 70, "Output",
      CellTags->"WordBinomial"],
    Cell[590128, 22881, 131, 3, 70, "Input",
      CellTags->"WordBinomial"],
    Cell[590262, 22886, 127, 3, 70, "Output",
      CellTags->"WordBinomial"]},
  "WordConjugateQ"->{
    Cell[590416, 22893, 66, 1, 31, "ObjectName",
      CellTags->"WordConjugateQ"],
    Cell[590485, 22896, 65, 1, 74, "Highlight",
      CellTags->"WordConjugateQ"],
    Cell[590553, 22899, 205, 8, 43, "Usage",
      CellTags->"WordConjugateQ"],
    Cell[590761, 22909, 114, 5, 33, "Notes",
      CellTags->"WordConjugateQ"],
    Cell[590878, 22916, 158, 5, 33, "Notes",
      CellTags->"WordConjugateQ"],
    Cell[591039, 22923, 168, 7, 33, "Notes",
      CellTags->"WordConjugateQ"],
    Cell[591232, 22934, 72, 1, 59, "ExampleSection",
      CellTags->"WordConjugateQ"],
    Cell[591307, 22937, 89, 1, 70, "ExampleText",
      CellTags->"WordConjugateQ"],
    Cell[591421, 22942, 100, 2, 70, "Input",
      CellTags->"WordConjugateQ"],
    Cell[591524, 22946, 93, 3, 70, "Output",
      CellTags->"WordConjugateQ"],
    Cell[591654, 22954, 100, 2, 70, "Input",
      CellTags->"WordConjugateQ"],
    Cell[591757, 22958, 94, 3, 70, "Output",
      CellTags->"WordConjugateQ"],
    Cell[591888, 22966, 104, 2, 70, "Input",
      CellTags->"WordConjugateQ"],
    Cell[591995, 22970, 204, 4, 70, "Output",
      CellTags->"WordConjugateQ"]},
  "WordConjugates"->{
    Cell[592226, 22978, 66, 1, 31, "ObjectName",
      CellTags->"WordConjugates"],
    Cell[592295, 22981, 65, 1, 74, "Highlight",
      CellTags->"WordConjugates"],
    Cell[592363, 22984, 193, 6, 43, "Usage",
      CellTags->"WordConjugates"],
    Cell[592559, 22992, 114, 5, 33, "Notes",
      CellTags->"WordConjugates"],
    Cell[592698, 23001, 72, 1, 59, "ExampleSection",
      CellTags->"WordConjugates"],
    Cell[592773, 23004, 283, 10, 70, "ExampleText",
      CellTags->"WordConjugates"],
    Cell[593081, 23018, 95, 2, 70, "Input",
      CellTags->"WordConjugates"],
    Cell[593179, 23022, 134, 3, 70, "Output",
      CellTags->"WordConjugates"],
    Cell[593350, 23030, 95, 2, 70, "Input",
      CellTags->"WordConjugates"],
    Cell[593448, 23034, 106, 3, 70, "Output",
      CellTags->"WordConjugates"]},
  "WordFactorizations"->{
    Cell[593581, 23041, 74, 1, 31, "ObjectName",
      CellTags->"WordFactorizations"],
    Cell[593658, 23044, 69, 1, 74, "Highlight",
      CellTags->"WordFactorizations"],
    Cell[593730, 23047, 213, 8, 43, "Usage",
      CellTags->"WordFactorizations"],
    Cell[593946, 23057, 199, 8, 33, "Notes",
      CellTags->"WordFactorizations"],
    Cell[594148, 23067, 61, 1, 33, "Notes",
      CellTags->"WordFactorizations"],
    Cell[594234, 23072, 76, 1, 59, "ExampleSection",
      CellTags->"WordFactorizations"],
    Cell[594313, 23075, 179, 6, 70, "ExampleText",
      CellTags->"WordFactorizations"],
    Cell[594517, 23085, 103, 2, 70, "Input",
      CellTags->"WordFactorizations"],
    Cell[594623, 23089, 239, 5, 70, "Output",
      CellTags->"WordFactorizations"],
    Cell[594899, 23099, 125, 3, 70, "Input",
      CellTags->"WordFactorizations"],
    Cell[595027, 23104, 103, 3, 70, "Output",
      CellTags->"WordFactorizations"]},
  "WordFactors"->{
    Cell[595157, 23111, 60, 1, 31, "ObjectName",
      CellTags->"WordFactors"],
    Cell[595220, 23114, 62, 1, 74, "Highlight",
      CellTags->"WordFactors"],
    Cell[595285, 23117, 162, 4, 43, "Usage",
      CellTags->"WordFactors"],
    Cell[595450, 23123, 111, 5, 33, "Notes",
      CellTags->"WordFactors"],
    Cell[595564, 23130, 73, 1, 33, "Notes",
      CellTags->"WordFactors"],
    Cell[595640, 23133, 54, 1, 33, "Notes",
      CellTags->"WordFactors"],
    Cell[595697, 23136, 54, 1, 33, "Notes",
      CellTags->"WordFactors"],
    Cell[595754, 23139, 271, 11, 33, "Notes",
      CellTags->"WordFactors"],
    Cell[596028, 23152, 116, 5, 33, "Notes",
      CellTags->"WordFactors"],
    Cell[596169, 23161, 69, 1, 59, "ExampleSection",
      CellTags->"WordFactors"],
    Cell[596241, 23164, 163, 6, 70, "ExampleText",
      CellTags->"WordFactors"],
    Cell[596429, 23174, 89, 2, 70, "Input",
      CellTags->"WordFactors"],
    Cell[596521, 23178, 143, 3, 70, "Output",
      CellTags->"WordFactors"],
    Cell[596701, 23186, 89, 2, 70, "Input",
      CellTags->"WordFactors"],
    Cell[596793, 23190, 252, 5, 70, "Output",
      CellTags->"WordFactors"],
    Cell[597082, 23200, 93, 2, 70, "Input",
      CellTags->"WordFactors"],
    Cell[597178, 23204, 159, 4, 70, "Output",
      CellTags->"WordFactors"]},
  "WordFusion"->{
    Cell[597364, 23212, 58, 1, 31, "ObjectName",
      CellTags->"WordFusion"],
    Cell[597425, 23215, 61, 1, 74, "Highlight",
      CellTags->"WordFusion"],
    Cell[597489, 23218, 223, 10, 43, "Usage",
      CellTags->"WordFusion"],
    Cell[597715, 23230, 150, 5, 33, "Notes",
      CellTags->"WordFusion"],
    Cell[597868, 23237, 195, 8, 33, "Notes",
      CellTags->"WordFusion"],
    Cell[598088, 23249, 68, 1, 59, "ExampleSection",
      CellTags->"WordFusion"],
    Cell[598159, 23252, 220, 9, 70, "ExampleText",
      CellTags->"WordFusion"],
    Cell[598404, 23265, 96, 2, 70, "Input",
      CellTags->"WordFusion"],
    Cell[598503, 23269, 94, 3, 70, "Output",
      CellTags->"WordFusion"],
    Cell[598612, 23275, 96, 2, 70, "Input",
      CellTags->"WordFusion"]},
  "WordLength"->{
    Cell[598723, 23280, 58, 1, 31, "ObjectName",
      CellTags->"WordLength"],
    Cell[598784, 23283, 61, 1, 74, "Highlight",
      CellTags->"WordLength"],
    Cell[598848, 23286, 148, 5, 43, "Usage",
      CellTags->"WordLength"],
    Cell[598999, 23293, 110, 5, 33, "Notes",
      CellTags->"WordLength"],
    Cell[599112, 23300, 233, 7, 54, "Notes",
      CellTags->"WordLength"],
    Cell[599370, 23311, 68, 1, 59, "ExampleSection",
      CellTags->"WordLength"],
    Cell[599441, 23314, 126, 4, 70, "ExampleText",
      CellTags->"WordLength"],
    Cell[599592, 23322, 78, 2, 70, "Input",
      CellTags->"WordLength"],
    Cell[599673, 23326, 195, 4, 70, "Output",
      CellTags->"WordLength"],
    Cell[599905, 23335, 98, 3, 70, "Input",
      CellTags->"WordLength"],
    Cell[600006, 23340, 131, 3, 70, "Output",
      CellTags->"WordLength"]},
  "WordOrder"->{
    Cell[600164, 23347, 56, 1, 31, "ObjectName",
      CellTags->"WordOrder"],
    Cell[600223, 23350, 60, 1, 74, "Highlight",
      CellTags->"WordOrder"],
    Cell[600286, 23353, 230, 8, 43, "Usage",
      CellTags->"WordOrder"],
    Cell[600519, 23363, 200, 6, 54, "Notes",
      CellTags->"WordOrder"],
    Cell[600722, 23371, 444, 19, 54, "Notes",
      CellTags->"WordOrder"],
    Cell[601191, 23394, 67, 1, 59, "ExampleSection",
      CellTags->"WordOrder"],
    Cell[601261, 23397, 98, 1, 70, "ExampleText",
      CellTags->"WordOrder"],
    Cell[601384, 23402, 81, 2, 70, "Input",
      CellTags->"WordOrder"],
    Cell[601468, 23406, 131, 3, 70, "Output",
      CellTags->"WordOrder"],
    Cell[601636, 23414, 154, 4, 70, "Input",
      CellTags->"WordOrder"],
    Cell[601793, 23420, 365, 7, 70, "Output",
      CellTags->"WordOrder"]},
  "WordPower"->{
    Cell[602185, 23431, 56, 1, 31, "ObjectName",
      CellTags->"WordPower"],
    Cell[602244, 23434, 60, 1, 74, "Highlight",
      CellTags->"WordPower"],
    Cell[602307, 23437, 207, 7, 43, "Usage",
      CellTags->"WordPower"],
    Cell[602517, 23446, 109, 5, 33, "Notes",
      CellTags->"WordPower"],
    Cell[602629, 23453, 268, 11, 33, "Notes",
      CellTags->"WordPower"],
    Cell[602922, 23468, 67, 1, 59, "ExampleSection",
      CellTags->"WordPower"],
    Cell[602992, 23471, 123, 4, 70, "ExampleText",
      CellTags->"WordPower"],
    Cell[603140, 23479, 138, 3, 70, "Input",
      CellTags->"WordPower"],
    Cell[603281, 23484, 293, 6, 70, "Output",
      CellTags->"WordPower"],
    Cell[603611, 23495, 111, 3, 70, "Input",
      CellTags->"WordPower"],
    Cell[603725, 23500, 133, 3, 70, "Output",
      CellTags->"WordPower"],
    Cell[603895, 23508, 111, 3, 70, "Input",
      CellTags->"WordPower"],
    Cell[604009, 23513, 293, 6, 70, "Output",
      CellTags->"WordPower"],
    Cell[604339, 23524, 105, 3, 70, "Input",
      CellTags->"WordPower"],
    Cell[604447, 23529, 89, 3, 70, "Output",
      CellTags->"WordPower"]},
  "WordPrefixes"->{
    Cell[604563, 23536, 62, 1, 31, "ObjectName",
      CellTags->"WordPrefixes"],
    Cell[604628, 23539, 63, 1, 74, "Highlight",
      CellTags->"WordPrefixes"],
    Cell[604694, 23542, 156, 5, 43, "Usage",
      CellTags->"WordPrefixes"],
    Cell[604853, 23549, 112, 5, 33, "Notes",
      CellTags->"WordPrefixes"],
    Cell[604968, 23556, 271, 11, 33, "Notes",
      CellTags->"WordPrefixes"],
    Cell[605242, 23569, 113, 5, 33, "Notes",
      CellTags->"WordPrefixes"],
    Cell[605380, 23578, 70, 1, 59, "ExampleSection",
      CellTags->"WordPrefixes"],
    Cell[605453, 23581, 173, 6, 70, "ExampleText",
      CellTags->"WordPrefixes"],
    Cell[605651, 23591, 91, 2, 70, "Input",
      CellTags->"WordPrefixes"],
    Cell[605745, 23595, 144, 3, 70, "Output",
      CellTags->"WordPrefixes"],
    Cell[605926, 23603, 94, 2, 70, "Input",
      CellTags->"WordPrefixes"],
    Cell[606023, 23607, 160, 4, 70, "Output",
      CellTags->"WordPrefixes"]},
  "WordReverse"->{
    Cell[606210, 23615, 60, 1, 31, "ObjectName",
      CellTags->"WordReverse"],
    Cell[606273, 23618, 62, 1, 74, "Highlight",
      CellTags->"WordReverse"],
    Cell[606338, 23621, 225, 6, 64, "Usage",
      CellTags->"WordReverse"],
    Cell[606566, 23629, 111, 5, 33, "Notes",
      CellTags->"WordReverse"],
    Cell[606680, 23636, 54, 1, 33, "Notes",
      CellTags->"WordReverse"],
    Cell[606737, 23639, 54, 1, 33, "Notes",
      CellTags->"WordReverse"],
    Cell[606816, 23644, 69, 1, 59, "ExampleSection",
      CellTags->"WordReverse"],
    Cell[606888, 23647, 65, 1, 70, "ExampleText",
      CellTags->"WordReverse"],
    Cell[606978, 23652, 69, 2, 70, "Input",
      CellTags->"WordReverse"],
    Cell[607050, 23656, 86, 3, 70, "Output",
      CellTags->"WordReverse"]},
  "WordRoot"->{
    Cell[607163, 23663, 54, 1, 31, "ObjectName",
      CellTags->"WordRoot"],
    Cell[607220, 23666, 59, 1, 74, "Highlight",
      CellTags->"WordRoot"],
    Cell[607282, 23669, 289, 12, 43, "Usage",
      CellTags->"WordRoot"],
    Cell[607574, 23683, 108, 5, 33, "Notes",
      CellTags->"WordRoot"],
    Cell[607685, 23690, 362, 15, 33, "Notes",
      CellTags->"WordRoot"],
    Cell[608072, 23709, 66, 1, 59, "ExampleSection",
      CellTags->"WordRoot"],
    Cell[608141, 23712, 92, 1, 70, "ExampleText",
      CellTags->"WordRoot"],
    Cell[608258, 23717, 103, 2, 70, "Input",
      CellTags->"WordRoot"],
    Cell[608364, 23721, 292, 6, 70, "Output",
      CellTags->"WordRoot"],
    Cell[608693, 23732, 94, 3, 70, "Input",
      CellTags->"WordRoot"],
    Cell[608790, 23737, 209, 4, 70, "Output",
      CellTags->"WordRoot"]},
  "WordRotate"->{
    Cell[609026, 23745, 58, 1, 31, "ObjectName",
      CellTags->"WordRotate"],
    Cell[609087, 23748, 61, 1, 74, "Highlight",
      CellTags->"WordRotate"],
    Cell[609151, 23751, 199, 8, 43, "Usage",
      CellTags->"WordRotate"],
    Cell[609353, 23761, 110, 5, 33, "Notes",
      CellTags->"WordRotate"],
    Cell[609466, 23768, 97, 4, 33, "Notes",
      CellTags->"WordRotate"],
    Cell[609566, 23774, 68, 1, 33, "Notes",
      CellTags->"WordRotate"],
    Cell[609637, 23777, 278, 11, 33, "Notes",
      CellTags->"WordRotate"],
    Cell[609940, 23792, 68, 1, 59, "ExampleSection",
      CellTags->"WordRotate"],
    Cell[610011, 23795, 73, 1, 70, "ExampleText",
      CellTags->"WordRotate"],
    Cell[610109, 23800, 104, 2, 70, "Input",
      CellTags->"WordRotate"],
    Cell[610216, 23804, 131, 3, 70, "Output",
      CellTags->"WordRotate"],
    Cell[610384, 23812, 109, 3, 70, "Input",
      CellTags->"WordRotate"],
    Cell[610496, 23817, 116, 3, 70, "Output",
      CellTags->"WordRotate"]},
  "WordShuffle"->{
    Cell[610639, 23824, 60, 1, 31, "ObjectName",
      CellTags->"WordShuffle"],
    Cell[610702, 23827, 62, 1, 74, "Highlight",
      CellTags->"WordShuffle"],
    Cell[610767, 23830, 196, 7, 43, "Usage",
      CellTags->"WordShuffle"],
    Cell[610966, 23839, 81, 1, 33, "Notes",
      CellTags->"WordShuffle"],
    Cell[611072, 23844, 69, 1, 59, "ExampleSection",
      CellTags->"WordShuffle"],
    Cell[611144, 23847, 134, 4, 70, "ExampleText",
      CellTags->"WordShuffle"],
    Cell[611303, 23855, 93, 2, 70, "Input",
      CellTags->"WordShuffle"],
    Cell[611399, 23859, 97, 3, 70, "Output",
      CellTags->"WordShuffle"],
    Cell[611533, 23867, 93, 2, 70, "Input",
      CellTags->"WordShuffle"],
    Cell[611629, 23871, 303, 6, 70, "Output",
      CellTags->"WordShuffle"]},
  "WordSort"->{
    Cell[611959, 23881, 54, 1, 31, "ObjectName",
      CellTags->"WordSort"],
    Cell[612016, 23884, 59, 1, 74, "Highlight",
      CellTags->"WordSort"],
    Cell[612078, 23887, 206, 6, 43, "Usage",
      CellTags->"WordSort"],
    Cell[612287, 23895, 526, 13, 33, "Notes",
      CellTags->"WordSort"],
    Cell[612816, 23910, 136, 4, 33, "Notes",
      CellTags->"WordSort"],
    Cell[612955, 23916, 159, 7, 33, "Notes",
      CellTags->"WordSort"],
    Cell[613139, 23927, 66, 1, 59, "ExampleSection",
      CellTags->"WordSort"],
    Cell[613208, 23930, 147, 4, 70, "ExampleText",
      CellTags->"WordSort"],
    Cell[613380, 23938, 84, 2, 70, "Input",
      CellTags->"WordSort"],
    Cell[613467, 23942, 193, 4, 70, "Output",
      CellTags->"WordSort"],
    Cell[613697, 23951, 94, 3, 70, "Input",
      CellTags->"WordSort"],
    Cell[613794, 23956, 193, 4, 70, "Output",
      CellTags->"WordSort"]},
  "WordSuffixes"->{
    Cell[614014, 23964, 62, 1, 31, "ObjectName",
      CellTags->"WordSuffixes"],
    Cell[614079, 23967, 63, 1, 74, "Highlight",
      CellTags->"WordSuffixes"],
    Cell[614145, 23970, 184, 7, 43, "Usage",
      CellTags->"WordSuffixes"],
    Cell[614332, 23979, 112, 5, 33, "Notes",
      CellTags->"WordSuffixes"],
    Cell[614447, 23986, 270, 11, 33, "Notes",
      CellTags->"WordSuffixes"],
    Cell[614742, 24001, 70, 1, 59, "ExampleSection",
      CellTags->"WordSuffixes"],
    Cell[614815, 24004, 173, 6, 70, "ExampleText",
      CellTags->"WordSuffixes"],
    Cell[615013, 24014, 91, 2, 70, "Input",
      CellTags->"WordSuffixes"],
    Cell[615107, 24018, 144, 3, 70, "Output",
      CellTags->"WordSuffixes"],
    Cell[615288, 24026, 94, 2, 70, "Input",
      CellTags->"WordSuffixes"],
    Cell[615385, 24030, 160, 4, 70, "Output",
      CellTags->"WordSuffixes"]},
  "Words"->{
    Cell[615572, 24038, 48, 1, 31, "ObjectName",
      CellTags->"Words"],
    Cell[615623, 24041, 56, 1, 74, "Highlight",
      CellTags->"Words"],
    Cell[615682, 24044, 310, 12, 64, "Usage",
      CellTags->"Words"],
    Cell[615995, 24058, 84, 1, 33, "Notes",
      CellTags->"Words"],
    Cell[616082, 24061, 148, 7, 33, "Notes",
      CellTags->"Words"],
    Cell[616255, 24072, 63, 1, 59, "ExampleSection",
      CellTags->"Words"],
    Cell[616321, 24075, 89, 1, 70, "ExampleText",
      CellTags->"Words"],
    Cell[616435, 24080, 72, 2, 70, "Input",
      CellTags->"Words"],
    Cell[616510, 24084, 136, 3, 70, "Output",
      CellTags->"Words"],
    Cell[616683, 24092, 92, 3, 70, "Input",
      CellTags->"Words"],
    Cell[616778, 24097, 189, 4, 70, "Output",
      CellTags->"Words"],
    Cell[617004, 24106, 95, 3, 70, "Input",
      CellTags->"Words"],
    Cell[617102, 24111, 136, 3, 70, "Output",
      CellTags->"Words"],
    Cell[617275, 24119, 107, 3, 70, "Input",
      CellTags->"Words"],
    Cell[617385, 24124, 136, 3, 70, "Output",
      CellTags->"Words"]},
  "Alphabetic"->{
    Cell[617548, 24131, 58, 1, 31, "ObjectName",
      CellTags->"Alphabetic"],
    Cell[617609, 24134, 59, 1, 74, "Highlight",
      CellTags->"Alphabetic"],
    Cell[617671, 24137, 197, 8, 43, "Usage",
      CellTags->"Alphabetic"],
    Cell[617871, 24147, 203, 6, 33, "Notes",
      CellTags->"Alphabetic"],
    Cell[618077, 24155, 270, 11, 33, "Notes",
      CellTags->"Alphabetic"]},
  "Boundary"->{
    Cell[618350, 24168, 54, 1, 42, "ObjectName",
      CellTags->"Boundary"],
    Cell[618407, 24171, 57, 1, 74, "Highlight",
      CellTags->"Boundary"],
    Cell[618467, 24174, 144, 6, 43, "Usage",
      CellTags->"Boundary"],
    Cell[618614, 24182, 186, 9, 33, "Notes",
      CellTags->"Boundary"],
    Cell[618803, 24193, 345, 15, 33, "Notes",
      CellTags->"Boundary"]},
  "Cyclic"->{
    Cell[619151, 24210, 50, 1, 42, "ObjectName",
      CellTags->"Cyclic"],
    Cell[619204, 24213, 55, 1, 74, "Highlight",
      CellTags->"Cyclic"],
    Cell[619262, 24216, 237, 8, 64, "Usage",
      CellTags->"Cyclic"],
    Cell[619502, 24226, 338, 15, 33, "Notes",
      CellTags->"Cyclic"]},
  "EdgeLU"->{
    Cell[619843, 24243, 50, 1, 42, "ObjectName",
      CellTags->"EdgeLU"],
    Cell[619896, 24246, 55, 1, 74, "Highlight",
      CellTags->"EdgeLU"],
    Cell[619954, 24249, 147, 6, 43, "Usage",
      CellTags->"EdgeLU"],
    Cell[620104, 24257, 98, 1, 33, "Notes",
      CellTags->"EdgeLU"],
    Cell[620205, 24260, 166, 7, 33, "Notes",
      CellTags->"EdgeLU"]},
  "Empty"->{
    Cell[620374, 24269, 48, 1, 42, "ObjectName",
      CellTags->"Empty"],
    Cell[620425, 24272, 54, 1, 74, "Highlight",
      CellTags->"Empty"],
    Cell[620482, 24275, 134, 4, 43, "Usage",
      CellTags->"Empty"],
    Cell[620619, 24281, 180, 7, 33, "Notes",
      CellTags->"Empty"]},
  "EpsElim"->{
    Cell[620802, 24290, 52, 1, 42, "ObjectName",
      CellTags->"EpsElim"],
    Cell[620857, 24293, 56, 1, 74, "Highlight",
      CellTags->"EpsElim"],
    Cell[620916, 24296, 194, 8, 43, "Usage",
      CellTags->"EpsElim"],
    Cell[621113, 24306, 174, 5, 33, "Notes",
      CellTags->"EpsElim"],
    Cell[621290, 24313, 289, 11, 33, "Notes",
      CellTags->"EpsElim"]},
  "FinLU"->{
    Cell[621582, 24326, 48, 1, 42, "ObjectName",
      CellTags->"FinLU"],
    Cell[621633, 24329, 54, 1, 74, "Highlight",
      CellTags->"FinLU"],
    Cell[621690, 24332, 145, 6, 43, "Usage",
      CellTags->"FinLU"],
    Cell[621838, 24340, 76, 1, 33, "Notes",
      CellTags->"FinLU"],
    Cell[621917, 24343, 165, 7, 33, "Notes",
      CellTags->"FinLU"]},
  "Fixed"->{
    Cell[622085, 24352, 48, 1, 42, "ObjectName",
      CellTags->"Fixed"],
    Cell[622136, 24355, 54, 1, 74, "Highlight",
      CellTags->"Fixed"],
    Cell[622193, 24358, 137, 6, 43, "Usage",
      CellTags->"Fixed"],
    Cell[622333, 24366, 82, 1, 33, "Notes",
      CellTags->"Fixed"],
    Cell[622418, 24369, 149, 7, 33, "Notes",
      CellTags->"Fixed"]},
  "FLBound"->{
    Cell[622570, 24378, 52, 1, 42, "ObjectName",
      CellTags->"FLBound"],
    Cell[622625, 24381, 56, 1, 74, "Highlight",
      CellTags->"FLBound"],
    Cell[622684, 24384, 114, 4, 43, "Usage",
      CellTags->"FLBound"],
    Cell[622801, 24390, 96, 1, 33, "Notes",
      CellTags->"FLBound"],
    Cell[622900, 24393, 118, 5, 33, "Notes",
      CellTags->"FLBound"],
    Cell[623021, 24400, 155, 7, 33, "Notes",
      CellTags->"FLBound"]},
  "Hopcroft"->{
    Cell[623179, 24409, 54, 1, 42, "ObjectName",
      CellTags->"Hopcroft"],
    Cell[623236, 24412, 57, 1, 74, "Highlight",
      CellTags->"Hopcroft"],
    Cell[623296, 24415, 157, 6, 43, "Usage",
      CellTags->"Hopcroft"],
    Cell[623456, 24423, 162, 6, 33, "Notes",
      CellTags->"Hopcroft"],
    Cell[623621, 24431, 145, 4, 33, "Notes",
      CellTags->"Hopcroft"]},
  "Implementation"->{
    Cell[623769, 24437, 66, 1, 42, "ObjectName",
      CellTags->"Implementation"],
    Cell[623838, 24440, 63, 1, 74, "Highlight",
      CellTags->"Implementation"],
    Cell[623904, 24443, 172, 6, 43, "Usage",
      CellTags->"Implementation"],
    Cell[624079, 24451, 91, 1, 33, "Notes",
      CellTags->"Implementation"],
    Cell[624173, 24454, 162, 7, 33, "Notes",
      CellTags->"Implementation"]},
  "IniLU"->{
    Cell[624338, 24463, 48, 1, 42, "ObjectName",
      CellTags->"IniLU"],
    Cell[624389, 24466, 54, 1, 74, "Highlight",
      CellTags->"IniLU"],
    Cell[624446, 24469, 163, 6, 43, "Usage",
      CellTags->"IniLU"],
    Cell[624612, 24477, 79, 1, 33, "Notes",
      CellTags->"IniLU"],
    Cell[624694, 24480, 165, 7, 33, "Notes",
      CellTags->"IniLU"]},
  "ListAble"->{
    Cell[624862, 24489, 54, 1, 42, "ObjectName",
      CellTags->"ListAble"],
    Cell[624919, 24492, 57, 1, 74, "Highlight",
      CellTags->"ListAble"],
    Cell[624979, 24495, 151, 6, 43, "Usage",
      CellTags->"ListAble"],
    Cell[625133, 24503, 173, 7, 33, "Notes",
      CellTags->"ListAble"]},
  "MakeTrim"->{
    Cell[625309, 24512, 54, 1, 42, "ObjectName",
      CellTags->"MakeTrim"],
    Cell[625366, 24515, 57, 1, 74, "Highlight",
      CellTags->"MakeTrim"],
    Cell[625426, 24518, 154, 6, 43, "Usage",
      CellTags->"MakeTrim"],
    Cell[625583, 24526, 147, 4, 33, "Notes",
      CellTags->"MakeTrim"],
    Cell[625733, 24532, 161, 7, 33, "Notes",
      CellTags->"MakeTrim"]},
  "RegExpSimp"->{
    Cell[625897, 24541, 58, 1, 42, "ObjectName",
      CellTags->"RegExpSimp"],
    Cell[625958, 24544, 59, 1, 74, "Highlight",
      CellTags->"RegExpSimp"],
    Cell[626020, 24547, 161, 6, 43, "Usage",
      CellTags->"RegExpSimp"],
    Cell[626184, 24555, 167, 4, 54, "Notes",
      CellTags->"RegExpSimp"],
    Cell[626354, 24561, 203, 7, 33, "Notes",
      CellTags->"RegExpSimp"]},
  "ShowAll"->{
    Cell[626560, 24570, 52, 1, 42, "ObjectName",
      CellTags->"ShowAll"],
    Cell[626615, 24573, 56, 1, 74, "Highlight",
      CellTags->"ShowAll"],
    Cell[626674, 24576, 152, 6, 43, "Usage",
      CellTags->"ShowAll"],
    Cell[626829, 24584, 100, 1, 33, "Notes",
      CellTags->"ShowAll"],
    Cell[626932, 24587, 132, 5, 33, "Notes",
      CellTags->"ShowAll"],
    Cell[627067, 24594, 174, 7, 33, "Notes",
      CellTags->"ShowAll"]},
  "ShowEdges"->{
    Cell[627244, 24603, 56, 1, 42, "ObjectName",
      CellTags->"ShowEdges"],
    Cell[627303, 24606, 58, 1, 74, "Highlight",
      CellTags->"ShowEdges"],
    Cell[627364, 24609, 154, 6, 43, "Usage",
      CellTags->"ShowEdges"],
    Cell[627521, 24617, 140, 4, 33, "Notes",
      CellTags->"ShowEdges"],
    Cell[627664, 24623, 176, 7, 33, "Notes",
      CellTags->"ShowEdges"]},
  "SizeOnly"->{
    Cell[627843, 24632, 54, 1, 42, "ObjectName",
      CellTags->"SizeOnly"],
    Cell[627900, 24635, 57, 1, 74, "Highlight",
      CellTags->"SizeOnly"],
    Cell[627960, 24638, 148, 5, 43, "Usage",
      CellTags->"SizeOnly"],
    Cell[628111, 24645, 294, 10, 54, "Notes",
      CellTags->"SizeOnly"],
    Cell[628408, 24657, 209, 7, 54, "Notes",
      CellTags->"SizeOnly"],
    Cell[628620, 24666, 279, 11, 33, "Notes",
      CellTags->"SizeOnly"],
    Cell[628924, 24681, 66, 1, 59, "ExampleSection",
      CellTags->"SizeOnly"],
    Cell[628993, 24684, 65, 1, 70, "ExampleText",
      CellTags->"SizeOnly"],
    Cell[629061, 24687, 213, 5, 70, "Input",
      CellTags->"SizeOnly"],
    Cell[629299, 24696, 136, 3, 70, "Input",
      CellTags->"SizeOnly"],
    Cell[629438, 24701, 126, 3, 70, "Output",
      CellTags->"SizeOnly"]},
  "Some"->{
    Cell[629591, 24708, 46, 1, 31, "ObjectName",
      CellTags->"Some"],
    Cell[629640, 24711, 53, 1, 74, "Highlight",
      CellTags->"Some"],
    Cell[629696, 24714, 141, 6, 43, "Usage",
      CellTags->"Some"],
    Cell[629840, 24722, 160, 7, 33, "Notes",
      CellTags->"Some"]},
  "Thompson"->{
    Cell[630003, 24731, 54, 1, 42, "ObjectName",
      CellTags->"Thompson"],
    Cell[630060, 24734, 57, 1, 74, "Highlight",
      CellTags->"Thompson"],
    Cell[630120, 24737, 156, 6, 43, "Usage",
      CellTags->"Thompson"],
    Cell[630279, 24745, 213, 7, 54, "Notes",
      CellTags->"Thompson"],
    Cell[630495, 24754, 183, 7, 33, "Notes",
      CellTags->"Thompson"]},
  "ToMatrix"->{
    Cell[630681, 24763, 54, 1, 42, "ObjectName",
      CellTags->"ToMatrix"],
    Cell[630738, 24766, 57, 1, 74, "Highlight",
      CellTags->"ToMatrix"],
    Cell[630798, 24769, 147, 6, 43, "Usage",
      CellTags->"ToMatrix"],
    Cell[630948, 24777, 138, 4, 33, "Notes",
      CellTags->"ToMatrix"],
    Cell[631089, 24783, 163, 7, 33, "Notes",
      CellTags->"ToMatrix"]},
  "TransOnly"->{
    Cell[631255, 24792, 56, 1, 42, "ObjectName",
      CellTags->"TransOnly"],
    Cell[631314, 24795, 58, 1, 74, "Highlight",
      CellTags->"TransOnly"],
    Cell[631375, 24798, 145, 6, 43, "Usage",
      CellTags->"TransOnly"],
    Cell[631523, 24806, 152, 5, 33, "Notes",
      CellTags->"TransOnly"],
    Cell[631678, 24813, 156, 7, 33, "Notes",
      CellTags->"TransOnly"],
    Cell[631859, 24824, 67, 1, 59, "ExampleSection",
      CellTags->"TransOnly"],
    Cell[631929, 24827, 73, 1, 70, "ExampleText",
      CellTags->"TransOnly"],
    Cell[632005, 24830, 215, 5, 70, "Input",
      CellTags->"TransOnly"],
    Cell[632245, 24839, 94, 3, 70, "Input",
      CellTags->"TransOnly"],
    Cell[632342, 24844, 213, 5, 70, "Print",
      CellTags->"TransOnly"],
    Cell[632558, 24851, 213, 5, 70, "Print",
      CellTags->"TransOnly"],
    Cell[632774, 24858, 231, 5, 70, "Print",
      CellTags->"TransOnly"],
    Cell[633008, 24865, 112, 3, 70, "Print",
      CellTags->"TransOnly"],
    Cell[633123, 24870, 112, 3, 70, "Print",
      CellTags->"TransOnly"],
    Cell[633238, 24875, 2438, 76, 70, "Output",
      CellTags->"TransOnly"],
    Cell[635713, 24956, 118, 3, 70, "Input",
      CellTags->"TransOnly"],
    Cell[635834, 24961, 2438, 76, 70, "Output",
      CellTags->"TransOnly"]},
  "Tropical"->{
    Cell[638299, 25041, 54, 1, 31, "ObjectName",
      CellTags->"Tropical"],
    Cell[638356, 25044, 57, 1, 74, "Highlight",
      CellTags->"Tropical"],
    Cell[638416, 25047, 154, 6, 43, "Usage",
      CellTags->"Tropical"],
    Cell[638573, 25055, 112, 4, 33, "Notes",
      CellTags->"Tropical"],
    Cell[638688, 25061, 340, 11, 33, "Notes",
      CellTags->"Tropical"]},
  "Unlabeled"->{
    Cell[639031, 25074, 56, 1, 42, "ObjectName",
      CellTags->"Unlabeled"],
    Cell[639090, 25077, 58, 1, 74, "Highlight",
      CellTags->"Unlabeled"],
    Cell[639151, 25080, 190, 6, 43, "Usage",
      CellTags->"Unlabeled"],
    Cell[639344, 25088, 108, 5, 33, "Notes",
      CellTags->"Unlabeled"],
    Cell[639455, 25095, 155, 7, 33, "Notes",
      CellTags->"Unlabeled"],
    Cell[639635, 25106, 67, 1, 59, "ExampleSection",
      CellTags->"Unlabeled"],
    Cell[639705, 25109, 82, 1, 70, "ExampleText",
      CellTags->"Unlabeled"],
    Cell[639790, 25112, 214, 5, 70, "Input",
      CellTags->"Unlabeled"],
    Cell[640029, 25121, 80, 2, 70, "Input",
      CellTags->"Unlabeled"],
    Cell[640112, 25125, 274, 8, 70, "Output",
      CellTags->"Unlabeled"],
    Cell[640423, 25138, 121, 3, 70, "Input",
      CellTags->"Unlabeled"],
    Cell[640547, 25143, 347, 10, 70, "Output",
      CellTags->"Unlabeled"]},
  "WordMap"->{
    Cell[640921, 25157, 52, 1, 31, "ObjectName",
      CellTags->"WordMap"],
    Cell[640976, 25160, 56, 1, 74, "Highlight",
      CellTags->"WordMap"],
    Cell[641035, 25163, 158, 4, 43, "Usage",
      CellTags->"WordMap"],
    Cell[641196, 25169, 228, 10, 137, "Notes",
      CellTags->"WordMap"],
    Cell[641449, 25183, 65, 1, 59, "ExampleSection",
      CellTags->"WordMap"],
    Cell[641517, 25186, 161, 4, 70, "ExampleText",
      CellTags->"WordMap"],
    Cell[641681, 25192, 125, 3, 70, "Input",
      CellTags->"WordMap"],
    Cell[641831, 25199, 88, 3, 70, "Input",
      CellTags->"WordMap"],
    Cell[641922, 25204, 48, 1, 70, "Print",
      CellTags->"WordMap"],
    Cell[641973, 25207, 844, 27, 70, "Print",
      CellTags->"WordMap"]},
  "BEFA"->{
    Cell[642844, 25238, 46, 1, 31, "ObjectName",
      CellTags->"BEFA"],
    Cell[642893, 25241, 53, 1, 74, "Highlight",
      CellTags->"BEFA"],
    Cell[642949, 25244, 321, 7, 85, "Usage",
      CellTags->"BEFA"],
    Cell[643273, 25253, 201, 7, 33, "Notes",
      CellTags->"BEFA"],
    Cell[643477, 25262, 196, 6, 36, "Notes",
      CellTags->"BEFA"],
    Cell[643676, 25270, 95, 1, 33, "Notes",
      CellTags->"BEFA"],
    Cell[643796, 25275, 62, 1, 59, "ExampleSection",
      CellTags->"BEFA"],
    Cell[643861, 25278, 193, 6, 70, "ExampleText",
      CellTags->"BEFA"],
    Cell[644079, 25288, 177, 4, 70, "Input",
      CellTags->"BEFA"],
    Cell[644259, 25294, 205, 5, 70, "Output",
      CellTags->"BEFA"]},
  "CA"->{
    Cell[644491, 25303, 42, 1, 31, "ObjectName",
      CellTags->"CA"],
    Cell[644536, 25306, 51, 1, 74, "Highlight",
      CellTags->"CA"],
    Cell[644590, 25309, 244, 8, 64, "Usage",
      CellTags->"CA"],
    Cell[644837, 25319, 271, 10, 33, "Notes",
      CellTags->"CA"],
    Cell[645133, 25333, 60, 1, 59, "ExampleSection",
      CellTags->"CA"],
    Cell[645196, 25336, 130, 4, 70, "ExampleText",
      CellTags->"CA"],
    Cell[645351, 25344, 68, 2, 70, "Input",
      CellTags->"CA"],
    Cell[645422, 25348, 95, 3, 70, "Output",
      CellTags->"CA"],
    Cell[645532, 25354, 91, 1, 70, "ExampleText",
      CellTags->"CA"],
    Cell[645648, 25359, 79, 2, 70, "Input",
      CellTags->"CA"],
    Cell[645730, 25363, 97, 3, 70, "Output",
      CellTags->"CA"],
    Cell[645864, 25371, 86, 3, 70, "Input",
      CellTags->"CA"],
    Cell[645953, 25376, 809, 18, 70, "Output",
      CellTags->"CA"]},
  "DFA"->{
    Cell[646789, 25398, 44, 1, 31, "ObjectName",
      CellTags->"DFA"],
    Cell[646836, 25401, 52, 1, 74, "Highlight",
      CellTags->"DFA"],
    Cell[646891, 25404, 142, 4, 43, "Usage",
      CellTags->"DFA"],
    Cell[647036, 25410, 319, 12, 54, "Notes",
      CellTags->"DFA"],
    Cell[647358, 25424, 197, 9, 33, "Notes",
      CellTags->"DFA"],
    Cell[647558, 25435, 188, 8, 33, "Notes",
      CellTags->"DFA"],
    Cell[647749, 25445, 352, 9, 54, "Notes",
      CellTags->"DFA"],
    Cell[648104, 25456, 164, 7, 33, "Notes",
      CellTags->"DFA"],
    Cell[648293, 25467, 61, 1, 59, "ExampleSection",
      CellTags->"DFA"],
    Cell[648357, 25470, 350, 10, 70, "ExampleText",
      CellTags->"DFA"],
    Cell[648710, 25482, 98, 3, 70, "Input",
      CellTags->"DFA"],
    Cell[648833, 25489, 199, 5, 70, "Input",
      CellTags->"DFA"],
    Cell[649035, 25496, 159, 4, 70, "Output",
      CellTags->"DFA"],
    Cell[649231, 25505, 117, 4, 70, "Input",
      CellTags->"DFA"],
    Cell[649351, 25511, 100, 3, 70, "Output",
      CellTags->"DFA"],
    Cell[649454, 25516, 89, 3, 70, "Output",
      CellTags->"DFA"]},
  "FA"->{
    Cell[649570, 25523, 42, 1, 31, "ObjectName",
      CellTags->"FA"],
    Cell[649615, 25526, 51, 1, 74, "Highlight",
      CellTags->"FA"],
    Cell[649669, 25529, 124, 4, 43, "Usage",
      CellTags->"FA"],
    Cell[649796, 25535, 231, 9, 33, "Notes",
      CellTags->"FA"],
    Cell[650030, 25546, 168, 7, 33, "Notes",
      CellTags->"FA"],
    Cell[650201, 25555, 261, 9, 33, "Notes",
      CellTags->"FA"],
    Cell[650465, 25566, 183, 7, 33, "Notes",
      CellTags->"FA"],
    Cell[650651, 25575, 303, 15, 33, "Notes",
      CellTags->"FA"],
    Cell[650979, 25594, 60, 1, 59, "ExampleSection",
      CellTags->"FA"],
    Cell[651042, 25597, 52, 1, 70, "ExampleText",
      CellTags->"FA"],
    Cell[651097, 25600, 207, 5, 70, "Input",
      CellTags->"FA"],
    Cell[651329, 25609, 142, 5, 70, "Input",
      CellTags->"FA"],
    Cell[651474, 25616, 81, 3, 70, "Output",
      CellTags->"FA"],
    Cell[651558, 25621, 81, 3, 70, "Output",
      CellTags->"FA"],
    Cell[651642, 25626, 88, 3, 70, "Output",
      CellTags->"FA"]},
  "NFA"->{
    Cell[651757, 25633, 44, 1, 31, "ObjectName",
      CellTags->"NFA"],
    Cell[651804, 25636, 52, 1, 74, "Highlight",
      CellTags->"NFA"],
    Cell[651859, 25639, 136, 4, 43, "Usage",
      CellTags->"NFA"],
    Cell[651998, 25645, 276, 11, 33, "Notes",
      CellTags->"NFA"],
    Cell[652277, 25658, 169, 7, 33, "Notes",
      CellTags->"NFA"],
    Cell[652449, 25667, 262, 9, 33, "Notes",
      CellTags->"NFA"],
    Cell[652714, 25678, 184, 7, 33, "Notes",
      CellTags->"NFA"],
    Cell[652901, 25687, 302, 15, 33, "Notes",
      CellTags->"NFA"],
    Cell[653228, 25706, 61, 1, 59, "ExampleSection",
      CellTags->"NFA"],
    Cell[653292, 25709, 54, 1, 70, "ExampleText",
      CellTags->"NFA"],
    Cell[653371, 25714, 173, 5, 70, "Input",
      CellTags->"NFA"],
    Cell[653547, 25721, 392, 12, 70, "Output",
      CellTags->"NFA"],
    Cell[653976, 25738, 109, 3, 70, "Input",
      CellTags->"NFA"],
    Cell[654088, 25743, 336, 9, 70, "Output",
      CellTags->"NFA"]},
  "NNFA"->{
    Cell[654451, 25756, 46, 1, 31, "ObjectName",
      CellTags->"NNFA"],
    Cell[654500, 25759, 53, 1, 74, "Highlight",
      CellTags->"NNFA"],
    Cell[654556, 25762, 157, 4, 43, "Usage",
      CellTags->"NNFA"],
    Cell[654716, 25768, 291, 6, 75, "Notes",
      CellTags->"NNFA"],
    Cell[655010, 25776, 270, 11, 33, "Notes",
      CellTags->"NNFA"],
    Cell[655305, 25791, 62, 1, 59, "ExampleSection",
      CellTags->"NNFA"],
    Cell[655370, 25794, 56, 1, 70, "ExampleText",
      CellTags->"NNFA"],
    Cell[655451, 25799, 104, 2, 70, "Input",
      CellTags->"NNFA"],
    Cell[655558, 25803, 193, 5, 70, "Output",
      CellTags->"NNFA"]},
  "REP"->{
    Cell[655778, 25812, 44, 1, 31, "ObjectName",
      CellTags->"REP"],
    Cell[655825, 25815, 52, 1, 74, "Highlight",
      CellTags->"REP"],
    Cell[655880, 25818, 130, 4, 43, "Usage",
      CellTags->"REP"],
    Cell[656013, 25824, 97, 5, 33, "Notes",
      CellTags->"REP"],
    Cell[656113, 25831, 379, 15, 33, "Notes",
      CellTags->"REP"],
    Cell[656517, 25850, 61, 1, 59, "ExampleSection",
      CellTags->"REP"],
    Cell[656581, 25853, 279, 10, 70, "ExampleText",
      CellTags->"REP"],
    Cell[656885, 25867, 137, 5, 70, "Input",
      CellTags->"REP"],
    Cell[657025, 25874, 89, 3, 70, "Output",
      CellTags->"REP"],
    Cell[657117, 25879, 159, 5, 70, "Output",
      CellTags->"REP"],
    Cell[657313, 25889, 111, 3, 70, "Input",
      CellTags->"REP"],
    Cell[657427, 25894, 568, 15, 70, "Output",
      CellTags->"REP"],
    Cell[658032, 25914, 98, 3, 70, "Input",
      CellTags->"REP"],
    Cell[658133, 25919, 560, 9, 70, "Output",
      CellTags->"REP"]},
  "RES"->{
    Cell[658720, 25932, 44, 1, 31, "ObjectName",
      CellTags->"RES"],
    Cell[658767, 25935, 52, 1, 74, "Highlight",
      CellTags->"RES"],
    Cell[658822, 25938, 136, 4, 43, "Usage",
      CellTags->"RES"],
    Cell[658961, 25944, 94, 5, 33, "Notes",
      CellTags->"RES"],
    Cell[659058, 25951, 379, 15, 33, "Notes",
      CellTags->"RES"],
    Cell[659462, 25970, 61, 1, 59, "ExampleSection",
      CellTags->"RES"],
    Cell[659526, 25973, 279, 10, 70, "ExampleText",
      CellTags->"RES"],
    Cell[659830, 25987, 137, 5, 70, "Input",
      CellTags->"RES"],
    Cell[659970, 25994, 89, 3, 70, "Output",
      CellTags->"RES"],
    Cell[660062, 25999, 159, 5, 70, "Output",
      CellTags->"RES"],
    Cell[660258, 26009, 111, 3, 70, "Input",
      CellTags->"RES"],
    Cell[660372, 26014, 568, 15, 70, "Output",
      CellTags->"RES"],
    Cell[660977, 26034, 98, 3, 70, "Input",
      CellTags->"RES"],
    Cell[661078, 26039, 560, 9, 70, "Output",
      CellTags->"RES"]},
  "RET"->{
    Cell[661665, 26052, 44, 1, 31, "ObjectName",
      CellTags->"RET"],
    Cell[661712, 26055, 52, 1, 74, "Highlight",
      CellTags->"RET"],
    Cell[661767, 26058, 138, 4, 43, "Usage",
      CellTags->"RET"],
    Cell[661908, 26064, 97, 5, 33, "Notes",
      CellTags->"RET"],
    Cell[662008, 26071, 379, 15, 33, "Notes",
      CellTags->"RET"],
    Cell[662412, 26090, 61, 1, 59, "ExampleSection",
      CellTags->"RET"],
    Cell[662476, 26093, 279, 10, 70, "ExampleText",
      CellTags->"RET"],
    Cell[662780, 26107, 137, 5, 70, "Input",
      CellTags->"RET"],
    Cell[662920, 26114, 89, 3, 70, "Output",
      CellTags->"RET"],
    Cell[663012, 26119, 159, 5, 70, "Output",
      CellTags->"RET"],
    Cell[663208, 26129, 111, 3, 70, "Input",
      CellTags->"RET"],
    Cell[663322, 26134, 568, 15, 70, "Output",
      CellTags->"RET"],
    Cell[663927, 26154, 98, 3, 70, "Input",
      CellTags->"RET"],
    Cell[664028, 26159, 560, 9, 70, "Output",
      CellTags->"RET"]},
  "SA"->{
    Cell[664615, 26172, 42, 1, 31, "ObjectName",
      CellTags->"SA"],
    Cell[664660, 26175, 51, 1, 74, "Highlight",
      CellTags->"SA"],
    Cell[664714, 26178, 109, 4, 43, "Usage",
      CellTags->"SA"],
    Cell[664826, 26184, 231, 9, 33, "Notes",
      CellTags->"SA"],
    Cell[665060, 26195, 166, 5, 33, "Notes",
      CellTags->"SA"],
    Cell[665229, 26202, 79, 1, 33, "Notes",
      CellTags->"SA"],
    Cell[665311, 26205, 183, 7, 33, "Notes",
      CellTags->"SA"],
    Cell[665497, 26214, 303, 15, 33, "Notes",
      CellTags->"SA"],
    Cell[665825, 26233, 60, 1, 59, "ExampleSection",
      CellTags->"SA"],
    Cell[665888, 26236, 63, 1, 70, "ExampleText",
      CellTags->"SA"],
    Cell[665954, 26239, 212, 5, 70, "Input",
      CellTags->"SA"],
    Cell[666191, 26248, 141, 5, 70, "Input",
      CellTags->"SA"],
    Cell[666335, 26255, 89, 3, 70, "Output",
      CellTags->"SA"],
    Cell[666427, 26260, 89, 3, 70, "Output",
      CellTags->"SA"],
    Cell[666519, 26265, 87, 3, 70, "Output",
      CellTags->"SA"]},
  "TS"->{
    Cell[666633, 26272, 42, 1, 31, "ObjectName",
      CellTags->"TS"],
    Cell[666678, 26275, 51, 1, 74, "Highlight",
      CellTags->"TS"],
    Cell[666732, 26278, 196, 7, 43, "Usage",
      CellTags->"TS"],
    Cell[666931, 26287, 318, 13, 33, "Notes",
      CellTags->"TS"],
    Cell[667252, 26302, 253, 9, 54, "Notes",
      CellTags->"TS"],
    Cell[667508, 26313, 372, 15, 33, "Notes",
      CellTags->"TS"],
    Cell[667905, 26332, 60, 1, 59, "ExampleSection",
      CellTags->"TS"],
    Cell[667968, 26335, 79, 1, 70, "ExampleText",
      CellTags->"TS"],
    Cell[668072, 26340, 73, 2, 70, "Input",
      CellTags->"TS"],
    Cell[668148, 26344, 78, 3, 70, "Output",
      CellTags->"TS"],
    Cell[668263, 26352, 73, 2, 70, "Input",
      CellTags->"TS"],
    Cell[668339, 26356, 78, 3, 70, "Output",
      CellTags->"TS"],
    Cell[668454, 26364, 67, 2, 70, "Input",
      CellTags->"TS"],
    Cell[668524, 26368, 78, 3, 70, "Output",
      CellTags->"TS"],
    Cell[668639, 26376, 80, 2, 70, "Input",
      CellTags->"TS"],
    Cell[668722, 26380, 78, 3, 70, "Output",
      CellTags->"TS"],
    Cell[668837, 26388, 80, 2, 70, "Input",
      CellTags->"TS"],
    Cell[668920, 26392, 133, 4, 70, "Output",
      CellTags->"TS"],
    Cell[669090, 26401, 74, 2, 70, "Input",
      CellTags->"TS"],
    Cell[669167, 26405, 133, 4, 70, "Output",
      CellTags->"TS"]},
  "alphabet"->{
    Cell[669327, 26413, 55, 1, 31, "ObjectName",
      CellTags->"alphabet"],
    Cell[669385, 26416, 57, 1, 74, "Highlight",
      CellTags->"alphabet"],
    Cell[669445, 26419, 182, 5, 43, "Usage",
      CellTags->"alphabet"],
    Cell[669630, 26426, 177, 6, 33, "Notes",
      CellTags->"alphabet"],
    Cell[669810, 26434, 146, 4, 33, "Notes",
      CellTags->"alphabet"],
    Cell[669981, 26442, 66, 1, 59, "ExampleSection",
      CellTags->"alphabet"],
    Cell[670050, 26445, 81, 1, 70, "ExampleText",
      CellTags->"alphabet"],
    Cell[670156, 26450, 75, 2, 70, "Input",
      CellTags->"alphabet"],
    Cell[670234, 26454, 129, 3, 70, "Output",
      CellTags->"alphabet"],
    Cell[670400, 26462, 119, 3, 70, "Input",
      CellTags->"alphabet"],
    Cell[670522, 26467, 171, 4, 70, "Output",
      CellTags->"alphabet"],
    Cell[670730, 26476, 136, 3, 70, "Input",
      CellTags->"alphabet"],
    Cell[670869, 26481, 129, 3, 70, "Output",
      CellTags->"alphabet"]},
  "automataReleaseNumber"->{
    Cell[671025, 26488, 81, 1, 31, "ObjectName",
      CellTags->"automataReleaseNumber"],
    Cell[671109, 26491, 70, 1, 74, "Highlight",
      CellTags->"automataReleaseNumber"],
    Cell[671182, 26494, 169, 4, 43, "Usage",
      CellTags->"automataReleaseNumber"],
    Cell[671354, 26500, 90, 1, 33, "Notes",
      CellTags->"automataReleaseNumber"],
    Cell[671469, 26505, 79, 1, 59, "ExampleSection",
      CellTags->"automataReleaseNumber"],
    Cell[671551, 26508, 80, 1, 70, "ExampleText",
      CellTags->"automataReleaseNumber"],
    Cell[671656, 26513, 101, 2, 70, "Input",
      CellTags->"automataReleaseNumber"],
    Cell[671760, 26517, 101, 3, 70, "Output",
      CellTags->"automataReleaseNumber"]},
  "bottom"->{
    Cell[671888, 26524, 51, 1, 31, "ObjectName",
      CellTags->"bottom"],
    Cell[671942, 26527, 55, 1, 74, "Highlight",
      CellTags->"bottom"],
    Cell[672000, 26530, 194, 6, 43, "Usage",
      CellTags->"bottom"],
    Cell[672197, 26538, 59, 1, 33, "Notes",
      CellTags->"bottom"],
    Cell[672259, 26541, 113, 4, 33, "Notes",
      CellTags->"bottom"],
    Cell[672375, 26547, 159, 7, 33, "Notes",
      CellTags->"bottom"],
    Cell[672559, 26558, 64, 1, 59, "ExampleSection",
      CellTags->"bottom"],
    Cell[672626, 26561, 104, 2, 70, "ExampleText",
      CellTags->"bottom"],
    Cell[672733, 26565, 130, 3, 70, "Input",
      CellTags->"bottom"],
    Cell[672888, 26572, 89, 3, 70, "Input",
      CellTags->"bottom"],
    Cell[672980, 26577, 111, 3, 70, "Output",
      CellTags->"bottom"],
    Cell[673128, 26585, 121, 4, 70, "Input",
      CellTags->"bottom"],
    Cell[673252, 26591, 538, 15, 70, "Output",
      CellTags->"bottom"],
    Cell[673793, 26608, 119, 3, 70, "Output",
      CellTags->"bottom"],
    Cell[673949, 26616, 162, 4, 70, "Input",
      CellTags->"bottom"],
    Cell[674114, 26622, 538, 15, 70, "Output",
      CellTags->"bottom"],
    Cell[674655, 26639, 123, 3, 70, "Output",
      CellTags->"bottom"]},
  "defaultnormalize"->{
    Cell[674805, 26646, 71, 1, 31, "ObjectName",
      CellTags->"defaultnormalize"],
    Cell[674879, 26649, 65, 1, 74, "Highlight",
      CellTags->"defaultnormalize"],
    Cell[674947, 26652, 199, 6, 43, "Usage",
      CellTags->"defaultnormalize"],
    Cell[675149, 26660, 182, 5, 33, "Notes",
      CellTags->"defaultnormalize"],
    Cell[675334, 26667, 327, 10, 54, "Notes",
      CellTags->"defaultnormalize"],
    Cell[675664, 26679, 443, 12, 75, "Notes",
      CellTags->"defaultnormalize"],
    Cell[676110, 26693, 257, 7, 54, "Notes",
      CellTags->"defaultnormalize"],
    Cell[676370, 26702, 337, 7, 75, "Notes",
      CellTags->"defaultnormalize"],
    Cell[676710, 26711, 265, 11, 33, "Notes",
      CellTags->"defaultnormalize"],
    Cell[677000, 26726, 74, 1, 59, "ExampleSection",
      CellTags->"defaultnormalize"],
    Cell[677077, 26729, 94, 1, 70, "ExampleText",
      CellTags->"defaultnormalize"],
    Cell[677196, 26734, 111, 2, 70, "Input",
      CellTags->"defaultnormalize"],
    Cell[677310, 26738, 116, 3, 70, "Output",
      CellTags->"defaultnormalize"],
    Cell[677441, 26744, 79, 1, 70, "ExampleText",
      CellTags->"defaultnormalize"],
    Cell[677545, 26749, 167, 4, 70, "Input",
      CellTags->"defaultnormalize"],
    Cell[677715, 26755, 177, 4, 70, "Output",
      CellTags->"defaultnormalize"],
    Cell[677929, 26764, 162, 4, 70, "Input",
      CellTags->"defaultnormalize"],
    Cell[678094, 26770, 177, 4, 70, "Output",
      CellTags->"defaultnormalize"]},
  "LLL"->{
    Cell[678298, 26778, 45, 1, 31, "ObjectName",
      CellTags->"LLL"],
    Cell[678346, 26781, 52, 1, 74, "Highlight",
      CellTags->"LLL"],
    Cell[678401, 26784, 250, 8, 64, "Usage",
      CellTags->"LLL"],
    Cell[678654, 26794, 62, 1, 33, "Notes",
      CellTags->"LLL"],
    Cell[678719, 26797, 321, 13, 33, "Notes",
      CellTags->"LLL"],
    Cell[679043, 26812, 84, 1, 33, "Notes",
      CellTags->"LLL"],
    Cell[679152, 26817, 61, 1, 59, "ExampleSection",
      CellTags->"LLL"],
    Cell[679216, 26820, 171, 6, 70, "ExampleText",
      CellTags->"LLL"],
    Cell[679390, 26828, 189, 5, 70, "Input",
      CellTags->"LLL"],
    Cell[679582, 26835, 90, 1, 70, "ExampleText",
      CellTags->"LLL"],
    Cell[679697, 26840, 123, 3, 70, "Input",
      CellTags->"LLL"],
    Cell[679823, 26845, 194, 4, 70, "Output",
      CellTags->"LLL"],
    Cell[680032, 26852, 162, 5, 70, "ExampleText",
      CellTags->"LLL"],
    Cell[680219, 26861, 131, 3, 70, "Input",
      CellTags->"LLL"],
    Cell[680353, 26866, 923, 23, 70, "Output",
      CellTags->"LLL"],
    Cell[681291, 26892, 187, 6, 70, "ExampleText",
      CellTags->"LLL"],
    Cell[681503, 26902, 122, 3, 70, "Input",
      CellTags->"LLL"],
    Cell[681628, 26907, 646, 18, 70, "Output",
      CellTags->"LLL"]},
  "regexrules"->{
    Cell[682301, 26929, 59, 1, 31, "ObjectName",
      CellTags->"regexrules"],
    Cell[682363, 26932, 59, 1, 74, "Highlight",
      CellTags->"regexrules"],
    Cell[682425, 26935, 214, 7, 43, "Usage",
      CellTags->"regexrules"],
    Cell[682642, 26944, 140, 4, 33, "Notes",
      CellTags->"regexrules"],
    Cell[682785, 26950, 163, 4, 54, "Notes",
      CellTags->"regexrules"],
    Cell[682973, 26958, 68, 1, 59, "ExampleSection",
      CellTags->"regexrules"],
    Cell[683044, 26961, 136, 4, 70, "ExampleText",
      CellTags->"regexrules"],
    Cell[683205, 26969, 99, 2, 70, "Input",
      CellTags->"regexrules"],
    Cell[683307, 26973, 98, 3, 70, "Output",
      CellTags->"regexrules"],
    Cell[683442, 26981, 100, 2, 70, "Input",
      CellTags->"regexrules"],
    Cell[683545, 26985, 92, 3, 70, "Output",
      CellTags->"regexrules"]},
  "shortlines"->{
    Cell[683664, 26992, 59, 1, 31, "ObjectName",
      CellTags->"shortlines"],
    Cell[683726, 26995, 59, 1, 74, "Highlight",
      CellTags->"shortlines"],
    Cell[683788, 26998, 185, 5, 43, "Usage",
      CellTags->"shortlines"],
    Cell[683976, 27005, 164, 5, 33, "Notes",
      CellTags->"shortlines"],
    Cell[684143, 27012, 63, 1, 33, "Notes",
      CellTags->"shortlines"],
    Cell[684209, 27015, 171, 7, 33, "Notes",
      CellTags->"shortlines"],
    Cell[684405, 27026, 68, 1, 59, "ExampleSection",
      CellTags->"shortlines"],
    Cell[684476, 27029, 83, 1, 48, "ExampleText",
      CellTags->"shortlines"],
    Cell[684584, 27034, 112, 3, 37, "Input",
      CellTags->"shortlines"],
    Cell[684699, 27039, 388, 12, 30, "Output",
      CellTags->"shortlines"],
    Cell[685124, 27056, 126, 4, 60, "Input",
      CellTags->"shortlines"],
    Cell[685253, 27062, 675, 17, 99, "Output",
      CellTags->"shortlines"],
    Cell[685943, 27082, 105, 3, 37, "Input",
      CellTags->"shortlines"]},
  "transdispwidth"->{
    Cell[686063, 27088, 67, 1, 42, "ObjectName",
      CellTags->"transdispwidth"],
    Cell[686133, 27091, 63, 1, 74, "Highlight",
      CellTags->"transdispwidth"],
    Cell[686199, 27094, 199, 6, 43, "Usage",
      CellTags->"transdispwidth"],
    Cell[686401, 27102, 61, 1, 33, "Notes",
      CellTags->"transdispwidth"],
    Cell[686465, 27105, 156, 7, 33, "Notes",
      CellTags->"transdispwidth"],
    Cell[686646, 27116, 72, 1, 59, "ExampleSection",
      CellTags->"transdispwidth"],
    Cell[686721, 27119, 87, 1, 48, "ExampleText",
      CellTags->"transdispwidth"],
    Cell[686833, 27124, 95, 2, 40, "Input",
      CellTags->"transdispwidth"],
    Cell[686931, 27128, 392, 12, 30, "Output",
      CellTags->"transdispwidth"],
    Cell[687360, 27145, 129, 3, 37, "Input",
      CellTags->"transdispwidth"],
    Cell[687492, 27150, 220, 5, 30, "Print",
      CellTags->"transdispwidth"],
    Cell[687715, 27157, 220, 5, 30, "Print",
      CellTags->"transdispwidth"],
    Cell[687938, 27164, 236, 5, 30, "Print",
      CellTags->"transdispwidth"],
    Cell[688177, 27171, 222, 5, 30, "Print",
      CellTags->"transdispwidth"],
    Cell[688402, 27178, 224, 5, 30, "Print",
      CellTags->"transdispwidth"],
    Cell[688629, 27185, 5983, 185, 264, "Output",
      CellTags->"transdispwidth"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"AcceptQFA", 695311, 27392},
  {"AccessibleFA", 696561, 27427},
  {"AddTransitionFA", 698023, 27466},
  {"AllDFA", 699392, 27501},
  {"AlphabetSize", 700196, 27524},
  {"Alphabet", 701288, 27553},
  {"AmbiguousQFA", 702399, 27584},
  {"Arden", 703415, 27611},
  {"BehaviorFA", 705548, 27672},
  {"BFunctionToCA", 706717, 27703},
  {"BuildBEFA", 707925, 27734},
  {"BuildDFA", 708620, 27753},
  {"BuildNNFA", 709823, 27786},
  {"BuildStarDFA", 710521, 27805},
  {"CirculantSA", 711170, 27822},
  {"ClassifyCA", 712114, 27847},
  {"CoAccessibleFA", 713944, 27896},
  {"CodeterministicQFA", 715488, 27935},
  {"ComplementFA", 716435, 27958},
  {"CompleteFA", 718010, 27999},
  {"CompleteQFA", 718941, 28024},
  {"ComposeCA", 719960, 28051},
  {"ComputationFA", 720807, 28074},
  {"ComputationGraphFA", 722170, 28109},
  {"ConcatenateFA", 723120, 28132},
  {"ConvertToFA", 724322, 28163},
  {"CounterDFA", 725265, 28188},
  {"CoverQDFA", 726120, 28211},
  {"DeBruijnEdges", 727336, 28244},
  {"DeBruijnGraph", 728464, 28273},
  {"DefiniteQFA", 729749, 28306},
  {"DegreesFA", 731298, 28347},
  {"DeleteStateFA", 732075, 28368},
  {"DependencyCA", 733275, 28399},
  {"DeterministicQFA", 734159, 28422},
  {"EmptyDFA", 735408, 28453},
  {"EmptyQFA", 736095, 28472},
  {"EpsFreeQ", 736997, 28497},
  {"EpsilonEliminationFA", 737767, 28518},
  {"EquivalentQFA", 739600, 28561},
  {"EvolutionCA", 741371, 28606},
  {"FactorialQFA", 742801, 28643},
  {"FinalVectorFA", 743851, 28670},
  {"Final", 744588, 28689},
  {"FiniteComplementSA", 745266, 28708},
  {"FormatAutomata", 746225, 28731},
  {"FormatX", 748011, 28776},
  {"FrontierQ", 748919, 28801},
  {"FrontierToDFA", 749855, 28826},
  {"FSMQ", 751308, 28863},
  {"FSurjectiveCA", 752109, 28886},
  {"FullAlphabet", 752932, 28907},
  {"FullTransitionMatrixFA", 753990, 28934},
  {"FullTransitions", 755263, 28963},
  {"FunctionToCA", 756191, 28986},
  {"FunctionToDFA", 757404, 29017},
  {"FunctionToSA", 758702, 29050},
  {"GenerateDFA", 760065, 29085},
  {"GenerateQuotients", 761339, 29118},
  {"GlobalMapCA", 762284, 29141},
  {"HomomorphismFA", 763705, 29178},
  {"HurwitzProduct", 764782, 29205},
  {"IdealBaseFA", 766098, 29238},
  {"IdealQFA", 767362, 29271},
  {"IdentityCA", 768205, 29294},
  {"InfiniteQFA", 769378, 29325},
  {"InfixFA", 770639, 29358},
  {"InitialVectorFA", 771478, 29381},
  {"Initial", 772316, 29402},
  {"IntersectionFA", 773008, 29421},
  {"InverseCA", 774482, 29458},
  {"IrreducibleFA", 775414, 29483},
  {"IsomorphicQDFA", 776795, 29518},
  {"IterateCA", 777941, 29547},
  {"IthSymbolDFA", 778797, 29570},
  {"IthSymbolFA", 780000, 29601},
  {"JoinSA", 780951, 29626},
  {"LabelToCodeCA", 781918, 29653},
  {"LanguageFA", 782660, 29672},
  {"LanguageSort", 785665, 29751},
  {"LanguageToSeries", 786483, 29772},
  {"LeftQuotient", 787580, 29799},
  {"LeftShiftCA", 788932, 29834},
  {"LengthDFA", 789883, 29859},
  {"LocalMapCA", 791125, 29892},
  {"LocalUniversalFA", 792394, 29925},
  {"LoopAutomatonFA", 793763, 29958},
  {"MakeHomoDFA", 795121, 29991},
  {"MakeHomomorphism", 796488, 30026},
  {"MakeWord", 797957, 30062},
  {"MatrixToTransitions", 798670, 30081},
  {"MinimalFischerFA", 799569, 30102},
  {"MinimizeDFA", 800927, 30135},
  {"MinimizeFA", 802211, 30168},
  {"ModCounterDFA", 803326, 30197},
  {"NNFAToFA", 804479, 30226},
  {"NoFactorFA", 805712, 30259},
  {"NoPrefixFA", 806829, 30288},
  {"NormalizeControl", 807952, 30317},
  {"NormalizeFA", 809316, 30350},
  {"NoSuffix", 810438, 30379},
  {"NumberOfCA", 811527, 30408},
  {"NumberOfDFA", 812253, 30427},
  {"NumberOfTotalisticCA", 812998, 30446},
  {"NumTransitions", 813818, 30465},
  {"OrbitCA", 814575, 30484},
  {"ParikhVector", 815721, 30515},
  {"PermutationSA", 816386, 30532},
  {"PermuteFA", 817381, 30557},
  {"PlotComputationFA", 818332, 30582},
  {"PolynomialToCA", 819878, 30619},
  {"PrefixDFA", 820722, 30640},
  {"PrefixQ", 821511, 30661},
  {"PrimitiveCount", 822647, 30692},
  {"PrimitiveQ", 823488, 30713},
  {"PrintCA", 824520, 30740},
  {"PrintFA", 825215, 30759},
  {"ProductFA", 827234, 30814},
  {"ProductTransitions", 828572, 30849},
  {"ProperPrefixes", 830053, 30884},
  {"QuotientDFA", 831135, 30911},
  {"QuotientMachineFA", 832579, 30948},
  {"RandomDFA", 834208, 30987},
  {"RandomWord", 835075, 31010},
  {"RankOfDFA", 835948, 31033},
  {"RankToDFA", 836891, 31058},
  {"REEpsQ", 837678, 31079},
  {"RegularExpressionToBEFA", 838664, 31106},
  {"RegularExpressionToFA", 839786, 31131},
  {"RegularExpressionToNNFA", 841506, 31170},
  {"RemoveTransitionFA", 842536, 31193},
  {"REQ", 843842, 31224},
  {"RESimplify", 844716, 31249},
  {"ReverseFA", 845589, 31272},
  {"RightShiftCA", 846536, 31297},
  {"SelectFA", 847510, 31322},
  {"SetFinalFA", 848891, 31359},
  {"SetInitialFA", 849924, 31386},
  {"SetInitialFinalFA", 850988, 31413},
  {"ShowAcceptQFA", 852114, 31440},
  {"ShrinkCA", 852864, 31459},
  {"ShuffleProductFA", 854180, 31494},
  {"SinkQDFA", 855455, 31525},
  {"SinksDFA", 856540, 31554},
  {"Size", 857240, 31573},
  {"SquareSA", 857906, 31592},
  {"StarFA", 859206, 31627},
  {"StateMergeDFA", 860262, 31656},
  {"States", 861494, 31687},
  {"SubsetQFA", 862468, 31714},
  {"Substitute", 863637, 31745},
  {"SubwordCounterDFA", 864754, 31774},
  {"SubwordDFA", 865963, 31803},
  {"SubwordModCounterDFA", 867233, 31836},
  {"SuffixesFA", 868569, 31867},
  {"SuffixFA", 869444, 31890},
  {"SumFA", 870294, 31913},
  {"SwitchTransitionFA", 871776, 31954},
  {"SyntacticCongruence", 872837, 31979},
  {"SyntacticHomomorphism", 874089, 32008},
  {"SyntacticSG", 875527, 32041},
  {"TheInitial", 876416, 32064},
  {"TheSinkDFA", 877216, 32085},
  {"ToBlocks", 877937, 32104},
  {"ToCharacters", 879169, 32137},
  {"ToDFA", 879985, 32158},
  {"ToEquationsDFA", 881678, 32205},
  {"ToFA", 882845, 32234},
  {"ToFrontierDFA", 884084, 32269},
  {"ToGeneratorsFA", 885244, 32298},
  {"ToGraphFA", 886165, 32321},
  {"ToIndex", 887259, 32350},
  {"ToKernelFA", 888171, 32375},
  {"ToLabelCA", 889748, 32416},
  {"ToNFA", 890459, 32435},
  {"ToPeriodicFrontierDFA", 891364, 32460},
  {"ToPrefixFA", 892989, 32497},
  {"ToPrefix", 894329, 32532},
  {"ToRegExp", 895256, 32557},
  {"ToRegularExpressionFA", 896124, 32580},
  {"ToRulesCA", 897477, 32611},
  {"ToSA", 898420, 32636},
  {"ToSeries", 899509, 32667},
  {"ToSuffixFA", 900437, 32692},
  {"TotalisticRuleToCA", 901712, 32725},
  {"ToTotalisticRuleCA", 902685, 32748},
  {"ToTransitions", 903483, 32767},
  {"ToWord", 904152, 32784},
  {"TransferSequenceFA", 904989, 32807},
  {"TransitionFunctionFA", 906051, 32832},
  {"TransitionMatrixFA", 907748, 32871},
  {"TransitionsToMatrix", 909063, 32902},
  {"Transitions", 909782, 32919},
  {"TransitiveLangQFA", 910680, 32942},
  {"TransitiveQFA", 911720, 32967},
  {"TrimFA", 912865, 32996},
  {"TropicalIdentityMatrix", 913858, 33023},
  {"UnionFA", 914603, 33040},
  {"VerifyFA", 915969, 33077},
  {"WelchCA", 916370, 33088},
  {"WidthCA", 917585, 33121},
  {"WordBinomial", 918210, 33138},
  {"WordConjugateQ", 919424, 33169},
  {"WordConjugates", 920588, 33198},
  {"WordFactorizations", 921437, 33219},
  {"WordFactors", 922403, 33242},
  {"WordFusion", 923750, 33277},
  {"WordLength", 924549, 33298},
  {"WordOrder", 925424, 33321},
  {"WordPower", 926289, 33344},
  {"WordPrefixes", 927460, 33375},
  {"WordReverse", 928438, 33400},
  {"WordRoot", 929242, 33421},
  {"WordRotate", 930098, 33444},
  {"WordShuffle", 931127, 33471},
  {"WordSort", 931933, 33492},
  {"WordSuffixes", 932864, 33517},
  {"Words", 933758, 33540},
  {"Alphabetic", 934863, 33571},
  {"Boundary", 935268, 33582},
  {"Cyclic", 935661, 33593},
  {"EdgeLU", 935972, 33602},
  {"Empty", 936352, 33613},
  {"EpsElim", 936659, 33622},
  {"FinLU", 937046, 33633},
  {"Fixed", 937421, 33644},
  {"FLBound", 937798, 33655},
  {"Hopcroft", 938259, 33668},
  {"Implementation", 938659, 33679},
  {"IniLU", 939079, 33690},
  {"ListAble", 939457, 33701},
  {"MakeTrim", 939777, 33710},
  {"RegExpSimp", 940173, 33721},
  {"ShowAll", 940576, 33732},
  {"ShowEdges", 941039, 33745},
  {"SizeOnly", 941438, 33756},
  {"Some", 942288, 33779},
  {"Thompson", 942592, 33788},
  {"ToMatrix", 942986, 33799},
  {"TransOnly", 943381, 33810},
  {"Tropical", 944698, 33845},
  {"Unlabeled", 945094, 33856},
  {"WordMap", 946032, 33881},
  {"BEFA", 946797, 33902},
  {"CA", 947529, 33923},
  {"DFA", 948451, 33950},
  {"FA", 949590, 33983},
  {"NFA", 950643, 34014},
  {"NNFA", 951647, 34043},
  {"REP", 952311, 34062},
  {"RES", 953314, 34091},
  {"RET", 954317, 34120},
  {"SA", 955319, 34149},
  {"TS", 956370, 34180},
  {"alphabet", 957765, 34221},
  {"automataReleaseNumber", 958779, 34248},
  {"bottom", 959510, 34265},
  {"defaultnormalize", 960785, 34300},
  {"LLL", 962304, 34337},
  {"regexrules", 963607, 34374},
  {"shortlines", 964482, 34397},
  {"transdispwidth", 965516, 34424}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 56, 1, 42, "ObjectName",
  CellTags->"AcceptQFA"],
Cell[1813, 54, 60, 1, 74, "Highlight",
  CellTags->"AcceptQFA"],
Cell[1876, 57, 137, 4, 43, "Usage",
  CellTags->"AcceptQFA"],
Cell[2016, 63, 281, 10, 80, "Notes",
  CellTags->"AcceptQFA"],
Cell[2300, 75, 144, 5, 33, "Notes",
  CellTags->"AcceptQFA"],
Cell[2447, 82, 161, 5, 33, "Notes",
  CellTags->"AcceptQFA"],

Cell[CellGroupData[{
Cell[2633, 91, 67, 1, 59, "ExampleSection",
  CellTags->"AcceptQFA"],
Cell[2703, 94, 169, 6, 70, "ExampleText",
  CellTags->"AcceptQFA"],

Cell[CellGroupData[{
Cell[2897, 104, 87, 2, 70, "Input",
  CellTags->"AcceptQFA"],
Cell[2987, 108, 378, 12, 70, "Output",
  CellTags->"AcceptQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3402, 125, 103, 3, 70, "Input",
  CellTags->"AcceptQFA"],
Cell[3508, 130, 89, 3, 70, "Output",
  CellTags->"AcceptQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3634, 138, 125, 3, 70, "Input",
  CellTags->"AcceptQFA"],
Cell[3762, 143, 103, 3, 70, "Output",
  CellTags->"AcceptQFA"]
}, Open  ]],
Cell[3880, 149, 79, 1, 70, "ExampleText",
  CellTags->"AcceptQFA"],

Cell[CellGroupData[{
Cell[3984, 154, 123, 3, 70, "Input",
  CellTags->"AcceptQFA"],
Cell[4110, 159, 133, 3, 70, "Output",
  CellTags->"AcceptQFA"]
}, Open  ]]
}, Closed]],
Cell[4270, 166, 62, 1, 31, "ObjectName",
  CellTags->"AccessibleFA"],
Cell[4335, 169, 63, 1, 74, "Highlight",
  CellTags->"AccessibleFA"],
Cell[4401, 172, 171, 6, 43, "Usage",
  CellTags->"AccessibleFA"],
Cell[4575, 180, 319, 10, 82, "Notes",
  CellTags->"AccessibleFA"],
Cell[4897, 192, 92, 1, 33, "Notes",
  CellTags->"AccessibleFA"],
Cell[4992, 195, 129, 4, 33, "Notes",
  CellTags->"AccessibleFA"],
Cell[5124, 201, 264, 11, 33, "Notes",
  CellTags->"AccessibleFA"],

Cell[CellGroupData[{
Cell[5413, 216, 70, 1, 59, "ExampleSection",
  CellTags->"AccessibleFA"],
Cell[5486, 219, 180, 4, 70, "MathCaption",
  CellTags->"AccessibleFA"],

Cell[CellGroupData[{
Cell[5691, 227, 204, 5, 70, "Input",
  CellTags->"AccessibleFA"],
Cell[5898, 234, 398, 12, 70, "Output",
  CellTags->"AccessibleFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6333, 251, 149, 4, 70, "Input",
  CellTags->"AccessibleFA"],
Cell[6485, 257, 377, 12, 70, "Output",
  CellTags->"AccessibleFA"],
Cell[6865, 271, 91, 3, 70, "Output",
  CellTags->"AccessibleFA"]
}, Open  ]],
Cell[6971, 277, 106, 1, 70, "MathCaption",
  CellTags->"AccessibleFA"],

Cell[CellGroupData[{
Cell[7102, 282, 136, 3, 70, "Input",
  CellTags->"AccessibleFA"],
Cell[7241, 287, 96, 3, 70, "Output",
  CellTags->"AccessibleFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7374, 295, 136, 3, 70, "Input",
  CellTags->"AccessibleFA"],
Cell[7513, 300, 96, 3, 70, "Output",
  CellTags->"AccessibleFA"]
}, Open  ]]
}, Closed]],
Cell[7636, 307, 68, 1, 31, "ObjectName",
  CellTags->"AddTransitionFA"],
Cell[7707, 310, 66, 1, 74, "Highlight",
  CellTags->"AddTransitionFA"],
Cell[7776, 313, 399, 14, 64, "Usage",
  CellTags->"AddTransitionFA"],
Cell[8178, 329, 131, 4, 33, "Notes",
  CellTags->"AddTransitionFA"],
Cell[8312, 335, 184, 7, 33, "Notes",
  CellTags->"AddTransitionFA"],

Cell[CellGroupData[{
Cell[8521, 346, 73, 1, 59, "ExampleSection",
  CellTags->"AddTransitionFA"],
Cell[8597, 349, 94, 1, 70, "ExampleText",
  CellTags->"AddTransitionFA"],

Cell[CellGroupData[{
Cell[8716, 354, 204, 5, 70, "Input",
  CellTags->"AddTransitionFA"],
Cell[8923, 361, 392, 12, 70, "Output",
  CellTags->"AddTransitionFA"],
Cell[9318, 375, 120, 3, 70, "Output",
  CellTags->"AddTransitionFA"]
}, Open  ]],
Cell[9453, 381, 158, 6, 70, "ExampleText",
  CellTags->"AddTransitionFA"],

Cell[CellGroupData[{
Cell[9636, 391, 172, 4, 70, "Input",
  CellTags->"AddTransitionFA"],
Cell[9811, 397, 403, 12, 70, "Output",
  CellTags->"AddTransitionFA"],
Cell[10217, 411, 212, 4, 70, "Output",
  CellTags->"AddTransitionFA"]
}, Open  ]],
Cell[10444, 418, 161, 6, 70, "ExampleText",
  CellTags->"AddTransitionFA"],

Cell[CellGroupData[{
Cell[10630, 428, 178, 4, 70, "Input",
  CellTags->"AddTransitionFA"],
Cell[10811, 434, 739, 13, 70, "Output",
  CellTags->"AddTransitionFA"]
}, Open  ]]
}, Closed]],
Cell[11577, 451, 50, 1, 31, "ObjectName",
  CellTags->"AllDFA"],
Cell[11630, 454, 57, 1, 74, "Highlight",
  CellTags->"AllDFA"],
Cell[11690, 457, 172, 6, 43, "Usage",
  CellTags->"AllDFA"],
Cell[11865, 465, 225, 9, 58, "Notes",
  CellTags->"AllDFA"],
Cell[12093, 476, 148, 5, 33, "Notes",
  CellTags->"AllDFA"],

Cell[CellGroupData[{
Cell[12266, 485, 64, 1, 59, "ExampleSection",
  CellTags->"AllDFA"],
Cell[12333, 488, 179, 6, 70, "ExampleText",
  CellTags->"AllDFA"],

Cell[CellGroupData[{
Cell[12537, 498, 118, 3, 70, "Input",
  CellTags->"AllDFA"],
Cell[12658, 503, 371, 12, 70, "Output",
  CellTags->"AllDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13066, 520, 102, 3, 70, "Input",
  CellTags->"AllDFA"],
Cell[13171, 525, 386, 7, 70, "Output",
  CellTags->"AllDFA"]
}, Open  ]]
}, Closed]],
Cell[13584, 536, 62, 1, 31, "ObjectName",
  CellTags->"AlphabetSize"],
Cell[13649, 539, 63, 1, 74, "Highlight",
  CellTags->"AlphabetSize"],
Cell[13715, 542, 164, 6, 43, "Usage",
  CellTags->"AlphabetSize"],
Cell[13882, 550, 73, 1, 33, "Notes",
  CellTags->"AlphabetSize"],
Cell[13958, 553, 264, 11, 33, "Notes",
  CellTags->"AlphabetSize"],

Cell[CellGroupData[{
Cell[14247, 568, 70, 1, 59, "ExampleSection",
  CellTags->"AlphabetSize"],
Cell[14320, 571, 89, 1, 70, "ExampleText",
  CellTags->"AlphabetSize"],

Cell[CellGroupData[{
Cell[14434, 576, 207, 8, 70, "Input",
  CellTags->"AlphabetSize"],
Cell[14644, 586, 89, 3, 70, "Output",
  CellTags->"AlphabetSize"]
}, Open  ]],
Cell[14748, 592, 76, 1, 70, "ExampleText",
  CellTags->"AlphabetSize"],

Cell[CellGroupData[{
Cell[14849, 597, 110, 3, 70, "Input",
  CellTags->"AlphabetSize"],
Cell[14962, 602, 89, 3, 70, "Output",
  CellTags->"AlphabetSize"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15088, 610, 107, 3, 70, "Input",
  CellTags->"AlphabetSize"],
Cell[15198, 615, 89, 3, 70, "Output",
  CellTags->"AlphabetSize"]
}, Open  ]]
}, Closed]],
Cell[15314, 622, 54, 1, 31, "ObjectName",
  CellTags->"Alphabet"],
Cell[15371, 625, 59, 1, 74, "Highlight",
  CellTags->"Alphabet"],
Cell[15433, 628, 161, 6, 43, "Usage",
  CellTags->"Alphabet"],
Cell[15597, 636, 131, 4, 33, "Notes",
  CellTags->"Alphabet"],
Cell[15731, 642, 82, 1, 33, "Notes",
  CellTags->"Alphabet"],
Cell[15816, 645, 269, 11, 33, "Notes",
  CellTags->"Alphabet"],

Cell[CellGroupData[{
Cell[16110, 660, 66, 1, 59, "ExampleSection",
  CellTags->"Alphabet"],
Cell[16179, 663, 84, 1, 70, "ExampleText",
  CellTags->"Alphabet"],

Cell[CellGroupData[{
Cell[16288, 668, 199, 8, 70, "Input",
  CellTags->"Alphabet"],
Cell[16490, 678, 99, 3, 70, "Output",
  CellTags->"Alphabet"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16626, 686, 187, 7, 70, "Input",
  CellTags->"Alphabet"],
Cell[16816, 695, 99, 3, 70, "Output",
  CellTags->"Alphabet"]
}, Open  ]],
Cell[16930, 701, 70, 1, 70, "ExampleText",
  CellTags->"Alphabet"],

Cell[CellGroupData[{
Cell[17025, 706, 86, 2, 70, "Input",
  CellTags->"Alphabet"],
Cell[17114, 710, 104, 3, 70, "Output",
  CellTags->"Alphabet"]
}, Open  ]]
}, Closed]],
Cell[17245, 717, 62, 1, 31, "ObjectName",
  CellTags->"AmbiguousQFA"],
Cell[17310, 720, 63, 1, 74, "Highlight",
  CellTags->"AmbiguousQFA"],
Cell[17376, 723, 167, 6, 43, "Usage",
  CellTags->"AmbiguousQFA"],
Cell[17546, 731, 295, 10, 80, "Notes",
  CellTags->"AmbiguousQFA"],
Cell[17844, 743, 205, 6, 54, "Notes",
  CellTags->"AmbiguousQFA"],
Cell[18052, 751, 134, 4, 33, "Notes",
  CellTags->"AmbiguousQFA"],

Cell[CellGroupData[{
Cell[18211, 759, 70, 1, 59, "ExampleSection",
  CellTags->"AmbiguousQFA"],
Cell[18284, 762, 81, 1, 70, "ExampleText",
  CellTags->"AmbiguousQFA"],

Cell[CellGroupData[{
Cell[18390, 767, 219, 8, 70, "Input",
  CellTags->"AmbiguousQFA"],
Cell[18612, 777, 90, 3, 70, "Output",
  CellTags->"AmbiguousQFA"]
}, Open  ]],
Cell[18717, 783, 104, 1, 70, "ExampleText",
  CellTags->"AmbiguousQFA"],

Cell[CellGroupData[{
Cell[18846, 788, 145, 4, 70, "Input",
  CellTags->"AmbiguousQFA"],
Cell[18994, 794, 92, 3, 70, "Output",
  CellTags->"AmbiguousQFA"]
}, Open  ]]
}, Closed]],
Cell[19113, 801, 48, 1, 31, "ObjectName",
  CellTags->"Arden"],
Cell[19164, 804, 56, 1, 74, "Highlight",
  CellTags->"Arden"],
Cell[19223, 807, 310, 8, 64, "Usage",
  CellTags->"Arden"],
Cell[19536, 817, 117, 5, 33, "Notes",
  CellTags->"Arden"],
Cell[19656, 824, 203, 5, 54, "Notes",
  CellTags->"Arden"],

Cell[CellGroupData[{
Cell[19884, 833, 63, 1, 59, "ExampleSection",
  CellTags->"Arden"],
Cell[19950, 836, 266, 9, 70, "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{
Cell[20241, 849, 136, 3, 70, "Input",
  CellTags->"Arden"],
Cell[20380, 854, 373, 12, 70, "Output",
  CellTags->"Arden"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20790, 871, 267, 6, 70, "Input",
  CellTags->"Arden"],
Cell[21060, 879, 1533, 40, 70, "Output",
  CellTags->"Arden"]
}, Open  ]],
Cell[22608, 922, 273, 12, 70, "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{
Cell[22906, 938, 133, 4, 70, "Input",
  CellTags->"Arden"],
Cell[23042, 944, 177, 4, 70, "Output",
  CellTags->"Arden"]
}, Open  ]],
Cell[23234, 951, 296, 12, 70, "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{
Cell[23555, 967, 133, 4, 70, "Input",
  CellTags->"Arden"],
Cell[23691, 973, 171, 5, 70, "Output",
  CellTags->"Arden"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23899, 983, 120, 4, 70, "Input",
  CellTags->"Arden"],
Cell[24022, 989, 154, 4, 70, "Output",
  CellTags->"Arden"]
}, Open  ]],
Cell[24191, 996, 116, 4, 70, "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{
Cell[24332, 1004, 129, 4, 70, "Input",
  CellTags->"Arden"],
Cell[24464, 1010, 350, 7, 70, "Output",
  CellTags->"Arden"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24851, 1022, 120, 4, 70, "Input",
  CellTags->"Arden"],
Cell[24974, 1028, 286, 7, 70, "Output",
  CellTags->"Arden"]
}, Open  ]],
Cell[25275, 1038, 192, 5, 70, "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{
Cell[25492, 1047, 183, 5, 70, "Input",
  CellTags->"Arden"],
Cell[25678, 1054, 148, 4, 70, "Output",
  CellTags->"Arden"]
}, Open  ]],
Cell[25841, 1061, 122, 4, 70, "ExampleText",
  CellTags->"Arden"],

Cell[CellGroupData[{
Cell[25988, 1069, 224, 5, 70, "Input",
  CellTags->"Arden"],
Cell[26215, 1076, 84, 3, 70, "Output",
  CellTags->"Arden"]
}, Open  ]]
}, Closed]],
Cell[26326, 1083, 58, 1, 31, "ObjectName",
  CellTags->"BehaviorFA"],
Cell[26387, 1086, 61, 1, 74, "Highlight",
  CellTags->"BehaviorFA"],
Cell[26451, 1089, 409, 14, 64, "Usage",
  CellTags->"BehaviorFA"],
Cell[26863, 1105, 186, 7, 33, "Notes",
  CellTags->"BehaviorFA"],
Cell[27052, 1114, 164, 7, 33, "Notes",
  CellTags->"BehaviorFA"],

Cell[CellGroupData[{
Cell[27241, 1125, 68, 1, 59, "ExampleSection",
  CellTags->"BehaviorFA"],
Cell[27312, 1128, 199, 6, 70, "ExampleText",
  CellTags->"BehaviorFA"],

Cell[CellGroupData[{
Cell[27536, 1138, 92, 2, 70, "Input",
  CellTags->"BehaviorFA"],
Cell[27631, 1142, 372, 12, 70, "Output",
  CellTags->"BehaviorFA"]
}, Open  ]],
Cell[28018, 1157, 132, 4, 70, "ExampleText",
  CellTags->"BehaviorFA"],

Cell[CellGroupData[{
Cell[28175, 1165, 108, 3, 70, "Input",
  CellTags->"BehaviorFA"],
Cell[28286, 1170, 184, 4, 70, "Output",
  CellTags->"BehaviorFA"]
}, Open  ]],
Cell[28485, 1177, 187, 6, 70, "ExampleText",
  CellTags->"BehaviorFA"],

Cell[CellGroupData[{
Cell[28697, 1187, 108, 3, 70, "Input",
  CellTags->"BehaviorFA"],
Cell[28808, 1192, 181, 4, 70, "Output",
  CellTags->"BehaviorFA"]
}, Open  ]]
}, Closed]],
Cell[29016, 1200, 64, 1, 31, "ObjectName",
  CellTags->"BFunctionToCA"],
Cell[29083, 1203, 64, 1, 74, "Highlight",
  CellTags->"BFunctionToCA"],
Cell[29150, 1206, 458, 16, 64, "Usage",
  CellTags->"BFunctionToCA"],
Cell[29611, 1224, 226, 10, 33, "Notes",
  CellTags->"BFunctionToCA"],
Cell[29840, 1236, 269, 10, 33, "Notes",
  CellTags->"BFunctionToCA"],
Cell[30112, 1248, 156, 7, 33, "Notes",
  CellTags->"BFunctionToCA"],

Cell[CellGroupData[{
Cell[30293, 1259, 71, 1, 59, "ExampleSection",
  CellTags->"BFunctionToCA"],
Cell[30367, 1262, 136, 4, 70, "ExampleText",
  CellTags->"BFunctionToCA"],

Cell[CellGroupData[{
Cell[30528, 1270, 118, 5, 70, "Input",
  CellTags->"BFunctionToCA"],
Cell[30649, 1277, 105, 3, 70, "Output",
  CellTags->"BFunctionToCA"],
Cell[30757, 1282, 560, 14, 70, "Output",
  CellTags->"BFunctionToCA"]
}, Open  ]],
Cell[31332, 1299, 74, 1, 70, "ExampleText",
  CellTags->"BFunctionToCA"],

Cell[CellGroupData[{
Cell[31431, 1304, 119, 5, 70, "Input",
  CellTags->"BFunctionToCA"],
Cell[31553, 1311, 106, 3, 70, "Output",
  CellTags->"BFunctionToCA"],
Cell[31662, 1316, 560, 14, 70, "Output",
  CellTags->"BFunctionToCA"]
}, Open  ]]
}, Closed]],
Cell[32249, 1334, 56, 1, 31, "ObjectName",
  CellTags->"BuildBEFA"],
Cell[32308, 1337, 60, 1, 74, "Highlight",
  CellTags->"BuildBEFA"],
Cell[32371, 1340, 197, 7, 43, "Usage",
  CellTags->"BuildBEFA"],
Cell[32571, 1349, 117, 5, 33, "Notes",
  CellTags->"BuildBEFA"],
Cell[32691, 1356, 134, 4, 33, "Notes",
  CellTags->"BuildBEFA"],

Cell[CellGroupData[{
Cell[32850, 1364, 67, 1, 59, "ExampleSection",
  CellTags->"BuildBEFA"],
Cell[32920, 1367, 231, 7, 70, "ExampleText",
  CellTags->"BuildBEFA"],

Cell[CellGroupData[{
Cell[33176, 1378, 84, 2, 70, "Input",
  CellTags->"BuildBEFA"],
Cell[33263, 1382, 152, 4, 70, "Output",
  CellTags->"BuildBEFA"]
}, Open  ]]
}, Closed]],
Cell[33442, 1390, 54, 1, 31, "ObjectName",
  CellTags->"BuildDFA"],
Cell[33499, 1393, 59, 1, 74, "Highlight",
  CellTags->"BuildDFA"],
Cell[33561, 1396, 347, 11, 67, "Usage",
  CellTags->"BuildDFA"],
Cell[33911, 1409, 248, 9, 58, "Notes",
  CellTags->"BuildDFA"],
Cell[34162, 1420, 257, 8, 54, "Notes",
  CellTags->"BuildDFA"],
Cell[34422, 1430, 164, 7, 33, "Notes",
  CellTags->"BuildDFA"],

Cell[CellGroupData[{
Cell[34611, 1441, 66, 1, 59, "ExampleSection",
  CellTags->"BuildDFA"],
Cell[34680, 1444, 75, 1, 70, "ExampleText",
  CellTags->"BuildDFA"],

Cell[CellGroupData[{
Cell[34780, 1449, 151, 4, 70, "Input",
  CellTags->"BuildDFA"],
Cell[34934, 1455, 388, 12, 70, "Output",
  CellTags->"BuildDFA"],
Cell[35325, 1469, 127, 3, 70, "Output",
  CellTags->"BuildDFA"]
}, Open  ]],
Cell[35467, 1475, 86, 1, 70, "ExampleText",
  CellTags->"BuildDFA"],

Cell[CellGroupData[{
Cell[35578, 1480, 183, 5, 70, "Input",
  CellTags->"BuildDFA"],
Cell[35764, 1487, 210, 4, 70, "Output",
  CellTags->"BuildDFA"],
Cell[35977, 1493, 434, 14, 70, "Output",
  CellTags->"BuildDFA"],
Cell[36414, 1509, 247, 5, 70, "Output",
  CellTags->"BuildDFA"]
}, Open  ]]
}, Closed]],
Cell[36688, 1518, 56, 1, 31, "ObjectName",
  CellTags->"BuildNNFA"],
Cell[36747, 1521, 60, 1, 74, "Highlight",
  CellTags->"BuildNNFA"],
Cell[36810, 1524, 213, 6, 64, "Usage",
  CellTags->"BuildNNFA"],
Cell[37026, 1532, 117, 5, 33, "Notes",
  CellTags->"BuildNNFA"],
Cell[37146, 1539, 145, 4, 33, "Notes",
  CellTags->"BuildNNFA"],

Cell[CellGroupData[{
Cell[37316, 1547, 67, 1, 59, "ExampleSection",
  CellTags->"BuildNNFA"],
Cell[37386, 1550, 73, 1, 70, "ExampleText",
  CellTags->"BuildNNFA"],

Cell[CellGroupData[{
Cell[37484, 1555, 81, 2, 70, "Input",
  CellTags->"BuildNNFA"],
Cell[37568, 1559, 139, 3, 70, "Output",
  CellTags->"BuildNNFA"]
}, Open  ]]
}, Closed]],
Cell[37734, 1566, 62, 1, 31, "ObjectName",
  CellTags->"BuildStarDFA"],
Cell[37799, 1569, 63, 1, 74, "Highlight",
  CellTags->"BuildStarDFA"],
Cell[37865, 1572, 202, 7, 43, "Usage",
  CellTags->"BuildStarDFA"],
Cell[38070, 1581, 91, 1, 33, "Notes",
  CellTags->"BuildStarDFA"],

Cell[CellGroupData[{
Cell[38186, 1586, 70, 1, 59, "ExampleSection",
  CellTags->"BuildStarDFA"],
Cell[38259, 1589, 261, 9, 70, "ExampleText",
  CellTags->"BuildStarDFA"],

Cell[CellGroupData[{
Cell[38545, 1602, 90, 2, 70, "Input",
  CellTags->"BuildStarDFA"],
Cell[38638, 1606, 403, 12, 70, "Output",
  CellTags->"BuildStarDFA"]
}, Open  ]]
}, Closed]],
Cell[39068, 1622, 60, 1, 31, "ObjectName",
  CellTags->"CirculantSA"],
Cell[39131, 1625, 62, 1, 74, "Highlight",
  CellTags->"CirculantSA"],
Cell[39196, 1628, 318, 10, 64, "Usage",
  CellTags->"CirculantSA"],
Cell[39517, 1640, 132, 5, 33, "Notes",
  CellTags->"CirculantSA"],
Cell[39652, 1647, 167, 7, 33, "Notes",
  CellTags->"CirculantSA"],
Cell[39822, 1656, 172, 7, 33, "Notes",
  CellTags->"CirculantSA"],

Cell[CellGroupData[{
Cell[40019, 1667, 69, 1, 59, "ExampleSection",
  CellTags->"CirculantSA"],
Cell[40091, 1670, 245, 9, 70, "ExampleText",
  CellTags->"CirculantSA"],

Cell[CellGroupData[{
Cell[40361, 1683, 138, 3, 70, "Input",
  CellTags->"CirculantSA"],
Cell[40502, 1688, 369, 10, 70, "Output",
  CellTags->"CirculantSA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40908, 1703, 102, 3, 70, "Input",
  CellTags->"CirculantSA"],
Cell[41013, 1708, 226, 5, 70, "Output",
  CellTags->"CirculantSA"]
}, Open  ]]
}, Closed]],
Cell[41266, 1717, 58, 1, 31, "ObjectName",
  CellTags->"ClassifyCA"],
Cell[41327, 1720, 61, 1, 74, "Highlight",
  CellTags->"ClassifyCA"],
Cell[41391, 1723, 272, 6, 64, "Usage",
  CellTags->"ClassifyCA"],
Cell[41666, 1731, 296, 10, 80, "Notes",
  CellTags->"ClassifyCA"],
Cell[41965, 1743, 465, 17, 128, "Notes",
  CellTags->"ClassifyCA"],
Cell[42433, 1762, 208, 6, 54, "Notes",
  CellTags->"ClassifyCA"],
Cell[42644, 1770, 121, 4, 33, "Notes",
  CellTags->"ClassifyCA"],
Cell[42768, 1776, 157, 4, 33, "Notes",
  CellTags->"ClassifyCA"],

Cell[CellGroupData[{
Cell[42950, 1784, 68, 1, 59, "ExampleSection",
  CellTags->"ClassifyCA"],
Cell[43021, 1787, 83, 1, 70, "ExampleText",
  CellTags->"ClassifyCA"],

Cell[CellGroupData[{
Cell[43129, 1792, 88, 2, 70, "Input",
  CellTags->"ClassifyCA"],
Cell[43220, 1796, 87, 3, 70, "Output",
  CellTags->"ClassifyCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43344, 1804, 87, 2, 70, "Input",
  CellTags->"ClassifyCA"],
Cell[43434, 1808, 87, 3, 70, "Output",
  CellTags->"ClassifyCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43558, 1816, 87, 2, 70, "Input",
  CellTags->"ClassifyCA"],
Cell[43648, 1820, 87, 3, 70, "Output",
  CellTags->"ClassifyCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43772, 1828, 87, 2, 70, "Input",
  CellTags->"ClassifyCA"],
Cell[43862, 1832, 87, 3, 70, "Output",
  CellTags->"ClassifyCA"]
}, Open  ]],
Cell[43964, 1838, 89, 1, 70, "ExampleText",
  CellTags->"ClassifyCA"],

Cell[CellGroupData[{
Cell[44078, 1843, 121, 3, 70, "Input",
  CellTags->"ClassifyCA"],
Cell[44202, 1848, 87, 3, 70, "Output",
  CellTags->"ClassifyCA"]
}, Open  ]],
Cell[44304, 1854, 68, 1, 70, "ExampleText",
  CellTags->"ClassifyCA"],

Cell[CellGroupData[{
Cell[44397, 1859, 177, 4, 70, "Input",
  CellTags->"ClassifyCA"],
Cell[44577, 1865, 393, 14, 70, "Output",
  CellTags->"ClassifyCA"]
}, Open  ]]
}, Closed]],
Cell[44997, 1883, 66, 1, 31, "ObjectName",
  CellTags->"CoAccessibleFA"],
Cell[45066, 1886, 65, 1, 74, "Highlight",
  CellTags->"CoAccessibleFA"],
Cell[45134, 1889, 191, 6, 43, "Usage",
  CellTags->"CoAccessibleFA"],
Cell[45328, 1897, 321, 10, 82, "Notes",
  CellTags->"CoAccessibleFA"],
Cell[45652, 1909, 167, 5, 33, "Notes",
  CellTags->"CoAccessibleFA"],
Cell[45822, 1916, 262, 11, 33, "Notes",
  CellTags->"CoAccessibleFA"],

Cell[CellGroupData[{
Cell[46109, 1931, 72, 1, 59, "ExampleSection",
  CellTags->"CoAccessibleFA"],
Cell[46184, 1934, 125, 4, 70, "MathCaption",
  CellTags->"CoAccessibleFA"],

Cell[CellGroupData[{
Cell[46334, 1942, 193, 5, 70, "Input",
  CellTags->"CoAccessibleFA"],
Cell[46530, 1949, 389, 12, 70, "Output",
  CellTags->"CoAccessibleFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46956, 1966, 143, 4, 70, "Input",
  CellTags->"CoAccessibleFA"],
Cell[47102, 1972, 378, 12, 70, "Output",
  CellTags->"CoAccessibleFA"],
Cell[47483, 1986, 92, 3, 70, "Output",
  CellTags->"CoAccessibleFA"]
}, Open  ]],
Cell[47590, 1992, 108, 1, 70, "MathCaption",
  CellTags->"CoAccessibleFA"],

Cell[CellGroupData[{
Cell[47723, 1997, 139, 3, 70, "Input",
  CellTags->"CoAccessibleFA"],
Cell[47865, 2002, 97, 3, 70, "Output",
  CellTags->"CoAccessibleFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47999, 2010, 139, 3, 70, "Input",
  CellTags->"CoAccessibleFA"],
Cell[48141, 2015, 378, 12, 70, "Output",
  CellTags->"CoAccessibleFA"],
Cell[48522, 2029, 97, 3, 70, "Output",
  CellTags->"CoAccessibleFA"]
}, Open  ]]
}, Closed]],
Cell[48646, 2036, 74, 1, 31, "ObjectName",
  CellTags->"CodeterministicQFA"],
Cell[48723, 2039, 69, 1, 74, "Highlight",
  CellTags->"CodeterministicQFA"],
Cell[48795, 2042, 186, 5, 64, "Usage",
  CellTags->"CodeterministicQFA"],
Cell[48984, 2049, 237, 9, 58, "Notes",
  CellTags->"CodeterministicQFA"],
Cell[49224, 2060, 425, 17, 54, "Notes",
  CellTags->"CodeterministicQFA"],
Cell[49652, 2079, 183, 7, 33, "Notes",
  CellTags->"CodeterministicQFA"],

Cell[CellGroupData[{
Cell[49860, 2090, 76, 1, 59, "ExampleSection",
  CellTags->"CodeterministicQFA"],
Cell[49939, 2093, 141, 4, 70, "ExampleText",
  CellTags->"CodeterministicQFA"],

Cell[CellGroupData[{
Cell[50105, 2101, 149, 4, 70, "Input",
  CellTags->"CodeterministicQFA"],
Cell[50257, 2107, 357, 10, 70, "Output",
  CellTags->"CodeterministicQFA"],
Cell[50617, 2119, 98, 3, 70, "Output",
  CellTags->"CodeterministicQFA"]
}, Open  ]]
}, Closed]],
Cell[50742, 2126, 62, 1, 31, "ObjectName",
  CellTags->"ComplementFA"],
Cell[50807, 2129, 63, 1, 74, "Highlight",
  CellTags->"ComplementFA"],
Cell[50873, 2132, 187, 5, 64, "Usage",
  CellTags->"ComplementFA"],
Cell[51063, 2139, 252, 5, 54, "Notes",
  CellTags->"ComplementFA"],
Cell[51318, 2146, 151, 4, 33, "Notes",
  CellTags->"ComplementFA"],

Cell[CellGroupData[{
Cell[51494, 2154, 70, 1, 59, "ExampleSection",
  CellTags->"ComplementFA"],
Cell[51567, 2157, 134, 4, 70, "ExampleText",
  CellTags->"ComplementFA"],

Cell[CellGroupData[{
Cell[51726, 2165, 98, 2, 70, "Input",
  CellTags->"ComplementFA"],
Cell[51827, 2169, 393, 12, 70, "Output",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52257, 2186, 111, 3, 70, "Input",
  CellTags->"ComplementFA"],
Cell[52371, 2191, 405, 12, 70, "Output",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52813, 2208, 134, 3, 70, "Input",
  CellTags->"ComplementFA"],
Cell[52950, 2213, 121, 3, 70, "Output",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53108, 2221, 100, 2, 70, "Input",
  CellTags->"ComplementFA"],
Cell[53211, 2225, 414, 12, 70, "Output",
  CellTags->"ComplementFA"]
}, Open  ]],
Cell[53640, 2240, 110, 2, 70, "ExampleText",
  CellTags->"ComplementFA"],

Cell[CellGroupData[{
Cell[53775, 2246, 121, 3, 70, "Input",
  CellTags->"ComplementFA"],
Cell[53899, 2251, 411, 12, 70, "Output",
  CellTags->"ComplementFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54347, 2268, 134, 3, 70, "Input",
  CellTags->"ComplementFA"],
Cell[54484, 2273, 116, 3, 70, "Output",
  CellTags->"ComplementFA"]
}, Open  ]]
}, Closed]],
Cell[54627, 2280, 58, 1, 31, "ObjectName",
  CellTags->"CompleteFA"],
Cell[54688, 2283, 61, 1, 74, "Highlight",
  CellTags->"CompleteFA"],
Cell[54752, 2286, 158, 4, 43, "Usage",
  CellTags->"CompleteFA"],
Cell[54913, 2292, 126, 4, 33, "Notes",
  CellTags->"CompleteFA"],

Cell[CellGroupData[{
Cell[55064, 2300, 68, 1, 59, "ExampleSection",
  CellTags->"CompleteFA"],
Cell[55135, 2303, 102, 1, 70, "ExampleText",
  CellTags->"CompleteFA"],

Cell[CellGroupData[{
Cell[55262, 2308, 97, 2, 70, "Input",
  CellTags->"CompleteFA"],
Cell[55362, 2312, 364, 12, 70, "Output",
  CellTags->"CompleteFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55763, 2329, 97, 3, 70, "Input",
  CellTags->"CompleteFA"],
Cell[55863, 2334, 447, 14, 70, "Output",
  CellTags->"CompleteFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56347, 2353, 104, 3, 70, "Input",
  CellTags->"CompleteFA"],
Cell[56454, 2358, 89, 3, 70, "Output",
  CellTags->"CompleteFA"]
}, Open  ]]
}, Closed]],
Cell[56570, 2365, 60, 1, 31, "ObjectName",
  CellTags->"CompleteQFA"],
Cell[56633, 2368, 62, 1, 74, "Highlight",
  CellTags->"CompleteQFA"],
Cell[56698, 2371, 179, 6, 43, "Usage",
  CellTags->"CompleteQFA"],
Cell[56880, 2379, 160, 4, 33, "Notes",
  CellTags->"CompleteQFA"],
Cell[57043, 2385, 99, 1, 33, "Notes",
  CellTags->"CompleteQFA"],

Cell[CellGroupData[{
Cell[57167, 2390, 69, 1, 59, "ExampleSection",
  CellTags->"CompleteQFA"],
Cell[57239, 2393, 96, 1, 70, "ExampleText",
  CellTags->"CompleteQFA"],

Cell[CellGroupData[{
Cell[57360, 2398, 122, 5, 70, "Input",
  CellTags->"CompleteQFA"],
Cell[57485, 2405, 252, 8, 70, "Output",
  CellTags->"CompleteQFA"],
Cell[57740, 2415, 90, 3, 70, "Output",
  CellTags->"CompleteQFA"]
}, Open  ]],
Cell[57845, 2421, 112, 2, 70, "ExampleText",
  CellTags->"CompleteQFA"],

Cell[CellGroupData[{
Cell[57982, 2427, 102, 2, 70, "Input",
  CellTags->"CompleteQFA"],
Cell[58087, 2431, 91, 3, 70, "Output",
  CellTags->"CompleteQFA"]
}, Open  ]]
}, Closed]],
Cell[58205, 2438, 56, 1, 31, "ObjectName",
  CellTags->"ComposeCA"],
Cell[58264, 2441, 60, 1, 74, "Highlight",
  CellTags->"ComposeCA"],
Cell[58327, 2444, 257, 8, 64, "Usage",
  CellTags->"ComposeCA"],
Cell[58587, 2454, 247, 9, 58, "Notes",
  CellTags->"ComposeCA"],
Cell[58837, 2465, 284, 9, 54, "Notes",
  CellTags->"ComposeCA"],
Cell[59124, 2476, 168, 6, 33, "Notes",
  CellTags->"ComposeCA"],

Cell[CellGroupData[{
Cell[59317, 2486, 67, 1, 59, "ExampleSection",
  CellTags->"ComposeCA"],
Cell[59387, 2489, 103, 1, 70, "ExampleText",
  CellTags->"ComposeCA"],

Cell[CellGroupData[{
Cell[59515, 2494, 109, 2, 70, "Input",
  CellTags->"ComposeCA"],
Cell[59627, 2498, 109, 3, 70, "Output",
  CellTags->"ComposeCA"]
}, Open  ]],
Cell[59751, 2504, 111, 3, 70, "Input",
  CellTags->"ComposeCA"]
}, Closed]],
Cell[59877, 2510, 64, 1, 31, "ObjectName",
  CellTags->"ComputationFA"],
Cell[59944, 2513, 64, 1, 74, "Highlight",
  CellTags->"ComputationFA"],
Cell[60011, 2516, 251, 8, 64, "Usage",
  CellTags->"ComputationFA"],
Cell[60265, 2526, 231, 9, 58, "Notes",
  CellTags->"ComputationFA"],
Cell[60499, 2537, 195, 5, 54, "Notes",
  CellTags->"ComputationFA"],
Cell[60697, 2544, 148, 4, 33, "Notes",
  CellTags->"ComputationFA"],
Cell[60848, 2550, 295, 11, 33, "Notes",
  CellTags->"ComputationFA"],

Cell[CellGroupData[{
Cell[61168, 2565, 71, 1, 59, "ExampleSection",
  CellTags->"ComputationFA"],
Cell[61242, 2568, 202, 7, 70, "ExampleText",
  CellTags->"ComputationFA"],

Cell[CellGroupData[{
Cell[61469, 2579, 113, 3, 70, "Input",
  CellTags->"ComputationFA"],
Cell[61585, 2584, 483, 14, 70, "Output",
  CellTags->"ComputationFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62105, 2603, 117, 3, 70, "Input",
  CellTags->"ComputationFA"],
Cell[62225, 2608, 327, 6, 70, "Output",
  CellTags->"ComputationFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62589, 2619, 116, 3, 70, "Input",
  CellTags->"ComputationFA"],
Cell[62708, 2624, 133, 3, 70, "Output",
  CellTags->"ComputationFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62878, 2632, 136, 3, 70, "Input",
  CellTags->"ComputationFA"],
Cell[63017, 2637, 191, 4, 70, "Output",
  CellTags->"ComputationFA"]
}, Open  ]]
}, Closed]],
Cell[63235, 2645, 74, 1, 31, "ObjectName",
  CellTags->"ComputationGraphFA"],
Cell[63312, 2648, 69, 1, 74, "Highlight",
  CellTags->"ComputationGraphFA"],
Cell[63384, 2651, 253, 8, 64, "Usage",
  CellTags->"ComputationGraphFA"],
Cell[63640, 2661, 280, 9, 33, "Notes",
  CellTags->"ComputationGraphFA"],
Cell[63923, 2672, 290, 11, 33, "Notes",
  CellTags->"ComputationGraphFA"],

Cell[CellGroupData[{
Cell[64238, 2687, 76, 1, 59, "ExampleSection",
  CellTags->"ComputationGraphFA"],
Cell[64317, 2690, 207, 7, 70, "ExampleText",
  CellTags->"ComputationGraphFA"],

Cell[CellGroupData[{
Cell[64549, 2701, 118, 3, 70, "Input",
  CellTags->"ComputationGraphFA"],
Cell[64670, 2706, 488, 14, 70, "Output",
  CellTags->"ComputationGraphFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65195, 2725, 120, 3, 70, "Input",
  CellTags->"ComputationGraphFA"],
Cell[65318, 2730, 440, 11, 70, "Output",
  CellTags->"ComputationGraphFA"]
}, Open  ]]
}, Closed]],
Cell[65785, 2745, 64, 1, 31, "ObjectName",
  CellTags->"ConcatenateFA"],
Cell[65852, 2748, 64, 1, 74, "Highlight",
  CellTags->"ConcatenateFA"],
Cell[65919, 2751, 202, 5, 64, "Usage",
  CellTags->"ConcatenateFA"],
Cell[66124, 2758, 300, 10, 80, "Notes",
  CellTags->"ConcatenateFA"],
Cell[66427, 2770, 193, 6, 33, "Notes",
  CellTags->"ConcatenateFA"],
Cell[66623, 2778, 285, 9, 33, "Notes",
  CellTags->"ConcatenateFA"],
Cell[66911, 2789, 110, 4, 33, "Notes",
  CellTags->"ConcatenateFA"],

Cell[CellGroupData[{
Cell[67046, 2797, 71, 1, 59, "ExampleSection",
  CellTags->"ConcatenateFA"],
Cell[67120, 2800, 103, 1, 70, "ExampleText",
  CellTags->"ConcatenateFA"],

Cell[CellGroupData[{
Cell[67248, 2805, 100, 2, 70, "Input",
  CellTags->"ConcatenateFA"],
Cell[67351, 2809, 382, 12, 70, "Output",
  CellTags->"ConcatenateFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67770, 2826, 118, 3, 70, "Input",
  CellTags->"ConcatenateFA"],
Cell[67891, 2831, 546, 15, 70, "Output",
  CellTags->"ConcatenateFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68474, 2851, 141, 3, 70, "Input",
  CellTags->"ConcatenateFA"],
Cell[68618, 2856, 117, 3, 70, "Output",
  CellTags->"ConcatenateFA"]
}, Open  ]]
}, Closed]],
Cell[68762, 2863, 60, 1, 31, "ObjectName",
  CellTags->"ConvertToFA"],
Cell[68825, 2866, 62, 1, 74, "Highlight",
  CellTags->"ConvertToFA"],
Cell[68890, 2869, 206, 5, 64, "Usage",
  CellTags->"ConvertToFA"],
Cell[69099, 2876, 300, 10, 80, "Notes",
  CellTags->"ConvertToFA"],
Cell[69402, 2888, 218, 6, 54, "Notes",
  CellTags->"ConvertToFA"],
Cell[69623, 2896, 54, 1, 33, "Notes",
  CellTags->"ConvertToFA"],

Cell[CellGroupData[{
Cell[69702, 2901, 69, 1, 59, "ExampleSection",
  CellTags->"ConvertToFA"],
Cell[69774, 2904, 166, 4, 70, "ExampleText",
  CellTags->"ConvertToFA"],

Cell[CellGroupData[{
Cell[69965, 2912, 252, 7, 70, "Input",
  CellTags->"ConvertToFA"],
Cell[70220, 2921, 388, 12, 70, "Output",
  CellTags->"ConvertToFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70645, 2938, 107, 3, 70, "Input",
  CellTags->"ConvertToFA"],
Cell[70755, 2943, 133, 3, 70, "Output",
  CellTags->"ConvertToFA"]
}, Open  ]]
}, Closed]],
Cell[70915, 2950, 58, 1, 31, "ObjectName",
  CellTags->"CounterDFA"],
Cell[70976, 2953, 61, 1, 74, "Highlight",
  CellTags->"CounterDFA"],
Cell[71040, 2956, 270, 6, 64, "Usage",
  CellTags->"CounterDFA"],
Cell[71313, 2964, 250, 9, 58, "Notes",
  CellTags->"CounterDFA"],
Cell[71566, 2975, 170, 7, 33, "Notes",
  CellTags->"CounterDFA"],

Cell[CellGroupData[{
Cell[71761, 2986, 68, 1, 59, "ExampleSection",
  CellTags->"CounterDFA"],
Cell[71832, 2989, 84, 1, 70, "ExampleText",
  CellTags->"CounterDFA"],

Cell[CellGroupData[{
Cell[71941, 2994, 105, 3, 70, "Input",
  CellTags->"CounterDFA"],
Cell[72049, 2999, 385, 12, 70, "Output",
  CellTags->"CounterDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72471, 3016, 112, 3, 70, "Input",
  CellTags->"CounterDFA"],
Cell[72586, 3021, 251, 5, 70, "Output",
  CellTags->"CounterDFA"]
}, Open  ]]
}, Closed]],
Cell[72864, 3030, 56, 1, 31, "ObjectName",
  CellTags->"CoverQDFA"],
Cell[72923, 3033, 60, 1, 74, "Highlight",
  CellTags->"CoverQDFA"],
Cell[72986, 3036, 139, 4, 43, "Usage",
  CellTags->"CoverQDFA"],
Cell[73128, 3042, 228, 9, 58, "Notes",
  CellTags->"CoverQDFA"],
Cell[73359, 3053, 97, 1, 33, "Notes",
  CellTags->"CoverQDFA"],
Cell[73459, 3056, 259, 10, 33, "Notes",
  CellTags->"CoverQDFA"],
Cell[73721, 3068, 147, 5, 33, "Notes",
  CellTags->"CoverQDFA"],

Cell[CellGroupData[{
Cell[73893, 3077, 67, 1, 59, "ExampleSection",
  CellTags->"CoverQDFA"],
Cell[73963, 3080, 132, 4, 70, "ExampleText",
  CellTags->"CoverQDFA"],

Cell[CellGroupData[{
Cell[74120, 3088, 148, 4, 70, "Input",
  CellTags->"CoverQDFA"],
Cell[74271, 3094, 519, 15, 70, "Output",
  CellTags->"CoverQDFA"],
Cell[74793, 3111, 411, 12, 70, "Output",
  CellTags->"CoverQDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75241, 3128, 100, 3, 70, "Input",
  CellTags->"CoverQDFA"],
Cell[75344, 3133, 89, 3, 70, "Output",
  CellTags->"CoverQDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75470, 3141, 122, 3, 70, "Input",
  CellTags->"CoverQDFA"],
Cell[75595, 3146, 222, 5, 70, "Output",
  CellTags->"CoverQDFA"]
}, Open  ]]
}, Closed]],
Cell[75844, 3155, 64, 1, 31, "ObjectName",
  CellTags->"DeBruijnEdges"],
Cell[75911, 3158, 64, 1, 74, "Highlight",
  CellTags->"DeBruijnEdges"],
Cell[75978, 3161, 180, 5, 43, "Usage",
  CellTags->"DeBruijnEdges"],
Cell[76161, 3168, 230, 9, 58, "Notes",
  CellTags->"DeBruijnEdges"],
Cell[76394, 3179, 155, 6, 33, "Notes",
  CellTags->"DeBruijnEdges"],
Cell[76552, 3187, 209, 7, 33, "Notes",
  CellTags->"DeBruijnEdges"],
Cell[76764, 3196, 172, 7, 33, "Notes",
  CellTags->"DeBruijnEdges"],

Cell[CellGroupData[{
Cell[76961, 3207, 71, 1, 59, "ExampleSection",
  CellTags->"DeBruijnEdges"],
Cell[77035, 3210, 175, 6, 70, "ExampleText",
  CellTags->"DeBruijnEdges"],

Cell[CellGroupData[{
Cell[77235, 3220, 112, 3, 70, "Input",
  CellTags->"DeBruijnEdges"],
Cell[77350, 3225, 381, 7, 70, "Output",
  CellTags->"DeBruijnEdges"]
}, Open  ]],
Cell[77746, 3235, 84, 1, 70, "ExampleText",
  CellTags->"DeBruijnEdges"],

Cell[CellGroupData[{
Cell[77855, 3240, 133, 3, 70, "Input",
  CellTags->"DeBruijnEdges"],
Cell[77991, 3245, 235, 5, 70, "Output",
  CellTags->"DeBruijnEdges"]
}, Open  ]]
}, Closed]],
Cell[78253, 3254, 64, 1, 31, "ObjectName",
  CellTags->"DeBruijnGraph"],
Cell[78320, 3257, 64, 1, 74, "Highlight",
  CellTags->"DeBruijnGraph"],
Cell[78387, 3260, 161, 4, 43, "Usage",
  CellTags->"DeBruijnGraph"],
Cell[78551, 3266, 230, 9, 58, "Notes",
  CellTags->"DeBruijnGraph"],
Cell[78784, 3277, 155, 6, 33, "Notes",
  CellTags->"DeBruijnGraph"],
Cell[78942, 3285, 839, 30, 75, "Notes",
  CellTags->"DeBruijnGraph"],
Cell[79784, 3317, 172, 7, 33, "Notes",
  CellTags->"DeBruijnGraph"],

Cell[CellGroupData[{
Cell[79981, 3328, 71, 1, 59, "ExampleSection",
  CellTags->"DeBruijnGraph"],
Cell[80055, 3331, 165, 6, 70, "ExampleText",
  CellTags->"DeBruijnGraph"],

Cell[CellGroupData[{
Cell[80245, 3341, 141, 3, 70, "Input",
  CellTags->"DeBruijnGraph"],
Cell[80389, 3346, 420, 11, 70, "Output",
  CellTags->"DeBruijnGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80846, 3362, 100, 3, 70, "Input",
  CellTags->"DeBruijnGraph"],
Cell[80949, 3367, 145, 3, 70, "Output",
  CellTags->"DeBruijnGraph"]
}, Open  ]],
Cell[81109, 3373, 150, 4, 70, "ExampleText",
  CellTags->"DeBruijnGraph"],

Cell[CellGroupData[{
Cell[81284, 3381, 176, 4, 70, "Input",
  CellTags->"DeBruijnGraph"],
Cell[81463, 3387, 678, 15, 70, "Output",
  CellTags->"DeBruijnGraph"]
}, Open  ]]
}, Closed]],
Cell[82168, 3406, 60, 1, 31, "ObjectName",
  CellTags->"DefiniteQFA"],
Cell[82231, 3409, 62, 1, 74, "Highlight",
  CellTags->"DefiniteQFA"],
Cell[82296, 3412, 261, 6, 91, "Usage",
  CellTags->"DefiniteQFA"],
Cell[82560, 3420, 294, 10, 80, "Notes",
  CellTags->"DefiniteQFA"],
Cell[82857, 3432, 164, 5, 33, "Notes",
  CellTags->"DefiniteQFA"],
Cell[83024, 3439, 170, 4, 54, "Notes",
  CellTags->"DefiniteQFA"],
Cell[83197, 3445, 162, 7, 33, "Notes",
  CellTags->"DefiniteQFA"],

Cell[CellGroupData[{
Cell[83384, 3456, 69, 1, 59, "ExampleSection",
  CellTags->"DefiniteQFA"],
Cell[83456, 3459, 71, 1, 70, "ExampleText",
  CellTags->"DefiniteQFA"],

Cell[CellGroupData[{
Cell[83552, 3464, 179, 5, 70, "Input",
  CellTags->"DefiniteQFA"],
Cell[83734, 3471, 520, 15, 70, "Output",
  CellTags->"DefiniteQFA"],
Cell[84257, 3488, 90, 3, 70, "Output",
  CellTags->"DefiniteQFA"]
}, Open  ]],
Cell[84362, 3494, 105, 1, 70, "ExampleText",
  CellTags->"DefiniteQFA"],

Cell[CellGroupData[{
Cell[84492, 3499, 118, 3, 70, "Input",
  CellTags->"DefiniteQFA"],
Cell[84613, 3504, 87, 3, 70, "Output",
  CellTags->"DefiniteQFA"]
}, Open  ]],
Cell[84715, 3510, 118, 3, 70, "Input",
  CellTags->"DefiniteQFA"],

Cell[CellGroupData[{
Cell[84858, 3517, 124, 3, 70, "Input",
  CellTags->"DefiniteQFA"],
Cell[84985, 3522, 153, 4, 70, "Output",
  CellTags->"DefiniteQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85175, 3531, 124, 3, 70, "Input",
  CellTags->"DefiniteQFA"],
Cell[85302, 3536, 131, 3, 70, "Output",
  CellTags->"DefiniteQFA"]
}, Open  ]]
}, Closed]],
Cell[85460, 3543, 56, 1, 31, "ObjectName",
  CellTags->"DegreesFA"],
Cell[85519, 3546, 60, 1, 74, "Highlight",
  CellTags->"DegreesFA"],
Cell[85582, 3549, 373, 15, 64, "Usage",
  CellTags->"DegreesFA"],
Cell[85958, 3566, 155, 4, 33, "Notes",
  CellTags->"DegreesFA"],

Cell[CellGroupData[{
Cell[86138, 3574, 67, 1, 59, "ExampleSection",
  CellTags->"DegreesFA"],
Cell[86208, 3577, 135, 4, 70, "ExampleText",
  CellTags->"DegreesFA"],

Cell[CellGroupData[{
Cell[86368, 3585, 96, 2, 70, "Input",
  CellTags->"DegreesFA"],
Cell[86467, 3589, 490, 14, 70, "Output",
  CellTags->"DegreesFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[86994, 3608, 113, 3, 70, "Input",
  CellTags->"DegreesFA"],
Cell[87110, 3613, 343, 10, 70, "Output",
  CellTags->"DegreesFA"]
}, Open  ]]
}, Closed]],
Cell[87480, 3627, 64, 1, 31, "ObjectName",
  CellTags->"DeleteStateFA"],
Cell[87547, 3630, 64, 1, 74, "Highlight",
  CellTags->"DeleteStateFA"],
Cell[87614, 3633, 134, 4, 43, "Usage",
  CellTags->"DeleteStateFA"],
Cell[87751, 3639, 230, 9, 58, "Notes",
  CellTags->"DeleteStateFA"],
Cell[87984, 3650, 84, 1, 33, "Notes",
  CellTags->"DeleteStateFA"],
Cell[88071, 3653, 97, 1, 33, "Notes",
  CellTags->"DeleteStateFA"],

Cell[CellGroupData[{
Cell[88193, 3658, 71, 1, 59, "ExampleSection",
  CellTags->"DeleteStateFA"],
Cell[88267, 3661, 129, 4, 70, "ExampleText",
  CellTags->"DeleteStateFA"],

Cell[CellGroupData[{
Cell[88421, 3669, 314, 7, 70, "Input",
  CellTags->"DeleteStateFA"],
Cell[88738, 3678, 287, 8, 70, "Output",
  CellTags->"DeleteStateFA"],
Cell[89028, 3688, 276, 8, 70, "Output",
  CellTags->"DeleteStateFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89341, 3701, 276, 5, 70, "Input",
  CellTags->"DeleteStateFA"],
Cell[89620, 3708, 123, 3, 70, "Output",
  CellTags->"DeleteStateFA"],
Cell[89746, 3713, 122, 3, 70, "Output",
  CellTags->"DeleteStateFA"],
Cell[89871, 3718, 117, 3, 70, "Output",
  CellTags->"DeleteStateFA"]
}, Open  ]]
}, Closed]],
Cell[90015, 3725, 62, 1, 31, "ObjectName",
  CellTags->"DependencyCA"],
Cell[90080, 3728, 63, 1, 74, "Highlight",
  CellTags->"DependencyCA"],
Cell[90146, 3731, 207, 5, 64, "Usage",
  CellTags->"DependencyCA"],
Cell[90356, 3738, 165, 7, 33, "Notes",
  CellTags->"DependencyCA"],

Cell[CellGroupData[{
Cell[90546, 3749, 70, 1, 59, "ExampleSection",
  CellTags->"DependencyCA"],
Cell[90619, 3752, 160, 4, 70, "ExampleText",
  CellTags->"DependencyCA"],

Cell[CellGroupData[{
Cell[90804, 3760, 144, 4, 70, "Input",
  CellTags->"DependencyCA"],
Cell[90951, 3766, 107, 3, 70, "Output",
  CellTags->"DependencyCA"],
Cell[91061, 3771, 93, 3, 70, "Output",
  CellTags->"DependencyCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91191, 3779, 96, 3, 70, "Input",
  CellTags->"DependencyCA"],
Cell[91290, 3784, 819, 18, 70, "Output",
  CellTags->"DependencyCA"]
}, Open  ]]
}, Closed]],
Cell[92136, 3806, 70, 1, 31, "ObjectName",
  CellTags->"DeterministicQFA"],
Cell[92209, 3809, 67, 1, 74, "Highlight",
  CellTags->"DeterministicQFA"],
Cell[92279, 3812, 178, 4, 43, "Usage",
  CellTags->"DeterministicQFA"],
Cell[92460, 3818, 235, 9, 58, "Notes",
  CellTags->"DeterministicQFA"],
Cell[92698, 3829, 419, 17, 54, "Notes",
  CellTags->"DeterministicQFA"],
Cell[93120, 3848, 185, 7, 33, "Notes",
  CellTags->"DeterministicQFA"],

Cell[CellGroupData[{
Cell[93330, 3859, 74, 1, 59, "ExampleSection",
  CellTags->"DeterministicQFA"],
Cell[93407, 3862, 137, 4, 70, "ExampleText",
  CellTags->"DeterministicQFA"],

Cell[CellGroupData[{
Cell[93569, 3870, 145, 4, 70, "Input",
  CellTags->"DeterministicQFA"],
Cell[93717, 3876, 355, 10, 70, "Output",
  CellTags->"DeterministicQFA"],
Cell[94075, 3888, 93, 3, 70, "Output",
  CellTags->"DeterministicQFA"]
}, Open  ]],
Cell[94183, 3894, 151, 4, 70, "ExampleText",
  CellTags->"DeterministicQFA"],

Cell[CellGroupData[{
Cell[94359, 3902, 164, 4, 70, "Input",
  CellTags->"DeterministicQFA"],
Cell[94526, 3908, 355, 10, 70, "Output",
  CellTags->"DeterministicQFA"],
Cell[94884, 3920, 93, 3, 70, "Output",
  CellTags->"DeterministicQFA"]
}, Open  ]]
}, Closed]],
Cell[95004, 3927, 54, 1, 31, "ObjectName",
  CellTags->"EmptyDFA"],
Cell[95061, 3930, 59, 1, 74, "Highlight",
  CellTags->"EmptyDFA"],
Cell[95123, 3933, 157, 4, 43, "Usage",
  CellTags->"EmptyDFA"],

Cell[CellGroupData[{
Cell[95305, 3941, 66, 1, 59, "ExampleSection",
  CellTags->"EmptyDFA"],
Cell[95374, 3944, 79, 1, 70, "ExampleText",
  CellTags->"EmptyDFA"],

Cell[CellGroupData[{
Cell[95478, 3949, 82, 2, 70, "Input",
  CellTags->"EmptyDFA"],
Cell[95563, 3953, 363, 12, 70, "Output",
  CellTags->"EmptyDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95963, 3970, 104, 3, 70, "Input",
  CellTags->"EmptyDFA"],
Cell[96070, 3975, 108, 3, 70, "Output",
  CellTags->"EmptyDFA"]
}, Open  ]]
}, Closed]],
Cell[96205, 3982, 54, 1, 31, "ObjectName",
  CellTags->"EmptyQFA"],
Cell[96262, 3985, 59, 1, 74, "Highlight",
  CellTags->"EmptyQFA"],
Cell[96324, 3988, 144, 4, 43, "Usage",
  CellTags->"EmptyQFA"],
Cell[96471, 3994, 125, 4, 33, "Notes",
  CellTags->"EmptyQFA"],

Cell[CellGroupData[{
Cell[96621, 4002, 66, 1, 59, "ExampleSection",
  CellTags->"EmptyQFA"],
Cell[96690, 4005, 102, 1, 70, "ExampleText",
  CellTags->"EmptyQFA"],
Cell[96795, 4008, 174, 5, 70, "Input",
  CellTags->"EmptyQFA"],
Cell[96972, 4015, 194, 5, 70, "Input",
  CellTags->"EmptyQFA"],

Cell[CellGroupData[{
Cell[97191, 4024, 175, 5, 70, "Input",
  CellTags->"EmptyQFA"],
Cell[97369, 4031, 89, 3, 70, "Output",
  CellTags->"EmptyQFA"],
Cell[97461, 4036, 89, 3, 70, "Output",
  CellTags->"EmptyQFA"],
Cell[97553, 4041, 88, 3, 70, "Output",
  CellTags->"EmptyQFA"]
}, Open  ]]
}, Closed]],
Cell[97668, 4048, 54, 1, 31, "ObjectName",
  CellTags->"EpsFreeQ"],
Cell[97725, 4051, 59, 1, 74, "Highlight",
  CellTags->"EpsFreeQ"],
Cell[97787, 4054, 132, 4, 43, "Usage",
  CellTags->"EpsFreeQ"],
Cell[97922, 4060, 120, 5, 33, "Notes",
  CellTags->"EpsFreeQ"],

Cell[CellGroupData[{
Cell[98067, 4069, 66, 1, 59, "ExampleSection",
  CellTags->"EpsFreeQ"],
Cell[98136, 4072, 130, 4, 70, "ExampleText",
  CellTags->"EpsFreeQ"],

Cell[CellGroupData[{
Cell[98291, 4080, 109, 2, 70, "Input",
  CellTags->"EpsFreeQ"],
Cell[98403, 4084, 223, 5, 70, "Output",
  CellTags->"EpsFreeQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98663, 4094, 94, 3, 70, "Input",
  CellTags->"EpsFreeQ"],
Cell[98760, 4099, 89, 3, 70, "Output",
  CellTags->"EpsFreeQ"]
}, Open  ]]
}, Closed]],
Cell[98876, 4106, 78, 1, 31, "ObjectName",
  CellTags->"EpsilonEliminationFA"],
Cell[98957, 4109, 71, 1, 74, "Highlight",
  CellTags->"EpsilonEliminationFA"],
Cell[99031, 4112, 178, 4, 43, "Usage",
  CellTags->"EpsilonEliminationFA"],
Cell[99212, 4118, 375, 11, 106, "Notes",
  CellTags->"EpsilonEliminationFA"],
Cell[99590, 4131, 837, 29, 75, "Notes",
  CellTags->"EpsilonEliminationFA"],
Cell[100430, 4162, 186, 4, 54, "Notes",
  CellTags->"EpsilonEliminationFA"],
Cell[100619, 4168, 187, 4, 54, "Notes",
  CellTags->"EpsilonEliminationFA"],

Cell[CellGroupData[{
Cell[100831, 4176, 78, 1, 59, "ExampleSection",
  CellTags->"EpsilonEliminationFA"],
Cell[100912, 4179, 160, 4, 70, "ExampleText",
  CellTags->"EpsilonEliminationFA"],
Cell[101075, 4185, 667, 11, 70, "Input",
  CellTags->"EpsilonEliminationFA"],
Cell[101745, 4198, 132, 3, 70, "Input",
  CellTags->"EpsilonEliminationFA"],

Cell[CellGroupData[{
Cell[101902, 4205, 115, 3, 70, "Input",
  CellTags->"EpsilonEliminationFA"],
Cell[102020, 4210, 100, 3, 70, "Output",
  CellTags->"EpsilonEliminationFA"]
}, Open  ]],
Cell[102135, 4216, 86, 1, 70, "ExampleText",
  CellTags->"EpsilonEliminationFA"],
Cell[102224, 4219, 176, 4, 70, "Input",
  CellTags->"EpsilonEliminationFA"],

Cell[CellGroupData[{
Cell[102425, 4227, 97, 3, 70, "Input",
  CellTags->"EpsilonEliminationFA"],
Cell[102525, 4232, 146, 3, 70, "Output",
  CellTags->"EpsilonEliminationFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102708, 4240, 96, 3, 70, "Input",
  CellTags->"EpsilonEliminationFA"],
Cell[102807, 4245, 500, 8, 70, "Output",
  CellTags->"EpsilonEliminationFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103344, 4258, 97, 3, 70, "Input",
  CellTags->"EpsilonEliminationFA"],
Cell[103444, 4263, 253, 5, 70, "Output",
  CellTags->"EpsilonEliminationFA"]
}, Open  ]]
}, Closed]],
Cell[103724, 4272, 64, 1, 31, "ObjectName",
  CellTags->"EquivalentQFA"],
Cell[103791, 4275, 64, 1, 74, "Highlight",
  CellTags->"EquivalentQFA"],
Cell[103858, 4278, 155, 4, 43, "Usage",
  CellTags->"EquivalentQFA"],
Cell[104016, 4284, 299, 10, 80, "Notes",
  CellTags->"EquivalentQFA"],
Cell[104318, 4296, 617, 20, 75, "Notes",
  CellTags->"EquivalentQFA"],
Cell[104938, 4318, 194, 5, 60, "Notes",
  CellTags->"EquivalentQFA"],
Cell[105135, 4325, 216, 5, 54, "Notes",
  CellTags->"EquivalentQFA"],

Cell[CellGroupData[{
Cell[105376, 4334, 71, 1, 59, "ExampleSection",
  CellTags->"EquivalentQFA"],
Cell[105450, 4337, 80, 1, 70, "ExampleText",
  CellTags->"EquivalentQFA"],
Cell[105533, 4340, 223, 5, 70, "Input",
  CellTags->"EquivalentQFA"],
Cell[105759, 4347, 280, 6, 70, "Input",
  CellTags->"EquivalentQFA"],
Cell[106042, 4355, 202, 5, 70, "Input",
  CellTags->"EquivalentQFA"],

Cell[CellGroupData[{
Cell[106269, 4364, 115, 3, 70, "Input",
  CellTags->"EquivalentQFA"],
Cell[106387, 4369, 93, 3, 70, "Output",
  CellTags->"EquivalentQFA"]
}, Open  ]],
Cell[106495, 4375, 96, 1, 70, "ExampleText",
  CellTags->"EquivalentQFA"],

Cell[CellGroupData[{
Cell[106616, 4380, 115, 3, 70, "Input",
  CellTags->"EquivalentQFA"],
Cell[106734, 4385, 93, 3, 70, "Output",
  CellTags->"EquivalentQFA"]
}, Open  ]],
Cell[106842, 4391, 194, 5, 70, "ExampleText",
  CellTags->"EquivalentQFA"],

Cell[CellGroupData[{
Cell[107061, 4400, 165, 4, 70, "Input",
  CellTags->"EquivalentQFA"],
Cell[107229, 4406, 256, 6, 70, "Output",
  CellTags->"EquivalentQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107522, 4417, 121, 3, 70, "Input",
  CellTags->"EquivalentQFA"],
Cell[107646, 4422, 143, 3, 70, "Output",
  CellTags->"EquivalentQFA"]
}, Open  ]]
}, Closed]],
Cell[107816, 4429, 60, 1, 31, "ObjectName",
  CellTags->"EvolutionCA"],
Cell[107879, 4432, 62, 1, 74, "Highlight",
  CellTags->"EvolutionCA"],
Cell[107944, 4435, 199, 5, 64, "Usage",
  CellTags->"EvolutionCA"],
Cell[108146, 4442, 299, 10, 80, "Notes",
  CellTags->"EvolutionCA"],
Cell[108448, 4454, 142, 5, 33, "Notes",
  CellTags->"EvolutionCA"],
Cell[108593, 4461, 249, 9, 33, "Notes",
  CellTags->"EvolutionCA"],
Cell[108845, 4472, 112, 5, 33, "Notes",
  CellTags->"EvolutionCA"],
Cell[108960, 4479, 128, 5, 33, "Notes",
  CellTags->"EvolutionCA"],
Cell[109091, 4486, 328, 13, 33, "Notes",
  CellTags->"EvolutionCA"],

Cell[CellGroupData[{
Cell[109444, 4503, 69, 1, 59, "ExampleSection",
  CellTags->"EvolutionCA"],
Cell[109516, 4506, 88, 1, 70, "ExampleText",
  CellTags->"EvolutionCA"],

Cell[CellGroupData[{
Cell[109629, 4511, 90, 2, 70, "Input",
  CellTags->"EvolutionCA"],
Cell[109722, 4515, 21368, 362, 70, 21189, 356, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"EvolutionCA"]
}, Open  ]],
Cell[131105, 4880, 197, 5, 70, "ExampleText",
  CellTags->"EvolutionCA"],

Cell[CellGroupData[{
Cell[131327, 4889, 236, 5, 70, "Input",
  CellTags->"EvolutionCA"],
Cell[131566, 4896, 3123, 183, 70, 2943, 177, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"EvolutionCA"]
}, Open  ]]
}, Closed]],
Cell[134716, 5083, 62, 1, 31, "ObjectName",
  CellTags->"FactorialQFA"],
Cell[134781, 5086, 63, 1, 74, "Highlight",
  CellTags->"FactorialQFA"],
Cell[134847, 5089, 219, 6, 64, "Usage",
  CellTags->"FactorialQFA"],
Cell[135069, 5097, 295, 10, 80, "Notes",
  CellTags->"FactorialQFA"],
Cell[135367, 5109, 221, 6, 54, "Notes",
  CellTags->"FactorialQFA"],

Cell[CellGroupData[{
Cell[135613, 5119, 70, 1, 59, "ExampleSection",
  CellTags->"FactorialQFA"],
Cell[135686, 5122, 81, 1, 70, "ExampleText",
  CellTags->"FactorialQFA"],
Cell[135770, 5125, 187, 5, 70, "Input",
  CellTags->"FactorialQFA"],

Cell[CellGroupData[{
Cell[135982, 5134, 102, 3, 70, "Input",
  CellTags->"FactorialQFA"],
Cell[136087, 5139, 92, 3, 70, "Output",
  CellTags->"FactorialQFA"]
}, Open  ]],
Cell[136194, 5145, 86, 1, 70, "ExampleText",
  CellTags->"FactorialQFA"],

Cell[CellGroupData[{
Cell[136305, 5150, 121, 3, 70, "Input",
  CellTags->"FactorialQFA"],
Cell[136429, 5155, 262, 6, 70, "Output",
  CellTags->"FactorialQFA"]
}, Open  ]]
}, Closed]],
Cell[136718, 5165, 64, 1, 31, "ObjectName",
  CellTags->"FinalVectorFA"],
Cell[136785, 5168, 64, 1, 74, "Highlight",
  CellTags->"FinalVectorFA"],
Cell[136852, 5171, 159, 4, 43, "Usage",
  CellTags->"FinalVectorFA"],
Cell[137014, 5177, 92, 1, 33, "Notes",
  CellTags->"FinalVectorFA"],
Cell[137109, 5180, 265, 11, 33, "Notes",
  CellTags->"FinalVectorFA"],

Cell[CellGroupData[{
Cell[137399, 5195, 71, 1, 59, "ExampleSection",
  CellTags->"FinalVectorFA"],
Cell[137473, 5198, 96, 1, 70, "ExampleText",
  CellTags->"FinalVectorFA"],

Cell[CellGroupData[{
Cell[137594, 5203, 227, 6, 70, "Input",
  CellTags->"FinalVectorFA"],
Cell[137824, 5211, 107, 3, 70, "Output",
  CellTags->"FinalVectorFA"]
}, Open  ]]
}, Closed]],
Cell[137958, 5218, 48, 1, 31, "ObjectName",
  CellTags->"Final"],
Cell[138009, 5221, 56, 1, 74, "Highlight",
  CellTags->"Final"],
Cell[138068, 5224, 198, 6, 43, "Usage",
  CellTags->"Final"],
Cell[138269, 5232, 257, 11, 33, "Notes",
  CellTags->"Final"],

Cell[CellGroupData[{
Cell[138551, 5247, 63, 1, 59, "ExampleSection",
  CellTags->"Final"],
Cell[138617, 5250, 141, 4, 70, "ExampleText",
  CellTags->"Final"],
Cell[138761, 5256, 151, 4, 70, "Input",
  CellTags->"Final"],

Cell[CellGroupData[{
Cell[138937, 5264, 88, 3, 70, "Input",
  CellTags->"Final"],
Cell[139028, 5269, 95, 3, 70, "Output",
  CellTags->"Final"]
}, Open  ]]
}, Closed]],
Cell[139150, 5276, 74, 1, 31, "ObjectName",
  CellTags->"FiniteComplementSA"],
Cell[139227, 5279, 69, 1, 74, "Highlight",
  CellTags->"FiniteComplementSA"],
Cell[139299, 5282, 263, 7, 64, "Usage",
  CellTags->"FiniteComplementSA"],
Cell[139565, 5291, 242, 9, 58, "Notes",
  CellTags->"FiniteComplementSA"],
Cell[139810, 5302, 117, 4, 33, "Notes",
  CellTags->"FiniteComplementSA"],

Cell[CellGroupData[{
Cell[139952, 5310, 76, 1, 59, "ExampleSection",
  CellTags->"FiniteComplementSA"],
Cell[140031, 5313, 104, 1, 70, "ExampleText",
  CellTags->"FiniteComplementSA"],

Cell[CellGroupData[{
Cell[140160, 5318, 104, 2, 70, "Input",
  CellTags->"FiniteComplementSA"],
Cell[140267, 5322, 280, 8, 70, "Output",
  CellTags->"FiniteComplementSA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140584, 5335, 112, 3, 70, "Input",
  CellTags->"FiniteComplementSA"],
Cell[140699, 5340, 195, 4, 70, "Output",
  CellTags->"FiniteComplementSA"]
}, Open  ]]
}, Closed]],
Cell[140921, 5348, 66, 1, 31, "ObjectName",
  CellTags->"FormatAutomata"],
Cell[140990, 5351, 65, 1, 74, "Highlight",
  CellTags->"FormatAutomata"],
Cell[141058, 5354, 184, 5, 43, "Usage",
  CellTags->"FormatAutomata"],
Cell[141245, 5361, 190, 5, 54, "Notes",
  CellTags->"FormatAutomata"],
Cell[141438, 5368, 167, 5, 33, "Notes",
  CellTags->"FormatAutomata"],
Cell[141608, 5375, 199, 6, 33, "Notes",
  CellTags->"FormatAutomata"],
Cell[141810, 5383, 169, 6, 33, "Notes",
  CellTags->"FormatAutomata"],
Cell[141982, 5391, 161, 4, 33, "Notes",
  CellTags->"FormatAutomata"],
Cell[142146, 5397, 168, 7, 33, "Notes",
  CellTags->"FormatAutomata"],

Cell[CellGroupData[{
Cell[142339, 5408, 72, 1, 59, "ExampleSection",
  CellTags->"FormatAutomata"],
Cell[142414, 5411, 101, 1, 70, "ExampleText",
  CellTags->"FormatAutomata"],
Cell[142518, 5414, 149, 4, 70, "Input",
  CellTags->"FormatAutomata"],

Cell[CellGroupData[{
Cell[142692, 5422, 128, 4, 70, "Input",
  CellTags->"FormatAutomata"],
Cell[142823, 5428, 940, 15, 70, "Output",
  CellTags->"FormatAutomata"]
}, Open  ]],

Cell[CellGroupData[{
Cell[143800, 5448, 128, 4, 70, "Input",
  CellTags->"FormatAutomata"],
Cell[143931, 5454, 504, 10, 70, "Output",
  CellTags->"FormatAutomata"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144472, 5469, 133, 4, 70, "Input",
  CellTags->"FormatAutomata"],
Cell[144608, 5475, 641, 17, 70, "Output",
  CellTags->"FormatAutomata"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145286, 5497, 128, 4, 70, "Input",
  CellTags->"FormatAutomata"],
Cell[145417, 5503, 96, 3, 70, "Output",
  CellTags->"FormatAutomata"]
}, Open  ]],
Cell[145528, 5509, 73, 1, 70, "ExampleText",
  CellTags->"FormatAutomata"],
Cell[145604, 5512, 113, 3, 70, "Input",
  CellTags->"FormatAutomata"]
}, Closed]],
Cell[145732, 5518, 52, 1, 31, "ObjectName",
  CellTags->"FormatX"],
Cell[145787, 5521, 58, 1, 74, "Highlight",
  CellTags->"FormatX"],
Cell[145848, 5524, 196, 8, 43, "Usage",
  CellTags->"FormatX"],
Cell[146047, 5534, 132, 4, 33, "Notes",
  CellTags->"FormatX"],
Cell[146182, 5540, 140, 4, 33, "Notes",
  CellTags->"FormatX"],
Cell[146325, 5546, 169, 7, 33, "Notes",
  CellTags->"FormatX"],

Cell[CellGroupData[{
Cell[146519, 5557, 65, 1, 59, "ExampleSection",
  CellTags->"FormatX"],
Cell[146587, 5560, 90, 1, 70, "ExampleText",
  CellTags->"FormatX"],

Cell[CellGroupData[{
Cell[146702, 5565, 119, 2, 70, "Input",
  CellTags->"FormatX"],
Cell[146824, 5569, 1174, 34, 70, "Output",
  CellTags->"FormatX"]
}, Open  ]],

Cell[CellGroupData[{
Cell[148035, 5608, 169, 4, 70, "Input",
  CellTags->"FormatX"],
Cell[148207, 5614, 1247, 33, 70, "Output",
  CellTags->"FormatX"]
}, Open  ]]
}, Closed]],
Cell[149481, 5651, 56, 1, 31, "ObjectName",
  CellTags->"FrontierQ"],
Cell[149540, 5654, 60, 1, 74, "Highlight",
  CellTags->"FrontierQ"],
Cell[149603, 5657, 217, 8, 43, "Usage",
  CellTags->"FrontierQ"],
Cell[149823, 5667, 120, 4, 33, "Notes",
  CellTags->"FrontierQ"],
Cell[149946, 5673, 265, 11, 33, "Notes",
  CellTags->"FrontierQ"],

Cell[CellGroupData[{
Cell[150236, 5688, 67, 1, 59, "ExampleSection",
  CellTags->"FrontierQ"],
Cell[150306, 5691, 74, 1, 70, "ExampleText",
  CellTags->"FrontierQ"],

Cell[CellGroupData[{
Cell[150405, 5696, 124, 3, 70, "Input",
  CellTags->"FrontierQ"],
Cell[150532, 5701, 87, 3, 70, "Output",
  CellTags->"FrontierQ"]
}, Open  ]],
Cell[150634, 5707, 90, 1, 70, "ExampleText",
  CellTags->"FrontierQ"],

Cell[CellGroupData[{
Cell[150749, 5712, 124, 3, 70, "Input",
  CellTags->"FrontierQ"],
Cell[150876, 5717, 88, 3, 70, "Output",
  CellTags->"FrontierQ"]
}, Open  ]]
}, Closed]],
Cell[150991, 5724, 64, 1, 31, "ObjectName",
  CellTags->"FrontierToDFA"],
Cell[151058, 5727, 64, 1, 74, "Highlight",
  CellTags->"FrontierToDFA"],
Cell[151125, 5730, 209, 7, 43, "Usage",
  CellTags->"FrontierToDFA"],
Cell[151337, 5739, 218, 8, 33, "Notes",
  CellTags->"FrontierToDFA"],
Cell[151558, 5749, 389, 15, 33, "Notes",
  CellTags->"FrontierToDFA"],

Cell[CellGroupData[{
Cell[151972, 5768, 71, 1, 59, "ExampleSection",
  CellTags->"FrontierToDFA"],
Cell[152046, 5771, 151, 4, 70, "ExampleText",
  CellTags->"FrontierToDFA"],
Cell[152200, 5777, 107, 3, 70, "Input",
  CellTags->"FrontierToDFA"],

Cell[CellGroupData[{
Cell[152332, 5784, 287, 6, 70, "Input",
  CellTags->"FrontierToDFA"],
Cell[152622, 5792, 92, 3, 70, "Output",
  CellTags->"FrontierToDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152751, 5800, 161, 4, 70, "Input",
  CellTags->"FrontierToDFA"],
Cell[152915, 5806, 387, 12, 70, "Output",
  CellTags->"FrontierToDFA"]
}, Open  ]],
Cell[153317, 5821, 172, 4, 70, "ExampleText",
  CellTags->"FrontierToDFA"],

Cell[CellGroupData[{
Cell[153514, 5829, 96, 3, 70, "Input",
  CellTags->"FrontierToDFA"],
Cell[153613, 5834, 122, 3, 70, "Output",
  CellTags->"FrontierToDFA"]
}, Open  ]],
Cell[153750, 5840, 90, 1, 70, "ExampleText",
  CellTags->"FrontierToDFA"],

Cell[CellGroupData[{
Cell[153865, 5845, 114, 3, 70, "Input",
  CellTags->"FrontierToDFA"],
Cell[153982, 5850, 570, 9, 70, "Output",
  CellTags->"FrontierToDFA"]
}, Open  ]]
}, Closed]],
Cell[154579, 5863, 46, 1, 31, "ObjectName",
  CellTags->"FSMQ"],
Cell[154628, 5866, 55, 1, 74, "Highlight",
  CellTags->"FSMQ"],
Cell[154686, 5869, 154, 6, 43, "Usage",
  CellTags->"FSMQ"],
Cell[154843, 5877, 147, 5, 33, "Notes",
  CellTags->"FSMQ"],

Cell[CellGroupData[{
Cell[155015, 5886, 62, 1, 59, "ExampleSection",
  CellTags->"FSMQ"],
Cell[155080, 5889, 91, 1, 70, "ExampleText",
  CellTags->"FSMQ"],
Cell[155174, 5892, 97, 2, 70, "Input",
  CellTags->"FSMQ"],

Cell[CellGroupData[{
Cell[155296, 5898, 118, 3, 70, "Input",
  CellTags->"FSMQ"],
Cell[155417, 5903, 406, 12, 70, "Output",
  CellTags->"FSMQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[155860, 5920, 94, 3, 70, "Input",
  CellTags->"FSMQ"],
Cell[155957, 5925, 98, 3, 70, "Output",
  CellTags->"FSMQ"]
}, Open  ]]
}, Closed]],
Cell[156082, 5932, 64, 1, 31, "ObjectName",
  CellTags->"FSurjectiveCA"],
Cell[156149, 5935, 64, 1, 74, "Highlight",
  CellTags->"FSurjectiveCA"],
Cell[156216, 5938, 187, 5, 43, "Usage",
  CellTags->"FSurjectiveCA"],
Cell[156406, 5945, 150, 4, 33, "Notes",
  CellTags->"FSurjectiveCA"],
Cell[156559, 5951, 281, 9, 54, "Notes",
  CellTags->"FSurjectiveCA"],

Cell[CellGroupData[{
Cell[156865, 5964, 71, 1, 59, "ExampleSection",
  CellTags->"FSurjectiveCA"],
Cell[156939, 5967, 177, 4, 70, "ExampleText",
  CellTags->"FSurjectiveCA"],
Cell[157119, 5973, 185, 4, 70, "Input",
  CellTags->"FSurjectiveCA"],

Cell[CellGroupData[{
Cell[157329, 5981, 133, 3, 70, "Input",
  CellTags->"FSurjectiveCA"],
Cell[157465, 5986, 113, 3, 70, "Output",
  CellTags->"FSurjectiveCA"]
}, Open  ]]
}, Closed]],
Cell[157605, 5993, 62, 1, 31, "ObjectName",
  CellTags->"FullAlphabet"],
Cell[157670, 5996, 63, 1, 74, "Highlight",
  CellTags->"FullAlphabet"],
Cell[157736, 5999, 311, 12, 64, "Usage",
  CellTags->"FullAlphabet"],
Cell[158050, 6013, 155, 4, 33, "Notes",
  CellTags->"FullAlphabet"],
Cell[158208, 6019, 264, 11, 33, "Notes",
  CellTags->"FullAlphabet"],

Cell[CellGroupData[{
Cell[158497, 6034, 70, 1, 59, "ExampleSection",
  CellTags->"FullAlphabet"],
Cell[158570, 6037, 82, 1, 70, "ExampleText",
  CellTags->"FullAlphabet"],

Cell[CellGroupData[{
Cell[158677, 6042, 220, 8, 70, "Input",
  CellTags->"FullAlphabet"],
Cell[158900, 6052, 108, 3, 70, "Output",
  CellTags->"FullAlphabet"],
Cell[159011, 6057, 280, 8, 70, "Output",
  CellTags->"FullAlphabet"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159328, 6070, 215, 8, 70, "Input",
  CellTags->"FullAlphabet"],
Cell[159546, 6080, 103, 3, 70, "Output",
  CellTags->"FullAlphabet"],
Cell[159652, 6085, 271, 8, 70, "Output",
  CellTags->"FullAlphabet"]
}, Open  ]]
}, Closed]],
Cell[159950, 6097, 82, 1, 31, "ObjectName",
  CellTags->"FullTransitionMatrixFA"],
Cell[160035, 6100, 73, 1, 74, "Highlight",
  CellTags->"FullTransitionMatrixFA"],
Cell[160111, 6103, 231, 5, 64, "Usage",
  CellTags->"FullTransitionMatrixFA"],
Cell[160345, 6110, 249, 8, 58, "Notes",
  CellTags->"FullTransitionMatrixFA"],
Cell[160597, 6120, 164, 5, 33, "Notes",
  CellTags->"FullTransitionMatrixFA"],

Cell[CellGroupData[{
Cell[160786, 6129, 80, 1, 59, "ExampleSection",
  CellTags->"FullTransitionMatrixFA"],
Cell[160869, 6132, 115, 1, 70, "ExampleText",
  CellTags->"FullTransitionMatrixFA"],

Cell[CellGroupData[{
Cell[161009, 6137, 107, 2, 70, "Input",
  CellTags->"FullTransitionMatrixFA"],
Cell[161119, 6141, 408, 12, 70, "Output",
  CellTags->"FullTransitionMatrixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161564, 6158, 172, 4, 70, "Input",
  CellTags->"FullTransitionMatrixFA"],
Cell[161739, 6164, 597, 14, 70, "Output",
  CellTags->"FullTransitionMatrixFA"]
}, Open  ]],
Cell[162351, 6181, 141, 4, 70, "ExampleText",
  CellTags->"FullTransitionMatrixFA"],

Cell[CellGroupData[{
Cell[162517, 6189, 129, 3, 70, "Input",
  CellTags->"FullTransitionMatrixFA"],
Cell[162649, 6194, 98, 3, 70, "Output",
  CellTags->"FullTransitionMatrixFA"]
}, Open  ]]
}, Closed]],
Cell[162774, 6201, 68, 1, 31, "ObjectName",
  CellTags->"FullTransitions"],
Cell[162845, 6204, 66, 1, 74, "Highlight",
  CellTags->"FullTransitions"],
Cell[162914, 6207, 164, 4, 43, "Usage",
  CellTags->"FullTransitions"],
Cell[163081, 6213, 383, 12, 54, "Notes",
  CellTags->"FullTransitions"],
Cell[163467, 6227, 293, 11, 33, "Notes",
  CellTags->"FullTransitions"],

Cell[CellGroupData[{
Cell[163785, 6242, 73, 1, 59, "ExampleSection",
  CellTags->"FullTransitions"],
Cell[163861, 6245, 107, 1, 70, "ExampleText",
  CellTags->"FullTransitions"],

Cell[CellGroupData[{
Cell[163993, 6250, 100, 2, 70, "Input",
  CellTags->"FullTransitions"],
Cell[164096, 6254, 401, 12, 70, "Output",
  CellTags->"FullTransitions"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164534, 6271, 124, 3, 70, "Input",
  CellTags->"FullTransitions"],
Cell[164661, 6276, 796, 24, 70, "Output",
  CellTags->"FullTransitions"]
}, Open  ]]
}, Closed]],
Cell[165484, 6304, 62, 1, 31, "ObjectName",
  CellTags->"FunctionToCA"],
Cell[165549, 6307, 63, 1, 74, "Highlight",
  CellTags->"FunctionToCA"],
Cell[165615, 6310, 323, 11, 64, "Usage",
  CellTags->"FunctionToCA"],
Cell[165941, 6323, 235, 8, 54, "Notes",
  CellTags->"FunctionToCA"],
Cell[166179, 6333, 276, 11, 33, "Notes",
  CellTags->"FunctionToCA"],

Cell[CellGroupData[{
Cell[166480, 6348, 70, 1, 59, "ExampleSection",
  CellTags->"FunctionToCA"],
Cell[166553, 6351, 123, 4, 70, "ExampleText",
  CellTags->"FunctionToCA"],

Cell[CellGroupData[{
Cell[166701, 6359, 134, 3, 70, "Input",
  CellTags->"FunctionToCA"],
Cell[166838, 6364, 116, 3, 70, "Output",
  CellTags->"FunctionToCA"]
}, Open  ]],
Cell[166969, 6370, 89, 1, 70, "ExampleText",
  CellTags->"FunctionToCA"],

Cell[CellGroupData[{
Cell[167083, 6375, 100, 3, 70, "Input",
  CellTags->"FunctionToCA"],
Cell[167186, 6380, 89, 3, 70, "Output",
  CellTags->"FunctionToCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167312, 6388, 110, 3, 70, "Input",
  CellTags->"FunctionToCA"],
Cell[167425, 6393, 32526, 534, 70, 32345, 528, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"FunctionToCA"]
}, Open  ]]
}, Closed]],
Cell[199978, 6931, 64, 1, 31, "ObjectName",
  CellTags->"FunctionToDFA"],
Cell[200045, 6934, 64, 1, 74, "Highlight",
  CellTags->"FunctionToDFA"],
Cell[200112, 6937, 186, 4, 64, "Usage",
  CellTags->"FunctionToDFA"],
Cell[200301, 6943, 303, 10, 80, "Notes",
  CellTags->"FunctionToDFA"],
Cell[200607, 6955, 316, 10, 33, "Notes",
  CellTags->"FunctionToDFA"],
Cell[200926, 6967, 287, 10, 54, "Notes",
  CellTags->"FunctionToDFA"],
Cell[201216, 6979, 311, 13, 33, "Notes",
  CellTags->"FunctionToDFA"],

Cell[CellGroupData[{
Cell[201552, 6996, 71, 1, 59, "ExampleSection",
  CellTags->"FunctionToDFA"],
Cell[201626, 6999, 105, 1, 70, "ExampleText",
  CellTags->"FunctionToDFA"],

Cell[CellGroupData[{
Cell[201756, 7004, 121, 3, 70, "Input",
  CellTags->"FunctionToDFA"],
Cell[201880, 7009, 217, 4, 70, "Output",
  CellTags->"FunctionToDFA"]
}, Open  ]],
Cell[202112, 7016, 145, 3, 70, "Input",
  CellTags->"FunctionToDFA"],

Cell[CellGroupData[{
Cell[202282, 7023, 156, 4, 70, "Input",
  CellTags->"FunctionToDFA"],
Cell[202441, 7029, 488, 14, 70, "Output",
  CellTags->"FunctionToDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[202966, 7048, 114, 3, 70, "Input",
  CellTags->"FunctionToDFA"],
Cell[203083, 7053, 219, 4, 70, "Output",
  CellTags->"FunctionToDFA"]
}, Open  ]]
}, Closed]],
Cell[203329, 7061, 62, 1, 31, "ObjectName",
  CellTags->"FunctionToSA"],
Cell[203394, 7064, 63, 1, 74, "Highlight",
  CellTags->"FunctionToSA"],
Cell[203460, 7067, 245, 10, 43, "Usage",
  CellTags->"FunctionToSA"],
Cell[203708, 7079, 302, 10, 80, "Notes",
  CellTags->"FunctionToSA"],
Cell[204013, 7091, 249, 7, 33, "Notes",
  CellTags->"FunctionToSA"],
Cell[204265, 7100, 150, 5, 33, "Notes",
  CellTags->"FunctionToSA"],
Cell[204418, 7107, 349, 13, 33, "Notes",
  CellTags->"FunctionToSA"],

Cell[CellGroupData[{
Cell[204792, 7124, 70, 1, 59, "ExampleSection",
  CellTags->"FunctionToSA"],
Cell[204865, 7127, 142, 4, 70, "ExampleText",
  CellTags->"FunctionToSA"],
Cell[205010, 7133, 253, 6, 70, "Input",
  CellTags->"FunctionToSA"],

Cell[CellGroupData[{
Cell[205288, 7143, 172, 5, 70, "Input",
  CellTags->"FunctionToSA"],
Cell[205463, 7150, 359, 10, 70, "Output",
  CellTags->"FunctionToSA"]
}, Open  ]],
Cell[205837, 7163, 83, 1, 70, "ExampleText",
  CellTags->"FunctionToSA"],

Cell[CellGroupData[{
Cell[205945, 7168, 124, 3, 70, "Input",
  CellTags->"FunctionToSA"],
Cell[206072, 7173, 483, 14, 70, "Output",
  CellTags->"FunctionToSA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206592, 7192, 134, 3, 70, "Input",
  CellTags->"FunctionToSA"],
Cell[206729, 7197, 120, 3, 70, "Output",
  CellTags->"FunctionToSA"]
}, Open  ]]
}, Closed]],
Cell[206876, 7204, 60, 1, 31, "ObjectName",
  CellTags->"GenerateDFA"],
Cell[206939, 7207, 62, 1, 74, "Highlight",
  CellTags->"GenerateDFA"],
Cell[207004, 7210, 287, 8, 64, "Usage",
  CellTags->"GenerateDFA"],
Cell[207294, 7220, 278, 7, 54, "Notes",
  CellTags->"GenerateDFA"],
Cell[207575, 7229, 300, 9, 54, "Notes",
  CellTags->"GenerateDFA"],
Cell[207878, 7240, 221, 9, 33, "Notes",
  CellTags->"GenerateDFA"],

Cell[CellGroupData[{
Cell[208124, 7253, 69, 1, 59, "ExampleSection",
  CellTags->"GenerateDFA"],
Cell[208196, 7256, 229, 7, 70, "ExampleText",
  CellTags->"GenerateDFA"],
Cell[208428, 7265, 201, 4, 70, "Input",
  CellTags->"GenerateDFA"],

Cell[CellGroupData[{
Cell[208654, 7273, 173, 5, 70, "Input",
  CellTags->"GenerateDFA"],
Cell[208830, 7280, 716, 19, 70, "Output",
  CellTags->"GenerateDFA"]
}, Open  ]],
Cell[209561, 7302, 254, 7, 70, "ExampleText",
  CellTags->"GenerateDFA"],

Cell[CellGroupData[{
Cell[209840, 7313, 124, 3, 70, "Input",
  CellTags->"GenerateDFA"],
Cell[209967, 7318, 605, 16, 70, "Output",
  CellTags->"GenerateDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[210609, 7339, 157, 4, 70, "Input",
  CellTags->"GenerateDFA"],
Cell[210769, 7345, 123, 3, 70, "Output",
  CellTags->"GenerateDFA"]
}, Open  ]]
}, Closed]],
Cell[210919, 7352, 72, 1, 31, "ObjectName",
  CellTags->"GenerateQuotients"],
Cell[210994, 7355, 68, 1, 74, "Highlight",
  CellTags->"GenerateQuotients"],
Cell[211065, 7358, 232, 8, 43, "Usage",
  CellTags->"GenerateQuotients"],
Cell[211300, 7368, 173, 5, 33, "Notes",
  CellTags->"GenerateQuotients"],
Cell[211476, 7375, 476, 19, 33, "Notes",
  CellTags->"GenerateQuotients"],

Cell[CellGroupData[{
Cell[211977, 7398, 75, 1, 59, "ExampleSection",
  CellTags->"GenerateQuotients"],
Cell[212055, 7401, 146, 4, 70, "ExampleText",
  CellTags->"GenerateQuotients"],

Cell[CellGroupData[{
Cell[212226, 7409, 94, 2, 70, "Input",
  CellTags->"GenerateQuotients"],
Cell[212323, 7413, 142, 3, 70, "Output",
  CellTags->"GenerateQuotients"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212502, 7421, 115, 3, 70, "Input",
  CellTags->"GenerateQuotients"],
Cell[212620, 7426, 245, 5, 70, "Output",
  CellTags->"GenerateQuotients"]
}, Open  ]]
}, Closed]],
Cell[212892, 7435, 60, 1, 31, "ObjectName",
  CellTags->"GlobalMapCA"],
Cell[212955, 7438, 62, 1, 74, "Highlight",
  CellTags->"GlobalMapCA"],
Cell[213020, 7441, 310, 10, 64, "Usage",
  CellTags->"GlobalMapCA"],
Cell[213333, 7453, 274, 9, 80, "Notes",
  CellTags->"GlobalMapCA"],
Cell[213610, 7464, 112, 5, 33, "Notes",
  CellTags->"GlobalMapCA"],
Cell[213725, 7471, 142, 5, 33, "Notes",
  CellTags->"GlobalMapCA"],
Cell[213870, 7478, 189, 6, 33, "Notes",
  CellTags->"GlobalMapCA"],
Cell[214062, 7486, 164, 7, 33, "Notes",
  CellTags->"GlobalMapCA"],

Cell[CellGroupData[{
Cell[214251, 7497, 69, 1, 59, "ExampleSection",
  CellTags->"GlobalMapCA"],
Cell[214323, 7500, 100, 1, 70, "ExampleText",
  CellTags->"GlobalMapCA"],
Cell[214426, 7503, 108, 3, 70, "Input",
  CellTags->"GlobalMapCA"],

Cell[CellGroupData[{
Cell[214559, 7510, 148, 4, 70, "Input",
  CellTags->"GlobalMapCA"],
Cell[214710, 7516, 367, 6, 70, "Output",
  CellTags->"GlobalMapCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215114, 7527, 127, 3, 70, "Input",
  CellTags->"GlobalMapCA"],
Cell[215244, 7532, 844, 21, 70, "Output",
  CellTags->"GlobalMapCA"]
}, Open  ]],
Cell[216103, 7556, 89, 1, 70, "ExampleText",
  CellTags->"GlobalMapCA"],

Cell[CellGroupData[{
Cell[216217, 7561, 264, 5, 70, "Input",
  CellTags->"GlobalMapCA"],
Cell[216484, 7568, 91, 3, 70, "Output",
  CellTags->"GlobalMapCA"]
}, Open  ]]
}, Closed]],
Cell[216602, 7575, 66, 1, 31, "ObjectName",
  CellTags->"HomomorphismFA"],
Cell[216671, 7578, 65, 1, 74, "Highlight",
  CellTags->"HomomorphismFA"],
Cell[216739, 7581, 257, 8, 64, "Usage",
  CellTags->"HomomorphismFA"],
Cell[216999, 7591, 164, 5, 33, "Notes",
  CellTags->"HomomorphismFA"],
Cell[217166, 7598, 163, 5, 33, "Notes",
  CellTags->"HomomorphismFA"],
Cell[217332, 7605, 179, 7, 33, "Notes",
  CellTags->"HomomorphismFA"],

Cell[CellGroupData[{
Cell[217536, 7616, 72, 1, 59, "ExampleSection",
  CellTags->"HomomorphismFA"],
Cell[217611, 7619, 303, 12, 70, "ExampleText",
  CellTags->"HomomorphismFA"],

Cell[CellGroupData[{
Cell[217939, 7635, 221, 5, 70, "Input",
  CellTags->"HomomorphismFA"],
Cell[218163, 7642, 495, 14, 70, "Output",
  CellTags->"HomomorphismFA"],
Cell[218661, 7658, 571, 15, 70, "Output",
  CellTags->"HomomorphismFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219269, 7678, 110, 3, 70, "Input",
  CellTags->"HomomorphismFA"],
Cell[219382, 7683, 229, 5, 70, "Output",
  CellTags->"HomomorphismFA"]
}, Open  ]]
}, Closed]],
Cell[219638, 7692, 66, 1, 31, "ObjectName",
  CellTags->"HurwitzProduct"],
Cell[219707, 7695, 65, 1, 74, "Highlight",
  CellTags->"HurwitzProduct"],
Cell[219775, 7698, 164, 4, 43, "Usage",
  CellTags->"HurwitzProduct"],
Cell[219942, 7704, 84, 1, 33, "Notes",
  CellTags->"HurwitzProduct"],
Cell[220029, 7707, 418, 15, 33, "Notes",
  CellTags->"HurwitzProduct"],

Cell[CellGroupData[{
Cell[220472, 7726, 72, 1, 59, "ExampleSection",
  CellTags->"HurwitzProduct"],
Cell[220547, 7729, 114, 2, 70, "ExampleText",
  CellTags->"HurwitzProduct"],

Cell[CellGroupData[{
Cell[220686, 7735, 142, 6, 70, "Input",
  CellTags->"HurwitzProduct"],
Cell[220831, 7743, 232, 5, 70, "Output",
  CellTags->"HurwitzProduct"]
}, Open  ]],

Cell[CellGroupData[{
Cell[221100, 7753, 160, 6, 70, "Input",
  CellTags->"HurwitzProduct"],
Cell[221263, 7761, 325, 6, 70, "Output",
  CellTags->"HurwitzProduct"]
}, Open  ]],

Cell[CellGroupData[{
Cell[221625, 7772, 112, 3, 70, "Input",
  CellTags->"HurwitzProduct"],
Cell[221740, 7777, 315, 6, 70, "Output",
  CellTags->"HurwitzProduct"]
}, Open  ]],
Cell[222070, 7786, 196, 6, 70, "ExampleText",
  CellTags->"HurwitzProduct"],

Cell[CellGroupData[{
Cell[222291, 7796, 229, 5, 70, "Input",
  CellTags->"HurwitzProduct"],
Cell[222523, 7803, 834, 26, 70, "Output",
  CellTags->"HurwitzProduct"]
}, Open  ]]
}, Closed]],
Cell[223384, 7833, 60, 1, 31, "ObjectName",
  CellTags->"IdealBaseFA"],
Cell[223447, 7836, 62, 1, 74, "Highlight",
  CellTags->"IdealBaseFA"],
Cell[223512, 7839, 177, 6, 43, "Usage",
  CellTags->"IdealBaseFA"],
Cell[223692, 7847, 255, 9, 54, "Notes",
  CellTags->"IdealBaseFA"],
Cell[223950, 7858, 450, 19, 33, "Notes",
  CellTags->"IdealBaseFA"],

Cell[CellGroupData[{
Cell[224425, 7881, 69, 1, 59, "ExampleSection",
  CellTags->"IdealBaseFA"],
Cell[224497, 7884, 98, 1, 70, "ExampleText",
  CellTags->"IdealBaseFA"],

Cell[CellGroupData[{
Cell[224620, 7889, 127, 3, 70, "Input",
  CellTags->"IdealBaseFA"],
Cell[224750, 7894, 379, 12, 70, "Output",
  CellTags->"IdealBaseFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[225166, 7911, 96, 3, 70, "Input",
  CellTags->"IdealBaseFA"],
Cell[225265, 7916, 90, 3, 70, "Output",
  CellTags->"IdealBaseFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[225392, 7924, 109, 3, 70, "Input",
  CellTags->"IdealBaseFA"],
Cell[225504, 7929, 386, 12, 70, "Output",
  CellTags->"IdealBaseFA"]
}, Open  ]],
Cell[225905, 7944, 269, 9, 70, "ExampleText",
  CellTags->"IdealBaseFA"],

Cell[CellGroupData[{
Cell[226199, 7957, 112, 3, 70, "Input",
  CellTags->"IdealBaseFA"],
Cell[226314, 7962, 206, 4, 70, "Output",
  CellTags->"IdealBaseFA"]
}, Open  ]]
}, Closed]],
Cell[226547, 7970, 54, 1, 31, "ObjectName",
  CellTags->"IdealQFA"],
Cell[226604, 7973, 59, 1, 74, "Highlight",
  CellTags->"IdealQFA"],
Cell[226666, 7976, 168, 6, 43, "Usage",
  CellTags->"IdealQFA"],
Cell[226837, 7984, 147, 5, 33, "Notes",
  CellTags->"IdealQFA"],
Cell[226987, 7991, 163, 7, 33, "Notes",
  CellTags->"IdealQFA"],

Cell[CellGroupData[{
Cell[227175, 8002, 66, 1, 59, "ExampleSection",
  CellTags->"IdealQFA"],
Cell[227244, 8005, 95, 1, 70, "ExampleText",
  CellTags->"IdealQFA"],

Cell[CellGroupData[{
Cell[227364, 8010, 124, 3, 70, "Input",
  CellTags->"IdealQFA"],
Cell[227491, 8015, 376, 12, 70, "Output",
  CellTags->"IdealQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[227904, 8032, 93, 3, 70, "Input",
  CellTags->"IdealQFA"],
Cell[228000, 8037, 87, 3, 70, "Output",
  CellTags->"IdealQFA"]
}, Open  ]]
}, Closed]],
Cell[228114, 8044, 58, 1, 31, "ObjectName",
  CellTags->"IdentityCA"],
Cell[228175, 8047, 61, 1, 74, "Highlight",
  CellTags->"IdentityCA"],
Cell[228239, 8050, 167, 4, 43, "Usage",
  CellTags->"IdentityCA"],
Cell[228409, 8056, 99, 1, 33, "Notes",
  CellTags->"IdentityCA"],
Cell[228511, 8059, 262, 11, 33, "Notes",
  CellTags->"IdentityCA"],

Cell[CellGroupData[{
Cell[228798, 8074, 68, 1, 59, "ExampleSection",
  CellTags->"IdentityCA"],
Cell[228869, 8077, 82, 1, 70, "ExampleText",
  CellTags->"IdentityCA"],

Cell[CellGroupData[{
Cell[228976, 8082, 153, 4, 70, "Input",
  CellTags->"IdentityCA"],
Cell[229132, 8088, 103, 3, 70, "Output",
  CellTags->"IdentityCA"],
Cell[229238, 8093, 106, 3, 70, "Output",
  CellTags->"IdentityCA"]
}, Open  ]],
Cell[229359, 8099, 123, 4, 70, "ExampleText",
  CellTags->"IdentityCA"],

Cell[CellGroupData[{
Cell[229507, 8107, 100, 3, 70, "Input",
  CellTags->"IdentityCA"],
Cell[229610, 8112, 92, 3, 70, "Output",
  CellTags->"IdentityCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[229739, 8120, 96, 3, 70, "Input",
  CellTags->"IdentityCA"],
Cell[229838, 8125, 103, 3, 70, "Output",
  CellTags->"IdentityCA"]
}, Open  ]]
}, Closed]],
Cell[229968, 8132, 60, 1, 31, "ObjectName",
  CellTags->"InfiniteQFA"],
Cell[230031, 8135, 62, 1, 74, "Highlight",
  CellTags->"InfiniteQFA"],
Cell[230096, 8138, 181, 6, 43, "Usage",
  CellTags->"InfiniteQFA"],
Cell[230280, 8146, 130, 5, 33, "Notes",
  CellTags->"InfiniteQFA"],
Cell[230413, 8153, 157, 7, 33, "Notes",
  CellTags->"InfiniteQFA"],

Cell[CellGroupData[{
Cell[230595, 8164, 69, 1, 59, "ExampleSection",
  CellTags->"InfiniteQFA"],
Cell[230667, 8167, 83, 1, 70, "ExampleText",
  CellTags->"InfiniteQFA"],

Cell[CellGroupData[{
Cell[230775, 8172, 100, 2, 70, "Input",
  CellTags->"InfiniteQFA"],
Cell[230878, 8176, 412, 12, 70, "Output",
  CellTags->"InfiniteQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231327, 8193, 100, 3, 70, "Input",
  CellTags->"InfiniteQFA"],
Cell[231430, 8198, 92, 3, 70, "Output",
  CellTags->"InfiniteQFA"]
}, Open  ]],
Cell[231537, 8204, 100, 1, 70, "ExampleText",
  CellTags->"InfiniteQFA"],

Cell[CellGroupData[{
Cell[231662, 8209, 84, 2, 70, "Input",
  CellTags->"InfiniteQFA"],
Cell[231749, 8213, 548, 15, 70, "Output",
  CellTags->"InfiniteQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[232334, 8233, 101, 3, 70, "Input",
  CellTags->"InfiniteQFA"],
Cell[232438, 8238, 91, 3, 70, "Output",
  CellTags->"InfiniteQFA"]
}, Open  ]]
}, Closed]],
Cell[232556, 8245, 52, 1, 31, "ObjectName",
  CellTags->"InfixFA"],
Cell[232611, 8248, 58, 1, 74, "Highlight",
  CellTags->"InfixFA"],
Cell[232672, 8251, 192, 6, 43, "Usage",
  CellTags->"InfixFA"],
Cell[232867, 8259, 247, 9, 58, "Notes",
  CellTags->"InfixFA"],
Cell[233117, 8270, 254, 11, 33, "Notes",
  CellTags->"InfixFA"],

Cell[CellGroupData[{
Cell[233396, 8285, 65, 1, 59, "ExampleSection",
  CellTags->"InfixFA"],
Cell[233464, 8288, 71, 1, 70, "ExampleText",
  CellTags->"InfixFA"],

Cell[CellGroupData[{
Cell[233560, 8293, 83, 2, 70, "Input",
  CellTags->"InfixFA"],
Cell[233646, 8297, 477, 14, 70, "Output",
  CellTags->"InfixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[234160, 8316, 102, 3, 70, "Input",
  CellTags->"InfixFA"],
Cell[234265, 8321, 443, 8, 70, "Output",
  CellTags->"InfixFA"]
}, Open  ]]
}, Closed]],
Cell[234735, 8333, 68, 1, 31, "ObjectName",
  CellTags->"InitialVectorFA"],
Cell[234806, 8336, 66, 1, 74, "Highlight",
  CellTags->"InitialVectorFA"],
Cell[234875, 8339, 167, 4, 43, "Usage",
  CellTags->"InitialVectorFA"],
Cell[235045, 8345, 94, 1, 33, "Notes",
  CellTags->"InitialVectorFA"],
Cell[235142, 8348, 267, 11, 33, "Notes",
  CellTags->"InitialVectorFA"],

Cell[CellGroupData[{
Cell[235434, 8363, 73, 1, 59, "ExampleSection",
  CellTags->"InitialVectorFA"],
Cell[235510, 8366, 151, 4, 70, "ExampleText",
  CellTags->"InitialVectorFA"],
Cell[235664, 8372, 161, 4, 70, "Input",
  CellTags->"InitialVectorFA"],

Cell[CellGroupData[{
Cell[235850, 8380, 108, 3, 70, "Input",
  CellTags->"InitialVectorFA"],
Cell[235961, 8385, 139, 3, 70, "Output",
  CellTags->"InitialVectorFA"]
}, Open  ]]
}, Closed]],
Cell[236127, 8392, 52, 1, 31, "ObjectName",
  CellTags->"Initial"],
Cell[236182, 8395, 58, 1, 74, "Highlight",
  CellTags->"Initial"],
Cell[236243, 8398, 178, 5, 43, "Usage",
  CellTags->"Initial"],
Cell[236424, 8405, 259, 11, 33, "Notes",
  CellTags->"Initial"],

Cell[CellGroupData[{
Cell[236708, 8420, 65, 1, 59, "ExampleSection",
  CellTags->"Initial"],
Cell[236776, 8423, 143, 4, 70, "ExampleText",
  CellTags->"Initial"],
Cell[236922, 8429, 153, 4, 70, "Input",
  CellTags->"Initial"],

Cell[CellGroupData[{
Cell[237100, 8437, 92, 3, 70, "Input",
  CellTags->"Initial"],
Cell[237195, 8442, 96, 3, 70, "Output",
  CellTags->"Initial"]
}, Open  ]]
}, Closed]],
Cell[237318, 8449, 66, 1, 31, "ObjectName",
  CellTags->"IntersectionFA"],
Cell[237387, 8452, 65, 1, 74, "Highlight",
  CellTags->"IntersectionFA"],
Cell[237455, 8455, 271, 9, 64, "Usage",
  CellTags->"IntersectionFA"],
Cell[237729, 8466, 299, 10, 80, "Notes",
  CellTags->"IntersectionFA"],
Cell[238031, 8478, 141, 5, 33, "Notes",
  CellTags->"IntersectionFA"],
Cell[238175, 8485, 202, 8, 33, "Notes",
  CellTags->"IntersectionFA"],
Cell[238380, 8495, 83, 1, 33, "Notes",
  CellTags->"IntersectionFA"],
Cell[238466, 8498, 59, 1, 33, "Notes",
  CellTags->"IntersectionFA"],
Cell[238528, 8501, 341, 15, 33, "Notes",
  CellTags->"IntersectionFA"],

Cell[CellGroupData[{
Cell[238894, 8520, 72, 1, 59, "ExampleSection",
  CellTags->"IntersectionFA"],
Cell[238969, 8523, 205, 5, 70, "ExampleText",
  CellTags->"IntersectionFA"],

Cell[CellGroupData[{
Cell[239199, 8532, 167, 4, 70, "Input",
  CellTags->"IntersectionFA"],
Cell[239369, 8538, 365, 12, 70, "Output",
  CellTags->"IntersectionFA"],
Cell[239737, 8552, 368, 12, 70, "Output",
  CellTags->"IntersectionFA"]
}, Open  ]],
Cell[240120, 8567, 133, 4, 70, "ExampleText",
  CellTags->"IntersectionFA"],

Cell[CellGroupData[{
Cell[240278, 8575, 182, 4, 70, "Input",
  CellTags->"IntersectionFA"],
Cell[240463, 8581, 396, 12, 70, "Output",
  CellTags->"IntersectionFA"],
Cell[240862, 8595, 174, 4, 70, "Output",
  CellTags->"IntersectionFA"]
}, Open  ]]
}, Closed]],
Cell[241063, 8603, 56, 1, 31, "ObjectName",
  CellTags->"InverseCA"],
Cell[241122, 8606, 60, 1, 74, "Highlight",
  CellTags->"InverseCA"],
Cell[241185, 8609, 180, 6, 43, "Usage",
  CellTags->"InverseCA"],
Cell[241368, 8617, 247, 9, 58, "Notes",
  CellTags->"InverseCA"],
Cell[241618, 8628, 113, 4, 33, "Notes",
  CellTags->"InverseCA"],

Cell[CellGroupData[{
Cell[241756, 8636, 67, 1, 59, "ExampleSection",
  CellTags->"InverseCA"],
Cell[241826, 8639, 80, 1, 70, "ExampleText",
  CellTags->"InverseCA"],

Cell[CellGroupData[{
Cell[241931, 8644, 170, 5, 70, "Input",
  CellTags->"InverseCA"],
Cell[242104, 8651, 86, 3, 70, "Output",
  CellTags->"InverseCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242227, 8659, 201, 6, 70, "Input",
  CellTags->"InverseCA"],
Cell[242431, 8667, 139, 3, 70, "Output",
  CellTags->"InverseCA"],
Cell[242573, 8672, 101, 3, 70, "Output",
  CellTags->"InverseCA"]
}, Open  ]]
}, Closed]],
Cell[242701, 8679, 64, 1, 31, "ObjectName",
  CellTags->"IrreducibleFA"],
Cell[242768, 8682, 64, 1, 74, "Highlight",
  CellTags->"IrreducibleFA"],
Cell[242835, 8685, 292, 10, 64, "Usage",
  CellTags->"IrreducibleFA"],
Cell[243130, 8697, 298, 10, 80, "Notes",
  CellTags->"IrreducibleFA"],
Cell[243431, 8709, 401, 15, 54, "Notes",
  CellTags->"IrreducibleFA"],
Cell[243835, 8726, 146, 5, 33, "Notes",
  CellTags->"IrreducibleFA"],
Cell[243984, 8733, 167, 7, 33, "Notes",
  CellTags->"IrreducibleFA"],

Cell[CellGroupData[{
Cell[244176, 8744, 71, 1, 59, "ExampleSection",
  CellTags->"IrreducibleFA"],
Cell[244250, 8747, 221, 9, 70, "ExampleText",
  CellTags->"IrreducibleFA"],
Cell[244474, 8758, 82, 2, 70, "Input",
  CellTags->"IrreducibleFA"],

Cell[CellGroupData[{
Cell[244581, 8764, 114, 3, 70, "Input",
  CellTags->"IrreducibleFA"],
Cell[244698, 8769, 406, 12, 70, "Output",
  CellTags->"IrreducibleFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[245141, 8786, 114, 3, 70, "Input",
  CellTags->"IrreducibleFA"],
Cell[245258, 8791, 191, 4, 70, "Output",
  CellTags->"IrreducibleFA"]
}, Open  ]],
Cell[245464, 8798, 96, 1, 70, "ExampleText",
  CellTags->"IrreducibleFA"],

Cell[CellGroupData[{
Cell[245585, 8803, 142, 3, 70, "Input",
  CellTags->"IrreducibleFA"],
Cell[245730, 8808, 121, 3, 70, "Output",
  CellTags->"IrreducibleFA"]
}, Open  ]]
}, Closed]],
Cell[245878, 8815, 66, 1, 31, "ObjectName",
  CellTags->"IsomorphicQDFA"],
Cell[245947, 8818, 65, 1, 74, "Highlight",
  CellTags->"IsomorphicQDFA"],
Cell[246015, 8821, 157, 4, 43, "Usage",
  CellTags->"IsomorphicQDFA"],
Cell[246175, 8827, 300, 10, 80, "Notes",
  CellTags->"IsomorphicQDFA"],
Cell[246478, 8839, 150, 4, 33, "Notes",
  CellTags->"IsomorphicQDFA"],
Cell[246631, 8845, 167, 5, 33, "Notes",
  CellTags->"IsomorphicQDFA"],
Cell[246801, 8852, 163, 4, 33, "Notes",
  CellTags->"IsomorphicQDFA"],

Cell[CellGroupData[{
Cell[246989, 8860, 72, 1, 59, "ExampleSection",
  CellTags->"IsomorphicQDFA"],
Cell[247064, 8863, 77, 1, 70, "ExampleText",
  CellTags->"IsomorphicQDFA"],
Cell[247144, 8866, 336, 8, 70, "Input",
  CellTags->"IsomorphicQDFA"],

Cell[CellGroupData[{
Cell[247505, 8878, 111, 3, 70, "Input",
  CellTags->"IsomorphicQDFA"],
Cell[247619, 8883, 94, 3, 70, "Output",
  CellTags->"IsomorphicQDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[247750, 8891, 133, 3, 70, "Input",
  CellTags->"IsomorphicQDFA"],
Cell[247886, 8896, 163, 4, 70, "Output",
  CellTags->"IsomorphicQDFA"]
}, Open  ]]
}, Closed]],
Cell[248076, 8904, 56, 1, 31, "ObjectName",
  CellTags->"IterateCA"],
Cell[248135, 8907, 60, 1, 74, "Highlight",
  CellTags->"IterateCA"],
Cell[248198, 8910, 166, 4, 43, "Usage",
  CellTags->"IterateCA"],
Cell[248367, 8916, 249, 9, 58, "Notes",
  CellTags->"IterateCA"],
Cell[248619, 8927, 322, 12, 54, "Notes",
  CellTags->"IterateCA"],

Cell[CellGroupData[{
Cell[248966, 8943, 67, 1, 59, "ExampleSection",
  CellTags->"IterateCA"],
Cell[249036, 8946, 98, 1, 70, "ExampleText",
  CellTags->"IterateCA"],

Cell[CellGroupData[{
Cell[249159, 8951, 93, 2, 70, "Input",
  CellTags->"IterateCA"],
Cell[249255, 8955, 138, 3, 70, "Output",
  CellTags->"IterateCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[249430, 8963, 143, 4, 70, "Input",
  CellTags->"IterateCA"],
Cell[249576, 8969, 85, 3, 70, "Output",
  CellTags->"IterateCA"]
}, Open  ]]
}, Closed]],
Cell[249688, 8976, 62, 1, 31, "ObjectName",
  CellTags->"IthSymbolDFA"],
Cell[249753, 8979, 63, 1, 74, "Highlight",
  CellTags->"IthSymbolDFA"],
Cell[249819, 8982, 200, 5, 64, "Usage",
  CellTags->"IthSymbolDFA"],
Cell[250022, 8989, 252, 9, 58, "Notes",
  CellTags->"IthSymbolDFA"],
Cell[250277, 9000, 82, 1, 33, "Notes",
  CellTags->"IthSymbolDFA"],
Cell[250362, 9003, 167, 7, 33, "Notes",
  CellTags->"IthSymbolDFA"],

Cell[CellGroupData[{
Cell[250554, 9014, 70, 1, 59, "ExampleSection",
  CellTags->"IthSymbolDFA"],
Cell[250627, 9017, 180, 6, 70, "ExampleText",
  CellTags->"IthSymbolDFA"],

Cell[CellGroupData[{
Cell[250832, 9027, 117, 3, 70, "Input",
  CellTags->"IthSymbolDFA"],
Cell[250952, 9032, 524, 15, 70, "Output",
  CellTags->"IthSymbolDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251513, 9052, 114, 3, 70, "Input",
  CellTags->"IthSymbolDFA"],
Cell[251630, 9057, 369, 6, 70, "Output",
  CellTags->"IthSymbolDFA"]
}, Open  ]],
Cell[252014, 9066, 89, 1, 70, "ExampleText",
  CellTags->"IthSymbolDFA"],

Cell[CellGroupData[{
Cell[252128, 9071, 112, 3, 70, "Input",
  CellTags->"IthSymbolDFA"],
Cell[252243, 9076, 89, 3, 70, "Output",
  CellTags->"IthSymbolDFA"]
}, Open  ]]
}, Closed]],
Cell[252359, 9083, 60, 1, 31, "ObjectName",
  CellTags->"IthSymbolFA"],
Cell[252422, 9086, 62, 1, 74, "Highlight",
  CellTags->"IthSymbolFA"],
Cell[252487, 9089, 226, 7, 64, "Usage",
  CellTags->"IthSymbolFA"],
Cell[252716, 9098, 251, 9, 58, "Notes",
  CellTags->"IthSymbolFA"],
Cell[252970, 9109, 125, 5, 33, "Notes",
  CellTags->"IthSymbolFA"],
Cell[253098, 9116, 166, 7, 33, "Notes",
  CellTags->"IthSymbolFA"],

Cell[CellGroupData[{
Cell[253289, 9127, 69, 1, 59, "ExampleSection",
  CellTags->"IthSymbolFA"],
Cell[253361, 9130, 179, 6, 70, "ExampleText",
  CellTags->"IthSymbolFA"],

Cell[CellGroupData[{
Cell[253565, 9140, 115, 3, 70, "Input",
  CellTags->"IthSymbolFA"],
Cell[253683, 9145, 460, 14, 70, "Output",
  CellTags->"IthSymbolFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254180, 9164, 113, 3, 70, "Input",
  CellTags->"IthSymbolFA"],
Cell[254296, 9169, 368, 6, 70, "Output",
  CellTags->"IthSymbolFA"]
}, Open  ]]
}, Closed]],
Cell[254691, 9179, 50, 1, 31, "ObjectName",
  CellTags->"JoinSA"],
Cell[254744, 9182, 57, 1, 74, "Highlight",
  CellTags->"JoinSA"],
Cell[254804, 9185, 190, 6, 43, "Usage",
  CellTags->"JoinSA"],
Cell[254997, 9193, 246, 9, 58, "Notes",
  CellTags->"JoinSA"],
Cell[255246, 9204, 158, 5, 33, "Notes",
  CellTags->"JoinSA"],
Cell[255407, 9211, 149, 7, 33, "Notes",
  CellTags->"JoinSA"],

Cell[CellGroupData[{
Cell[255581, 9222, 64, 1, 59, "ExampleSection",
  CellTags->"JoinSA"],
Cell[255648, 9225, 79, 1, 70, "ExampleText",
  CellTags->"JoinSA"],
Cell[255730, 9228, 183, 4, 70, "Input",
  CellTags->"JoinSA"],

Cell[CellGroupData[{
Cell[255938, 9236, 118, 3, 70, "Input",
  CellTags->"JoinSA"],
Cell[256059, 9241, 269, 8, 70, "Output",
  CellTags->"JoinSA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256365, 9254, 131, 3, 70, "Input",
  CellTags->"JoinSA"],
Cell[256499, 9259, 185, 4, 70, "Output",
  CellTags->"JoinSA"]
}, Open  ]]
}, Closed]],
Cell[256711, 9267, 64, 1, 31, "ObjectName",
  CellTags->"LabelToCodeCA"],
Cell[256778, 9270, 64, 1, 74, "Highlight",
  CellTags->"LabelToCodeCA"],
Cell[256845, 9273, 149, 4, 43, "Usage",
  CellTags->"LabelToCodeCA"],
Cell[256997, 9279, 147, 4, 33, "Notes",
  CellTags->"LabelToCodeCA"],
Cell[257147, 9285, 125, 4, 33, "Notes",
  CellTags->"LabelToCodeCA"],

Cell[CellGroupData[{
Cell[257297, 9293, 71, 1, 59, "ExampleSection",
  CellTags->"LabelToCodeCA"],
Cell[257371, 9296, 85, 1, 70, "ExampleText",
  CellTags->"LabelToCodeCA"],

Cell[CellGroupData[{
Cell[257481, 9301, 148, 3, 70, "Input",
  CellTags->"LabelToCodeCA"],
Cell[257632, 9306, 106, 3, 70, "Output",
  CellTags->"LabelToCodeCA"]
}, Open  ]]
}, Closed]],
Cell[257765, 9313, 58, 1, 31, "ObjectName",
  CellTags->"LanguageFA"],
Cell[257826, 9316, 61, 1, 74, "Highlight",
  CellTags->"LanguageFA"],
Cell[257890, 9319, 207, 8, 43, "Usage",
  CellTags->"LanguageFA"],
Cell[258100, 9329, 473, 14, 176, "Notes",
  CellTags->"LanguageFA"],
Cell[258576, 9345, 181, 7, 33, "Notes",
  CellTags->"LanguageFA"],
Cell[258760, 9354, 211, 7, 33, "Notes",
  CellTags->"LanguageFA"],
Cell[258974, 9363, 183, 5, 33, "Notes",
  CellTags->"LanguageFA"],
Cell[259160, 9370, 156, 5, 33, "Notes",
  CellTags->"LanguageFA"],
Cell[259319, 9377, 345, 10, 54, "Notes",
  CellTags->"LanguageFA"],
Cell[259667, 9389, 398, 14, 54, "Notes",
  CellTags->"LanguageFA"],
Cell[260068, 9405, 205, 7, 33, "Notes",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{
Cell[260298, 9416, 68, 1, 59, "ExampleSection",
  CellTags->"LanguageFA"],
Cell[260369, 9419, 134, 4, 70, "ExampleText",
  CellTags->"LanguageFA"],
Cell[260506, 9425, 193, 5, 70, "Input",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{
Cell[260724, 9434, 105, 3, 70, "Input",
  CellTags->"LanguageFA"],
Cell[260832, 9439, 366, 6, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261235, 9450, 154, 4, 70, "Input",
  CellTags->"LanguageFA"],
Cell[261392, 9456, 127, 3, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]],
Cell[261534, 9462, 110, 2, 70, "ExampleText",
  CellTags->"LanguageFA"],
Cell[261647, 9466, 218, 5, 70, "Input",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{
Cell[261890, 9475, 175, 4, 70, "Input",
  CellTags->"LanguageFA"],
Cell[262068, 9481, 366, 6, 70, "Output",
  CellTags->"LanguageFA"],
Cell[262437, 9489, 127, 3, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]],
Cell[262579, 9495, 124, 4, 70, "ExampleText",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{
Cell[262728, 9503, 127, 3, 70, "Input",
  CellTags->"LanguageFA"],
Cell[262858, 9508, 336, 6, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]],
Cell[263209, 9517, 144, 4, 70, "ExampleText",
  CellTags->"LanguageFA"],
Cell[263356, 9523, 224, 5, 70, "Input",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{
Cell[263605, 9532, 128, 3, 70, "Input",
  CellTags->"LanguageFA"],
Cell[263736, 9537, 119, 3, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263892, 9545, 127, 3, 70, "Input",
  CellTags->"LanguageFA"],
Cell[264022, 9550, 320, 6, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]],
Cell[264357, 9559, 85, 1, 70, "ExampleText",
  CellTags->"LanguageFA"],

Cell[CellGroupData[{
Cell[264467, 9564, 114, 3, 70, "Input",
  CellTags->"LanguageFA"],
Cell[264584, 9569, 384, 12, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[265005, 9586, 128, 3, 70, "Input",
  CellTags->"LanguageFA"],
Cell[265136, 9591, 106, 3, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[265279, 9599, 116, 3, 70, "Input",
  CellTags->"LanguageFA"],
Cell[265398, 9604, 141, 3, 70, "Output",
  CellTags->"LanguageFA"]
}, Open  ]]
}, Closed]],
Cell[265566, 9611, 62, 1, 31, "ObjectName",
  CellTags->"LanguageSort"],
Cell[265631, 9614, 63, 1, 74, "Highlight",
  CellTags->"LanguageSort"],
Cell[265697, 9617, 207, 6, 43, "Usage",
  CellTags->"LanguageSort"],
Cell[265907, 9625, 145, 5, 33, "Notes",
  CellTags->"LanguageSort"],
Cell[266055, 9632, 178, 7, 33, "Notes",
  CellTags->"LanguageSort"],

Cell[CellGroupData[{
Cell[266258, 9643, 70, 1, 59, "ExampleSection",
  CellTags->"LanguageSort"],
Cell[266331, 9646, 171, 4, 70, "ExampleText",
  CellTags->"LanguageSort"],
Cell[266505, 9652, 220, 6, 70, "Input",
  CellTags->"LanguageSort"],

Cell[CellGroupData[{
Cell[266750, 9662, 204, 5, 70, "Input",
  CellTags->"LanguageSort"],
Cell[266957, 9669, 841, 17, 70, "Output",
  CellTags->"LanguageSort"]
}, Open  ]]
}, Closed]],
Cell[267825, 9690, 70, 1, 31, "ObjectName",
  CellTags->"LanguageToSeries"],
Cell[267898, 9693, 67, 1, 74, "Highlight",
  CellTags->"LanguageToSeries"],
Cell[267968, 9696, 175, 6, 43, "Usage",
  CellTags->"LanguageToSeries"],
Cell[268146, 9704, 156, 5, 33, "Notes",
  CellTags->"LanguageToSeries"],
Cell[268305, 9711, 269, 11, 33, "Notes",
  CellTags->"LanguageToSeries"],

Cell[CellGroupData[{
Cell[268599, 9726, 74, 1, 59, "ExampleSection",
  CellTags->"LanguageToSeries"],
Cell[268676, 9729, 77, 1, 70, "ExampleText",
  CellTags->"LanguageToSeries"],

Cell[CellGroupData[{
Cell[268778, 9734, 83, 2, 70, "Input",
  CellTags->"LanguageToSeries"],
Cell[268864, 9738, 148, 3, 70, "Output",
  CellTags->"LanguageToSeries"]
}, Open  ]],

Cell[CellGroupData[{
Cell[269049, 9746, 110, 3, 70, "Input",
  CellTags->"LanguageToSeries"],
Cell[269162, 9751, 197, 4, 70, "Output",
  CellTags->"LanguageToSeries"]
}, Open  ]],

Cell[CellGroupData[{
Cell[269396, 9760, 102, 3, 70, "Input",
  CellTags->"LanguageToSeries"],
Cell[269501, 9765, 177, 4, 70, "Output",
  CellTags->"LanguageToSeries"]
}, Open  ]]
}, Closed]],
Cell[269705, 9773, 62, 1, 31, "ObjectName",
  CellTags->"LeftQuotient"],
Cell[269770, 9776, 63, 1, 74, "Highlight",
  CellTags->"LeftQuotient"],
Cell[269836, 9779, 231, 8, 43, "Usage",
  CellTags->"LeftQuotient"],
Cell[270070, 9789, 182, 7, 33, "Notes",
  CellTags->"LeftQuotient"],
Cell[270255, 9798, 481, 19, 33, "Notes",
  CellTags->"LeftQuotient"],

Cell[CellGroupData[{
Cell[270761, 9821, 70, 1, 59, "ExampleSection",
  CellTags->"LeftQuotient"],
Cell[270834, 9824, 145, 4, 70, "ExampleText",
  CellTags->"LeftQuotient"],

Cell[CellGroupData[{
Cell[271004, 9832, 89, 2, 70, "Input",
  CellTags->"LeftQuotient"],
Cell[271096, 9836, 137, 3, 70, "Output",
  CellTags->"LeftQuotient"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271270, 9844, 105, 3, 70, "Input",
  CellTags->"LeftQuotient"],
Cell[271378, 9849, 106, 3, 70, "Output",
  CellTags->"LeftQuotient"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271521, 9857, 106, 3, 70, "Input",
  CellTags->"LeftQuotient"],
Cell[271630, 9862, 93, 3, 70, "Output",
  CellTags->"LeftQuotient"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271760, 9870, 107, 3, 70, "Input",
  CellTags->"LeftQuotient"],
Cell[271870, 9875, 90, 3, 70, "Output",
  CellTags->"LeftQuotient"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271997, 9883, 106, 3, 70, "Input",
  CellTags->"LeftQuotient"],
Cell[272106, 9888, 98, 3, 70, "Output",
  CellTags->"LeftQuotient"]
}, Open  ]]
}, Closed]],
Cell[272231, 9895, 60, 1, 31, "ObjectName",
  CellTags->"LeftShiftCA"],
Cell[272294, 9898, 62, 1, 74, "Highlight",
  CellTags->"LeftShiftCA"],
Cell[272359, 9901, 162, 4, 43, "Usage",
  CellTags->"LeftShiftCA"],
Cell[272524, 9907, 168, 7, 33, "Notes",
  CellTags->"LeftShiftCA"],

Cell[CellGroupData[{
Cell[272717, 9918, 69, 1, 59, "ExampleSection",
  CellTags->"LeftShiftCA"],
Cell[272789, 9921, 60, 1, 70, "ExampleText",
  CellTags->"LeftShiftCA"],

Cell[CellGroupData[{
Cell[272874, 9926, 84, 2, 70, "Input",
  CellTags->"LeftShiftCA"],
Cell[272961, 9930, 104, 3, 70, "Output",
  CellTags->"LeftShiftCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[273102, 9938, 139, 3, 70, "Input",
  CellTags->"LeftShiftCA"],
Cell[273244, 9943, 106, 3, 70, "Output",
  CellTags->"LeftShiftCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[273387, 9951, 96, 3, 70, "Input",
  CellTags->"LeftShiftCA"],
Cell[273486, 9956, 102, 3, 70, "Output",
  CellTags->"LeftShiftCA"]
}, Open  ]]
}, Closed]],
Cell[273615, 9963, 56, 1, 31, "ObjectName",
  CellTags->"LengthDFA"],
Cell[273674, 9966, 60, 1, 74, "Highlight",
  CellTags->"LengthDFA"],
Cell[273737, 9969, 228, 8, 43, "Usage",
  CellTags->"LengthDFA"],
Cell[273968, 9979, 249, 9, 58, "Notes",
  CellTags->"LengthDFA"],
Cell[274220, 9990, 113, 4, 33, "Notes",
  CellTags->"LengthDFA"],
Cell[274336, 9996, 161, 5, 33, "Notes",
  CellTags->"LengthDFA"],

Cell[CellGroupData[{
Cell[274522, 10005, 67, 1, 59, "ExampleSection",
  CellTags->"LengthDFA"],
Cell[274592, 10008, 92, 1, 70, "ExampleText",
  CellTags->"LengthDFA"],

Cell[CellGroupData[{
Cell[274709, 10013, 132, 3, 70, "Input",
  CellTags->"LengthDFA"],
Cell[274844, 10018, 402, 12, 70, "Output",
  CellTags->"LengthDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[275283, 10035, 136, 3, 70, "Input",
  CellTags->"LengthDFA"],
Cell[275422, 10040, 113, 3, 70, "Output",
  CellTags->"LengthDFA"]
}, Open  ]],
Cell[275550, 10046, 94, 1, 70, "ExampleText",
  CellTags->"LengthDFA"],
Cell[275647, 10049, 133, 3, 70, "Input",
  CellTags->"LengthDFA"],

Cell[CellGroupData[{
Cell[275805, 10056, 136, 3, 70, "Input",
  CellTags->"LengthDFA"],
Cell[275944, 10061, 113, 3, 70, "Output",
  CellTags->"LengthDFA"]
}, Open  ]]
}, Closed]],
Cell[276084, 10068, 58, 1, 31, "ObjectName",
  CellTags->"LocalMapCA"],
Cell[276145, 10071, 61, 1, 74, "Highlight",
  CellTags->"LocalMapCA"],
Cell[276209, 10074, 213, 8, 43, "Usage",
  CellTags->"LocalMapCA"],
Cell[276425, 10084, 229, 9, 58, "Notes",
  CellTags->"LocalMapCA"],
Cell[276657, 10095, 111, 5, 33, "Notes",
  CellTags->"LocalMapCA"],
Cell[276771, 10102, 141, 5, 33, "Notes",
  CellTags->"LocalMapCA"],
Cell[276915, 10109, 188, 6, 33, "Notes",
  CellTags->"LocalMapCA"],
Cell[277106, 10117, 165, 7, 33, "Notes",
  CellTags->"LocalMapCA"],

Cell[CellGroupData[{
Cell[277296, 10128, 68, 1, 59, "ExampleSection",
  CellTags->"LocalMapCA"],
Cell[277367, 10131, 99, 1, 70, "ExampleText",
  CellTags->"LocalMapCA"],
Cell[277469, 10134, 105, 3, 70, "Input",
  CellTags->"LocalMapCA"],

Cell[CellGroupData[{
Cell[277599, 10141, 122, 3, 70, "Input",
  CellTags->"LocalMapCA"],
Cell[277724, 10146, 109, 3, 70, "Output",
  CellTags->"LocalMapCA"]
}, Open  ]],
Cell[277848, 10152, 176, 4, 70, "ExampleText",
  CellTags->"LocalMapCA"],

Cell[CellGroupData[{
Cell[278049, 10160, 177, 4, 70, "Input",
  CellTags->"LocalMapCA"],
Cell[278229, 10166, 106, 3, 70, "Output",
  CellTags->"LocalMapCA"]
}, Open  ]]
}, Closed]],
Cell[278362, 10173, 70, 1, 31, "ObjectName",
  CellTags->"LocalUniversalFA"],
Cell[278435, 10176, 67, 1, 74, "Highlight",
  CellTags->"LocalUniversalFA"],
Cell[278505, 10179, 227, 7, 43, "Usage",
  CellTags->"LocalUniversalFA"],
Cell[278735, 10188, 437, 12, 128, "Notes",
  CellTags->"LocalUniversalFA"],
Cell[279175, 10202, 292, 11, 54, "Notes",
  CellTags->"LocalUniversalFA"],
Cell[279470, 10215, 83, 1, 33, "Notes",
  CellTags->"LocalUniversalFA"],
Cell[279556, 10218, 175, 7, 33, "Notes",
  CellTags->"LocalUniversalFA"],

Cell[CellGroupData[{
Cell[279756, 10229, 74, 1, 59, "ExampleSection",
  CellTags->"LocalUniversalFA"],
Cell[279833, 10232, 335, 9, 70, "ExampleText",
  CellTags->"LocalUniversalFA"],

Cell[CellGroupData[{
Cell[280193, 10245, 296, 7, 70, "Input",
  CellTags->"LocalUniversalFA"],
Cell[280492, 10254, 558, 15, 70, "Output",
  CellTags->"LocalUniversalFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[281087, 10274, 100, 3, 70, "Input",
  CellTags->"LocalUniversalFA"],
Cell[281190, 10279, 148, 3, 70, "Output",
  CellTags->"LocalUniversalFA"]
}, Open  ]],
Cell[281353, 10285, 173, 6, 70, "ExampleText",
  CellTags->"LocalUniversalFA"],

Cell[CellGroupData[{
Cell[281551, 10295, 118, 3, 70, "Input",
  CellTags->"LocalUniversalFA"],
Cell[281672, 10300, 373, 6, 70, "Output",
  CellTags->"LocalUniversalFA"]
}, Open  ]]
}, Closed]],
Cell[282072, 10310, 68, 1, 31, "ObjectName",
  CellTags->"LoopAutomatonFA"],
Cell[282143, 10313, 66, 1, 74, "Highlight",
  CellTags->"LoopAutomatonFA"],
Cell[282212, 10316, 172, 6, 43, "Usage",
  CellTags->"LoopAutomatonFA"],
Cell[282387, 10324, 104, 1, 33, "Notes",
  CellTags->"LoopAutomatonFA"],
Cell[282494, 10327, 271, 11, 33, "Notes",
  CellTags->"LoopAutomatonFA"],

Cell[CellGroupData[{
Cell[282790, 10342, 73, 1, 59, "ExampleSection",
  CellTags->"LoopAutomatonFA"],
Cell[282866, 10345, 176, 4, 70, "ExampleText",
  CellTags->"LoopAutomatonFA"],

Cell[CellGroupData[{
Cell[283067, 10353, 197, 4, 70, "Input",
  CellTags->"LoopAutomatonFA"],
Cell[283267, 10359, 301, 6, 70, "Output",
  CellTags->"LoopAutomatonFA"]
}, Open  ]],
Cell[283583, 10368, 121, 3, 70, "Input",
  CellTags->"LoopAutomatonFA"],
Cell[283707, 10373, 219, 6, 70, "ExampleText",
  CellTags->"LoopAutomatonFA"],

Cell[CellGroupData[{
Cell[283951, 10383, 190, 4, 70, "Input",
  CellTags->"LoopAutomatonFA"],
Cell[284144, 10389, 2403, 58, 70, "Output",
  CellTags->"LoopAutomatonFA"]
}, Open  ]],
Cell[286562, 10450, 128, 4, 70, "ExampleText",
  CellTags->"LoopAutomatonFA"],

Cell[CellGroupData[{
Cell[286715, 10458, 167, 4, 70, "Input",
  CellTags->"LoopAutomatonFA"],
Cell[286885, 10464, 4509, 108, 70, "Output",
  CellTags->"LoopAutomatonFA"]
}, Open  ]]
}, Closed]],
Cell[291421, 10576, 60, 1, 31, "ObjectName",
  CellTags->"MakeHomoDFA"],
Cell[291484, 10579, 62, 1, 74, "Highlight",
  CellTags->"MakeHomoDFA"],
Cell[291549, 10582, 273, 10, 64, "Usage",
  CellTags->"MakeHomoDFA"],
Cell[291825, 10594, 177, 7, 33, "Notes",
  CellTags->"MakeHomoDFA"],
Cell[292005, 10603, 165, 7, 33, "Notes",
  CellTags->"MakeHomoDFA"],

Cell[CellGroupData[{
Cell[292195, 10614, 69, 1, 59, "ExampleSection",
  CellTags->"MakeHomoDFA"],
Cell[292267, 10617, 90, 1, 70, "ExampleText",
  CellTags->"MakeHomoDFA"],

Cell[CellGroupData[{
Cell[292382, 10622, 120, 5, 70, "Input",
  CellTags->"MakeHomoDFA"],
Cell[292505, 10629, 521, 15, 70, "Output",
  CellTags->"MakeHomoDFA"],
Cell[293029, 10646, 413, 12, 70, "Output",
  CellTags->"MakeHomoDFA"]
}, Open  ]],
Cell[293457, 10661, 132, 4, 70, "ExampleText",
  CellTags->"MakeHomoDFA"],

Cell[CellGroupData[{
Cell[293614, 10669, 119, 3, 70, "Input",
  CellTags->"MakeHomoDFA"],
Cell[293736, 10674, 91, 3, 70, "Output",
  CellTags->"MakeHomoDFA"]
}, Open  ]],
Cell[293842, 10680, 161, 4, 70, "Input",
  CellTags->"MakeHomoDFA"],

Cell[CellGroupData[{
Cell[294028, 10688, 178, 4, 70, "Input",
  CellTags->"MakeHomoDFA"],
Cell[294209, 10694, 132, 3, 70, "Output",
  CellTags->"MakeHomoDFA"],
Cell[294344, 10699, 132, 3, 70, "Output",
  CellTags->"MakeHomoDFA"]
}, Open  ]]
}, Closed]],
Cell[294503, 10706, 70, 1, 31, "ObjectName",
  CellTags->"MakeHomomorphism"],
Cell[294576, 10709, 67, 1, 74, "Highlight",
  CellTags->"MakeHomomorphism"],
Cell[294646, 10712, 267, 10, 64, "Usage",
  CellTags->"MakeHomomorphism"],
Cell[294916, 10724, 236, 9, 58, "Notes",
  CellTags->"MakeHomomorphism"],
Cell[295155, 10735, 191, 7, 33, "Notes",
  CellTags->"MakeHomomorphism"],
Cell[295349, 10744, 117, 5, 33, "Notes",
  CellTags->"MakeHomomorphism"],
Cell[295469, 10751, 208, 8, 33, "Notes",
  CellTags->"MakeHomomorphism"],
Cell[295680, 10761, 177, 7, 33, "Notes",
  CellTags->"MakeHomomorphism"],

Cell[CellGroupData[{
Cell[295882, 10772, 74, 1, 59, "ExampleSection",
  CellTags->"MakeHomomorphism"],
Cell[295959, 10775, 101, 1, 70, "ExampleText",
  CellTags->"MakeHomomorphism"],

Cell[CellGroupData[{
Cell[296085, 10780, 107, 2, 70, "Input",
  CellTags->"MakeHomomorphism"],
Cell[296195, 10784, 126, 3, 70, "Output",
  CellTags->"MakeHomomorphism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[296358, 10792, 184, 5, 70, "Input",
  CellTags->"MakeHomomorphism"],
Cell[296545, 10799, 840, 21, 70, "Output",
  CellTags->"MakeHomomorphism"]
}, Open  ]],
Cell[297400, 10823, 132, 2, 70, "ExampleText",
  Evaluatable->False,
  CellTags->"MakeHomomorphism"],

Cell[CellGroupData[{
Cell[297557, 10829, 104, 3, 70, "Input",
  CellTags->"MakeHomomorphism"],
Cell[297664, 10834, 125, 3, 70, "Output",
  CellTags->"MakeHomomorphism"]
}, Open  ]]
}, Closed]],
Cell[297816, 10841, 54, 1, 31, "ObjectName",
  CellTags->"MakeWord"],
Cell[297873, 10844, 59, 1, 74, "Highlight",
  CellTags->"MakeWord"],
Cell[297935, 10847, 231, 7, 45, "Usage",
  CellTags->"MakeWord"],
Cell[298169, 10856, 76, 1, 33, "Notes",
  CellTags->"MakeWord"],
Cell[298248, 10859, 159, 7, 33, "Notes",
  CellTags->"MakeWord"],

Cell[CellGroupData[{
Cell[298432, 10870, 66, 1, 59, "ExampleSection",
  CellTags->"MakeWord"],
Cell[298501, 10873, 68, 1, 70, "ExampleText",
  CellTags->"MakeWord"],

Cell[CellGroupData[{
Cell[298594, 10878, 86, 2, 70, "Input",
  CellTags->"MakeWord"],
Cell[298683, 10882, 113, 3, 70, "Output",
  CellTags->"MakeWord"]
}, Open  ]]
}, Closed]],
Cell[298823, 10889, 76, 1, 31, "ObjectName",
  CellTags->"MatrixToTransitions"],
Cell[298902, 10892, 70, 1, 74, "Highlight",
  CellTags->"MatrixToTransitions"],
Cell[298975, 10895, 282, 8, 64, "Usage",
  CellTags->"MatrixToTransitions"],
Cell[299260, 10905, 280, 11, 33, "Notes",
  CellTags->"MatrixToTransitions"],

Cell[CellGroupData[{
Cell[299565, 10920, 77, 1, 59, "ExampleSection",
  CellTags->"MatrixToTransitions"],
Cell[299645, 10923, 130, 4, 70, "ExampleText",
  CellTags->"MatrixToTransitions"],

Cell[CellGroupData[{
Cell[299800, 10931, 118, 2, 70, "Input",
  CellTags->"MatrixToTransitions"],
Cell[299921, 10935, 116, 3, 70, "Output",
  CellTags->"MatrixToTransitions"]
}, Open  ]],

Cell[CellGroupData[{
Cell[300074, 10943, 101, 2, 70, "Input",
  CellTags->"MatrixToTransitions"],
Cell[300178, 10947, 169, 4, 70, "Output",
  CellTags->"MatrixToTransitions"]
}, Open  ]]
}, Closed]],
Cell[300374, 10955, 70, 1, 31, "ObjectName",
  CellTags->"MinimalFischerFA"],
Cell[300447, 10958, 67, 1, 74, "Highlight",
  CellTags->"MinimalFischerFA"],
Cell[300517, 10961, 165, 4, 43, "Usage",
  CellTags->"MinimalFischerFA"],
Cell[300685, 10967, 368, 11, 106, "Notes",
  CellTags->"MinimalFischerFA"],
Cell[301056, 10980, 250, 8, 54, "Notes",
  CellTags->"MinimalFischerFA"],
Cell[301309, 10990, 218, 6, 54, "Notes",
  CellTags->"MinimalFischerFA"],

Cell[CellGroupData[{
Cell[301552, 11000, 74, 1, 59, "ExampleSection",
  CellTags->"MinimalFischerFA"],
Cell[301629, 11003, 106, 1, 70, "ExampleText",
  CellTags->"MinimalFischerFA"],

Cell[CellGroupData[{
Cell[301760, 11008, 93, 2, 70, "Input",
  CellTags->"MinimalFischerFA"],
Cell[301856, 11012, 355, 10, 70, "Output",
  CellTags->"MinimalFischerFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[302248, 11027, 119, 3, 70, "Input",
  CellTags->"MinimalFischerFA"],
Cell[302370, 11032, 426, 11, 70, "Output",
  CellTags->"MinimalFischerFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[302833, 11048, 111, 3, 70, "Input",
  CellTags->"MinimalFischerFA"],
Cell[302947, 11053, 96, 3, 70, "Output",
  CellTags->"MinimalFischerFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[303080, 11061, 115, 3, 70, "Input",
  CellTags->"MinimalFischerFA"],
Cell[303198, 11066, 96, 3, 70, "Output",
  CellTags->"MinimalFischerFA"]
}, Open  ]]
}, Closed]],
Cell[303321, 11073, 60, 1, 31, "ObjectName",
  CellTags->"MinimizeDFA"],
Cell[303384, 11076, 62, 1, 74, "Highlight",
  CellTags->"MinimizeDFA"],
Cell[303449, 11079, 141, 4, 43, "Usage",
  CellTags->"MinimizeDFA"],
Cell[303593, 11085, 348, 11, 104, "Notes",
  CellTags->"MinimizeDFA"],
Cell[303944, 11098, 305, 9, 54, "Notes",
  CellTags->"MinimizeDFA"],
Cell[304252, 11109, 146, 5, 33, "Notes",
  CellTags->"MinimizeDFA"],
Cell[304401, 11116, 272, 8, 54, "Notes",
  CellTags->"MinimizeDFA"],
Cell[304676, 11126, 269, 11, 33, "Notes",
  CellTags->"MinimizeDFA"],

Cell[CellGroupData[{
Cell[304970, 11141, 69, 1, 59, "ExampleSection",
  CellTags->"MinimizeDFA"],
Cell[305042, 11144, 78, 1, 70, "ExampleText",
  CellTags->"MinimizeDFA"],

Cell[CellGroupData[{
Cell[305145, 11149, 120, 3, 70, "Input",
  CellTags->"MinimizeDFA"],
Cell[305268, 11154, 523, 15, 70, "Output",
  CellTags->"MinimizeDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[305828, 11174, 286, 8, 70, "Input",
  CellTags->"MinimizeDFA"],
Cell[306117, 11184, 413, 12, 70, "Output",
  CellTags->"MinimizeDFA"],
Cell[306533, 11198, 163, 4, 70, "Output",
  CellTags->"MinimizeDFA"],
Cell[306699, 11204, 11936, 380, 70, "Output",
  CellTags->"MinimizeDFA"]
}, Open  ]]
}, Closed]],
Cell[318662, 11588, 58, 1, 31, "ObjectName",
  CellTags->"MinimizeFA"],
Cell[318723, 11591, 61, 1, 74, "Highlight",
  CellTags->"MinimizeFA"],
Cell[318787, 11594, 232, 6, 64, "Usage",
  CellTags->"MinimizeFA"],
Cell[319022, 11602, 365, 11, 106, "Notes",
  CellTags->"MinimizeFA"],
Cell[319390, 11615, 222, 6, 54, "Notes",
  CellTags->"MinimizeFA"],
Cell[319615, 11623, 209, 6, 54, "Notes",
  CellTags->"MinimizeFA"],
Cell[319827, 11631, 362, 15, 33, "Notes",
  CellTags->"MinimizeFA"],

Cell[CellGroupData[{
Cell[320214, 11650, 68, 1, 59, "ExampleSection",
  CellTags->"MinimizeFA"],
Cell[320285, 11653, 158, 4, 70, "ExampleText",
  CellTags->"MinimizeFA"],

Cell[CellGroupData[{
Cell[320468, 11661, 115, 5, 70, "Input",
  CellTags->"MinimizeFA"],
Cell[320586, 11668, 522, 15, 70, "Output",
  CellTags->"MinimizeFA"],
Cell[321111, 11685, 412, 12, 70, "Output",
  CellTags->"MinimizeFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[321560, 11702, 147, 4, 70, "Input",
  CellTags->"MinimizeFA"],
Cell[321710, 11708, 117, 3, 70, "Output",
  CellTags->"MinimizeFA"]
}, Open  ]]
}, Closed]],
Cell[321854, 11715, 64, 1, 31, "ObjectName",
  CellTags->"ModCounterDFA"],
Cell[321921, 11718, 64, 1, 74, "Highlight",
  CellTags->"ModCounterDFA"],
Cell[321988, 11721, 232, 5, 64, "Usage",
  CellTags->"ModCounterDFA"],
Cell[322223, 11728, 253, 9, 58, "Notes",
  CellTags->"ModCounterDFA"],
Cell[322479, 11739, 168, 7, 33, "Notes",
  CellTags->"ModCounterDFA"],

Cell[CellGroupData[{
Cell[322672, 11750, 71, 1, 59, "ExampleSection",
  CellTags->"ModCounterDFA"],
Cell[322746, 11753, 121, 4, 70, "ExampleText",
  CellTags->"ModCounterDFA"],

Cell[CellGroupData[{
Cell[322892, 11761, 114, 3, 70, "Input",
  CellTags->"ModCounterDFA"],
Cell[323009, 11766, 376, 12, 70, "Output",
  CellTags->"ModCounterDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323422, 11783, 115, 3, 70, "Input",
  CellTags->"ModCounterDFA"],
Cell[323540, 11788, 289, 5, 70, "Output",
  CellTags->"ModCounterDFA"]
}, Open  ]],
Cell[323844, 11796, 135, 4, 70, "ExampleText",
  CellTags->"ModCounterDFA"],

Cell[CellGroupData[{
Cell[324004, 11804, 159, 4, 70, "Input",
  CellTags->"ModCounterDFA"],
Cell[324166, 11810, 98, 3, 70, "Output",
  CellTags->"ModCounterDFA"]
}, Open  ]]
}, Closed]],
Cell[324291, 11817, 54, 1, 31, "ObjectName",
  CellTags->"NNFAToFA"],
Cell[324348, 11820, 59, 1, 74, "Highlight",
  CellTags->"NNFAToFA"],
Cell[324410, 11823, 177, 6, 43, "Usage",
  CellTags->"NNFAToFA"],
Cell[324590, 11831, 140, 4, 33, "Notes",
  CellTags->"NNFAToFA"],
Cell[324733, 11837, 187, 7, 33, "Notes",
  CellTags->"NNFAToFA"],

Cell[CellGroupData[{
Cell[324945, 11848, 66, 1, 59, "ExampleSection",
  CellTags->"NNFAToFA"],
Cell[325014, 11851, 242, 7, 70, "ExampleText",
  CellTags->"NNFAToFA"],

Cell[CellGroupData[{
Cell[325281, 11862, 110, 2, 70, "Input",
  CellTags->"NNFAToFA"],
Cell[325394, 11866, 127, 3, 70, "Output",
  CellTags->"NNFAToFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325558, 11874, 109, 3, 70, "Input",
  CellTags->"NNFAToFA"],
Cell[325670, 11879, 274, 6, 70, "Output",
  CellTags->"NNFAToFA"]
}, Open  ]],
Cell[325959, 11888, 67, 1, 70, "ExampleText",
  CellTags->"NNFAToFA"],

Cell[CellGroupData[{
Cell[326051, 11893, 77, 2, 70, "Input",
  CellTags->"NNFAToFA"],
Cell[326131, 11897, 543, 15, 70, "Output",
  CellTags->"NNFAToFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[326711, 11917, 103, 3, 70, "Input",
  CellTags->"NNFAToFA"],
Cell[326817, 11922, 364, 6, 70, "Output",
  CellTags->"NNFAToFA"]
}, Open  ]]
}, Closed]],
Cell[327208, 11932, 58, 1, 31, "ObjectName",
  CellTags->"NoFactorFA"],
Cell[327269, 11935, 61, 1, 74, "Highlight",
  CellTags->"NoFactorFA"],
Cell[327333, 11938, 390, 15, 67, "Usage",
  CellTags->"NoFactorFA"],
Cell[327726, 11955, 250, 9, 58, "Notes",
  CellTags->"NoFactorFA"],
Cell[327979, 11966, 358, 15, 33, "Notes",
  CellTags->"NoFactorFA"],

Cell[CellGroupData[{
Cell[328362, 11985, 68, 1, 59, "ExampleSection",
  CellTags->"NoFactorFA"],
Cell[328433, 11988, 159, 6, 70, "ExampleText",
  CellTags->"NoFactorFA"],

Cell[CellGroupData[{
Cell[328617, 11998, 108, 3, 70, "Input",
  CellTags->"NoFactorFA"],
Cell[328728, 12003, 385, 12, 70, "Output",
  CellTags->"NoFactorFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[329150, 12020, 111, 3, 70, "Input",
  CellTags->"NoFactorFA"],
Cell[329264, 12025, 557, 15, 70, "Output",
  CellTags->"NoFactorFA"]
}, Open  ]],
Cell[329836, 12043, 250, 9, 70, "ExampleText",
  CellTags->"NoFactorFA"],

Cell[CellGroupData[{
Cell[330111, 12056, 107, 3, 70, "Input",
  CellTags->"NoFactorFA"],
Cell[330221, 12061, 205, 4, 70, "Output",
  CellTags->"NoFactorFA"]
}, Open  ]]
}, Closed]],
Cell[330453, 12069, 58, 1, 31, "ObjectName",
  CellTags->"NoPrefixFA"],
Cell[330514, 12072, 61, 1, 74, "Highlight",
  CellTags->"NoPrefixFA"],
Cell[330578, 12075, 437, 16, 64, "Usage",
  CellTags->"NoPrefixFA"],
Cell[331018, 12093, 250, 9, 58, "Notes",
  CellTags->"NoPrefixFA"],
Cell[331271, 12104, 357, 15, 33, "Notes",
  CellTags->"NoPrefixFA"],

Cell[CellGroupData[{
Cell[331653, 12123, 68, 1, 59, "ExampleSection",
  CellTags->"NoPrefixFA"],
Cell[331724, 12126, 159, 6, 70, "ExampleText",
  CellTags->"NoPrefixFA"],

Cell[CellGroupData[{
Cell[331908, 12136, 108, 3, 70, "Input",
  CellTags->"NoPrefixFA"],
Cell[332019, 12141, 385, 12, 70, "Output",
  CellTags->"NoPrefixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[332441, 12158, 111, 3, 70, "Input",
  CellTags->"NoPrefixFA"],
Cell[332555, 12163, 470, 14, 70, "Output",
  CellTags->"NoPrefixFA"]
}, Open  ]],
Cell[333040, 12180, 241, 9, 70, "ExampleText",
  CellTags->"NoPrefixFA"],

Cell[CellGroupData[{
Cell[333306, 12193, 107, 3, 70, "Input",
  CellTags->"NoPrefixFA"],
Cell[333416, 12198, 318, 6, 70, "Output",
  CellTags->"NoPrefixFA"]
}, Open  ]]
}, Closed]],
Cell[333761, 12208, 70, 1, 31, "ObjectName",
  CellTags->"NormalizeControl"],
Cell[333834, 12211, 67, 1, 74, "Highlight",
  CellTags->"NormalizeControl"],
Cell[333904, 12214, 158, 4, 43, "Usage",
  CellTags->"NormalizeControl"],
Cell[334065, 12220, 176, 5, 33, "Notes",
  CellTags->"NormalizeControl"],
Cell[334244, 12227, 154, 5, 33, "Notes",
  CellTags->"NormalizeControl"],
Cell[334401, 12234, 163, 4, 33, "Notes",
  CellTags->"NormalizeControl"],

Cell[CellGroupData[{
Cell[334589, 12242, 74, 1, 59, "ExampleSection",
  CellTags->"NormalizeControl"],
Cell[334666, 12245, 157, 4, 70, "ExampleText",
  CellTags->"NormalizeControl"],

Cell[CellGroupData[{
Cell[334848, 12253, 152, 4, 70, "Input",
  CellTags->"NormalizeControl"],
Cell[335003, 12259, 115, 3, 70, "Output",
  CellTags->"NormalizeControl"]
}, Open  ]],

Cell[CellGroupData[{
Cell[335155, 12267, 173, 4, 70, "Input",
  CellTags->"NormalizeControl"],
Cell[335331, 12273, 176, 4, 70, "Output",
  CellTags->"NormalizeControl"]
}, Open  ]],
Cell[335522, 12280, 128, 4, 70, "ExampleText",
  CellTags->"NormalizeControl"],

Cell[CellGroupData[{
Cell[335675, 12288, 187, 5, 70, "Input",
  CellTags->"NormalizeControl"],
Cell[335865, 12295, 189, 4, 70, "Message",
  CellTags->"NormalizeControl"],
Cell[336057, 12301, 176, 4, 70, "Output",
  CellTags->"NormalizeControl"]
}, Open  ]]
}, Closed]],
Cell[336260, 12309, 60, 1, 31, "ObjectName",
  CellTags->"NormalizeFA"],
Cell[336323, 12312, 62, 1, 74, "Highlight",
  CellTags->"NormalizeFA"],
Cell[336388, 12315, 160, 6, 43, "Usage",
  CellTags->"NormalizeFA"],
Cell[336551, 12323, 291, 9, 54, "Notes",
  CellTags->"NormalizeFA"],
Cell[336845, 12334, 139, 4, 33, "Notes",
  CellTags->"NormalizeFA"],
Cell[336987, 12340, 185, 7, 33, "Notes",
  CellTags->"NormalizeFA"],

Cell[CellGroupData[{
Cell[337197, 12351, 69, 1, 59, "ExampleSection",
  CellTags->"NormalizeFA"],
Cell[337269, 12354, 133, 4, 70, "ExampleText",
  CellTags->"NormalizeFA"],

Cell[CellGroupData[{
Cell[337427, 12362, 171, 4, 70, "Input",
  CellTags->"NormalizeFA"],
Cell[337601, 12368, 413, 12, 70, "Output",
  CellTags->"NormalizeFA"],
Cell[338017, 12382, 172, 4, 70, "Output",
  CellTags->"NormalizeFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[338226, 12391, 138, 4, 70, "Input",
  CellTags->"NormalizeFA"],
Cell[338367, 12397, 413, 12, 70, "Output",
  CellTags->"NormalizeFA"],
Cell[338783, 12411, 111, 3, 70, "Output",
  CellTags->"NormalizeFA"]
}, Open  ]]
}, Closed]],
Cell[338921, 12418, 56, 1, 31, "ObjectName",
  CellTags->"NoSuffix"],
Cell[338980, 12421, 59, 1, 74, "Highlight",
  CellTags->"NoSuffix"],
Cell[339042, 12424, 439, 16, 64, "Usage",
  CellTags->"NoSuffix"],
Cell[339484, 12442, 248, 9, 58, "Notes",
  CellTags->"NoSuffix"],
Cell[339735, 12453, 355, 15, 33, "Notes",
  CellTags->"NoSuffix"],

Cell[CellGroupData[{
Cell[340115, 12472, 66, 1, 59, "ExampleSection",
  CellTags->"NoSuffix"],
Cell[340184, 12475, 157, 6, 70, "ExampleText",
  CellTags->"NoSuffix"],

Cell[CellGroupData[{
Cell[340366, 12485, 106, 3, 70, "Input",
  CellTags->"NoSuffix"],
Cell[340475, 12490, 383, 12, 70, "Output",
  CellTags->"NoSuffix"]
}, Open  ]],

Cell[CellGroupData[{
Cell[340895, 12507, 109, 3, 70, "Input",
  CellTags->"NoSuffix"],
Cell[341007, 12512, 468, 14, 70, "Output",
  CellTags->"NoSuffix"]
}, Open  ]],
Cell[341490, 12529, 241, 9, 70, "ExampleText",
  CellTags->"NoSuffix"],

Cell[CellGroupData[{
Cell[341756, 12542, 105, 3, 70, "Input",
  CellTags->"NoSuffix"],
Cell[341864, 12547, 316, 6, 70, "Output",
  CellTags->"NoSuffix"]
}, Open  ]]
}, Closed]],
Cell[342207, 12557, 58, 1, 31, "ObjectName",
  CellTags->"NumberOfCA"],
Cell[342268, 12560, 61, 1, 74, "Highlight",
  CellTags->"NumberOfCA"],
Cell[342332, 12563, 234, 8, 43, "Usage",
  CellTags->"NumberOfCA"],
Cell[342569, 12573, 132, 6, 37, "Notes",
  CellTags->"NumberOfCA"],
Cell[342704, 12581, 183, 7, 33, "Notes",
  CellTags->"NumberOfCA"],

Cell[CellGroupData[{
Cell[342912, 12592, 68, 1, 59, "ExampleSection",
  CellTags->"NumberOfCA"],
Cell[342983, 12595, 75, 1, 70, "ExampleText",
  CellTags->"NumberOfCA"],

Cell[CellGroupData[{
Cell[343083, 12600, 116, 2, 70, "Input",
  CellTags->"NumberOfCA"],
Cell[343202, 12604, 427, 15, 70, "Output",
  CellTags->"NumberOfCA"]
}, Open  ]]
}, Closed]],
Cell[343656, 12623, 60, 1, 31, "ObjectName",
  CellTags->"NumberOfDFA"],
Cell[343719, 12626, 62, 1, 74, "Highlight",
  CellTags->"NumberOfDFA"],
Cell[343784, 12629, 210, 8, 43, "Usage",
  CellTags->"NumberOfDFA"],
Cell[343997, 12639, 135, 4, 33, "Notes",
  CellTags->"NumberOfDFA"],
Cell[344135, 12645, 354, 15, 33, "Notes",
  CellTags->"NumberOfDFA"],

Cell[CellGroupData[{
Cell[344514, 12664, 69, 1, 59, "ExampleSection",
  CellTags->"NumberOfDFA"],
Cell[344586, 12667, 91, 1, 70, "ExampleText",
  CellTags->"NumberOfDFA"],

Cell[CellGroupData[{
Cell[344702, 12672, 115, 2, 70, "Input",
  CellTags->"NumberOfDFA"],
Cell[344820, 12676, 567, 18, 70, "Output",
  CellTags->"NumberOfDFA"]
}, Open  ]]
}, Closed]],
Cell[345414, 12698, 78, 1, 31, "ObjectName",
  CellTags->"NumberOfTotalisticCA"],
Cell[345495, 12701, 71, 1, 74, "Highlight",
  CellTags->"NumberOfTotalisticCA"],
Cell[345569, 12704, 268, 8, 64, "Usage",
  CellTags->"NumberOfTotalisticCA"],
Cell[345840, 12714, 150, 6, 35, "Notes",
  CellTags->"NumberOfTotalisticCA"],
Cell[345993, 12722, 401, 15, 33, "Notes",
  CellTags->"NumberOfTotalisticCA"],

Cell[CellGroupData[{
Cell[346419, 12741, 78, 1, 59, "ExampleSection",
  CellTags->"NumberOfTotalisticCA"],
Cell[346500, 12744, 79, 1, 70, "ExampleText",
  CellTags->"NumberOfTotalisticCA"],

Cell[CellGroupData[{
Cell[346604, 12749, 136, 2, 70, "Input",
  CellTags->"NumberOfTotalisticCA"],
Cell[346743, 12753, 436, 15, 70, "Output",
  CellTags->"NumberOfTotalisticCA"]
}, Open  ]]
}, Closed]],
Cell[347206, 12772, 66, 1, 31, "ObjectName",
  CellTags->"NumTransitions"],
Cell[347275, 12775, 65, 1, 74, "Highlight",
  CellTags->"NumTransitions"],
Cell[347343, 12778, 179, 6, 43, "Usage",
  CellTags->"NumTransitions"],
Cell[347525, 12786, 155, 7, 33, "Notes",
  CellTags->"NumTransitions"],

Cell[CellGroupData[{
Cell[347705, 12797, 72, 1, 59, "ExampleSection",
  CellTags->"NumTransitions"],
Cell[347780, 12800, 109, 1, 70, "ExampleText",
  CellTags->"NumTransitions"],
Cell[347892, 12803, 209, 5, 70, "Input",
  CellTags->"NumTransitions"],

Cell[CellGroupData[{
Cell[348126, 12812, 106, 3, 70, "Input",
  CellTags->"NumTransitions"],
Cell[348235, 12817, 91, 3, 70, "Output",
  CellTags->"NumTransitions"]
}, Open  ]]
}, Closed]],
Cell[348353, 12824, 52, 1, 31, "ObjectName",
  CellTags->"OrbitCA"],
Cell[348408, 12827, 58, 1, 74, "Highlight",
  CellTags->"OrbitCA"],
Cell[348469, 12830, 211, 5, 64, "Usage",
  CellTags->"OrbitCA"],
Cell[348683, 12837, 295, 10, 80, "Notes",
  CellTags->"OrbitCA"],
Cell[348981, 12849, 138, 5, 33, "Notes",
  CellTags->"OrbitCA"],
Cell[349122, 12856, 148, 4, 33, "Notes",
  CellTags->"OrbitCA"],
Cell[349273, 12862, 263, 11, 33, "Notes",
  CellTags->"OrbitCA"],

Cell[CellGroupData[{
Cell[349561, 12877, 65, 1, 59, "ExampleSection",
  CellTags->"OrbitCA"],
Cell[349629, 12880, 128, 4, 70, "ExampleText",
  CellTags->"OrbitCA"],
Cell[349760, 12886, 147, 5, 70, "Input",
  CellTags->"OrbitCA"],

Cell[CellGroupData[{
Cell[349932, 12895, 103, 3, 70, "Input",
  CellTags->"OrbitCA"],
Cell[350038, 12900, 92, 3, 70, "Output",
  CellTags->"OrbitCA"]
}, Open  ]],
Cell[350145, 12906, 117, 4, 70, "ExampleText",
  CellTags->"OrbitCA"],

Cell[CellGroupData[{
Cell[350287, 12914, 113, 3, 70, "Input",
  CellTags->"OrbitCA"],
Cell[350403, 12919, 105, 3, 70, "Output",
  CellTags->"OrbitCA"]
}, Open  ]]
}, Closed]],
Cell[350535, 12926, 62, 1, 31, "ObjectName",
  CellTags->"ParikhVector"],
Cell[350600, 12929, 63, 1, 74, "Highlight",
  CellTags->"ParikhVector"],
Cell[350666, 12932, 155, 4, 43, "Usage",
  CellTags->"ParikhVector"],
Cell[350824, 12938, 75, 1, 33, "Notes",
  CellTags->"ParikhVector"],

Cell[CellGroupData[{
Cell[350924, 12943, 70, 1, 59, "ExampleSection",
  CellTags->"ParikhVector"],
Cell[350997, 12946, 95, 1, 70, "ExampleText",
  CellTags->"ParikhVector"],

Cell[CellGroupData[{
Cell[351117, 12951, 98, 2, 70, "Input",
  CellTags->"ParikhVector"],
Cell[351218, 12955, 234, 5, 70, "Output",
  CellTags->"ParikhVector"]
}, Open  ]]
}, Closed]],
Cell[351479, 12964, 64, 1, 31, "ObjectName",
  CellTags->"PermutationSA"],
Cell[351546, 12967, 64, 1, 74, "Highlight",
  CellTags->"PermutationSA"],
Cell[351613, 12970, 212, 6, 64, "Usage",
  CellTags->"PermutationSA"],
Cell[351828, 12978, 150, 4, 33, "Notes",
  CellTags->"PermutationSA"],

Cell[CellGroupData[{
Cell[352003, 12986, 71, 1, 59, "ExampleSection",
  CellTags->"PermutationSA"],
Cell[352077, 12989, 87, 1, 70, "ExampleText",
  CellTags->"PermutationSA"],

Cell[CellGroupData[{
Cell[352189, 12994, 114, 2, 70, "Input",
  CellTags->"PermutationSA"],
Cell[352306, 12998, 349, 10, 70, "Output",
  CellTags->"PermutationSA"]
}, Open  ]],
Cell[352670, 13011, 131, 4, 70, "ExampleText",
  CellTags->"PermutationSA"],

Cell[CellGroupData[{
Cell[352826, 13019, 174, 5, 70, "Input",
  CellTags->"PermutationSA"],
Cell[353003, 13026, 488, 9, 70, "Output",
  CellTags->"PermutationSA"],
Cell[353494, 13037, 91, 3, 70, "Output",
  CellTags->"PermutationSA"]
}, Open  ]]
}, Closed]],
Cell[353612, 13044, 56, 1, 31, "ObjectName",
  CellTags->"PermuteFA"],
Cell[353671, 13047, 60, 1, 74, "Highlight",
  CellTags->"PermuteFA"],
Cell[353734, 13050, 215, 8, 43, "Usage",
  CellTags->"PermuteFA"],
Cell[353952, 13060, 211, 7, 33, "Notes",
  CellTags->"PermuteFA"],

Cell[CellGroupData[{
Cell[354188, 13071, 67, 1, 59, "ExampleSection",
  CellTags->"PermuteFA"],
Cell[354258, 13074, 104, 1, 48, "ExampleText",
  CellTags->"PermuteFA"],

Cell[CellGroupData[{
Cell[354387, 13079, 100, 2, 40, "Input",
  CellTags->"PermuteFA"],
Cell[354490, 13083, 372, 12, 30, "Output",
  CellTags->"PermuteFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[354899, 13100, 122, 3, 37, "Input",
  CellTags->"PermuteFA"],
Cell[355024, 13105, 372, 12, 30, "Output",
  CellTags->"PermuteFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[355433, 13122, 105, 3, 37, "Input",
  CellTags->"PermuteFA"],
Cell[355541, 13127, 89, 3, 30, "Output",
  CellTags->"PermuteFA"]
}, Open  ]]
}, Open  ]],
Cell[355657, 13134, 72, 1, 42, "ObjectName",
  CellTags->"PlotComputationFA"],
Cell[355732, 13137, 68, 1, 74, "Highlight",
  CellTags->"PlotComputationFA"],
Cell[355803, 13140, 222, 8, 43, "Usage",
  CellTags->"PlotComputationFA"],
Cell[356028, 13150, 378, 12, 128, "Notes",
  CellTags->"PlotComputationFA"],
Cell[356409, 13164, 161, 5, 33, "Notes",
  CellTags->"PlotComputationFA"],
Cell[356573, 13171, 151, 5, 33, "Notes",
  CellTags->"PlotComputationFA"],
Cell[356727, 13178, 293, 11, 33, "Notes",
  CellTags->"PlotComputationFA"],

Cell[CellGroupData[{
Cell[357045, 13193, 75, 1, 59, "ExampleSection",
  CellTags->"PlotComputationFA"],
Cell[357123, 13196, 206, 7, 70, "ExampleText",
  CellTags->"PlotComputationFA"],

Cell[CellGroupData[{
Cell[357354, 13207, 117, 3, 70, "Input",
  CellTags->"PlotComputationFA"],
Cell[357474, 13212, 487, 14, 70, "Output",
  CellTags->"PlotComputationFA"]
}, Open  ]],
Cell[357976, 13229, 155, 4, 70, "ExampleText",
  CellTags->"PlotComputationFA"],

Cell[CellGroupData[{
Cell[358156, 13237, 126, 3, 70, "Input",
  CellTags->"PlotComputationFA"],
Cell[358285, 13242, 2413, 168, 70, 2227, 162, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PlotComputationFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[360735, 13415, 184, 4, 70, "Input",
  CellTags->"PlotComputationFA"],
Cell[360922, 13421, 1899, 105, 70, 1713, 99, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PlotComputationFA"]
}, Open  ]]
}, Closed]],
Cell[362848, 13530, 66, 1, 31, "ObjectName",
  CellTags->"PolynomialToCA"],
Cell[362917, 13533, 65, 1, 74, "Highlight",
  CellTags->"PolynomialToCA"],
Cell[362985, 13536, 303, 9, 64, "Usage",
  CellTags->"PolynomialToCA"],
Cell[363291, 13547, 270, 11, 33, "Notes",
  CellTags->"PolynomialToCA"],
Cell[363564, 13560, 277, 11, 33, "Notes",
  CellTags->"PolynomialToCA"],

Cell[CellGroupData[{
Cell[363866, 13575, 72, 1, 59, "ExampleSection",
  CellTags->"PolynomialToCA"],
Cell[363941, 13578, 146, 4, 70, "ExampleText",
  CellTags->"PolynomialToCA"],

Cell[CellGroupData[{
Cell[364112, 13586, 123, 5, 70, "Input",
  CellTags->"PolynomialToCA"],
Cell[364238, 13593, 106, 3, 70, "Output",
  CellTags->"PolynomialToCA"],
Cell[364347, 13598, 561, 14, 70, "Output",
  CellTags->"PolynomialToCA"]
}, Open  ]]
}, Closed]],
Cell[364935, 13616, 56, 1, 31, "ObjectName",
  CellTags->"PrefixDFA"],
Cell[364994, 13619, 60, 1, 74, "Highlight",
  CellTags->"PrefixDFA"],
Cell[365057, 13622, 175, 5, 43, "Usage",
  CellTags->"PrefixDFA"],
Cell[365235, 13629, 249, 9, 58, "Notes",
  CellTags->"PrefixDFA"],

Cell[CellGroupData[{
Cell[365509, 13642, 67, 1, 59, "ExampleSection",
  CellTags->"PrefixDFA"],
Cell[365579, 13645, 89, 1, 70, "ExampleText",
  CellTags->"PrefixDFA"],

Cell[CellGroupData[{
Cell[365693, 13650, 103, 3, 70, "Input",
  CellTags->"PrefixDFA"],
Cell[365799, 13655, 390, 12, 70, "Output",
  CellTags->"PrefixDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[366226, 13672, 100, 3, 70, "Input",
  CellTags->"PrefixDFA"],
Cell[366329, 13677, 125, 3, 70, "Output",
  CellTags->"PrefixDFA"]
}, Open  ]]
}, Closed]],
Cell[366481, 13684, 52, 1, 31, "ObjectName",
  CellTags->"PrefixQ"],
Cell[366536, 13687, 58, 1, 74, "Highlight",
  CellTags->"PrefixQ"],
Cell[366597, 13690, 191, 8, 43, "Usage",
  CellTags->"PrefixQ"],
Cell[366791, 13700, 90, 1, 33, "Notes",
  CellTags->"PrefixQ"],
Cell[366884, 13703, 150, 7, 33, "Notes",
  CellTags->"PrefixQ"],

Cell[CellGroupData[{
Cell[367059, 13714, 65, 1, 59, "ExampleSection",
  CellTags->"PrefixQ"],
Cell[367127, 13717, 87, 1, 70, "ExampleText",
  CellTags->"PrefixQ"],

Cell[CellGroupData[{
Cell[367239, 13722, 96, 3, 70, "Input",
  CellTags->"PrefixQ"],
Cell[367338, 13727, 86, 3, 70, "Output",
  CellTags->"PrefixQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[367461, 13735, 96, 3, 70, "Input",
  CellTags->"PrefixQ"],
Cell[367560, 13740, 87, 3, 70, "Output",
  CellTags->"PrefixQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[367684, 13748, 105, 3, 70, "Input",
  CellTags->"PrefixQ"],
Cell[367792, 13753, 86, 3, 70, "Output",
  CellTags->"PrefixQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[367915, 13761, 122, 3, 70, "Input",
  CellTags->"PrefixQ"],
Cell[368040, 13766, 118, 3, 70, "Output",
  CellTags->"PrefixQ"]
}, Open  ]]
}, Closed]],
Cell[368185, 13773, 66, 1, 31, "ObjectName",
  CellTags->"PrimitiveCount"],
Cell[368254, 13776, 65, 1, 74, "Highlight",
  CellTags->"PrimitiveCount"],
Cell[368322, 13779, 238, 8, 43, "Usage",
  CellTags->"PrimitiveCount"],
Cell[368563, 13789, 114, 5, 33, "Notes",
  CellTags->"PrimitiveCount"],
Cell[368680, 13796, 82, 1, 33, "Notes",
  CellTags->"PrimitiveCount"],
Cell[368765, 13799, 355, 15, 33, "Notes",
  CellTags->"PrimitiveCount"],

Cell[CellGroupData[{
Cell[369145, 13818, 72, 1, 59, "ExampleSection",
  CellTags->"PrimitiveCount"],
Cell[369220, 13821, 78, 1, 70, "ExampleText",
  CellTags->"PrimitiveCount"],

Cell[CellGroupData[{
Cell[369323, 13826, 127, 2, 70, "Input",
  CellTags->"PrimitiveCount"],
Cell[369453, 13830, 600, 20, 70, "Output",
  CellTags->"PrimitiveCount"]
}, Open  ]]
}, Closed]],
Cell[370080, 13854, 58, 1, 31, "ObjectName",
  CellTags->"PrimitiveQ"],
Cell[370141, 13857, 61, 1, 74, "Highlight",
  CellTags->"PrimitiveQ"],
Cell[370205, 13860, 254, 8, 64, "Usage",
  CellTags->"PrimitiveQ"],
Cell[370462, 13870, 110, 5, 33, "Notes",
  CellTags->"PrimitiveQ"],
Cell[370575, 13877, 136, 5, 33, "Notes",
  CellTags->"PrimitiveQ"],
Cell[370714, 13884, 361, 15, 33, "Notes",
  CellTags->"PrimitiveQ"],

Cell[CellGroupData[{
Cell[371100, 13903, 68, 1, 59, "ExampleSection",
  CellTags->"PrimitiveQ"],
Cell[371171, 13906, 128, 4, 70, "ExampleText",
  CellTags->"PrimitiveQ"],

Cell[CellGroupData[{
Cell[371324, 13914, 125, 3, 70, "Input",
  CellTags->"PrimitiveQ"],
Cell[371452, 13919, 89, 3, 70, "Output",
  CellTags->"PrimitiveQ"]
}, Open  ]],
Cell[371556, 13925, 132, 4, 70, "ExampleText",
  CellTags->"PrimitiveQ"],

Cell[CellGroupData[{
Cell[371713, 13933, 125, 3, 70, "Input",
  CellTags->"PrimitiveQ"],
Cell[371841, 13938, 89, 3, 70, "Output",
  CellTags->"PrimitiveQ"]
}, Open  ]]
}, Closed]],
Cell[371957, 13945, 52, 1, 31, "ObjectName",
  CellTags->"PrintCA"],
Cell[372012, 13948, 58, 1, 74, "Highlight",
  CellTags->"PrintCA"],
Cell[372073, 13951, 181, 5, 43, "Usage",
  CellTags->"PrintCA"],

Cell[CellGroupData[{
Cell[372279, 13960, 65, 1, 59, "ExampleSection",
  CellTags->"PrintCA"],
Cell[372347, 13963, 69, 1, 70, "ExampleText",
  CellTags->"PrintCA"],

Cell[CellGroupData[{
Cell[372441, 13968, 83, 2, 70, "Input",
  CellTags->"PrintCA"],
Cell[372527, 13972, 554, 14, 70, "Output",
  CellTags->"PrintCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[373118, 13991, 90, 2, 70, "Input",
  CellTags->"PrintCA"],
Cell[373211, 13995, 814, 18, 70, "Output",
  CellTags->"PrintCA"]
}, Open  ]]
}, Closed]],
Cell[374052, 14017, 52, 1, 31, "ObjectName",
  CellTags->"PrintFA"],
Cell[374107, 14020, 58, 1, 74, "Highlight",
  CellTags->"PrintFA"],
Cell[374168, 14023, 158, 6, 43, "Usage",
  CellTags->"PrintFA"],
Cell[374329, 14031, 273, 10, 80, "Notes",
  CellTags->"PrintFA"],
Cell[374605, 14043, 144, 5, 33, "Notes",
  CellTags->"PrintFA"],
Cell[374752, 14050, 135, 5, 33, "Notes",
  CellTags->"PrintFA"],
Cell[374890, 14057, 79, 1, 33, "Notes",
  CellTags->"PrintFA"],

Cell[CellGroupData[{
Cell[374994, 14062, 65, 1, 59, "ExampleSection",
  CellTags->"PrintFA"],
Cell[375062, 14065, 61, 1, 70, "ExampleText",
  CellTags->"PrintFA"],

Cell[CellGroupData[{
Cell[375148, 14070, 91, 2, 70, "Input",
  CellTags->"PrintFA"],
Cell[375242, 14074, 399, 12, 70, "Output",
  CellTags->"PrintFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[375678, 14091, 92, 3, 70, "Input",
  CellTags->"PrintFA"],
Cell[375773, 14096, 209, 5, 70, "Print",
  CellTags->"PrintFA"],
Cell[375985, 14103, 237, 5, 70, "Print",
  CellTags->"PrintFA"],
Cell[376225, 14110, 213, 5, 70, "Print",
  CellTags->"PrintFA"],
Cell[376441, 14117, 213, 5, 70, "Print",
  CellTags->"PrintFA"],
Cell[376657, 14124, 606, 16, 70, "Output",
  CellTags->"PrintFA"]
}, Open  ]],
Cell[377278, 14143, 61, 1, 70, "ExampleText",
  CellTags->"PrintFA"],

Cell[CellGroupData[{
Cell[377364, 14148, 93, 2, 70, "Input",
  CellTags->"PrintFA"],
Cell[377460, 14152, 489, 14, 70, "Output",
  CellTags->"PrintFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[377986, 14171, 92, 3, 70, "Input",
  CellTags->"PrintFA"],
Cell[378081, 14176, 211, 5, 70, "Print",
  CellTags->"PrintFA"],
Cell[378295, 14183, 213, 5, 70, "Print",
  CellTags->"PrintFA"],
Cell[378511, 14190, 246, 6, 70, "Print",
  CellTags->"PrintFA"],
Cell[378760, 14198, 215, 5, 70, "Print",
  CellTags->"PrintFA"],
Cell[378978, 14205, 215, 5, 70, "Print",
  CellTags->"PrintFA"],
Cell[379196, 14212, 2964, 92, 70, "Output",
  CellTags->"PrintFA"]
}, Open  ]]
}, Closed]],
Cell[382187, 14308, 56, 1, 31, "ObjectName",
  CellTags->"ProductFA"],
Cell[382246, 14311, 60, 1, 74, "Highlight",
  CellTags->"ProductFA"],
Cell[382309, 14314, 199, 8, 43, "Usage",
  CellTags->"ProductFA"],
Cell[382511, 14324, 350, 11, 104, "Notes",
  CellTags->"ProductFA"],
Cell[382864, 14337, 226, 6, 60, "Notes",
  CellTags->"ProductFA"],
Cell[383093, 14345, 235, 6, 54, "Notes",
  CellTags->"ProductFA"],
Cell[383331, 14353, 446, 19, 33, "Notes",
  CellTags->"ProductFA"],

Cell[CellGroupData[{
Cell[383802, 14376, 67, 1, 59, "ExampleSection",
  CellTags->"ProductFA"],
Cell[383872, 14379, 97, 1, 70, "ExampleText",
  CellTags->"ProductFA"],

Cell[CellGroupData[{
Cell[383994, 14384, 128, 5, 70, "Input",
  CellTags->"ProductFA"],
Cell[384125, 14391, 377, 12, 70, "Output",
  CellTags->"ProductFA"],
Cell[384505, 14405, 383, 12, 70, "Output",
  CellTags->"ProductFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[384925, 14422, 108, 3, 70, "Input",
  CellTags->"ProductFA"],
Cell[385036, 14427, 491, 14, 70, "Output",
  CellTags->"ProductFA"]
}, Open  ]],
Cell[385542, 14444, 244, 9, 70, "ExampleText",
  CellTags->"ProductFA"],

Cell[CellGroupData[{
Cell[385811, 14457, 104, 3, 70, "Input",
  CellTags->"ProductFA"],
Cell[385918, 14462, 213, 4, 70, "Output",
  CellTags->"ProductFA"]
}, Open  ]]
}, Closed]],
Cell[386158, 14470, 74, 1, 31, "ObjectName",
  CellTags->"ProductTransitions"],
Cell[386235, 14473, 69, 1, 74, "Highlight",
  CellTags->"ProductTransitions"],
Cell[386307, 14476, 199, 5, 64, "Usage",
  CellTags->"ProductTransitions"],
Cell[386509, 14483, 230, 9, 58, "Notes",
  CellTags->"ProductTransitions"],
Cell[386742, 14494, 446, 16, 54, "Notes",
  CellTags->"ProductTransitions"],
Cell[387191, 14512, 253, 11, 33, "Notes",
  CellTags->"ProductTransitions"],
Cell[387447, 14525, 276, 11, 33, "Notes",
  CellTags->"ProductTransitions"],
Cell[387726, 14538, 286, 12, 33, "Notes",
  CellTags->"ProductTransitions"],

Cell[CellGroupData[{
Cell[388037, 14554, 76, 1, 59, "ExampleSection",
  CellTags->"ProductTransitions"],
Cell[388116, 14557, 112, 1, 70, "ExampleText",
  CellTags->"ProductTransitions"],
Cell[388231, 14560, 203, 4, 70, "Input",
  CellTags->"ProductTransitions"],

Cell[CellGroupData[{
Cell[388459, 14568, 120, 3, 70, "Input",
  CellTags->"ProductTransitions"],
Cell[388582, 14573, 907, 14, 70, "Output",
  CellTags->"ProductTransitions"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389526, 14592, 138, 3, 70, "Input",
  CellTags->"ProductTransitions"],
Cell[389667, 14597, 598, 10, 70, "Output",
  CellTags->"ProductTransitions"]
}, Open  ]],

Cell[CellGroupData[{
Cell[390302, 14612, 138, 3, 70, "Input",
  CellTags->"ProductTransitions"],
Cell[390443, 14617, 310, 6, 70, "Output",
  CellTags->"ProductTransitions"]
}, Open  ]]
}, Closed]],
Cell[390780, 14627, 66, 1, 31, "ObjectName",
  CellTags->"ProperPrefixes"],
Cell[390849, 14630, 65, 1, 74, "Highlight",
  CellTags->"ProperPrefixes"],
Cell[390917, 14633, 170, 4, 43, "Usage",
  CellTags->"ProperPrefixes"],
Cell[391090, 14639, 148, 5, 33, "Notes",
  CellTags->"ProperPrefixes"],
Cell[391241, 14646, 239, 7, 33, "Notes",
  CellTags->"ProperPrefixes"],
Cell[391483, 14655, 186, 5, 33, "Notes",
  CellTags->"ProperPrefixes"],
Cell[391672, 14662, 262, 11, 33, "Notes",
  CellTags->"ProperPrefixes"],

Cell[CellGroupData[{
Cell[391959, 14677, 72, 1, 59, "ExampleSection",
  CellTags->"ProperPrefixes"],
Cell[392034, 14680, 96, 1, 70, "ExampleText",
  CellTags->"ProperPrefixes"],

Cell[CellGroupData[{
Cell[392155, 14685, 165, 4, 70, "Input",
  CellTags->"ProperPrefixes"],
Cell[392323, 14691, 186, 4, 70, "Output",
  CellTags->"ProperPrefixes"]
}, Open  ]],

Cell[CellGroupData[{
Cell[392546, 14700, 99, 2, 70, "Input",
  CellTags->"ProperPrefixes"],
Cell[392648, 14704, 123, 3, 70, "Output",
  CellTags->"ProperPrefixes"]
}, Open  ]]
}, Closed]],
Cell[392798, 14711, 60, 1, 31, "ObjectName",
  CellTags->"QuotientDFA"],
Cell[392861, 14714, 62, 1, 74, "Highlight",
  CellTags->"QuotientDFA"],
Cell[392926, 14717, 228, 8, 43, "Usage",
  CellTags->"QuotientDFA"],
Cell[393157, 14727, 251, 9, 58, "Notes",
  CellTags->"QuotientDFA"],
Cell[393411, 14738, 74, 1, 33, "Notes",
  CellTags->"QuotientDFA"],
Cell[393488, 14741, 580, 23, 54, "Notes",
  CellTags->"QuotientDFA"],

Cell[CellGroupData[{
Cell[394093, 14768, 69, 1, 59, "ExampleSection",
  CellTags->"QuotientDFA"],
Cell[394165, 14771, 155, 4, 70, "ExampleText",
  CellTags->"QuotientDFA"],

Cell[CellGroupData[{
Cell[394345, 14779, 88, 2, 70, "Input",
  CellTags->"QuotientDFA"],
Cell[394436, 14783, 136, 3, 70, "Output",
  CellTags->"QuotientDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[394609, 14791, 128, 3, 70, "Input",
  CellTags->"QuotientDFA"],
Cell[394740, 14796, 398, 12, 70, "Output",
  CellTags->"QuotientDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[395175, 14813, 113, 3, 70, "Input",
  CellTags->"QuotientDFA"],
Cell[395291, 14818, 641, 17, 70, "Output",
  CellTags->"QuotientDFA"]
}, Open  ]],
Cell[395947, 14838, 111, 2, 70, "ExampleText",
  CellTags->"QuotientDFA"],

Cell[CellGroupData[{
Cell[396083, 14844, 142, 4, 70, "Input",
  CellTags->"QuotientDFA"],
Cell[396228, 14850, 105, 3, 70, "Output",
  CellTags->"QuotientDFA"],
Cell[396336, 14855, 92, 3, 70, "Output",
  CellTags->"QuotientDFA"]
}, Open  ]]
}, Closed]],
Cell[396455, 14862, 72, 1, 31, "ObjectName",
  CellTags->"QuotientMachineFA"],
Cell[396530, 14865, 68, 1, 74, "Highlight",
  CellTags->"QuotientMachineFA"],
Cell[396601, 14868, 553, 19, 64, "Usage",
  CellTags->"QuotientMachineFA"],
Cell[397157, 14889, 257, 9, 58, "Notes",
  CellTags->"QuotientMachineFA"],
Cell[397417, 14900, 107, 1, 33, "Notes",
  CellTags->"QuotientMachineFA"],
Cell[397527, 14903, 475, 19, 33, "Notes",
  CellTags->"QuotientMachineFA"],

Cell[CellGroupData[{
Cell[398027, 14926, 75, 1, 59, "ExampleSection",
  CellTags->"QuotientMachineFA"],
Cell[398105, 14929, 378, 12, 70, "ExampleText",
  CellTags->"QuotientMachineFA"],

Cell[CellGroupData[{
Cell[398508, 14945, 174, 5, 70, "Input",
  CellTags->"QuotientMachineFA"],
Cell[398685, 14952, 148, 3, 70, "Output",
  CellTags->"QuotientMachineFA"]
}, Open  ]],
Cell[398848, 14958, 143, 3, 70, "Input",
  CellTags->"QuotientMachineFA"],
Cell[398994, 14963, 162, 4, 70, "Input",
  CellTags->"QuotientMachineFA"],

Cell[CellGroupData[{
Cell[399181, 14971, 107, 2, 70, "Input",
  CellTags->"QuotientMachineFA"],
Cell[399291, 14975, 477, 14, 70, "Output",
  CellTags->"QuotientMachineFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[399805, 14994, 119, 3, 70, "Input",
  CellTags->"QuotientMachineFA"],
Cell[399927, 14999, 240, 5, 70, "Output",
  CellTags->"QuotientMachineFA"]
}, Open  ]],
Cell[400182, 15007, 103, 1, 70, "ExampleText",
  CellTags->"QuotientMachineFA"],

Cell[CellGroupData[{
Cell[400310, 15012, 118, 3, 70, "Input",
  CellTags->"QuotientMachineFA"],
Cell[400431, 15017, 97, 3, 70, "Output",
  CellTags->"QuotientMachineFA"]
}, Open  ]]
}, Closed]],
Cell[400555, 15024, 56, 1, 31, "ObjectName",
  CellTags->"RandomDFA"],
Cell[400614, 15027, 60, 1, 74, "Highlight",
  CellTags->"RandomDFA"],
Cell[400677, 15030, 147, 4, 43, "Usage",
  CellTags->"RandomDFA"],
Cell[400827, 15036, 102, 1, 33, "Notes",
  CellTags->"RandomDFA"],
Cell[400932, 15039, 356, 15, 33, "Notes",
  CellTags->"RandomDFA"],

Cell[CellGroupData[{
Cell[401313, 15058, 67, 1, 59, "ExampleSection",
  CellTags->"RandomDFA"],
Cell[401383, 15061, 99, 1, 70, "ExampleText",
  CellTags->"RandomDFA"],

Cell[CellGroupData[{
Cell[401507, 15066, 82, 2, 70, "Input",
  CellTags->"RandomDFA"],
Cell[401592, 15070, 410, 12, 70, "Output",
  CellTags->"RandomDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[402039, 15087, 82, 2, 70, "Input",
  CellTags->"RandomDFA"],
Cell[402124, 15091, 407, 12, 70, "Output",
  CellTags->"RandomDFA"]
}, Open  ]]
}, Closed]],
Cell[402558, 15107, 58, 1, 31, "ObjectName",
  CellTags->"RandomWord"],
Cell[402619, 15110, 61, 1, 74, "Highlight",
  CellTags->"RandomWord"],
Cell[402683, 15113, 150, 4, 43, "Usage",
  CellTags->"RandomWord"],
Cell[402836, 15119, 72, 1, 33, "Notes",
  CellTags->"RandomWord"],
Cell[402911, 15122, 155, 7, 33, "Notes",
  CellTags->"RandomWord"],

Cell[CellGroupData[{
Cell[403091, 15133, 68, 1, 59, "ExampleSection",
  CellTags->"RandomWord"],
Cell[403162, 15136, 62, 1, 70, "ExampleText",
  CellTags->"RandomWord"],

Cell[CellGroupData[{
Cell[403249, 15141, 85, 2, 70, "Input",
  CellTags->"RandomWord"],
Cell[403337, 15145, 108, 3, 70, "Output",
  CellTags->"RandomWord"]
}, Open  ]],

Cell[CellGroupData[{
Cell[403482, 15153, 86, 2, 70, "Input",
  CellTags->"RandomWord"],
Cell[403571, 15157, 108, 3, 70, "Output",
  CellTags->"RandomWord"]
}, Open  ]]
}, Closed]],
Cell[403706, 15164, 56, 1, 31, "ObjectName",
  CellTags->"RankOfDFA"],
Cell[403765, 15167, 60, 1, 74, "Highlight",
  CellTags->"RankOfDFA"],
Cell[403828, 15170, 169, 5, 43, "Usage",
  CellTags->"RankOfDFA"],
Cell[404000, 15177, 352, 15, 33, "Notes",
  CellTags->"RankOfDFA"],

Cell[CellGroupData[{
Cell[404377, 15196, 67, 1, 59, "ExampleSection",
  CellTags->"RankOfDFA"],
Cell[404447, 15199, 66, 1, 70, "ExampleText",
  CellTags->"RankOfDFA"],

Cell[CellGroupData[{
Cell[404538, 15204, 90, 2, 70, "Input",
  CellTags->"RankOfDFA"],
Cell[404631, 15208, 399, 12, 70, "Output",
  CellTags->"RankOfDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[405067, 15225, 100, 3, 70, "Input",
  CellTags->"RankOfDFA"],
Cell[405170, 15230, 100, 3, 70, "Output",
  CellTags->"RankOfDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[405307, 15238, 110, 3, 70, "Input",
  CellTags->"RankOfDFA"],
Cell[405420, 15243, 399, 12, 70, "Output",
  CellTags->"RankOfDFA"]
}, Open  ]]
}, Closed]],
Cell[405846, 15259, 56, 1, 31, "ObjectName",
  CellTags->"RankToDFA"],
Cell[405905, 15262, 60, 1, 74, "Highlight",
  CellTags->"RankToDFA"],
Cell[405968, 15265, 194, 5, 64, "Usage",
  CellTags->"RankToDFA"],
Cell[406165, 15272, 80, 1, 33, "Notes",
  CellTags->"RankToDFA"],
Cell[406248, 15275, 369, 17, 33, "Notes",
  CellTags->"RankToDFA"],

Cell[CellGroupData[{
Cell[406642, 15296, 67, 1, 59, "ExampleSection",
  CellTags->"RankToDFA"],
Cell[406712, 15299, 61, 1, 70, "ExampleText",
  CellTags->"RankToDFA"],

Cell[CellGroupData[{
Cell[406798, 15304, 133, 5, 70, "Input",
  CellTags->"RankToDFA"],
Cell[406934, 15311, 95, 3, 70, "Output",
  CellTags->"RankToDFA"],
Cell[407032, 15316, 390, 12, 70, "Output",
  CellTags->"RankToDFA"]
}, Open  ]]
}, Closed]],
Cell[407449, 15332, 50, 1, 31, "ObjectName",
  CellTags->"REEpsQ"],
Cell[407502, 15335, 57, 1, 74, "Highlight",
  CellTags->"REEpsQ"],
Cell[407562, 15338, 197, 6, 43, "Usage",
  CellTags->"REEpsQ"],
Cell[407762, 15346, 376, 14, 54, "Notes",
  CellTags->"REEpsQ"],
Cell[408141, 15362, 155, 7, 33, "Notes",
  CellTags->"REEpsQ"],

Cell[CellGroupData[{
Cell[408321, 15373, 64, 1, 59, "ExampleSection",
  CellTags->"REEpsQ"],
Cell[408388, 15376, 78, 1, 70, "ExampleText",
  CellTags->"REEpsQ"],

Cell[CellGroupData[{
Cell[408491, 15381, 85, 2, 70, "Input",
  CellTags->"REEpsQ"],
Cell[408579, 15385, 87, 3, 70, "Output",
  CellTags->"REEpsQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[408703, 15393, 90, 2, 70, "Input",
  CellTags->"REEpsQ"],
Cell[408796, 15397, 86, 3, 70, "Output",
  CellTags->"REEpsQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[408919, 15405, 97, 2, 70, "Input",
  CellTags->"REEpsQ"],
Cell[409019, 15409, 87, 3, 70, "Output",
  CellTags->"REEpsQ"]
}, Open  ]]
}, Closed]],
Cell[409133, 15416, 84, 1, 31, "ObjectName",
  CellTags->"RegularExpressionToBEFA"],
Cell[409220, 15419, 74, 1, 74, "Highlight",
  CellTags->"RegularExpressionToBEFA"],
Cell[409297, 15422, 197, 6, 43, "Usage",
  CellTags->"RegularExpressionToBEFA"],
Cell[409497, 15430, 103, 1, 33, "Notes",
  CellTags->"RegularExpressionToBEFA"],
Cell[409603, 15433, 131, 4, 33, "Notes",
  CellTags->"RegularExpressionToBEFA"],
Cell[409737, 15439, 282, 11, 33, "Notes",
  CellTags->"RegularExpressionToBEFA"],

Cell[CellGroupData[{
Cell[410044, 15454, 81, 1, 59, "ExampleSection",
  CellTags->"RegularExpressionToBEFA"],
Cell[410128, 15457, 257, 7, 70, "ExampleText",
  CellTags->"RegularExpressionToBEFA"],

Cell[CellGroupData[{
Cell[410410, 15468, 126, 2, 70, "Input",
  CellTags->"RegularExpressionToBEFA"],
Cell[410539, 15472, 143, 3, 70, "Output",
  CellTags->"RegularExpressionToBEFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[410719, 15480, 125, 3, 70, "Input",
  CellTags->"RegularExpressionToBEFA"],
Cell[410847, 15485, 288, 6, 70, "Output",
  CellTags->"RegularExpressionToBEFA"]
}, Open  ]]
}, Closed]],
Cell[411162, 15495, 80, 1, 31, "ObjectName",
  CellTags->"RegularExpressionToFA"],
Cell[411245, 15498, 72, 1, 74, "Highlight",
  CellTags->"RegularExpressionToFA"],
Cell[411320, 15501, 237, 8, 43, "Usage",
  CellTags->"RegularExpressionToFA"],
Cell[411560, 15511, 337, 11, 104, "Notes",
  CellTags->"RegularExpressionToFA"],
Cell[411900, 15524, 171, 5, 33, "Notes",
  CellTags->"RegularExpressionToFA"],
Cell[412074, 15531, 180, 5, 33, "Notes",
  CellTags->"RegularExpressionToFA"],
Cell[412257, 15538, 172, 5, 33, "Notes",
  CellTags->"RegularExpressionToFA"],
Cell[412432, 15545, 245, 6, 33, "Notes",
  CellTags->"RegularExpressionToFA"],

Cell[CellGroupData[{
Cell[412702, 15555, 79, 1, 59, "ExampleSection",
  CellTags->"RegularExpressionToFA"],
Cell[412784, 15558, 254, 7, 70, "ExampleText",
  CellTags->"RegularExpressionToFA"],

Cell[CellGroupData[{
Cell[413063, 15569, 124, 2, 70, "Input",
  CellTags->"RegularExpressionToFA"],
Cell[413190, 15573, 141, 3, 70, "Output",
  CellTags->"RegularExpressionToFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[413368, 15581, 129, 3, 70, "Input",
  CellTags->"RegularExpressionToFA"],
Cell[413500, 15586, 557, 15, 70, "Output",
  CellTags->"RegularExpressionToFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[414094, 15606, 117, 3, 70, "Input",
  CellTags->"RegularExpressionToFA"],
Cell[414214, 15611, 378, 6, 70, "Output",
  CellTags->"RegularExpressionToFA"]
}, Open  ]],
Cell[414607, 15620, 146, 4, 70, "ExampleText",
  CellTags->"RegularExpressionToFA"],

Cell[CellGroupData[{
Cell[414778, 15628, 196, 5, 70, "Input",
  CellTags->"RegularExpressionToFA"],
Cell[414977, 15635, 503, 14, 70, "Output",
  CellTags->"RegularExpressionToFA"]
}, Open  ]]
}, Closed]],
Cell[415507, 15653, 84, 1, 31, "ObjectName",
  CellTags->"RegularExpressionToNNFA"],
Cell[415594, 15656, 74, 1, 74, "Highlight",
  CellTags->"RegularExpressionToNNFA"],
Cell[415671, 15659, 197, 6, 43, "Usage",
  CellTags->"RegularExpressionToNNFA"],
Cell[415871, 15667, 138, 4, 33, "Notes",
  CellTags->"RegularExpressionToNNFA"],
Cell[416012, 15673, 282, 11, 33, "Notes",
  CellTags->"RegularExpressionToNNFA"],

Cell[CellGroupData[{
Cell[416319, 15688, 81, 1, 59, "ExampleSection",
  CellTags->"RegularExpressionToNNFA"],
Cell[416403, 15691, 257, 7, 70, "ExampleText",
  CellTags->"RegularExpressionToNNFA"],

Cell[CellGroupData[{
Cell[416685, 15702, 126, 2, 70, "Input",
  CellTags->"RegularExpressionToNNFA"],
Cell[416814, 15706, 143, 3, 70, "Output",
  CellTags->"RegularExpressionToNNFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[416994, 15714, 125, 3, 70, "Input",
  CellTags->"RegularExpressionToNNFA"],
Cell[417122, 15719, 290, 6, 70, "Output",
  CellTags->"RegularExpressionToNNFA"]
}, Open  ]]
}, Closed]],
Cell[417439, 15729, 74, 1, 31, "ObjectName",
  CellTags->"RemoveTransitionFA"],
Cell[417516, 15732, 69, 1, 74, "Highlight",
  CellTags->"RemoveTransitionFA"],
Cell[417588, 15735, 284, 10, 64, "Usage",
  CellTags->"RemoveTransitionFA"],
Cell[417875, 15747, 243, 7, 54, "Notes",
  CellTags->"RemoveTransitionFA"],
Cell[418121, 15756, 293, 11, 33, "Notes",
  CellTags->"RemoveTransitionFA"],

Cell[CellGroupData[{
Cell[418439, 15771, 76, 1, 59, "ExampleSection",
  CellTags->"RemoveTransitionFA"],
Cell[418518, 15774, 96, 1, 70, "ExampleText",
  CellTags->"RemoveTransitionFA"],
Cell[418617, 15777, 223, 5, 70, "Input",
  CellTags->"RemoveTransitionFA"],

Cell[CellGroupData[{
Cell[418865, 15786, 105, 3, 70, "Input",
  CellTags->"RemoveTransitionFA"],
Cell[418973, 15791, 368, 12, 70, "Output",
  CellTags->"RemoveTransitionFA"]
}, Open  ]],
Cell[419356, 15806, 152, 4, 70, "ExampleText",
  CellTags->"RemoveTransitionFA"],

Cell[CellGroupData[{
Cell[419533, 15814, 131, 3, 70, "Input",
  CellTags->"RemoveTransitionFA"],
Cell[419667, 15819, 342, 10, 70, "Output",
  CellTags->"RemoveTransitionFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[420046, 15834, 106, 3, 70, "Input",
  CellTags->"RemoveTransitionFA"],
Cell[420155, 15839, 567, 15, 70, "Output",
  CellTags->"RemoveTransitionFA"]
}, Open  ]]
}, Closed]],
Cell[420749, 15858, 44, 1, 31, "ObjectName",
  CellTags->"REQ"],
Cell[420796, 15861, 54, 1, 74, "Highlight",
  CellTags->"REQ"],
Cell[420853, 15864, 273, 7, 66, "Usage",
  CellTags->"REQ"],
Cell[421129, 15873, 313, 7, 54, "Notes",
  CellTags->"REQ"],
Cell[421445, 15882, 178, 7, 33, "Notes",
  CellTags->"REQ"],

Cell[CellGroupData[{
Cell[421648, 15893, 61, 1, 59, "ExampleSection",
  CellTags->"REQ"],
Cell[421712, 15896, 148, 6, 70, "ExampleText",
  CellTags->"REQ"],

Cell[CellGroupData[{
Cell[421885, 15906, 84, 2, 70, "Input",
  CellTags->"REQ"],
Cell[421972, 15910, 121, 3, 70, "Output",
  CellTags->"REQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[422130, 15918, 90, 3, 70, "Input",
  CellTags->"REQ"],
Cell[422223, 15923, 109, 3, 70, "Output",
  CellTags->"REQ"]
}, Open  ]],
Cell[422347, 15929, 189, 6, 70, "ExampleText",
  CellTags->"REQ"]
}, Closed]],
Cell[422551, 15938, 58, 1, 31, "ObjectName",
  CellTags->"RESimplify"],
Cell[422612, 15941, 61, 1, 74, "Highlight",
  CellTags->"RESimplify"],
Cell[422676, 15944, 238, 8, 64, "Usage",
  CellTags->"RESimplify"],
Cell[422917, 15954, 129, 4, 33, "Notes",
  CellTags->"RESimplify"],
Cell[423049, 15960, 165, 7, 33, "Notes",
  CellTags->"RESimplify"],

Cell[CellGroupData[{
Cell[423239, 15971, 68, 1, 59, "ExampleSection",
  CellTags->"RESimplify"],
Cell[423310, 15974, 85, 1, 70, "ExampleText",
  CellTags->"RESimplify"],

Cell[CellGroupData[{
Cell[423420, 15979, 95, 2, 70, "Input",
  CellTags->"RESimplify"],
Cell[423518, 15983, 91, 3, 70, "Output",
  CellTags->"RESimplify"]
}, Open  ]],

Cell[CellGroupData[{
Cell[423646, 15991, 104, 2, 70, "Input",
  CellTags->"RESimplify"],
Cell[423753, 15995, 99, 3, 70, "Output",
  CellTags->"RESimplify"]
}, Open  ]]
}, Closed]],
Cell[423879, 16002, 56, 1, 31, "ObjectName",
  CellTags->"ReverseFA"],
Cell[423938, 16005, 60, 1, 74, "Highlight",
  CellTags->"ReverseFA"],
Cell[424001, 16008, 207, 6, 43, "Usage",
  CellTags->"ReverseFA"],
Cell[424211, 16016, 117, 4, 33, "Notes",
  CellTags->"ReverseFA"],

Cell[CellGroupData[{
Cell[424353, 16024, 67, 1, 59, "ExampleSection",
  CellTags->"ReverseFA"],
Cell[424423, 16027, 178, 6, 70, "ExampleText",
  CellTags->"ReverseFA"],

Cell[CellGroupData[{
Cell[424626, 16037, 109, 3, 70, "Input",
  CellTags->"ReverseFA"],
Cell[424738, 16042, 384, 12, 70, "Output",
  CellTags->"ReverseFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[425159, 16059, 101, 3, 70, "Input",
  CellTags->"ReverseFA"],
Cell[425263, 16064, 491, 14, 70, "Output",
  CellTags->"ReverseFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[425791, 16083, 112, 3, 70, "Input",
  CellTags->"ReverseFA"],
Cell[425906, 16088, 366, 6, 70, "Output",
  CellTags->"ReverseFA"]
}, Open  ]]
}, Closed]],
Cell[426299, 16098, 62, 1, 31, "ObjectName",
  CellTags->"RightShiftCA"],
Cell[426364, 16101, 63, 1, 74, "Highlight",
  CellTags->"RightShiftCA"],
Cell[426430, 16104, 165, 4, 43, "Usage",
  CellTags->"RightShiftCA"],
Cell[426598, 16110, 167, 7, 33, "Notes",
  CellTags->"RightShiftCA"],

Cell[CellGroupData[{
Cell[426790, 16121, 70, 1, 59, "ExampleSection",
  CellTags->"RightShiftCA"],
Cell[426863, 16124, 61, 1, 70, "ExampleText",
  CellTags->"RightShiftCA"],

Cell[CellGroupData[{
Cell[426949, 16129, 86, 2, 70, "Input",
  CellTags->"RightShiftCA"],
Cell[427038, 16133, 104, 3, 70, "Output",
  CellTags->"RightShiftCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[427179, 16141, 140, 3, 70, "Input",
  CellTags->"RightShiftCA"],
Cell[427322, 16146, 107, 3, 70, "Output",
  CellTags->"RightShiftCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[427466, 16154, 97, 3, 70, "Input",
  CellTags->"RightShiftCA"],
Cell[427566, 16159, 103, 3, 70, "Output",
  CellTags->"RightShiftCA"]
}, Open  ]]
}, Closed]],
Cell[427696, 16166, 54, 1, 31, "ObjectName",
  CellTags->"SelectFA"],
Cell[427753, 16169, 59, 1, 74, "Highlight",
  CellTags->"SelectFA"],
Cell[427815, 16172, 208, 8, 43, "Usage",
  CellTags->"SelectFA"],
Cell[428026, 16182, 225, 9, 58, "Notes",
  CellTags->"SelectFA"],
Cell[428254, 16193, 91, 1, 33, "Notes",
  CellTags->"SelectFA"],
Cell[428348, 16196, 114, 4, 33, "Notes",
  CellTags->"SelectFA"],

Cell[CellGroupData[{
Cell[428487, 16204, 66, 1, 59, "ExampleSection",
  CellTags->"SelectFA"],
Cell[428556, 16207, 254, 7, 70, "ExampleText",
  CellTags->"SelectFA"],
Cell[428813, 16216, 272, 6, 70, "Input",
  CellTags->"SelectFA"],

Cell[CellGroupData[{
Cell[429110, 16226, 151, 4, 70, "Input",
  CellTags->"SelectFA"],
Cell[429264, 16232, 572, 15, 70, "Output",
  CellTags->"SelectFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[429873, 16252, 93, 3, 70, "Input",
  CellTags->"SelectFA"],
Cell[429969, 16257, 114, 3, 70, "Output",
  CellTags->"SelectFA"]
}, Open  ]],
Cell[430098, 16263, 138, 4, 70, "ExampleText",
  CellTags->"SelectFA"],

Cell[CellGroupData[{
Cell[430261, 16271, 115, 3, 70, "Input",
  CellTags->"SelectFA"],
Cell[430379, 16276, 572, 15, 70, "Output",
  CellTags->"SelectFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[430988, 16296, 103, 3, 70, "Input",
  CellTags->"SelectFA"],
Cell[431094, 16301, 88, 3, 70, "Output",
  CellTags->"SelectFA"]
}, Open  ]]
}, Closed]],
Cell[431209, 16308, 58, 1, 31, "ObjectName",
  CellTags->"SetFinalFA"],
Cell[431270, 16311, 61, 1, 74, "Highlight",
  CellTags->"SetFinalFA"],
Cell[431334, 16314, 200, 8, 43, "Usage",
  CellTags->"SetFinalFA"],
Cell[431537, 16324, 138, 5, 33, "Notes",
  CellTags->"SetFinalFA"],
Cell[431678, 16331, 68, 1, 33, "Notes",
  CellTags->"SetFinalFA"],
Cell[431749, 16334, 277, 11, 33, "Notes",
  CellTags->"SetFinalFA"],

Cell[CellGroupData[{
Cell[432051, 16349, 68, 1, 59, "ExampleSection",
  CellTags->"SetFinalFA"],
Cell[432122, 16352, 259, 7, 50, "ExampleText",
  CellTags->"SetFinalFA"],
Cell[432384, 16361, 215, 5, 60, "Input",
  CellTags->"SetFinalFA"],

Cell[CellGroupData[{
Cell[432624, 16370, 103, 3, 37, "Input",
  CellTags->"SetFinalFA"],
Cell[432730, 16375, 459, 14, 53, "Output",
  CellTags->"SetFinalFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[433226, 16394, 106, 3, 37, "Input",
  CellTags->"SetFinalFA"],
Cell[433335, 16399, 386, 7, 99, "Output",
  CellTags->"SetFinalFA"]
}, Open  ]]
}, Open  ]],
Cell[433748, 16410, 62, 1, 42, "ObjectName",
  CellTags->"SetInitialFA"],
Cell[433813, 16413, 63, 1, 74, "Highlight",
  CellTags->"SetInitialFA"],
Cell[433879, 16416, 210, 8, 43, "Usage",
  CellTags->"SetInitialFA"],
Cell[434092, 16426, 140, 5, 33, "Notes",
  CellTags->"SetInitialFA"],
Cell[434235, 16433, 70, 1, 33, "Notes",
  CellTags->"SetInitialFA"],
Cell[434308, 16436, 275, 11, 33, "Notes",
  CellTags->"SetInitialFA"],

Cell[CellGroupData[{
Cell[434608, 16451, 70, 1, 59, "ExampleSection",
  CellTags->"SetInitialFA"],
Cell[434681, 16454, 261, 7, 70, "ExampleText",
  CellTags->"SetInitialFA"],
Cell[434945, 16463, 217, 5, 70, "Input",
  CellTags->"SetInitialFA"],

Cell[CellGroupData[{
Cell[435187, 16472, 107, 3, 70, "Input",
  CellTags->"SetInitialFA"],
Cell[435297, 16477, 461, 14, 70, "Output",
  CellTags->"SetInitialFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[435795, 16496, 108, 3, 70, "Input",
  CellTags->"SetInitialFA"],
Cell[435906, 16501, 134, 3, 70, "Output",
  CellTags->"SetInitialFA"]
}, Open  ]]
}, Closed]],
Cell[436067, 16508, 72, 1, 31, "ObjectName",
  CellTags->"SetInitialFinalFA"],
Cell[436142, 16511, 68, 1, 74, "Highlight",
  CellTags->"SetInitialFinalFA"],
Cell[436213, 16514, 276, 10, 64, "Usage",
  CellTags->"SetInitialFinalFA"],
Cell[436492, 16526, 183, 7, 33, "Notes",
  CellTags->"SetInitialFinalFA"],
Cell[436678, 16535, 75, 1, 33, "Notes",
  CellTags->"SetInitialFinalFA"],
Cell[436756, 16538, 270, 11, 33, "Notes",
  CellTags->"SetInitialFinalFA"],

Cell[CellGroupData[{
Cell[437051, 16553, 75, 1, 59, "ExampleSection",
  CellTags->"SetInitialFinalFA"],
Cell[437129, 16556, 156, 4, 70, "ExampleText",
  CellTags->"SetInitialFinalFA"],
Cell[437288, 16562, 223, 5, 70, "Input",
  CellTags->"SetInitialFinalFA"],

Cell[CellGroupData[{
Cell[437536, 16571, 122, 3, 70, "Input",
  CellTags->"SetInitialFinalFA"],
Cell[437661, 16576, 477, 14, 70, "Output",
  CellTags->"SetInitialFinalFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[438175, 16595, 113, 3, 70, "Input",
  CellTags->"SetInitialFinalFA"],
Cell[438291, 16600, 264, 5, 70, "Output",
  CellTags->"SetInitialFinalFA"]
}, Open  ]]
}, Closed]],
Cell[438582, 16609, 64, 1, 31, "ObjectName",
  CellTags->"ShowAcceptQFA"],
Cell[438649, 16612, 64, 1, 74, "Highlight",
  CellTags->"ShowAcceptQFA"],
Cell[438716, 16615, 221, 7, 43, "Usage",
  CellTags->"ShowAcceptQFA"],
Cell[438940, 16624, 114, 5, 33, "Notes",
  CellTags->"ShowAcceptQFA"],

Cell[CellGroupData[{
Cell[439079, 16633, 71, 1, 59, "ExampleSection",
  CellTags->"ShowAcceptQFA"],
Cell[439153, 16636, 70, 1, 70, "ExampleText",
  CellTags->"ShowAcceptQFA"],
Cell[439226, 16639, 218, 5, 70, "Input",
  CellTags->"ShowAcceptQFA"],

Cell[CellGroupData[{
Cell[439469, 16648, 134, 3, 70, "Input",
  CellTags->"ShowAcceptQFA"],
Cell[439606, 16653, 441, 12, 70, "Output",
  CellTags->"ShowAcceptQFA"]
}, Open  ]]
}, Closed]],
Cell[440074, 16669, 54, 1, 31, "ObjectName",
  CellTags->"ShrinkCA"],
Cell[440131, 16672, 59, 1, 74, "Highlight",
  CellTags->"ShrinkCA"],
Cell[440193, 16675, 202, 5, 64, "Usage",
  CellTags->"ShrinkCA"],
Cell[440398, 16682, 224, 9, 58, "Notes",
  CellTags->"ShrinkCA"],
Cell[440625, 16693, 148, 5, 33, "Notes",
  CellTags->"ShrinkCA"],

Cell[CellGroupData[{
Cell[440798, 16702, 66, 1, 59, "ExampleSection",
  CellTags->"ShrinkCA"],
Cell[440867, 16705, 166, 4, 70, "ExampleText",
  CellTags->"ShrinkCA"],

Cell[CellGroupData[{
Cell[441058, 16713, 179, 5, 70, "Input",
  CellTags->"ShrinkCA"],
Cell[441240, 16720, 101, 3, 70, "Output",
  CellTags->"ShrinkCA"],
Cell[441344, 16725, 104, 3, 70, "Output",
  CellTags->"ShrinkCA"],
Cell[441451, 16730, 101, 3, 70, "Output",
  CellTags->"ShrinkCA"]
}, Open  ]],
Cell[441567, 16736, 134, 4, 70, "ExampleText",
  CellTags->"ShrinkCA"],

Cell[CellGroupData[{
Cell[441726, 16744, 245, 7, 70, "Input",
  CellTags->"ShrinkCA"],
Cell[441974, 16753, 138, 3, 70, "Output",
  CellTags->"ShrinkCA"],
Cell[442115, 16758, 100, 3, 70, "Output",
  CellTags->"ShrinkCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[442252, 16766, 93, 3, 70, "Input",
  CellTags->"ShrinkCA"],
Cell[442348, 16771, 385, 12, 70, "Output",
  CellTags->"ShrinkCA"]
}, Open  ]]
}, Closed]],
Cell[442760, 16787, 70, 1, 31, "ObjectName",
  CellTags->"ShuffleProductFA"],
Cell[442833, 16790, 67, 1, 74, "Highlight",
  CellTags->"ShuffleProductFA"],
Cell[442903, 16793, 282, 9, 64, "Usage",
  CellTags->"ShuffleProductFA"],
Cell[443188, 16804, 256, 9, 58, "Notes",
  CellTags->"ShuffleProductFA"],
Cell[443447, 16815, 107, 1, 33, "Notes",
  CellTags->"ShuffleProductFA"],
Cell[443557, 16818, 171, 7, 33, "Notes",
  CellTags->"ShuffleProductFA"],

Cell[CellGroupData[{
Cell[443753, 16829, 74, 1, 59, "ExampleSection",
  CellTags->"ShuffleProductFA"],
Cell[443830, 16832, 287, 9, 70, "ExampleText",
  CellTags->"ShuffleProductFA"],

Cell[CellGroupData[{
Cell[444142, 16845, 137, 5, 70, "Input",
  CellTags->"ShuffleProductFA"],
Cell[444282, 16852, 373, 12, 70, "Output",
  CellTags->"ShuffleProductFA"],
Cell[444658, 16866, 373, 12, 70, "Output",
  CellTags->"ShuffleProductFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[445068, 16883, 124, 3, 70, "Input",
  CellTags->"ShuffleProductFA"],
Cell[445195, 16888, 549, 15, 70, "Output",
  CellTags->"ShuffleProductFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[445781, 16908, 138, 3, 70, "Input",
  CellTags->"ShuffleProductFA"],
Cell[445922, 16913, 126, 3, 70, "Output",
  CellTags->"ShuffleProductFA"]
}, Open  ]]
}, Closed]],
Cell[446075, 16920, 54, 1, 31, "ObjectName",
  CellTags->"SinkQDFA"],
Cell[446132, 16923, 59, 1, 74, "Highlight",
  CellTags->"SinkQDFA"],
Cell[446194, 16926, 249, 8, 64, "Usage",
  CellTags->"SinkQDFA"],
Cell[446446, 16936, 256, 11, 33, "Notes",
  CellTags->"SinkQDFA"],
Cell[446705, 16949, 66, 1, 59, "ExampleSection",
  CellTags->"SinkQDFA"],

Cell[CellGroupData[{
Cell[446796, 16954, 66, 1, 59, "ExampleSection",
  CellTags->"SinkQDFA"],
Cell[446865, 16957, 79, 1, 48, "ExampleText",
  CellTags->"SinkQDFA"],
Cell[446947, 16960, 154, 4, 37, "Input",
  CellTags->"SinkQDFA"],

Cell[CellGroupData[{
Cell[447126, 16968, 93, 3, 37, "Input",
  CellTags->"SinkQDFA"],
Cell[447222, 16973, 88, 3, 30, "Output",
  CellTags->"SinkQDFA"]
}, Open  ]],
Cell[447325, 16979, 97, 1, 48, "ExampleText",
  CellTags->"SinkQDFA"],
Cell[447425, 16982, 139, 3, 37, "Input",
  CellTags->"SinkQDFA"],

Cell[CellGroupData[{
Cell[447589, 16989, 93, 3, 37, "Input",
  CellTags->"SinkQDFA"],
Cell[447685, 16994, 87, 3, 30, "Output",
  CellTags->"SinkQDFA"]
}, Open  ]]
}, Open  ]],
Cell[447799, 17001, 54, 1, 42, "ObjectName",
  CellTags->"SinksDFA"],
Cell[447856, 17004, 59, 1, 74, "Highlight",
  CellTags->"SinksDFA"],
Cell[447918, 17007, 155, 4, 43, "Usage",
  CellTags->"SinksDFA"],
Cell[448076, 17013, 256, 11, 33, "Notes",
  CellTags->"SinksDFA"],

Cell[CellGroupData[{
Cell[448357, 17028, 66, 1, 59, "ExampleSection",
  CellTags->"SinksDFA"],
Cell[448426, 17031, 73, 1, 70, "ExampleText",
  CellTags->"SinksDFA"],
Cell[448502, 17034, 144, 4, 70, "Input",
  CellTags->"SinksDFA"],

Cell[CellGroupData[{
Cell[448671, 17042, 107, 3, 70, "Input",
  CellTags->"SinksDFA"],
Cell[448781, 17047, 89, 3, 70, "Output",
  CellTags->"SinksDFA"]
}, Open  ]]
}, Closed]],
Cell[448897, 17054, 46, 1, 31, "ObjectName",
  CellTags->"Size"],
Cell[448946, 17057, 55, 1, 74, "Highlight",
  CellTags->"Size"],
Cell[449004, 17060, 126, 4, 43, "Usage",
  CellTags->"Size"],
Cell[449133, 17066, 220, 9, 58, "Notes",
  CellTags->"Size"],
Cell[449356, 17077, 104, 5, 33, "Notes",
  CellTags->"Size"],

Cell[CellGroupData[{
Cell[449485, 17086, 62, 1, 59, "ExampleSection",
  CellTags->"Size"],
Cell[449550, 17089, 69, 1, 70, "ExampleText",
  CellTags->"Size"],

Cell[CellGroupData[{
Cell[449644, 17094, 90, 2, 70, "Input",
  CellTags->"Size"],
Cell[449737, 17098, 81, 3, 70, "Output",
  CellTags->"Size"]
}, Open  ]]
}, Closed]],
Cell[449845, 17105, 54, 1, 31, "ObjectName",
  CellTags->"SquareSA"],
Cell[449902, 17108, 59, 1, 74, "Highlight",
  CellTags->"SquareSA"],
Cell[449964, 17111, 187, 6, 43, "Usage",
  CellTags->"SquareSA"],
Cell[450154, 17119, 302, 10, 80, "Notes",
  CellTags->"SquareSA"],
Cell[450459, 17131, 159, 5, 33, "Notes",
  CellTags->"SquareSA"],
Cell[450621, 17138, 145, 5, 33, "Notes",
  CellTags->"SquareSA"],
Cell[450769, 17145, 100, 1, 33, "Notes",
  CellTags->"SquareSA"],
Cell[450872, 17148, 258, 11, 33, "Notes",
  CellTags->"SquareSA"],

Cell[CellGroupData[{
Cell[451155, 17163, 66, 1, 59, "ExampleSection",
  CellTags->"SquareSA"],
Cell[451224, 17166, 78, 1, 70, "ExampleText",
  CellTags->"SquareSA"],
Cell[451305, 17169, 213, 5, 70, "Input",
  CellTags->"SquareSA"],

Cell[CellGroupData[{
Cell[451543, 17178, 93, 3, 70, "Input",
  CellTags->"SquareSA"],
Cell[451639, 17183, 416, 11, 70, "Output",
  CellTags->"SquareSA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[452092, 17199, 109, 3, 70, "Input",
  CellTags->"SquareSA"],
Cell[452204, 17204, 421, 11, 70, "Output",
  CellTags->"SquareSA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[452662, 17220, 109, 3, 70, "Input",
  CellTags->"SquareSA"],
Cell[452774, 17225, 354, 10, 70, "Output",
  CellTags->"SquareSA"]
}, Open  ]]
}, Closed]],
Cell[453155, 17239, 50, 1, 31, "ObjectName",
  CellTags->"StarFA"],
Cell[453208, 17242, 57, 1, 74, "Highlight",
  CellTags->"StarFA"],
Cell[453268, 17245, 196, 7, 43, "Usage",
  CellTags->"StarFA"],
Cell[453467, 17254, 305, 10, 80, "Notes",
  CellTags->"StarFA"],
Cell[453775, 17266, 176, 5, 33, "Notes",
  CellTags->"StarFA"],
Cell[453954, 17273, 438, 19, 33, "Notes",
  CellTags->"StarFA"],

Cell[CellGroupData[{
Cell[454417, 17296, 64, 1, 59, "ExampleSection",
  CellTags->"StarFA"],
Cell[454484, 17299, 189, 6, 70, "ExampleText",
  CellTags->"StarFA"],

Cell[CellGroupData[{
Cell[454698, 17309, 84, 2, 70, "Input",
  CellTags->"StarFA"],
Cell[454785, 17313, 369, 12, 70, "Output",
  CellTags->"StarFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[455191, 17330, 99, 3, 70, "Input",
  CellTags->"StarFA"],
Cell[455293, 17335, 491, 14, 70, "Output",
  CellTags->"StarFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[455821, 17354, 134, 3, 70, "Input",
  CellTags->"StarFA"],
Cell[455958, 17359, 116, 3, 70, "Output",
  CellTags->"StarFA"]
}, Open  ]]
}, Closed]],
Cell[456101, 17366, 64, 1, 31, "ObjectName",
  CellTags->"StateMergeDFA"],
Cell[456168, 17369, 64, 1, 74, "Highlight",
  CellTags->"StateMergeDFA"],
Cell[456235, 17372, 227, 6, 64, "Usage",
  CellTags->"StateMergeDFA"],
Cell[456465, 17380, 350, 11, 104, "Notes",
  CellTags->"StateMergeDFA"],
Cell[456818, 17393, 228, 5, 54, "Notes",
  CellTags->"StateMergeDFA"],
Cell[457049, 17400, 187, 7, 33, "Notes",
  CellTags->"StateMergeDFA"],
Cell[457239, 17409, 202, 7, 33, "Notes",
  CellTags->"StateMergeDFA"],

Cell[CellGroupData[{
Cell[457466, 17420, 71, 1, 59, "ExampleSection",
  CellTags->"StateMergeDFA"],
Cell[457540, 17423, 242, 7, 70, "ExampleText",
  CellTags->"StateMergeDFA"],
Cell[457785, 17432, 202, 5, 70, "Input",
  CellTags->"StateMergeDFA"],
Cell[457990, 17439, 105, 1, 70, "ExampleText",
  CellTags->"StateMergeDFA"],

Cell[CellGroupData[{
Cell[458120, 17444, 112, 3, 70, "Input",
  CellTags->"StateMergeDFA"],
Cell[458235, 17449, 415, 12, 70, "Output",
  CellTags->"StateMergeDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[458687, 17466, 110, 3, 70, "Input",
  CellTags->"StateMergeDFA"],
Cell[458800, 17471, 370, 6, 70, "Output",
  CellTags->"StateMergeDFA"]
}, Open  ]]
}, Closed]],
Cell[459197, 17481, 50, 1, 31, "ObjectName",
  CellTags->"States"],
Cell[459250, 17484, 57, 1, 74, "Highlight",
  CellTags->"States"],
Cell[459310, 17487, 164, 6, 43, "Usage",
  CellTags->"States"],
Cell[459477, 17495, 196, 6, 33, "Notes",
  CellTags->"States"],
Cell[459676, 17503, 255, 11, 33, "Notes",
  CellTags->"States"],

Cell[CellGroupData[{
Cell[459956, 17518, 64, 1, 59, "ExampleSection",
  CellTags->"States"],
Cell[460023, 17521, 96, 1, 70, "ExampleText",
  CellTags->"States"],
Cell[460122, 17524, 101, 3, 70, "Input",
  CellTags->"States"],

Cell[CellGroupData[{
Cell[460248, 17531, 89, 3, 70, "Input",
  CellTags->"States"],
Cell[460340, 17536, 93, 3, 70, "Output",
  CellTags->"States"]
}, Open  ]],
Cell[460448, 17542, 122, 3, 70, "Input",
  CellTags->"States"],

Cell[CellGroupData[{
Cell[460595, 17549, 89, 3, 70, "Input",
  CellTags->"States"],
Cell[460687, 17554, 111, 3, 70, "Output",
  CellTags->"States"]
}, Open  ]]
}, Closed]],
Cell[460825, 17561, 56, 1, 31, "ObjectName",
  CellTags->"SubsetQFA"],
Cell[460884, 17564, 60, 1, 74, "Highlight",
  CellTags->"SubsetQFA"],
Cell[460947, 17567, 244, 8, 64, "Usage",
  CellTags->"SubsetQFA"],
Cell[461194, 17577, 247, 9, 58, "Notes",
  CellTags->"SubsetQFA"],
Cell[461444, 17588, 198, 6, 54, "Notes",
  CellTags->"SubsetQFA"],
Cell[461645, 17596, 168, 7, 33, "Notes",
  CellTags->"SubsetQFA"],

Cell[CellGroupData[{
Cell[461838, 17607, 67, 1, 59, "ExampleSection",
  CellTags->"SubsetQFA"],
Cell[461908, 17610, 125, 4, 70, "ExampleText",
  CellTags->"SubsetQFA"],

Cell[CellGroupData[{
Cell[462058, 17618, 156, 4, 70, "Input",
  CellTags->"SubsetQFA"],
Cell[462217, 17624, 399, 12, 70, "Output",
  CellTags->"SubsetQFA"],
Cell[462619, 17638, 402, 12, 70, "Output",
  CellTags->"SubsetQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[463058, 17655, 103, 3, 70, "Input",
  CellTags->"SubsetQFA"],
Cell[463164, 17660, 89, 3, 70, "Output",
  CellTags->"SubsetQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[463290, 17668, 103, 3, 70, "Input",
  CellTags->"SubsetQFA"],
Cell[463396, 17673, 90, 3, 70, "Output",
  CellTags->"SubsetQFA"]
}, Open  ]]
}, Closed]],
Cell[463513, 17680, 58, 1, 31, "ObjectName",
  CellTags->"Substitute"],
Cell[463574, 17683, 61, 1, 74, "Highlight",
  CellTags->"Substitute"],
Cell[463638, 17686, 229, 8, 43, "Usage",
  CellTags->"Substitute"],
Cell[463870, 17696, 126, 5, 33, "Notes",
  CellTags->"Substitute"],
Cell[463999, 17703, 257, 11, 33, "Notes",
  CellTags->"Substitute"],

Cell[CellGroupData[{
Cell[464281, 17718, 68, 1, 59, "ExampleSection",
  CellTags->"Substitute"],
Cell[464352, 17721, 78, 1, 70, "ExampleText",
  CellTags->"Substitute"],

Cell[CellGroupData[{
Cell[464455, 17726, 111, 3, 70, "Input",
  CellTags->"Substitute"],
Cell[464569, 17731, 378, 12, 70, "Output",
  CellTags->"Substitute"]
}, Open  ]],
Cell[464962, 17746, 129, 3, 70, "Input",
  CellTags->"Substitute"],

Cell[CellGroupData[{
Cell[465116, 17753, 117, 3, 70, "Input",
  CellTags->"Substitute"],
Cell[465236, 17758, 1465, 42, 70, "Output",
  CellTags->"Substitute"]
}, Open  ]],

Cell[CellGroupData[{
Cell[466738, 17805, 102, 3, 70, "Input",
  CellTags->"Substitute"],
Cell[466843, 17810, 163, 5, 70, "Output",
  CellTags->"Substitute"]
}, Open  ]]
}, Closed]],
Cell[467033, 17819, 72, 1, 31, "ObjectName",
  CellTags->"SubwordCounterDFA"],
Cell[467108, 17822, 68, 1, 74, "Highlight",
  CellTags->"SubwordCounterDFA"],
Cell[467179, 17825, 337, 11, 64, "Usage",
  CellTags->"SubwordCounterDFA"],
Cell[467519, 17838, 257, 9, 58, "Notes",
  CellTags->"SubwordCounterDFA"],
Cell[467779, 17849, 311, 11, 33, "Notes",
  CellTags->"SubwordCounterDFA"],
Cell[468093, 17862, 198, 6, 35, "Notes",
  CellTags->"SubwordCounterDFA"],
Cell[468294, 17870, 289, 11, 33, "Notes",
  CellTags->"SubwordCounterDFA"],

Cell[CellGroupData[{
Cell[468608, 17885, 75, 1, 59, "ExampleSection",
  CellTags->"SubwordCounterDFA"],
Cell[468686, 17888, 138, 4, 70, "ExampleText",
  CellTags->"SubwordCounterDFA"],

Cell[CellGroupData[{
Cell[468849, 17896, 228, 6, 70, "Input",
  CellTags->"SubwordCounterDFA"],
Cell[469080, 17904, 94, 3, 70, "Output",
  CellTags->"SubwordCounterDFA"],
Cell[469177, 17909, 882, 13, 70, "Output",
  CellTags->"SubwordCounterDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[470096, 17927, 203, 5, 70, "Input",
  CellTags->"SubwordCounterDFA"],
Cell[470302, 17934, 660, 21, 70, "Output",
  CellTags->"SubwordCounterDFA"]
}, Open  ]]
}, Closed]],
Cell[470989, 17959, 58, 1, 31, "ObjectName",
  CellTags->"SubwordDFA"],
Cell[471050, 17962, 61, 1, 74, "Highlight",
  CellTags->"SubwordDFA"],
Cell[471114, 17965, 234, 8, 43, "Usage",
  CellTags->"SubwordDFA"],
Cell[471351, 17975, 250, 9, 58, "Notes",
  CellTags->"SubwordDFA"],
Cell[471604, 17986, 142, 5, 33, "Notes",
  CellTags->"SubwordDFA"],
Cell[471749, 17993, 296, 11, 33, "Notes",
  CellTags->"SubwordDFA"],

Cell[CellGroupData[{
Cell[472070, 18008, 68, 1, 59, "ExampleSection",
  CellTags->"SubwordDFA"],
Cell[472141, 18011, 97, 1, 70, "ExampleText",
  CellTags->"SubwordDFA"],

Cell[CellGroupData[{
Cell[472263, 18016, 132, 3, 70, "Input",
  CellTags->"SubwordDFA"],
Cell[472398, 18021, 378, 12, 70, "Output",
  CellTags->"SubwordDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[472813, 18038, 93, 3, 70, "Input",
  CellTags->"SubwordDFA"],
Cell[472909, 18043, 115, 3, 70, "Output",
  CellTags->"SubwordDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[473061, 18051, 105, 3, 70, "Input",
  CellTags->"SubwordDFA"],
Cell[473169, 18056, 321, 6, 70, "Output",
  CellTags->"SubwordDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[473527, 18067, 113, 3, 70, "Input",
  CellTags->"SubwordDFA"],
Cell[473643, 18072, 158, 4, 70, "Output",
  CellTags->"SubwordDFA"]
}, Open  ]]
}, Closed]],
Cell[473828, 18080, 78, 1, 31, "ObjectName",
  CellTags->"SubwordModCounterDFA"],
Cell[473909, 18083, 71, 1, 74, "Highlight",
  CellTags->"SubwordModCounterDFA"],
Cell[473983, 18086, 326, 9, 64, "Usage",
  CellTags->"SubwordModCounterDFA"],
Cell[474312, 18097, 260, 9, 58, "Notes",
  CellTags->"SubwordModCounterDFA"],
Cell[474575, 18108, 317, 11, 33, "Notes",
  CellTags->"SubwordModCounterDFA"],
Cell[474895, 18121, 201, 6, 35, "Notes",
  CellTags->"SubwordModCounterDFA"],
Cell[475099, 18129, 286, 11, 33, "Notes",
  CellTags->"SubwordModCounterDFA"],

Cell[CellGroupData[{
Cell[475410, 18144, 78, 1, 59, "ExampleSection",
  CellTags->"SubwordModCounterDFA"],
Cell[475491, 18147, 138, 4, 70, "ExampleText",
  CellTags->"SubwordModCounterDFA"],

Cell[CellGroupData[{
Cell[475654, 18155, 128, 3, 70, "Input",
  CellTags->"SubwordModCounterDFA"],
Cell[475785, 18160, 452, 14, 70, "Output",
  CellTags->"SubwordModCounterDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[476274, 18179, 110, 3, 70, "Input",
  CellTags->"SubwordModCounterDFA"],
Cell[476387, 18184, 235, 5, 70, "Output",
  CellTags->"SubwordModCounterDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[476659, 18194, 113, 3, 70, "Input",
  CellTags->"SubwordModCounterDFA"],
Cell[476775, 18199, 137, 3, 70, "Output",
  CellTags->"SubwordModCounterDFA"]
}, Open  ]]
}, Closed]],
Cell[476939, 18206, 58, 1, 31, "ObjectName",
  CellTags->"SuffixesFA"],
Cell[477000, 18209, 61, 1, 74, "Highlight",
  CellTags->"SuffixesFA"],
Cell[477064, 18212, 225, 8, 43, "Usage",
  CellTags->"SuffixesFA"],
Cell[477292, 18222, 250, 9, 58, "Notes",
  CellTags->"SuffixesFA"],
Cell[477545, 18233, 159, 7, 33, "Notes",
  CellTags->"SuffixesFA"],

Cell[CellGroupData[{
Cell[477729, 18244, 68, 1, 59, "ExampleSection",
  CellTags->"SuffixesFA"],
Cell[477800, 18247, 86, 1, 70, "ExampleText",
  CellTags->"SuffixesFA"],

Cell[CellGroupData[{
Cell[477911, 18252, 92, 2, 70, "Input",
  CellTags->"SuffixesFA"],
Cell[478006, 18256, 466, 14, 70, "Output",
  CellTags->"SuffixesFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[478509, 18275, 110, 3, 70, "Input",
  CellTags->"SuffixesFA"],
Cell[478622, 18280, 163, 4, 70, "Output",
  CellTags->"SuffixesFA"]
}, Open  ]]
}, Closed]],
Cell[478812, 18288, 54, 1, 31, "ObjectName",
  CellTags->"SuffixFA"],
Cell[478869, 18291, 59, 1, 74, "Highlight",
  CellTags->"SuffixFA"],
Cell[478931, 18294, 222, 8, 43, "Usage",
  CellTags->"SuffixFA"],
Cell[479156, 18304, 248, 9, 58, "Notes",
  CellTags->"SuffixFA"],
Cell[479407, 18315, 200, 6, 33, "Notes",
  CellTags->"SuffixFA"],

Cell[CellGroupData[{
Cell[479632, 18325, 66, 1, 59, "ExampleSection",
  CellTags->"SuffixFA"],
Cell[479701, 18328, 85, 1, 48, "ExampleText",
  CellTags->"SuffixFA"],

Cell[CellGroupData[{
Cell[479811, 18333, 82, 2, 40, "Input",
  CellTags->"SuffixFA"],
Cell[479896, 18337, 407, 12, 53, "Output",
  CellTags->"SuffixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[480340, 18354, 104, 3, 37, "Input",
  CellTags->"SuffixFA"],
Cell[480447, 18359, 170, 4, 30, "Output",
  CellTags->"SuffixFA"]
}, Open  ]]
}, Open  ]],
Cell[480644, 18367, 48, 1, 42, "ObjectName",
  CellTags->"SumFA"],
Cell[480695, 18370, 56, 1, 74, "Highlight",
  CellTags->"SumFA"],
Cell[480754, 18373, 199, 8, 43, "Usage",
  CellTags->"SumFA"],
Cell[480956, 18383, 147, 5, 33, "Notes",
  CellTags->"SumFA"],
Cell[481106, 18390, 50, 1, 33, "Notes",
  CellTags->"SumFA"],
Cell[481159, 18393, 142, 4, 33, "Notes",
  CellTags->"SumFA"],
Cell[481304, 18399, 350, 15, 33, "Notes",
  CellTags->"SumFA"],

Cell[CellGroupData[{
Cell[481679, 18418, 63, 1, 59, "ExampleSection",
  CellTags->"SumFA"],
Cell[481745, 18421, 142, 4, 70, "ExampleText",
  CellTags->"SumFA"],

Cell[CellGroupData[{
Cell[481912, 18429, 132, 6, 70, "Input",
  CellTags->"SumFA"],
Cell[482047, 18437, 379, 12, 70, "Output",
  CellTags->"SumFA"],
Cell[482429, 18451, 379, 12, 70, "Output",
  CellTags->"SumFA"],
Cell[482811, 18465, 548, 15, 70, "Output",
  CellTags->"SumFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[483396, 18485, 100, 3, 70, "Input",
  CellTags->"SumFA"],
Cell[483499, 18490, 116, 3, 70, "Output",
  CellTags->"SumFA"]
}, Open  ]],
Cell[483630, 18496, 140, 4, 70, "ExampleText",
  CellTags->"SumFA"],

Cell[CellGroupData[{
Cell[483795, 18504, 105, 3, 70, "Input",
  CellTags->"SumFA"],
Cell[483903, 18509, 400, 12, 70, "Output",
  CellTags->"SumFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[484340, 18526, 99, 3, 70, "Input",
  CellTags->"SumFA"],
Cell[484442, 18531, 84, 3, 70, "Output",
  CellTags->"SumFA"]
}, Open  ]]
}, Closed]],
Cell[484553, 18538, 74, 1, 31, "ObjectName",
  CellTags->"SwitchTransitionFA"],
Cell[484630, 18541, 69, 1, 74, "Highlight",
  CellTags->"SwitchTransitionFA"],
Cell[484702, 18544, 347, 12, 64, "Usage",
  CellTags->"SwitchTransitionFA"],
Cell[485052, 18558, 245, 7, 54, "Notes",
  CellTags->"SwitchTransitionFA"],
Cell[485300, 18567, 296, 11, 33, "Notes",
  CellTags->"SwitchTransitionFA"],

Cell[CellGroupData[{
Cell[485621, 18582, 76, 1, 59, "ExampleSection",
  CellTags->"SwitchTransitionFA"],
Cell[485700, 18585, 200, 5, 70, "ExampleText",
  CellTags->"SwitchTransitionFA"],
Cell[485903, 18592, 224, 5, 70, "Input",
  CellTags->"SwitchTransitionFA"],

Cell[CellGroupData[{
Cell[486152, 18601, 129, 3, 70, "Input",
  CellTags->"SwitchTransitionFA"],
Cell[486284, 18606, 354, 10, 70, "Output",
  CellTags->"SwitchTransitionFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[486675, 18621, 114, 3, 70, "Input",
  CellTags->"SwitchTransitionFA"],
Cell[486792, 18626, 96, 3, 70, "Output",
  CellTags->"SwitchTransitionFA"]
}, Open  ]]
}, Closed]],
Cell[486915, 18633, 76, 1, 31, "ObjectName",
  CellTags->"SyntacticCongruence"],
Cell[486994, 18636, 70, 1, 74, "Highlight",
  CellTags->"SyntacticCongruence"],
Cell[487067, 18639, 214, 6, 43, "Usage",
  CellTags->"SyntacticCongruence"],
Cell[487284, 18647, 212, 7, 33, "Notes",
  CellTags->"SyntacticCongruence"],
Cell[487499, 18656, 510, 19, 33, "Notes",
  CellTags->"SyntacticCongruence"],

Cell[CellGroupData[{
Cell[488034, 18679, 77, 1, 59, "ExampleSection",
  CellTags->"SyntacticCongruence"],
Cell[488114, 18682, 146, 4, 70, "ExampleText",
  CellTags->"SyntacticCongruence"],

Cell[CellGroupData[{
Cell[488285, 18690, 104, 2, 70, "Input",
  CellTags->"SyntacticCongruence"],
Cell[488392, 18694, 381, 12, 70, "Output",
  CellTags->"SyntacticCongruence"]
}, Open  ]],

Cell[CellGroupData[{
Cell[488810, 18711, 127, 3, 70, "Input",
  CellTags->"SyntacticCongruence"],
Cell[488940, 18716, 165, 4, 70, "Output",
  CellTags->"SyntacticCongruence"]
}, Open  ]],
Cell[489120, 18723, 117, 2, 70, "ExampleText",
  CellTags->"SyntacticCongruence"],

Cell[CellGroupData[{
Cell[489262, 18729, 162, 4, 70, "Input",
  CellTags->"SyntacticCongruence"],
Cell[489427, 18735, 205, 4, 70, "Output",
  CellTags->"SyntacticCongruence"]
}, Open  ]]
}, Closed]],
Cell[489659, 18743, 80, 1, 31, "ObjectName",
  CellTags->"SyntacticHomomorphism"],
Cell[489742, 18746, 72, 1, 74, "Highlight",
  CellTags->"SyntacticHomomorphism"],
Cell[489817, 18749, 196, 6, 43, "Usage",
  CellTags->"SyntacticHomomorphism"],
Cell[490016, 18757, 122, 5, 33, "Notes",
  CellTags->"SyntacticHomomorphism"],
Cell[490141, 18764, 284, 9, 33, "Notes",
  CellTags->"SyntacticHomomorphism"],
Cell[490428, 18775, 412, 15, 33, "Notes",
  CellTags->"SyntacticHomomorphism"],

Cell[CellGroupData[{
Cell[490865, 18794, 79, 1, 59, "ExampleSection",
  CellTags->"SyntacticHomomorphism"],
Cell[490947, 18797, 110, 1, 70, "ExampleText",
  CellTags->"SyntacticHomomorphism"],

Cell[CellGroupData[{
Cell[491082, 18802, 106, 2, 70, "Input",
  CellTags->"SyntacticHomomorphism"],
Cell[491191, 18806, 383, 12, 70, "Output",
  CellTags->"SyntacticHomomorphism"]
}, Open  ]],
Cell[491589, 18821, 122, 3, 70, "Input",
  CellTags->"SyntacticHomomorphism"],

Cell[CellGroupData[{
Cell[491736, 18828, 99, 3, 70, "Input",
  CellTags->"SyntacticHomomorphism"],
Cell[491838, 18833, 106, 3, 70, "Output",
  CellTags->"SyntacticHomomorphism"]
}, Open  ]],

Cell[CellGroupData[{
Cell[491981, 18841, 124, 4, 70, "Input",
  CellTags->"SyntacticHomomorphism"],
Cell[492108, 18847, 106, 3, 70, "Output",
  CellTags->"SyntacticHomomorphism"],
Cell[492217, 18852, 106, 3, 70, "Output",
  CellTags->"SyntacticHomomorphism"]
}, Open  ]]
}, Closed]],
Cell[492350, 18859, 60, 1, 31, "ObjectName",
  CellTags->"SyntacticSG"],
Cell[492413, 18862, 62, 1, 74, "Highlight",
  CellTags->"SyntacticSG"],
Cell[492478, 18865, 167, 6, 43, "Usage",
  CellTags->"SyntacticSG"],
Cell[492648, 18873, 206, 7, 33, "Notes",
  CellTags->"SyntacticSG"],
Cell[492857, 18882, 304, 11, 33, "Notes",
  CellTags->"SyntacticSG"],

Cell[CellGroupData[{
Cell[493186, 18897, 69, 1, 59, "ExampleSection",
  CellTags->"SyntacticSG"],
Cell[493258, 18900, 135, 4, 70, "ExampleText",
  CellTags->"SyntacticSG"],

Cell[CellGroupData[{
Cell[493418, 18908, 96, 2, 70, "Input",
  CellTags->"SyntacticSG"],
Cell[493517, 18912, 373, 12, 70, "Output",
  CellTags->"SyntacticSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493927, 18929, 99, 3, 70, "Input",
  CellTags->"SyntacticSG"],
Cell[494029, 18934, 124, 3, 70, "Output",
  CellTags->"SyntacticSG"]
}, Open  ]]
}, Closed]],
Cell[494180, 18941, 58, 1, 31, "ObjectName",
  CellTags->"TheInitial"],
Cell[494241, 18944, 61, 1, 74, "Highlight",
  CellTags->"TheInitial"],
Cell[494305, 18947, 184, 6, 43, "Usage",
  CellTags->"TheInitial"],
Cell[494492, 18955, 157, 7, 33, "Notes",
  CellTags->"TheInitial"],

Cell[CellGroupData[{
Cell[494674, 18966, 68, 1, 59, "ExampleSection",
  CellTags->"TheInitial"],
Cell[494745, 18969, 103, 1, 70, "ExampleText",
  CellTags->"TheInitial"],

Cell[CellGroupData[{
Cell[494873, 18974, 94, 2, 70, "Input",
  CellTags->"TheInitial"],
Cell[494970, 18978, 383, 12, 70, "Output",
  CellTags->"TheInitial"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495390, 18995, 97, 3, 70, "Input",
  CellTags->"TheInitial"],
Cell[495490, 19000, 86, 3, 70, "Output",
  CellTags->"TheInitial"]
}, Open  ]]
}, Closed]],
Cell[495603, 19007, 58, 1, 31, "ObjectName",
  CellTags->"TheSinkDFA"],
Cell[495664, 19010, 61, 1, 74, "Highlight",
  CellTags->"TheSinkDFA"],
Cell[495728, 19013, 192, 5, 43, "Usage",
  CellTags->"TheSinkDFA"],
Cell[495923, 19020, 254, 11, 33, "Notes",
  CellTags->"TheSinkDFA"],

Cell[CellGroupData[{
Cell[496202, 19035, 68, 1, 59, "ExampleSection",
  CellTags->"TheSinkDFA"],
Cell[496273, 19038, 75, 1, 70, "ExampleText",
  CellTags->"TheSinkDFA"],
Cell[496351, 19041, 146, 4, 70, "Input",
  CellTags->"TheSinkDFA"],

Cell[CellGroupData[{
Cell[496522, 19049, 97, 3, 70, "Input",
  CellTags->"TheSinkDFA"],
Cell[496622, 19054, 86, 3, 70, "Output",
  CellTags->"TheSinkDFA"]
}, Open  ]]
}, Closed]],
Cell[496735, 19061, 54, 1, 31, "ObjectName",
  CellTags->"ToBlocks"],
Cell[496792, 19064, 59, 1, 74, "Highlight",
  CellTags->"ToBlocks"],
Cell[496854, 19067, 204, 6, 43, "Usage",
  CellTags->"ToBlocks"],
Cell[497061, 19075, 284, 10, 58, "Notes",
  CellTags->"ToBlocks"],
Cell[497348, 19087, 132, 5, 33, "Notes",
  CellTags->"ToBlocks"],
Cell[497483, 19094, 192, 7, 33, "Notes",
  CellTags->"ToBlocks"],
Cell[497678, 19103, 157, 5, 33, "Notes",
  CellTags->"ToBlocks"],

Cell[CellGroupData[{
Cell[497860, 19112, 66, 1, 59, "ExampleSection",
  CellTags->"ToBlocks"],
Cell[497929, 19115, 75, 1, 70, "ExampleText",
  CellTags->"ToBlocks"],

Cell[CellGroupData[{
Cell[498029, 19120, 89, 2, 70, "Input",
  CellTags->"ToBlocks"],
Cell[498121, 19124, 138, 3, 70, "Output",
  CellTags->"ToBlocks"]
}, Open  ]],

Cell[CellGroupData[{
Cell[498296, 19132, 106, 2, 70, "Input",
  CellTags->"ToBlocks"],
Cell[498405, 19136, 138, 3, 70, "Output",
  CellTags->"ToBlocks"]
}, Open  ]],
Cell[498558, 19142, 67, 1, 70, "ExampleText",
  CellTags->"ToBlocks"],

Cell[CellGroupData[{
Cell[498650, 19147, 91, 2, 70, "Input",
  CellTags->"ToBlocks"],
Cell[498744, 19151, 118, 3, 70, "Output",
  CellTags->"ToBlocks"]
}, Open  ]]
}, Closed]],
Cell[498889, 19158, 62, 1, 31, "ObjectName",
  CellTags->"ToCharacters"],
Cell[498954, 19161, 63, 1, 74, "Highlight",
  CellTags->"ToCharacters"],
Cell[499020, 19164, 160, 4, 43, "Usage",
  CellTags->"ToCharacters"],
Cell[499183, 19170, 164, 5, 33, "Notes",
  CellTags->"ToCharacters"],
Cell[499350, 19177, 86, 1, 33, "Notes",
  CellTags->"ToCharacters"],

Cell[CellGroupData[{
Cell[499461, 19182, 70, 1, 59, "ExampleSection",
  CellTags->"ToCharacters"],
Cell[499534, 19185, 124, 4, 70, "ExampleText",
  CellTags->"ToCharacters"],

Cell[CellGroupData[{
Cell[499683, 19193, 110, 5, 70, "Input",
  CellTags->"ToCharacters"],
Cell[499796, 19200, 107, 3, 70, "Output",
  CellTags->"ToCharacters"],
Cell[499906, 19205, 279, 8, 70, "Output",
  CellTags->"ToCharacters"]
}, Open  ]]
}, Closed]],
Cell[500212, 19217, 48, 1, 31, "ObjectName",
  CellTags->"ToDFA"],
Cell[500263, 19220, 56, 1, 74, "Highlight",
  CellTags->"ToDFA"],
Cell[500322, 19223, 142, 4, 43, "Usage",
  CellTags->"ToDFA"],
Cell[500467, 19229, 406, 12, 130, "Notes",
  CellTags->"ToDFA"],
Cell[500876, 19243, 208, 8, 33, "Notes",
  CellTags->"ToDFA"],
Cell[501087, 19253, 167, 5, 33, "Notes",
  CellTags->"ToDFA"],
Cell[501257, 19260, 209, 5, 54, "Notes",
  CellTags->"ToDFA"],
Cell[501469, 19267, 250, 8, 54, "Notes",
  CellTags->"ToDFA"],
Cell[501722, 19277, 150, 5, 33, "Notes",
  CellTags->"ToDFA"],
Cell[501875, 19284, 161, 4, 54, "Notes",
  CellTags->"ToDFA"],
Cell[502039, 19290, 316, 15, 33, "Notes",
  CellTags->"ToDFA"],

Cell[CellGroupData[{
Cell[502380, 19309, 63, 1, 59, "ExampleSection",
  CellTags->"ToDFA"],
Cell[502446, 19312, 147, 4, 70, "ExampleText",
  CellTags->"ToDFA"],
Cell[502596, 19318, 105, 3, 70, "Input",
  CellTags->"ToDFA"],

Cell[CellGroupData[{
Cell[502726, 19325, 146, 4, 70, "Input",
  CellTags->"ToDFA"],
Cell[502875, 19331, 620, 17, 70, "Output",
  CellTags->"ToDFA"],
Cell[503498, 19350, 643, 17, 70, "Output",
  CellTags->"ToDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[504178, 19372, 100, 3, 70, "Input",
  CellTags->"ToDFA"],
Cell[504281, 19377, 85, 3, 70, "Output",
  CellTags->"ToDFA"]
}, Open  ]],
Cell[504381, 19383, 105, 2, 70, "ExampleText",
  CellTags->"ToDFA"],

Cell[CellGroupData[{
Cell[504511, 19389, 201, 5, 70, "Input",
  CellTags->"ToDFA"],
Cell[504715, 19396, 454, 14, 70, "Output",
  CellTags->"ToDFA"],
Cell[505172, 19412, 166, 4, 70, "Output",
  CellTags->"ToDFA"]
}, Open  ]]
}, Closed]],
Cell[505365, 19420, 66, 1, 31, "ObjectName",
  CellTags->"ToEquationsDFA"],
Cell[505434, 19423, 65, 1, 74, "Highlight",
  CellTags->"ToEquationsDFA"],
Cell[505502, 19426, 175, 6, 43, "Usage",
  CellTags->"ToEquationsDFA"],
Cell[505680, 19434, 173, 4, 54, "Notes",
  CellTags->"ToEquationsDFA"],
Cell[505856, 19440, 251, 11, 33, "Notes",
  CellTags->"ToEquationsDFA"],

Cell[CellGroupData[{
Cell[506132, 19455, 72, 1, 59, "ExampleSection",
  CellTags->"ToEquationsDFA"],
Cell[506207, 19458, 115, 2, 70, "ExampleText",
  CellTags->"ToEquationsDFA"],

Cell[CellGroupData[{
Cell[506347, 19464, 97, 2, 70, "Input",
  CellTags->"ToEquationsDFA"],
Cell[506447, 19468, 376, 12, 70, "Output",
  CellTags->"ToEquationsDFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[506860, 19485, 122, 3, 70, "Input",
  CellTags->"ToEquationsDFA"],
Cell[506985, 19490, 1180, 34, 70, "Output",
  CellTags->"ToEquationsDFA"]
}, Open  ]],
Cell[508180, 19527, 82, 1, 70, "ExampleText",
  CellTags->"ToEquationsDFA"],

Cell[CellGroupData[{
Cell[508287, 19532, 193, 4, 70, "Input",
  CellTags->"ToEquationsDFA"],
Cell[508483, 19538, 1253, 33, 70, "Output",
  CellTags->"ToEquationsDFA"]
}, Open  ]]
}, Closed]],
Cell[509763, 19575, 46, 1, 31, "ObjectName",
  CellTags->"ToFA"],
Cell[509812, 19578, 55, 1, 74, "Highlight",
  CellTags->"ToFA"],
Cell[509870, 19581, 120, 4, 43, "Usage",
  CellTags->"ToFA"],
Cell[509993, 19587, 244, 9, 58, "Notes",
  CellTags->"ToFA"],
Cell[510240, 19598, 116, 4, 33, "Notes",
  CellTags->"ToFA"],
Cell[510359, 19604, 123, 4, 33, "Notes",
  CellTags->"ToFA"],
Cell[510485, 19610, 317, 15, 33, "Notes",
  CellTags->"ToFA"],

Cell[CellGroupData[{
Cell[510827, 19629, 62, 1, 59, "ExampleSection",
  CellTags->"ToFA"],
Cell[510892, 19632, 69, 1, 70, "ExampleText",
  CellTags->"ToFA"],
Cell[510964, 19635, 188, 5, 70, "Input",
  CellTags->"ToFA"],

Cell[CellGroupData[{
Cell[511177, 19644, 70, 2, 70, "Input",
  CellTags->"ToFA"],
Cell[511250, 19648, 546, 15, 70, "Output",
  CellTags->"ToFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[511833, 19668, 98, 3, 70, "Input",
  CellTags->"ToFA"],
Cell[511934, 19673, 84, 3, 70, "Output",
  CellTags->"ToFA"]
}, Open  ]],
Cell[512033, 19679, 75, 1, 70, "ExampleText",
  CellTags->"ToFA"],

Cell[CellGroupData[{
Cell[512133, 19684, 92, 3, 70, "Input",
  CellTags->"ToFA"],
Cell[512228, 19689, 485, 14, 70, "Output",
  CellTags->"ToFA"]
}, Open  ]]
}, Closed]],
Cell[512740, 19707, 64, 1, 31, "ObjectName",
  CellTags->"ToFrontierDFA"],
Cell[512807, 19710, 64, 1, 74, "Highlight",
  CellTags->"ToFrontierDFA"],
Cell[512874, 19713, 223, 7, 43, "Usage",
  CellTags->"ToFrontierDFA"],
Cell[513100, 19722, 191, 7, 33, "Notes",
  CellTags->"ToFrontierDFA"],
Cell[513294, 19731, 335, 13, 33, "Notes",
  CellTags->"ToFrontierDFA"],

Cell[CellGroupData[{
Cell[513654, 19748, 71, 1, 59, "ExampleSection",
  CellTags->"ToFrontierDFA"],
Cell[513728, 19751, 251, 6, 70, "ExampleText",
  CellTags->"ToFrontierDFA"],
Cell[513982, 19759, 148, 4, 70, "Input",
  CellTags->"ToFrontierDFA"],

Cell[CellGroupData[{
Cell[514155, 19767, 229, 6, 70, "Input",
  CellTags->"ToFrontierDFA"],
Cell[514387, 19775, 820, 19, 70, "Output",
  CellTags->"ToFrontierDFA"],
Cell[515210, 19796, 100, 3, 70, "Output",
  CellTags->"ToFrontierDFA"]
}, Open  ]],
Cell[515325, 19802, 143, 4, 70, "ExampleText",
  CellTags->"ToFrontierDFA"],

Cell[CellGroupData[{
Cell[515493, 19810, 173, 4, 70, "Input",
  CellTags->"ToFrontierDFA"],
Cell[515669, 19816, 92, 3, 70, "Output",
  CellTags->"ToFrontierDFA"]
}, Open  ]]
}, Closed]],
Cell[515788, 19823, 66, 1, 31, "ObjectName",
  CellTags->"ToGeneratorsFA"],
Cell[515857, 19826, 65, 1, 74, "Highlight",
  CellTags->"ToGeneratorsFA"],
Cell[515925, 19829, 216, 5, 64, "Usage",
  CellTags->"ToGeneratorsFA"],
Cell[516144, 19836, 268, 11, 33, "Notes",
  CellTags->"ToGeneratorsFA"],

Cell[CellGroupData[{
Cell[516437, 19851, 72, 1, 59, "ExampleSection",
  CellTags->"ToGeneratorsFA"],
Cell[516512, 19854, 92, 1, 70, "ExampleText",
  CellTags->"ToGeneratorsFA"],
Cell[516607, 19857, 197, 5, 70, "Input",
  CellTags->"ToGeneratorsFA"],

Cell[CellGroupData[{
Cell[516829, 19866, 105, 3, 70, "Input",
  CellTags->"ToGeneratorsFA"],
Cell[516937, 19871, 163, 5, 70, "Output",
  CellTags->"ToGeneratorsFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[517137, 19881, 102, 3, 70, "Input",
  CellTags->"ToGeneratorsFA"],
Cell[517242, 19886, 512, 9, 70, "Output",
  CellTags->"ToGeneratorsFA"]
}, Open  ]]
}, Closed]],
Cell[517781, 19899, 56, 1, 31, "ObjectName",
  CellTags->"ToGraphFA"],
Cell[517840, 19902, 60, 1, 74, "Highlight",
  CellTags->"ToGraphFA"],
Cell[517903, 19905, 206, 5, 64, "Usage",
  CellTags->"ToGraphFA"],
Cell[518112, 19912, 303, 10, 80, "Notes",
  CellTags->"ToGraphFA"],
Cell[518418, 19924, 140, 5, 33, "Notes",
  CellTags->"ToGraphFA"],
Cell[518561, 19931, 197, 7, 33, "Notes",
  CellTags->"ToGraphFA"],

Cell[CellGroupData[{
Cell[518783, 19942, 67, 1, 59, "ExampleSection",
  CellTags->"ToGraphFA"],
Cell[518853, 19945, 86, 1, 70, "ExampleText",
  CellTags->"ToGraphFA"],
Cell[518942, 19948, 214, 5, 70, "Input",
  CellTags->"ToGraphFA"],

Cell[CellGroupData[{
Cell[519181, 19957, 103, 3, 70, "Input",
  CellTags->"ToGraphFA"],
Cell[519287, 19962, 333, 10, 70, "Output",
  CellTags->"ToGraphFA"]
}, Open  ]],
Cell[519635, 19975, 76, 1, 70, "ExampleText",
  CellTags->"ToGraphFA"],

Cell[CellGroupData[{
Cell[519736, 19980, 113, 3, 70, "Input",
  CellTags->"ToGraphFA"],
Cell[519852, 19985, 98, 3, 70, "Output",
  CellTags->"ToGraphFA"]
}, Open  ]]
}, Closed]],
Cell[519977, 19992, 52, 1, 31, "ObjectName",
  CellTags->"ToIndex"],
Cell[520032, 19995, 58, 1, 74, "Highlight",
  CellTags->"ToIndex"],
Cell[520093, 19998, 214, 8, 43, "Usage",
  CellTags->"ToIndex"],
Cell[520310, 20008, 91, 1, 33, "Notes",
  CellTags->"ToIndex"],
Cell[520404, 20011, 90, 1, 33, "Notes",
  CellTags->"ToIndex"],
Cell[520497, 20014, 152, 7, 33, "Notes",
  CellTags->"ToIndex"],

Cell[CellGroupData[{
Cell[520674, 20025, 65, 1, 59, "ExampleSection",
  CellTags->"ToIndex"],
Cell[520742, 20028, 79, 1, 70, "ExampleText",
  CellTags->"ToIndex"],

Cell[CellGroupData[{
Cell[520846, 20033, 85, 2, 70, "Input",
  CellTags->"ToIndex"],
Cell[520934, 20037, 98, 3, 70, "Output",
  CellTags->"ToIndex"]
}, Open  ]],

Cell[CellGroupData[{
Cell[521069, 20045, 100, 3, 70, "Input",
  CellTags->"ToIndex"],
Cell[521172, 20050, 90, 3, 70, "Output",
  CellTags->"ToIndex"]
}, Open  ]]
}, Closed]],
Cell[521289, 20057, 58, 1, 31, "ObjectName",
  CellTags->"ToKernelFA"],
Cell[521350, 20060, 61, 1, 74, "Highlight",
  CellTags->"ToKernelFA"],
Cell[521414, 20063, 232, 8, 43, "Usage",
  CellTags->"ToKernelFA"],
Cell[521649, 20073, 294, 10, 80, "Notes",
  CellTags->"ToKernelFA"],
Cell[521946, 20085, 301, 12, 33, "Notes",
  CellTags->"ToKernelFA"],
Cell[522250, 20099, 288, 11, 33, "Notes",
  CellTags->"ToKernelFA"],
Cell[522541, 20112, 153, 7, 33, "Notes",
  CellTags->"ToKernelFA"],

Cell[CellGroupData[{
Cell[522719, 20123, 68, 1, 59, "ExampleSection",
  CellTags->"ToKernelFA"],
Cell[522790, 20126, 120, 4, 70, "ExampleText",
  CellTags->"ToKernelFA"],
Cell[522913, 20132, 220, 5, 70, "Input",
  CellTags->"ToKernelFA"],

Cell[CellGroupData[{
Cell[523158, 20141, 125, 4, 70, "Input",
  CellTags->"ToKernelFA"],
Cell[523286, 20147, 421, 11, 70, "Output",
  CellTags->"ToKernelFA"],
Cell[523710, 20160, 146, 4, 70, "Output",
  CellTags->"ToKernelFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[523893, 20169, 130, 4, 70, "Input",
  CellTags->"ToKernelFA"],
Cell[524026, 20175, 421, 11, 70, "Output",
  CellTags->"ToKernelFA"],
Cell[524450, 20188, 134, 3, 70, "Output",
  CellTags->"ToKernelFA"]
}, Open  ]],
Cell[524599, 20194, 151, 5, 70, "ExampleText",
  CellTags->"ToKernelFA"],

Cell[CellGroupData[{
Cell[524775, 20203, 141, 4, 70, "Input",
  CellTags->"ToKernelFA"],
Cell[524919, 20209, 421, 11, 70, "Output",
  CellTags->"ToKernelFA"],
Cell[525343, 20222, 157, 4, 70, "Output",
  CellTags->"ToKernelFA"]
}, Open  ]]
}, Closed]],
Cell[525527, 20230, 56, 1, 31, "ObjectName",
  CellTags->"ToLabelCA"],
Cell[525586, 20233, 60, 1, 74, "Highlight",
  CellTags->"ToLabelCA"],
Cell[525649, 20236, 160, 4, 43, "Usage",
  CellTags->"ToLabelCA"],
Cell[525812, 20242, 121, 4, 33, "Notes",
  CellTags->"ToLabelCA"],

Cell[CellGroupData[{
Cell[525958, 20250, 67, 1, 59, "ExampleSection",
  CellTags->"ToLabelCA"],
Cell[526028, 20253, 74, 1, 70, "ExampleText",
  CellTags->"ToLabelCA"],

Cell[CellGroupData[{
Cell[526127, 20258, 108, 5, 70, "Input",
  CellTags->"ToLabelCA"],
Cell[526238, 20265, 124, 3, 70, "Output",
  CellTags->"ToLabelCA"],
Cell[526365, 20270, 314, 9, 70, "Output",
  CellTags->"ToLabelCA"]
}, Open  ]]
}, Closed]],
Cell[526706, 20283, 48, 1, 31, "ObjectName",
  CellTags->"ToNFA"],
Cell[526757, 20286, 56, 1, 74, "Highlight",
  CellTags->"ToNFA"],
Cell[526816, 20289, 150, 6, 43, "Usage",
  CellTags->"ToNFA"],
Cell[526969, 20297, 117, 4, 33, "Notes",
  CellTags->"ToNFA"],
Cell[527089, 20303, 317, 15, 33, "Notes",
  CellTags->"ToNFA"],

Cell[CellGroupData[{
Cell[527431, 20322, 63, 1, 59, "ExampleSection",
  CellTags->"ToNFA"],
Cell[527497, 20325, 86, 1, 70, "ExampleText",
  CellTags->"ToNFA"],
Cell[527586, 20328, 214, 5, 70, "Input",
  CellTags->"ToNFA"],

Cell[CellGroupData[{
Cell[527825, 20337, 87, 3, 70, "Input",
  CellTags->"ToNFA"],
Cell[527915, 20342, 413, 12, 70, "Output",
  CellTags->"ToNFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[528365, 20359, 111, 3, 70, "Input",
  CellTags->"ToNFA"],
Cell[528479, 20364, 339, 9, 70, "Output",
  CellTags->"ToNFA"]
}, Open  ]]
}, Closed]],
Cell[528845, 20377, 80, 1, 31, "ObjectName",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[528928, 20380, 72, 1, 74, "Highlight",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[529003, 20383, 216, 5, 64, "Usage",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[529222, 20390, 369, 12, 54, "Notes",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[529594, 20404, 64, 1, 33, "Notes",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[529661, 20407, 327, 13, 33, "Notes",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[CellGroupData[{
Cell[530013, 20424, 79, 1, 59, "ExampleSection",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[530095, 20427, 259, 6, 70, "ExampleText",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[530357, 20435, 156, 4, 70, "Input",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[CellGroupData[{
Cell[530538, 20443, 185, 5, 70, "Input",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[530726, 20450, 828, 19, 70, "Output",
  CellTags->"ToPeriodicFrontierDFA"]
}, Open  ]],
Cell[531569, 20472, 199, 5, 70, "ExampleText",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[CellGroupData[{
Cell[531793, 20481, 241, 6, 70, "Input",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[532037, 20489, 943, 21, 70, "Output",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[532983, 20512, 115, 3, 70, "Output",
  CellTags->"ToPeriodicFrontierDFA"]
}, Open  ]],
Cell[533113, 20518, 151, 4, 70, "ExampleText",
  CellTags->"ToPeriodicFrontierDFA"],

Cell[CellGroupData[{
Cell[533289, 20526, 181, 4, 70, "Input",
  CellTags->"ToPeriodicFrontierDFA"],
Cell[533473, 20532, 100, 3, 70, "Output",
  CellTags->"ToPeriodicFrontierDFA"]
}, Open  ]]
}, Closed]],
Cell[533600, 20539, 58, 1, 31, "ObjectName",
  CellTags->"ToPrefixFA"],
Cell[533661, 20542, 61, 1, 74, "Highlight",
  CellTags->"ToPrefixFA"],
Cell[533725, 20545, 200, 5, 64, "Usage",
  CellTags->"ToPrefixFA"],
Cell[533928, 20552, 53, 1, 33, "Notes",
  CellTags->"ToPrefixFA"],
Cell[533984, 20555, 123, 4, 33, "Notes",
  CellTags->"ToPrefixFA"],
Cell[534110, 20561, 163, 7, 33, "Notes",
  CellTags->"ToPrefixFA"],

Cell[CellGroupData[{
Cell[534298, 20572, 68, 1, 59, "ExampleSection",
  CellTags->"ToPrefixFA"],
Cell[534369, 20575, 169, 6, 70, "ExampleText",
  CellTags->"ToPrefixFA"],

Cell[CellGroupData[{
Cell[534563, 20585, 111, 3, 70, "Input",
  CellTags->"ToPrefixFA"],
Cell[534677, 20590, 378, 12, 70, "Output",
  CellTags->"ToPrefixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[535092, 20607, 106, 3, 70, "Input",
  CellTags->"ToPrefixFA"],
Cell[535201, 20612, 384, 12, 70, "Output",
  CellTags->"ToPrefixFA"]
}, Open  ]],
Cell[535600, 20627, 159, 6, 70, "ExampleText",
  CellTags->"ToPrefixFA"],

Cell[CellGroupData[{
Cell[535784, 20637, 112, 3, 70, "Input",
  CellTags->"ToPrefixFA"],
Cell[535899, 20642, 469, 8, 70, "Output",
  CellTags->"ToPrefixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[536405, 20655, 129, 3, 70, "Input",
  CellTags->"ToPrefixFA"],
Cell[536537, 20660, 89, 3, 70, "Output",
  CellTags->"ToPrefixFA"]
}, Open  ]]
}, Closed]],
Cell[536653, 20667, 54, 1, 31, "ObjectName",
  CellTags->"ToPrefix"],
Cell[536710, 20670, 59, 1, 74, "Highlight",
  CellTags->"ToPrefix"],
Cell[536772, 20673, 176, 5, 43, "Usage",
  CellTags->"ToPrefix"],
Cell[536951, 20680, 156, 6, 33, "Notes",
  CellTags->"ToPrefix"],
Cell[537110, 20688, 156, 5, 33, "Notes",
  CellTags->"ToPrefix"],
Cell[537269, 20695, 268, 11, 33, "Notes",
  CellTags->"ToPrefix"],

Cell[CellGroupData[{
Cell[537562, 20710, 66, 1, 59, "ExampleSection",
  CellTags->"ToPrefix"],
Cell[537631, 20713, 90, 1, 70, "ExampleText",
  CellTags->"ToPrefix"],

Cell[CellGroupData[{
Cell[537746, 20718, 185, 4, 70, "Input",
  CellTags->"ToPrefix"],
Cell[537934, 20724, 117, 3, 70, "Output",
  CellTags->"ToPrefix"]
}, Open  ]],

Cell[CellGroupData[{
Cell[538088, 20732, 77, 2, 70, "Input",
  CellTags->"ToPrefix"],
Cell[538168, 20736, 123, 3, 70, "Output",
  CellTags->"ToPrefix"]
}, Open  ]]
}, Closed]],
Cell[538318, 20743, 54, 1, 31, "ObjectName",
  CellTags->"ToRegExp"],
Cell[538375, 20746, 59, 1, 74, "Highlight",
  CellTags->"ToRegExp"],
Cell[538437, 20749, 365, 12, 64, "Usage",
  CellTags->"ToRegExp"],
Cell[538805, 20763, 138, 4, 33, "Notes",
  CellTags->"ToRegExp"],
Cell[538946, 20769, 432, 19, 33, "Notes",
  CellTags->"ToRegExp"],

Cell[CellGroupData[{
Cell[539403, 20792, 66, 1, 59, "ExampleSection",
  CellTags->"ToRegExp"],
Cell[539472, 20795, 150, 4, 70, "ExampleText",
  CellTags->"ToRegExp"],

Cell[CellGroupData[{
Cell[539647, 20803, 111, 2, 70, "Input",
  CellTags->"ToRegExp"],
Cell[539761, 20807, 152, 4, 70, "Output",
  CellTags->"ToRegExp"]
}, Open  ]],

Cell[CellGroupData[{
Cell[539950, 20816, 94, 3, 70, "Input",
  CellTags->"ToRegExp"],
Cell[540047, 20821, 165, 5, 70, "Output",
  CellTags->"ToRegExp"]
}, Open  ]]
}, Closed]],
Cell[540239, 20830, 80, 1, 31, "ObjectName",
  CellTags->"ToRegularExpressionFA"],
Cell[540322, 20833, 72, 1, 74, "Highlight",
  CellTags->"ToRegularExpressionFA"],
Cell[540397, 20836, 200, 5, 64, "Usage",
  CellTags->"ToRegularExpressionFA"],
Cell[540600, 20843, 290, 10, 80, "Notes",
  CellTags->"ToRegularExpressionFA"],
Cell[540893, 20855, 223, 6, 54, "Notes",
  CellTags->"ToRegularExpressionFA"],
Cell[541119, 20863, 131, 4, 33, "Notes",
  CellTags->"ToRegularExpressionFA"],
Cell[541253, 20869, 270, 11, 33, "Notes",
  CellTags->"ToRegularExpressionFA"],

Cell[CellGroupData[{
Cell[541548, 20884, 79, 1, 59, "ExampleSection",
  CellTags->"ToRegularExpressionFA"],
Cell[541630, 20887, 93, 1, 70, "ExampleText",
  CellTags->"ToRegularExpressionFA"],
Cell[541726, 20890, 225, 5, 70, "Input",
  CellTags->"ToRegularExpressionFA"],

Cell[CellGroupData[{
Cell[541976, 20899, 119, 3, 70, "Input",
  CellTags->"ToRegularExpressionFA"],
Cell[542098, 20904, 203, 4, 70, "Output",
  CellTags->"ToRegularExpressionFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[542338, 20913, 173, 4, 70, "Input",
  CellTags->"ToRegularExpressionFA"],
Cell[542514, 20919, 212, 4, 70, "Output",
  CellTags->"ToRegularExpressionFA"]
}, Open  ]],
Cell[542741, 20926, 256, 7, 70, "ExampleText",
  CellTags->"ToRegularExpressionFA"]
}, Closed]],
Cell[543012, 20936, 56, 1, 31, "ObjectName",
  CellTags->"ToRulesCA"],
Cell[543071, 20939, 60, 1, 74, "Highlight",
  CellTags->"ToRulesCA"],
Cell[543134, 20942, 200, 5, 64, "Usage",
  CellTags->"ToRulesCA"],
Cell[543337, 20949, 227, 9, 58, "Notes",
  CellTags->"ToRulesCA"],
Cell[543567, 20960, 164, 5, 33, "Notes",
  CellTags->"ToRulesCA"],

Cell[CellGroupData[{
Cell[543756, 20969, 67, 1, 59, "ExampleSection",
  CellTags->"ToRulesCA"],
Cell[543826, 20972, 165, 6, 70, "ExampleText",
  CellTags->"ToRulesCA"],

Cell[CellGroupData[{
Cell[544016, 20982, 100, 3, 70, "Input",
  CellTags->"ToRulesCA"],
Cell[544119, 20987, 664, 17, 70, "Output",
  CellTags->"ToRulesCA"]
}, Open  ]],
Cell[544798, 21007, 66, 1, 70, "ExampleText",
  CellTags->"ToRulesCA"],

Cell[CellGroupData[{
Cell[544889, 21012, 123, 3, 70, "Input",
  CellTags->"ToRulesCA"],
Cell[545015, 21017, 699, 18, 70, "Output",
  CellTags->"ToRulesCA"]
}, Open  ]]
}, Closed]],
Cell[545741, 21039, 46, 1, 31, "ObjectName",
  CellTags->"ToSA"],
Cell[545790, 21042, 55, 1, 74, "Highlight",
  CellTags->"ToSA"],
Cell[545848, 21045, 154, 4, 43, "Usage",
  CellTags->"ToSA"],
Cell[546005, 21051, 244, 9, 58, "Notes",
  CellTags->"ToSA"],
Cell[546252, 21062, 127, 4, 33, "Notes",
  CellTags->"ToSA"],
Cell[546382, 21068, 137, 4, 33, "Notes",
  CellTags->"ToSA"],
Cell[546522, 21074, 317, 15, 33, "Notes",
  CellTags->"ToSA"],

Cell[CellGroupData[{
Cell[546864, 21093, 62, 1, 59, "ExampleSection",
  CellTags->"ToSA"],
Cell[546929, 21096, 89, 1, 70, "ExampleText",
  CellTags->"ToSA"],

Cell[CellGroupData[{
Cell[547043, 21101, 83, 2, 70, "Input",
  CellTags->"ToSA"],
Cell[547129, 21105, 378, 12, 70, "Output",
  CellTags->"ToSA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[547544, 21122, 85, 3, 70, "Input",
  CellTags->"ToSA"],
Cell[547632, 21127, 361, 10, 70, "Output",
  CellTags->"ToSA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[548030, 21142, 97, 3, 70, "Input",
  CellTags->"ToSA"],
Cell[548130, 21147, 83, 3, 70, "Output",
  CellTags->"ToSA"]
}, Open  ]]
}, Closed]],
Cell[548240, 21154, 54, 1, 31, "ObjectName",
  CellTags->"ToSeries"],
Cell[548297, 21157, 59, 1, 74, "Highlight",
  CellTags->"ToSeries"],
Cell[548359, 21160, 223, 7, 64, "Usage",
  CellTags->"ToSeries"],
Cell[548585, 21169, 141, 5, 33, "Notes",
  CellTags->"ToSeries"],
Cell[548729, 21176, 256, 11, 33, "Notes",
  CellTags->"ToSeries"],

Cell[CellGroupData[{
Cell[549010, 21191, 66, 1, 59, "ExampleSection",
  CellTags->"ToSeries"],
Cell[549079, 21194, 62, 1, 70, "ExampleText",
  CellTags->"ToSeries"],
Cell[549144, 21197, 88, 2, 70, "Input",
  CellTags->"ToSeries"],

Cell[CellGroupData[{
Cell[549257, 21203, 131, 3, 70, "Input",
  CellTags->"ToSeries"],
Cell[549391, 21208, 319, 6, 70, "Output",
  CellTags->"ToSeries"]
}, Open  ]],

Cell[CellGroupData[{
Cell[549747, 21219, 93, 3, 70, "Input",
  CellTags->"ToSeries"],
Cell[549843, 21224, 303, 6, 70, "Output",
  CellTags->"ToSeries"]
}, Open  ]]
}, Closed]],
Cell[550173, 21234, 58, 1, 31, "ObjectName",
  CellTags->"ToSuffixFA"],
Cell[550234, 21237, 61, 1, 74, "Highlight",
  CellTags->"ToSuffixFA"],
Cell[550298, 21240, 200, 5, 64, "Usage",
  CellTags->"ToSuffixFA"],
Cell[550501, 21247, 123, 4, 33, "Notes",
  CellTags->"ToSuffixFA"],
Cell[550627, 21253, 163, 7, 33, "Notes",
  CellTags->"ToSuffixFA"],

Cell[CellGroupData[{
Cell[550815, 21264, 68, 1, 59, "ExampleSection",
  CellTags->"ToSuffixFA"],
Cell[550886, 21267, 169, 6, 70, "ExampleText",
  CellTags->"ToSuffixFA"],

Cell[CellGroupData[{
Cell[551080, 21277, 111, 3, 70, "Input",
  CellTags->"ToSuffixFA"],
Cell[551194, 21282, 378, 12, 70, "Output",
  CellTags->"ToSuffixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[551609, 21299, 106, 3, 70, "Input",
  CellTags->"ToSuffixFA"],
Cell[551718, 21304, 478, 14, 70, "Output",
  CellTags->"ToSuffixFA"]
}, Open  ]],
Cell[552211, 21321, 159, 6, 70, "ExampleText",
  CellTags->"ToSuffixFA"],

Cell[CellGroupData[{
Cell[552395, 21331, 112, 3, 70, "Input",
  CellTags->"ToSuffixFA"],
Cell[552510, 21336, 469, 8, 70, "Output",
  CellTags->"ToSuffixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[553016, 21349, 129, 3, 70, "Input",
  CellTags->"ToSuffixFA"],
Cell[553148, 21354, 89, 3, 70, "Output",
  CellTags->"ToSuffixFA"]
}, Open  ]]
}, Closed]],
Cell[553264, 21361, 74, 1, 31, "ObjectName",
  CellTags->"TotalisticRuleToCA"],
Cell[553341, 21364, 69, 1, 74, "Highlight",
  CellTags->"TotalisticRuleToCA"],
Cell[553413, 21367, 184, 4, 43, "Usage",
  CellTags->"TotalisticRuleToCA"],
Cell[553600, 21373, 176, 6, 33, "Notes",
  CellTags->"TotalisticRuleToCA"],
Cell[553779, 21381, 187, 7, 33, "Notes",
  CellTags->"TotalisticRuleToCA"],

Cell[CellGroupData[{
Cell[553991, 21392, 76, 1, 59, "ExampleSection",
  CellTags->"TotalisticRuleToCA"],
Cell[554070, 21395, 133, 4, 70, "ExampleText",
  CellTags->"TotalisticRuleToCA"],

Cell[CellGroupData[{
Cell[554228, 21403, 101, 2, 70, "Input",
  CellTags->"TotalisticRuleToCA"],
Cell[554332, 21407, 95, 3, 70, "Output",
  CellTags->"TotalisticRuleToCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[554464, 21415, 140, 3, 70, "Input",
  CellTags->"TotalisticRuleToCA"],
Cell[554607, 21420, 442, 8, 70, "Output",
  CellTags->"TotalisticRuleToCA"]
}, Open  ]]
}, Closed]],
Cell[555076, 21432, 74, 1, 31, "ObjectName",
  CellTags->"ToTotalisticRuleCA"],
Cell[555153, 21435, 69, 1, 74, "Highlight",
  CellTags->"ToTotalisticRuleCA"],
Cell[555225, 21438, 169, 4, 43, "Usage",
  CellTags->"ToTotalisticRuleCA"],
Cell[555397, 21444, 103, 1, 33, "Notes",
  CellTags->"ToTotalisticRuleCA"],
Cell[555503, 21447, 187, 7, 33, "Notes",
  CellTags->"ToTotalisticRuleCA"],

Cell[CellGroupData[{
Cell[555715, 21458, 76, 1, 59, "ExampleSection",
  CellTags->"ToTotalisticRuleCA"],
Cell[555794, 21461, 80, 1, 70, "ExampleText",
  CellTags->"ToTotalisticRuleCA"],

Cell[CellGroupData[{
Cell[555899, 21466, 107, 2, 70, "Input",
  CellTags->"ToTotalisticRuleCA"],
Cell[556009, 21470, 95, 3, 70, "Output",
  CellTags->"ToTotalisticRuleCA"]
}, Open  ]]
}, Closed]],
Cell[556131, 21477, 64, 1, 31, "ObjectName",
  CellTags->"ToTransitions"],
Cell[556198, 21480, 64, 1, 74, "Highlight",
  CellTags->"ToTransitions"],
Cell[556265, 21483, 238, 5, 64, "Usage",
  CellTags->"ToTransitions"],
Cell[556506, 21490, 117, 4, 33, "Notes",
  CellTags->"ToTransitions"],

Cell[CellGroupData[{
Cell[556648, 21498, 71, 1, 59, "ExampleSection",
  CellTags->"ToTransitions"],
Cell[556722, 21501, 163, 4, 70, "ExampleText",
  CellTags->"ToTransitions"],

Cell[CellGroupData[{
Cell[556910, 21509, 114, 2, 70, "Input",
  CellTags->"ToTransitions"],
Cell[557027, 21513, 111, 3, 70, "Output",
  CellTags->"ToTransitions"]
}, Open  ]]
}, Closed]],
Cell[557165, 21520, 50, 1, 31, "ObjectName",
  CellTags->"ToWord"],
Cell[557218, 21523, 57, 1, 74, "Highlight",
  CellTags->"ToWord"],
Cell[557278, 21526, 196, 7, 43, "Usage",
  CellTags->"ToWord"],
Cell[557477, 21535, 132, 5, 33, "Notes",
  CellTags->"ToWord"],
Cell[557612, 21542, 118, 4, 33, "Notes",
  CellTags->"ToWord"],

Cell[CellGroupData[{
Cell[557755, 21550, 64, 1, 59, "ExampleSection",
  CellTags->"ToWord"],
Cell[557822, 21553, 85, 1, 70, "ExampleText",
  CellTags->"ToWord"],

Cell[CellGroupData[{
Cell[557932, 21558, 84, 2, 70, "Input",
  CellTags->"ToWord"],
Cell[558019, 21562, 89, 3, 70, "Output",
  CellTags->"ToWord"]
}, Open  ]],

Cell[CellGroupData[{
Cell[558145, 21570, 99, 2, 70, "Input",
  CellTags->"ToWord"],
Cell[558247, 21574, 92, 3, 70, "Output",
  CellTags->"ToWord"]
}, Open  ]]
}, Closed]],
Cell[558366, 21581, 74, 1, 31, "ObjectName",
  CellTags->"TransferSequenceFA"],
Cell[558443, 21584, 69, 1, 74, "Highlight",
  CellTags->"TransferSequenceFA"],
Cell[558515, 21587, 477, 16, 64, "Usage",
  CellTags->"TransferSequenceFA"],
Cell[558995, 21605, 171, 7, 33, "Notes",
  CellTags->"TransferSequenceFA"],
Cell[559169, 21614, 318, 9, 54, "Notes",
  CellTags->"TransferSequenceFA"],

Cell[CellGroupData[{
Cell[559512, 21627, 76, 1, 59, "ExampleSection",
  CellTags->"TransferSequenceFA"],
Cell[559591, 21630, 90, 1, 48, "ExampleText",
  CellTags->"TransferSequenceFA"],
Cell[559684, 21633, 207, 5, 60, "Input",
  CellTags->"TransferSequenceFA"],

Cell[CellGroupData[{
Cell[559916, 21642, 99, 2, 40, "Input",
  CellTags->"TransferSequenceFA"],
Cell[560018, 21646, 123, 3, 30, "Output",
  CellTags->"TransferSequenceFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[560178, 21654, 133, 2, 40, "Input",
  CellTags->"TransferSequenceFA"],
Cell[560314, 21658, 1353, 27, 216, "Output",
  CellTags->"TransferSequenceFA"]
}, Open  ]]
}, Open  ]],
Cell[561694, 21689, 78, 1, 42, "ObjectName",
  CellTags->"TransitionFunctionFA"],
Cell[561775, 21692, 71, 1, 74, "Highlight",
  CellTags->"TransitionFunctionFA"],
Cell[561849, 21695, 317, 7, 64, "Usage",
  CellTags->"TransitionFunctionFA"],
Cell[562169, 21704, 236, 9, 58, "Notes",
  CellTags->"TransitionFunctionFA"],
Cell[562408, 21715, 120, 5, 33, "Notes",
  CellTags->"TransitionFunctionFA"],
Cell[562531, 21722, 172, 5, 33, "Notes",
  CellTags->"TransitionFunctionFA"],
Cell[562706, 21729, 176, 7, 33, "Notes",
  CellTags->"TransitionFunctionFA"],

Cell[CellGroupData[{
Cell[562907, 21740, 78, 1, 59, "ExampleSection",
  CellTags->"TransitionFunctionFA"],
Cell[562988, 21743, 108, 1, 70, "ExampleText",
  CellTags->"TransitionFunctionFA"],

Cell[CellGroupData[{
Cell[563121, 21748, 215, 5, 70, "Input",
  CellTags->"TransitionFunctionFA"],
Cell[563339, 21755, 97, 3, 70, "Output",
  CellTags->"TransitionFunctionFA"]
}, Open  ]],
Cell[563451, 21761, 107, 1, 70, "ExampleText",
  CellTags->"TransitionFunctionFA"],

Cell[CellGroupData[{
Cell[563583, 21766, 244, 6, 70, "Input",
  CellTags->"TransitionFunctionFA"],
Cell[563830, 21774, 108, 3, 70, "Output",
  CellTags->"TransitionFunctionFA"],
Cell[563941, 21779, 98, 3, 70, "Output",
  CellTags->"TransitionFunctionFA"]
}, Open  ]],
Cell[564054, 21785, 101, 1, 70, "ExampleText",
  CellTags->"TransitionFunctionFA"],

Cell[CellGroupData[{
Cell[564180, 21790, 215, 5, 70, "Input",
  CellTags->"TransitionFunctionFA"],
Cell[564398, 21797, 134, 3, 70, "Output",
  CellTags->"TransitionFunctionFA"],
Cell[564535, 21802, 115, 3, 70, "Output",
  CellTags->"TransitionFunctionFA"]
}, Open  ]]
}, Closed]],
Cell[564677, 21809, 74, 1, 31, "ObjectName",
  CellTags->"TransitionMatrixFA"],
Cell[564754, 21812, 69, 1, 74, "Highlight",
  CellTags->"TransitionMatrixFA"],
Cell[564826, 21815, 493, 12, 85, "Usage",
  CellTags->"TransitionMatrixFA"],
Cell[565322, 21829, 251, 9, 58, "Notes",
  CellTags->"TransitionMatrixFA"],
Cell[565576, 21840, 118, 5, 33, "Notes",
  CellTags->"TransitionMatrixFA"],
Cell[565697, 21847, 144, 5, 33, "Notes",
  CellTags->"TransitionMatrixFA"],
Cell[565844, 21854, 147, 5, 33, "Notes",
  CellTags->"TransitionMatrixFA"],
Cell[565994, 21861, 314, 11, 33, "Notes",
  CellTags->"TransitionMatrixFA"],

Cell[CellGroupData[{
Cell[566333, 21876, 76, 1, 59, "ExampleSection",
  CellTags->"TransitionMatrixFA"],
Cell[566412, 21879, 185, 5, 70, "ExampleText",
  CellTags->"TransitionMatrixFA"],
Cell[566600, 21886, 167, 4, 70, "Input",
  CellTags->"TransitionMatrixFA"],

Cell[CellGroupData[{
Cell[566792, 21894, 117, 3, 70, "Input",
  CellTags->"TransitionMatrixFA"],
Cell[566912, 21899, 446, 12, 70, "Output",
  CellTags->"TransitionMatrixFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[567395, 21916, 118, 3, 70, "Input",
  CellTags->"TransitionMatrixFA"],
Cell[567516, 21921, 446, 12, 70, "Output",
  CellTags->"TransitionMatrixFA"]
}, Open  ]]
}, Closed]],
Cell[567989, 21937, 76, 1, 31, "ObjectName",
  CellTags->"TransitionsToMatrix"],
Cell[568068, 21940, 70, 1, 74, "Highlight",
  CellTags->"TransitionsToMatrix"],
Cell[568141, 21943, 221, 5, 64, "Usage",
  CellTags->"TransitionsToMatrix"],
Cell[568365, 21950, 252, 5, 54, "Notes",
  CellTags->"TransitionsToMatrix"],

Cell[CellGroupData[{
Cell[568642, 21959, 77, 1, 59, "ExampleSection",
  CellTags->"TransitionsToMatrix"],
Cell[568722, 21962, 73, 1, 70, "ExampleText",
  CellTags->"TransitionsToMatrix"],

Cell[CellGroupData[{
Cell[568820, 21967, 77, 2, 70, "Input",
  CellTags->"TransitionsToMatrix"],
Cell[568900, 21971, 94, 3, 70, "Output",
  CellTags->"TransitionsToMatrix"]
}, Open  ]]
}, Closed]],
Cell[569021, 21978, 60, 1, 31, "ObjectName",
  CellTags->"Transitions"],
Cell[569084, 21981, 62, 1, 74, "Highlight",
  CellTags->"Transitions"],
Cell[569149, 21984, 214, 5, 64, "Usage",
  CellTags->"Transitions"],
Cell[569366, 21991, 371, 12, 54, "Notes",
  CellTags->"Transitions"],
Cell[569740, 22005, 293, 11, 33, "Notes",
  CellTags->"Transitions"],

Cell[CellGroupData[{
Cell[570058, 22020, 69, 1, 59, "ExampleSection",
  CellTags->"Transitions"],
Cell[570130, 22023, 124, 4, 70, "ExampleText",
  CellTags->"Transitions"],

Cell[CellGroupData[{
Cell[570279, 22031, 120, 5, 70, "Input",
  CellTags->"Transitions"],
Cell[570402, 22038, 132, 3, 70, "Output",
  CellTags->"Transitions"]
}, Open  ]],

Cell[CellGroupData[{
Cell[570571, 22046, 114, 5, 70, "Input",
  CellTags->"Transitions"],
Cell[570688, 22053, 172, 4, 70, "Output",
  CellTags->"Transitions"]
}, Open  ]]
}, Closed]],
Cell[570887, 22061, 72, 1, 31, "ObjectName",
  CellTags->"TransitiveLangQFA"],
Cell[570962, 22064, 68, 1, 74, "Highlight",
  CellTags->"TransitiveLangQFA"],
Cell[571033, 22067, 194, 6, 43, "Usage",
  CellTags->"TransitiveLangQFA"],
Cell[571230, 22075, 255, 9, 58, "Notes",
  CellTags->"TransitiveLangQFA"],
Cell[571488, 22086, 110, 1, 33, "Notes",
  CellTags->"TransitiveLangQFA"],
Cell[571601, 22089, 176, 7, 33, "Notes",
  CellTags->"TransitiveLangQFA"],

Cell[CellGroupData[{
Cell[571802, 22100, 75, 1, 59, "ExampleSection",
  CellTags->"TransitiveLangQFA"],
Cell[571880, 22103, 129, 4, 70, "ExampleText",
  CellTags->"TransitiveLangQFA"],

Cell[CellGroupData[{
Cell[572034, 22111, 94, 2, 70, "Input",
  CellTags->"TransitiveLangQFA"],
Cell[572131, 22115, 356, 10, 70, "Output",
  CellTags->"TransitiveLangQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[572524, 22130, 112, 3, 70, "Input",
  CellTags->"TransitiveLangQFA"],
Cell[572639, 22135, 97, 3, 70, "Output",
  CellTags->"TransitiveLangQFA"]
}, Open  ]]
}, Closed]],
Cell[572763, 22142, 64, 1, 31, "ObjectName",
  CellTags->"TransitiveQFA"],
Cell[572830, 22145, 64, 1, 74, "Highlight",
  CellTags->"TransitiveQFA"],
Cell[572897, 22148, 138, 4, 43, "Usage",
  CellTags->"TransitiveQFA"],
Cell[573038, 22154, 299, 10, 80, "Notes",
  CellTags->"TransitiveQFA"],
Cell[573340, 22166, 201, 6, 54, "Notes",
  CellTags->"TransitiveQFA"],
Cell[573544, 22174, 180, 7, 33, "Notes",
  CellTags->"TransitiveQFA"],

Cell[CellGroupData[{
Cell[573749, 22185, 71, 1, 59, "ExampleSection",
  CellTags->"TransitiveQFA"],
Cell[573823, 22188, 151, 4, 70, "ExampleText",
  CellTags->"TransitiveQFA"],

Cell[CellGroupData[{
Cell[573999, 22196, 90, 2, 70, "Input",
  CellTags->"TransitiveQFA"],
Cell[574092, 22200, 352, 10, 70, "Output",
  CellTags->"TransitiveQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[574481, 22215, 104, 3, 70, "Input",
  CellTags->"TransitiveQFA"],
Cell[574588, 22220, 93, 3, 70, "Output",
  CellTags->"TransitiveQFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[574718, 22228, 126, 3, 70, "Input",
  CellTags->"TransitiveQFA"],
Cell[574847, 22233, 103, 3, 70, "Output",
  CellTags->"TransitiveQFA"]
}, Open  ]]
}, Closed]],
Cell[574977, 22240, 50, 1, 31, "ObjectName",
  CellTags->"TrimFA"],
Cell[575030, 22243, 57, 1, 74, "Highlight",
  CellTags->"TrimFA"],
Cell[575090, 22246, 232, 5, 64, "Usage",
  CellTags->"TrimFA"],
Cell[575325, 22253, 246, 9, 58, "Notes",
  CellTags->"TrimFA"],
Cell[575574, 22264, 196, 5, 54, "Notes",
  CellTags->"TrimFA"],
Cell[575773, 22271, 270, 11, 33, "Notes",
  CellTags->"TrimFA"],

Cell[CellGroupData[{
Cell[576068, 22286, 64, 1, 59, "ExampleSection",
  CellTags->"TrimFA"],
Cell[576135, 22289, 157, 4, 70, "MathCaption",
  CellTags->"TrimFA"],

Cell[CellGroupData[{
Cell[576317, 22297, 181, 5, 70, "Input",
  CellTags->"TrimFA"],
Cell[576501, 22304, 394, 12, 70, "Output",
  CellTags->"TrimFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[576932, 22321, 138, 4, 70, "Input",
  CellTags->"TrimFA"],
Cell[577073, 22327, 372, 12, 70, "Output",
  CellTags->"TrimFA"],
Cell[577448, 22341, 86, 3, 70, "Output",
  CellTags->"TrimFA"]
}, Open  ]]
}, Closed]],
Cell[577561, 22348, 82, 1, 31, "ObjectName",
  CellTags->"TropicalIdentityMatrix"],
Cell[577646, 22351, 73, 1, 74, "Highlight",
  CellTags->"TropicalIdentityMatrix"],
Cell[577722, 22354, 239, 8, 43, "Usage",
  CellTags->"TropicalIdentityMatrix"],
Cell[577964, 22364, 357, 15, 33, "Notes",
  CellTags->"TropicalIdentityMatrix"],

Cell[CellGroupData[{
Cell[578346, 22383, 80, 1, 59, "ExampleSection",
  CellTags->"TropicalIdentityMatrix"],
Cell[578429, 22386, 172, 6, 70, "ExampleText",
  CellTags->"TropicalIdentityMatrix"],

Cell[CellGroupData[{
Cell[578626, 22396, 120, 2, 70, "Input",
  CellTags->"TropicalIdentityMatrix"],
Cell[578749, 22400, 1375, 35, 70, "Output",
  CellTags->"TropicalIdentityMatrix"]
}, Open  ]]
}, Closed]],
Cell[580151, 22439, 52, 1, 31, "ObjectName",
  CellTags->"UnionFA"],
Cell[580206, 22442, 58, 1, 74, "Highlight",
  CellTags->"UnionFA"],
Cell[580267, 22445, 250, 9, 64, "Usage",
  CellTags->"UnionFA"],
Cell[580520, 22456, 292, 10, 80, "Notes",
  CellTags->"UnionFA"],
Cell[580815, 22468, 134, 5, 33, "Notes",
  CellTags->"UnionFA"],
Cell[580952, 22475, 195, 8, 33, "Notes",
  CellTags->"UnionFA"],
Cell[581150, 22485, 134, 4, 33, "Notes",
  CellTags->"UnionFA"],
Cell[581287, 22491, 52, 1, 33, "Notes",
  CellTags->"UnionFA"],
Cell[581342, 22494, 348, 15, 33, "Notes",
  CellTags->"UnionFA"],

Cell[CellGroupData[{
Cell[581715, 22513, 65, 1, 59, "ExampleSection",
  CellTags->"UnionFA"],
Cell[581783, 22516, 198, 5, 70, "ExampleText",
  CellTags->"UnionFA"],

Cell[CellGroupData[{
Cell[582006, 22525, 160, 4, 70, "Input",
  CellTags->"UnionFA"],
Cell[582169, 22531, 358, 12, 70, "Output",
  CellTags->"UnionFA"],
Cell[582530, 22545, 361, 12, 70, "Output",
  CellTags->"UnionFA"]
}, Open  ]],
Cell[582906, 22560, 123, 4, 70, "ExampleText",
  CellTags->"UnionFA"],

Cell[CellGroupData[{
Cell[583054, 22568, 168, 4, 70, "Input",
  CellTags->"UnionFA"],
Cell[583225, 22574, 404, 12, 70, "Output",
  CellTags->"UnionFA"],
Cell[583632, 22588, 167, 4, 70, "Output",
  CellTags->"UnionFA"]
}, Open  ]]
}, Closed]],
Cell[583826, 22596, 54, 1, 31, "ObjectName",
  CellTags->"VerifyFA"],
Cell[583883, 22599, 59, 1, 74, "Highlight",
  CellTags->"VerifyFA"],
Cell[583945, 22602, 182, 5, 43, "Usage",
  CellTags->"VerifyFA"],
Cell[584130, 22609, 143, 5, 33, "Notes",
  CellTags->"VerifyFA"],
Cell[584276, 22616, 66, 1, 59, "ExampleSection",
  CellTags->"VerifyFA"],
Cell[584345, 22619, 52, 1, 42, "ObjectName",
  CellTags->"WelchCA"],
Cell[584400, 22622, 58, 1, 74, "Highlight",
  CellTags->"WelchCA"],
Cell[584461, 22625, 155, 4, 43, "Usage",
  CellTags->"WelchCA"],
Cell[584619, 22631, 290, 10, 80, "Notes",
  CellTags->"WelchCA"],
Cell[584912, 22643, 142, 5, 33, "Notes",
  CellTags->"WelchCA"],
Cell[585057, 22650, 142, 5, 33, "Notes",
  CellTags->"WelchCA"],

Cell[CellGroupData[{
Cell[585224, 22659, 65, 1, 59, "ExampleSection",
  CellTags->"WelchCA"],
Cell[585292, 22662, 129, 4, 70, "ExampleText",
  CellTags->"WelchCA"],
Cell[585424, 22668, 179, 4, 70, "Input",
  CellTags->"WelchCA"],

Cell[CellGroupData[{
Cell[585628, 22676, 101, 2, 70, "Input",
  CellTags->"WelchCA"],
Cell[585732, 22680, 703, 25, 70, "Output",
  CellTags->"WelchCA"]
}, Open  ]],
Cell[586450, 22708, 82, 1, 70, "ExampleText",
  CellTags->"WelchCA"],

Cell[CellGroupData[{
Cell[586557, 22713, 116, 3, 70, "Input",
  CellTags->"WelchCA"],
Cell[586676, 22718, 685, 18, 70, "Output",
  CellTags->"WelchCA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[587398, 22741, 102, 3, 70, "Input",
  CellTags->"WelchCA"],
Cell[587503, 22746, 88, 3, 70, "Output",
  CellTags->"WelchCA"]
}, Open  ]]
}, Closed]],
Cell[587618, 22753, 52, 1, 31, "ObjectName",
  CellTags->"WidthCA"],
Cell[587673, 22756, 58, 1, 74, "Highlight",
  CellTags->"WidthCA"],
Cell[587734, 22759, 134, 4, 43, "Usage",
  CellTags->"WidthCA"],

Cell[CellGroupData[{
Cell[587893, 22767, 65, 1, 59, "ExampleSection",
  CellTags->"WidthCA"],
Cell[587961, 22770, 83, 1, 70, "ExampleText",
  CellTags->"WidthCA"],

Cell[CellGroupData[{
Cell[588069, 22775, 91, 5, 70, "Input",
  CellTags->"WidthCA"],
Cell[588163, 22782, 100, 3, 70, "Output",
  CellTags->"WidthCA"],
Cell[588266, 22787, 83, 3, 70, "Output",
  CellTags->"WidthCA"]
}, Open  ]]
}, Closed]],
Cell[588376, 22794, 62, 1, 31, "ObjectName",
  CellTags->"WordBinomial"],
Cell[588441, 22797, 63, 1, 74, "Highlight",
  CellTags->"WordBinomial"],
Cell[588507, 22800, 242, 9, 64, "Usage",
  CellTags->"WordBinomial"],
Cell[588752, 22811, 231, 9, 58, "Notes",
  CellTags->"WordBinomial"],
Cell[588986, 22822, 207, 9, 33, "Notes",
  CellTags->"WordBinomial"],
Cell[589196, 22833, 55, 1, 33, "Notes",
  CellTags->"WordBinomial"],

Cell[CellGroupData[{
Cell[589276, 22838, 70, 1, 59, "ExampleSection",
  CellTags->"WordBinomial"],
Cell[589349, 22841, 154, 4, 70, "ExampleText",
  CellTags->"WordBinomial"],

Cell[CellGroupData[{
Cell[589528, 22849, 142, 4, 70, "Input",
  CellTags->"WordBinomial"],
Cell[589673, 22855, 89, 3, 70, "Output",
  CellTags->"WordBinomial"],
Cell[589765, 22860, 89, 3, 70, "Output",
  CellTags->"WordBinomial"]
}, Open  ]],

Cell[CellGroupData[{
Cell[589891, 22868, 109, 3, 70, "Input",
  CellTags->"WordBinomial"],
Cell[590003, 22873, 88, 3, 70, "Output",
  CellTags->"WordBinomial"]
}, Open  ]],

Cell[CellGroupData[{
Cell[590128, 22881, 131, 3, 70, "Input",
  CellTags->"WordBinomial"],
Cell[590262, 22886, 127, 3, 70, "Output",
  CellTags->"WordBinomial"]
}, Open  ]]
}, Closed]],
Cell[590416, 22893, 66, 1, 31, "ObjectName",
  CellTags->"WordConjugateQ"],
Cell[590485, 22896, 65, 1, 74, "Highlight",
  CellTags->"WordConjugateQ"],
Cell[590553, 22899, 205, 8, 43, "Usage",
  CellTags->"WordConjugateQ"],
Cell[590761, 22909, 114, 5, 33, "Notes",
  CellTags->"WordConjugateQ"],
Cell[590878, 22916, 158, 5, 33, "Notes",
  CellTags->"WordConjugateQ"],
Cell[591039, 22923, 168, 7, 33, "Notes",
  CellTags->"WordConjugateQ"],

Cell[CellGroupData[{
Cell[591232, 22934, 72, 1, 59, "ExampleSection",
  CellTags->"WordConjugateQ"],
Cell[591307, 22937, 89, 1, 70, "ExampleText",
  CellTags->"WordConjugateQ"],

Cell[CellGroupData[{
Cell[591421, 22942, 100, 2, 70, "Input",
  CellTags->"WordConjugateQ"],
Cell[591524, 22946, 93, 3, 70, "Output",
  CellTags->"WordConjugateQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[591654, 22954, 100, 2, 70, "Input",
  CellTags->"WordConjugateQ"],
Cell[591757, 22958, 94, 3, 70, "Output",
  CellTags->"WordConjugateQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[591888, 22966, 104, 2, 70, "Input",
  CellTags->"WordConjugateQ"],
Cell[591995, 22970, 204, 4, 70, "Output",
  CellTags->"WordConjugateQ"]
}, Open  ]]
}, Closed]],
Cell[592226, 22978, 66, 1, 31, "ObjectName",
  CellTags->"WordConjugates"],
Cell[592295, 22981, 65, 1, 74, "Highlight",
  CellTags->"WordConjugates"],
Cell[592363, 22984, 193, 6, 43, "Usage",
  CellTags->"WordConjugates"],
Cell[592559, 22992, 114, 5, 33, "Notes",
  CellTags->"WordConjugates"],

Cell[CellGroupData[{
Cell[592698, 23001, 72, 1, 59, "ExampleSection",
  CellTags->"WordConjugates"],
Cell[592773, 23004, 283, 10, 70, "ExampleText",
  CellTags->"WordConjugates"],

Cell[CellGroupData[{
Cell[593081, 23018, 95, 2, 70, "Input",
  CellTags->"WordConjugates"],
Cell[593179, 23022, 134, 3, 70, "Output",
  CellTags->"WordConjugates"]
}, Open  ]],

Cell[CellGroupData[{
Cell[593350, 23030, 95, 2, 70, "Input",
  CellTags->"WordConjugates"],
Cell[593448, 23034, 106, 3, 70, "Output",
  CellTags->"WordConjugates"]
}, Open  ]]
}, Closed]],
Cell[593581, 23041, 74, 1, 31, "ObjectName",
  CellTags->"WordFactorizations"],
Cell[593658, 23044, 69, 1, 74, "Highlight",
  CellTags->"WordFactorizations"],
Cell[593730, 23047, 213, 8, 43, "Usage",
  CellTags->"WordFactorizations"],
Cell[593946, 23057, 199, 8, 33, "Notes",
  CellTags->"WordFactorizations"],
Cell[594148, 23067, 61, 1, 33, "Notes",
  CellTags->"WordFactorizations"],

Cell[CellGroupData[{
Cell[594234, 23072, 76, 1, 59, "ExampleSection",
  CellTags->"WordFactorizations"],
Cell[594313, 23075, 179, 6, 70, "ExampleText",
  CellTags->"WordFactorizations"],

Cell[CellGroupData[{
Cell[594517, 23085, 103, 2, 70, "Input",
  CellTags->"WordFactorizations"],
Cell[594623, 23089, 239, 5, 70, "Output",
  CellTags->"WordFactorizations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[594899, 23099, 125, 3, 70, "Input",
  CellTags->"WordFactorizations"],
Cell[595027, 23104, 103, 3, 70, "Output",
  CellTags->"WordFactorizations"]
}, Open  ]]
}, Closed]],
Cell[595157, 23111, 60, 1, 31, "ObjectName",
  CellTags->"WordFactors"],
Cell[595220, 23114, 62, 1, 74, "Highlight",
  CellTags->"WordFactors"],
Cell[595285, 23117, 162, 4, 43, "Usage",
  CellTags->"WordFactors"],
Cell[595450, 23123, 111, 5, 33, "Notes",
  CellTags->"WordFactors"],
Cell[595564, 23130, 73, 1, 33, "Notes",
  CellTags->"WordFactors"],
Cell[595640, 23133, 54, 1, 33, "Notes",
  CellTags->"WordFactors"],
Cell[595697, 23136, 54, 1, 33, "Notes",
  CellTags->"WordFactors"],
Cell[595754, 23139, 271, 11, 33, "Notes",
  CellTags->"WordFactors"],
Cell[596028, 23152, 116, 5, 33, "Notes",
  CellTags->"WordFactors"],

Cell[CellGroupData[{
Cell[596169, 23161, 69, 1, 59, "ExampleSection",
  CellTags->"WordFactors"],
Cell[596241, 23164, 163, 6, 70, "ExampleText",
  CellTags->"WordFactors"],

Cell[CellGroupData[{
Cell[596429, 23174, 89, 2, 70, "Input",
  CellTags->"WordFactors"],
Cell[596521, 23178, 143, 3, 70, "Output",
  CellTags->"WordFactors"]
}, Open  ]],

Cell[CellGroupData[{
Cell[596701, 23186, 89, 2, 70, "Input",
  CellTags->"WordFactors"],
Cell[596793, 23190, 252, 5, 70, "Output",
  CellTags->"WordFactors"]
}, Open  ]],

Cell[CellGroupData[{
Cell[597082, 23200, 93, 2, 70, "Input",
  CellTags->"WordFactors"],
Cell[597178, 23204, 159, 4, 70, "Output",
  CellTags->"WordFactors"]
}, Open  ]]
}, Closed]],
Cell[597364, 23212, 58, 1, 31, "ObjectName",
  CellTags->"WordFusion"],
Cell[597425, 23215, 61, 1, 74, "Highlight",
  CellTags->"WordFusion"],
Cell[597489, 23218, 223, 10, 43, "Usage",
  CellTags->"WordFusion"],
Cell[597715, 23230, 150, 5, 33, "Notes",
  CellTags->"WordFusion"],
Cell[597868, 23237, 195, 8, 33, "Notes",
  CellTags->"WordFusion"],

Cell[CellGroupData[{
Cell[598088, 23249, 68, 1, 59, "ExampleSection",
  CellTags->"WordFusion"],
Cell[598159, 23252, 220, 9, 70, "ExampleText",
  CellTags->"WordFusion"],

Cell[CellGroupData[{
Cell[598404, 23265, 96, 2, 70, "Input",
  CellTags->"WordFusion"],
Cell[598503, 23269, 94, 3, 70, "Output",
  CellTags->"WordFusion"]
}, Open  ]],
Cell[598612, 23275, 96, 2, 70, "Input",
  CellTags->"WordFusion"]
}, Closed]],
Cell[598723, 23280, 58, 1, 31, "ObjectName",
  CellTags->"WordLength"],
Cell[598784, 23283, 61, 1, 74, "Highlight",
  CellTags->"WordLength"],
Cell[598848, 23286, 148, 5, 43, "Usage",
  CellTags->"WordLength"],
Cell[598999, 23293, 110, 5, 33, "Notes",
  CellTags->"WordLength"],
Cell[599112, 23300, 233, 7, 54, "Notes",
  CellTags->"WordLength"],

Cell[CellGroupData[{
Cell[599370, 23311, 68, 1, 59, "ExampleSection",
  CellTags->"WordLength"],
Cell[599441, 23314, 126, 4, 70, "ExampleText",
  CellTags->"WordLength"],

Cell[CellGroupData[{
Cell[599592, 23322, 78, 2, 70, "Input",
  CellTags->"WordLength"],
Cell[599673, 23326, 195, 4, 70, "Output",
  CellTags->"WordLength"]
}, Open  ]],

Cell[CellGroupData[{
Cell[599905, 23335, 98, 3, 70, "Input",
  CellTags->"WordLength"],
Cell[600006, 23340, 131, 3, 70, "Output",
  CellTags->"WordLength"]
}, Open  ]]
}, Closed]],
Cell[600164, 23347, 56, 1, 31, "ObjectName",
  CellTags->"WordOrder"],
Cell[600223, 23350, 60, 1, 74, "Highlight",
  CellTags->"WordOrder"],
Cell[600286, 23353, 230, 8, 43, "Usage",
  CellTags->"WordOrder"],
Cell[600519, 23363, 200, 6, 54, "Notes",
  CellTags->"WordOrder"],
Cell[600722, 23371, 444, 19, 54, "Notes",
  CellTags->"WordOrder"],

Cell[CellGroupData[{
Cell[601191, 23394, 67, 1, 59, "ExampleSection",
  CellTags->"WordOrder"],
Cell[601261, 23397, 98, 1, 70, "ExampleText",
  CellTags->"WordOrder"],

Cell[CellGroupData[{
Cell[601384, 23402, 81, 2, 70, "Input",
  CellTags->"WordOrder"],
Cell[601468, 23406, 131, 3, 70, "Output",
  CellTags->"WordOrder"]
}, Open  ]],

Cell[CellGroupData[{
Cell[601636, 23414, 154, 4, 70, "Input",
  CellTags->"WordOrder"],
Cell[601793, 23420, 365, 7, 70, "Output",
  CellTags->"WordOrder"]
}, Open  ]]
}, Closed]],
Cell[602185, 23431, 56, 1, 31, "ObjectName",
  CellTags->"WordPower"],
Cell[602244, 23434, 60, 1, 74, "Highlight",
  CellTags->"WordPower"],
Cell[602307, 23437, 207, 7, 43, "Usage",
  CellTags->"WordPower"],
Cell[602517, 23446, 109, 5, 33, "Notes",
  CellTags->"WordPower"],
Cell[602629, 23453, 268, 11, 33, "Notes",
  CellTags->"WordPower"],

Cell[CellGroupData[{
Cell[602922, 23468, 67, 1, 59, "ExampleSection",
  CellTags->"WordPower"],
Cell[602992, 23471, 123, 4, 70, "ExampleText",
  CellTags->"WordPower"],

Cell[CellGroupData[{
Cell[603140, 23479, 138, 3, 70, "Input",
  CellTags->"WordPower"],
Cell[603281, 23484, 293, 6, 70, "Output",
  CellTags->"WordPower"]
}, Open  ]],

Cell[CellGroupData[{
Cell[603611, 23495, 111, 3, 70, "Input",
  CellTags->"WordPower"],
Cell[603725, 23500, 133, 3, 70, "Output",
  CellTags->"WordPower"]
}, Open  ]],

Cell[CellGroupData[{
Cell[603895, 23508, 111, 3, 70, "Input",
  CellTags->"WordPower"],
Cell[604009, 23513, 293, 6, 70, "Output",
  CellTags->"WordPower"]
}, Open  ]],

Cell[CellGroupData[{
Cell[604339, 23524, 105, 3, 70, "Input",
  CellTags->"WordPower"],
Cell[604447, 23529, 89, 3, 70, "Output",
  CellTags->"WordPower"]
}, Open  ]]
}, Closed]],
Cell[604563, 23536, 62, 1, 31, "ObjectName",
  CellTags->"WordPrefixes"],
Cell[604628, 23539, 63, 1, 74, "Highlight",
  CellTags->"WordPrefixes"],
Cell[604694, 23542, 156, 5, 43, "Usage",
  CellTags->"WordPrefixes"],
Cell[604853, 23549, 112, 5, 33, "Notes",
  CellTags->"WordPrefixes"],
Cell[604968, 23556, 271, 11, 33, "Notes",
  CellTags->"WordPrefixes"],
Cell[605242, 23569, 113, 5, 33, "Notes",
  CellTags->"WordPrefixes"],

Cell[CellGroupData[{
Cell[605380, 23578, 70, 1, 59, "ExampleSection",
  CellTags->"WordPrefixes"],
Cell[605453, 23581, 173, 6, 70, "ExampleText",
  CellTags->"WordPrefixes"],

Cell[CellGroupData[{
Cell[605651, 23591, 91, 2, 70, "Input",
  CellTags->"WordPrefixes"],
Cell[605745, 23595, 144, 3, 70, "Output",
  CellTags->"WordPrefixes"]
}, Open  ]],

Cell[CellGroupData[{
Cell[605926, 23603, 94, 2, 70, "Input",
  CellTags->"WordPrefixes"],
Cell[606023, 23607, 160, 4, 70, "Output",
  CellTags->"WordPrefixes"]
}, Open  ]]
}, Closed]],
Cell[606210, 23615, 60, 1, 31, "ObjectName",
  CellTags->"WordReverse"],
Cell[606273, 23618, 62, 1, 74, "Highlight",
  CellTags->"WordReverse"],
Cell[606338, 23621, 225, 6, 64, "Usage",
  CellTags->"WordReverse"],
Cell[606566, 23629, 111, 5, 33, "Notes",
  CellTags->"WordReverse"],
Cell[606680, 23636, 54, 1, 33, "Notes",
  CellTags->"WordReverse"],
Cell[606737, 23639, 54, 1, 33, "Notes",
  CellTags->"WordReverse"],

Cell[CellGroupData[{
Cell[606816, 23644, 69, 1, 59, "ExampleSection",
  CellTags->"WordReverse"],
Cell[606888, 23647, 65, 1, 70, "ExampleText",
  CellTags->"WordReverse"],

Cell[CellGroupData[{
Cell[606978, 23652, 69, 2, 70, "Input",
  CellTags->"WordReverse"],
Cell[607050, 23656, 86, 3, 70, "Output",
  CellTags->"WordReverse"]
}, Open  ]]
}, Closed]],
Cell[607163, 23663, 54, 1, 31, "ObjectName",
  CellTags->"WordRoot"],
Cell[607220, 23666, 59, 1, 74, "Highlight",
  CellTags->"WordRoot"],
Cell[607282, 23669, 289, 12, 43, "Usage",
  CellTags->"WordRoot"],
Cell[607574, 23683, 108, 5, 33, "Notes",
  CellTags->"WordRoot"],
Cell[607685, 23690, 362, 15, 33, "Notes",
  CellTags->"WordRoot"],

Cell[CellGroupData[{
Cell[608072, 23709, 66, 1, 59, "ExampleSection",
  CellTags->"WordRoot"],
Cell[608141, 23712, 92, 1, 70, "ExampleText",
  CellTags->"WordRoot"],

Cell[CellGroupData[{
Cell[608258, 23717, 103, 2, 70, "Input",
  CellTags->"WordRoot"],
Cell[608364, 23721, 292, 6, 70, "Output",
  CellTags->"WordRoot"]
}, Open  ]],

Cell[CellGroupData[{
Cell[608693, 23732, 94, 3, 70, "Input",
  CellTags->"WordRoot"],
Cell[608790, 23737, 209, 4, 70, "Output",
  CellTags->"WordRoot"]
}, Open  ]]
}, Closed]],
Cell[609026, 23745, 58, 1, 31, "ObjectName",
  CellTags->"WordRotate"],
Cell[609087, 23748, 61, 1, 74, "Highlight",
  CellTags->"WordRotate"],
Cell[609151, 23751, 199, 8, 43, "Usage",
  CellTags->"WordRotate"],
Cell[609353, 23761, 110, 5, 33, "Notes",
  CellTags->"WordRotate"],
Cell[609466, 23768, 97, 4, 33, "Notes",
  CellTags->"WordRotate"],
Cell[609566, 23774, 68, 1, 33, "Notes",
  CellTags->"WordRotate"],
Cell[609637, 23777, 278, 11, 33, "Notes",
  CellTags->"WordRotate"],

Cell[CellGroupData[{
Cell[609940, 23792, 68, 1, 59, "ExampleSection",
  CellTags->"WordRotate"],
Cell[610011, 23795, 73, 1, 70, "ExampleText",
  CellTags->"WordRotate"],

Cell[CellGroupData[{
Cell[610109, 23800, 104, 2, 70, "Input",
  CellTags->"WordRotate"],
Cell[610216, 23804, 131, 3, 70, "Output",
  CellTags->"WordRotate"]
}, Open  ]],

Cell[CellGroupData[{
Cell[610384, 23812, 109, 3, 70, "Input",
  CellTags->"WordRotate"],
Cell[610496, 23817, 116, 3, 70, "Output",
  CellTags->"WordRotate"]
}, Open  ]]
}, Closed]],
Cell[610639, 23824, 60, 1, 31, "ObjectName",
  CellTags->"WordShuffle"],
Cell[610702, 23827, 62, 1, 74, "Highlight",
  CellTags->"WordShuffle"],
Cell[610767, 23830, 196, 7, 43, "Usage",
  CellTags->"WordShuffle"],
Cell[610966, 23839, 81, 1, 33, "Notes",
  CellTags->"WordShuffle"],

Cell[CellGroupData[{
Cell[611072, 23844, 69, 1, 59, "ExampleSection",
  CellTags->"WordShuffle"],
Cell[611144, 23847, 134, 4, 70, "ExampleText",
  CellTags->"WordShuffle"],

Cell[CellGroupData[{
Cell[611303, 23855, 93, 2, 70, "Input",
  CellTags->"WordShuffle"],
Cell[611399, 23859, 97, 3, 70, "Output",
  CellTags->"WordShuffle"]
}, Open  ]],

Cell[CellGroupData[{
Cell[611533, 23867, 93, 2, 70, "Input",
  CellTags->"WordShuffle"],
Cell[611629, 23871, 303, 6, 70, "Output",
  CellTags->"WordShuffle"]
}, Open  ]]
}, Closed]],
Cell[611959, 23881, 54, 1, 31, "ObjectName",
  CellTags->"WordSort"],
Cell[612016, 23884, 59, 1, 74, "Highlight",
  CellTags->"WordSort"],
Cell[612078, 23887, 206, 6, 43, "Usage",
  CellTags->"WordSort"],
Cell[612287, 23895, 526, 13, 33, "Notes",
  CellTags->"WordSort"],
Cell[612816, 23910, 136, 4, 33, "Notes",
  CellTags->"WordSort"],
Cell[612955, 23916, 159, 7, 33, "Notes",
  CellTags->"WordSort"],

Cell[CellGroupData[{
Cell[613139, 23927, 66, 1, 59, "ExampleSection",
  CellTags->"WordSort"],
Cell[613208, 23930, 147, 4, 70, "ExampleText",
  CellTags->"WordSort"],

Cell[CellGroupData[{
Cell[613380, 23938, 84, 2, 70, "Input",
  CellTags->"WordSort"],
Cell[613467, 23942, 193, 4, 70, "Output",
  CellTags->"WordSort"]
}, Open  ]],

Cell[CellGroupData[{
Cell[613697, 23951, 94, 3, 70, "Input",
  CellTags->"WordSort"],
Cell[613794, 23956, 193, 4, 70, "Output",
  CellTags->"WordSort"]
}, Open  ]]
}, Closed]],
Cell[614014, 23964, 62, 1, 31, "ObjectName",
  CellTags->"WordSuffixes"],
Cell[614079, 23967, 63, 1, 74, "Highlight",
  CellTags->"WordSuffixes"],
Cell[614145, 23970, 184, 7, 43, "Usage",
  CellTags->"WordSuffixes"],
Cell[614332, 23979, 112, 5, 33, "Notes",
  CellTags->"WordSuffixes"],
Cell[614447, 23986, 270, 11, 33, "Notes",
  CellTags->"WordSuffixes"],

Cell[CellGroupData[{
Cell[614742, 24001, 70, 1, 59, "ExampleSection",
  CellTags->"WordSuffixes"],
Cell[614815, 24004, 173, 6, 70, "ExampleText",
  CellTags->"WordSuffixes"],

Cell[CellGroupData[{
Cell[615013, 24014, 91, 2, 70, "Input",
  CellTags->"WordSuffixes"],
Cell[615107, 24018, 144, 3, 70, "Output",
  CellTags->"WordSuffixes"]
}, Open  ]],

Cell[CellGroupData[{
Cell[615288, 24026, 94, 2, 70, "Input",
  CellTags->"WordSuffixes"],
Cell[615385, 24030, 160, 4, 70, "Output",
  CellTags->"WordSuffixes"]
}, Open  ]]
}, Closed]],
Cell[615572, 24038, 48, 1, 31, "ObjectName",
  CellTags->"Words"],
Cell[615623, 24041, 56, 1, 74, "Highlight",
  CellTags->"Words"],
Cell[615682, 24044, 310, 12, 64, "Usage",
  CellTags->"Words"],
Cell[615995, 24058, 84, 1, 33, "Notes",
  CellTags->"Words"],
Cell[616082, 24061, 148, 7, 33, "Notes",
  CellTags->"Words"],

Cell[CellGroupData[{
Cell[616255, 24072, 63, 1, 59, "ExampleSection",
  CellTags->"Words"],
Cell[616321, 24075, 89, 1, 70, "ExampleText",
  CellTags->"Words"],

Cell[CellGroupData[{
Cell[616435, 24080, 72, 2, 70, "Input",
  CellTags->"Words"],
Cell[616510, 24084, 136, 3, 70, "Output",
  CellTags->"Words"]
}, Open  ]],

Cell[CellGroupData[{
Cell[616683, 24092, 92, 3, 70, "Input",
  CellTags->"Words"],
Cell[616778, 24097, 189, 4, 70, "Output",
  CellTags->"Words"]
}, Open  ]],

Cell[CellGroupData[{
Cell[617004, 24106, 95, 3, 70, "Input",
  CellTags->"Words"],
Cell[617102, 24111, 136, 3, 70, "Output",
  CellTags->"Words"]
}, Open  ]],

Cell[CellGroupData[{
Cell[617275, 24119, 107, 3, 70, "Input",
  CellTags->"Words"],
Cell[617385, 24124, 136, 3, 70, "Output",
  CellTags->"Words"]
}, Open  ]]
}, Closed]],
Cell[617548, 24131, 58, 1, 31, "ObjectName",
  CellTags->"Alphabetic"],
Cell[617609, 24134, 59, 1, 74, "Highlight",
  CellTags->"Alphabetic"],
Cell[617671, 24137, 197, 8, 43, "Usage",
  CellTags->"Alphabetic"],
Cell[617871, 24147, 203, 6, 33, "Notes",
  CellTags->"Alphabetic"],
Cell[618077, 24155, 270, 11, 33, "Notes",
  CellTags->"Alphabetic"],
Cell[618350, 24168, 54, 1, 42, "ObjectName",
  CellTags->"Boundary"],
Cell[618407, 24171, 57, 1, 74, "Highlight",
  CellTags->"Boundary"],
Cell[618467, 24174, 144, 6, 43, "Usage",
  CellTags->"Boundary"],
Cell[618614, 24182, 186, 9, 33, "Notes",
  CellTags->"Boundary"],
Cell[618803, 24193, 345, 15, 33, "Notes",
  CellTags->"Boundary"],
Cell[619151, 24210, 50, 1, 42, "ObjectName",
  CellTags->"Cyclic"],
Cell[619204, 24213, 55, 1, 74, "Highlight",
  CellTags->"Cyclic"],
Cell[619262, 24216, 237, 8, 64, "Usage",
  CellTags->"Cyclic"],
Cell[619502, 24226, 338, 15, 33, "Notes",
  CellTags->"Cyclic"],
Cell[619843, 24243, 50, 1, 42, "ObjectName",
  CellTags->"EdgeLU"],
Cell[619896, 24246, 55, 1, 74, "Highlight",
  CellTags->"EdgeLU"],
Cell[619954, 24249, 147, 6, 43, "Usage",
  CellTags->"EdgeLU"],
Cell[620104, 24257, 98, 1, 33, "Notes",
  CellTags->"EdgeLU"],
Cell[620205, 24260, 166, 7, 33, "Notes",
  CellTags->"EdgeLU"],
Cell[620374, 24269, 48, 1, 42, "ObjectName",
  CellTags->"Empty"],
Cell[620425, 24272, 54, 1, 74, "Highlight",
  CellTags->"Empty"],
Cell[620482, 24275, 134, 4, 43, "Usage",
  CellTags->"Empty"],
Cell[620619, 24281, 180, 7, 33, "Notes",
  CellTags->"Empty"],
Cell[620802, 24290, 52, 1, 42, "ObjectName",
  CellTags->"EpsElim"],
Cell[620857, 24293, 56, 1, 74, "Highlight",
  CellTags->"EpsElim"],
Cell[620916, 24296, 194, 8, 43, "Usage",
  CellTags->"EpsElim"],
Cell[621113, 24306, 174, 5, 33, "Notes",
  CellTags->"EpsElim"],
Cell[621290, 24313, 289, 11, 33, "Notes",
  CellTags->"EpsElim"],
Cell[621582, 24326, 48, 1, 42, "ObjectName",
  CellTags->"FinLU"],
Cell[621633, 24329, 54, 1, 74, "Highlight",
  CellTags->"FinLU"],
Cell[621690, 24332, 145, 6, 43, "Usage",
  CellTags->"FinLU"],
Cell[621838, 24340, 76, 1, 33, "Notes",
  CellTags->"FinLU"],
Cell[621917, 24343, 165, 7, 33, "Notes",
  CellTags->"FinLU"],
Cell[622085, 24352, 48, 1, 42, "ObjectName",
  CellTags->"Fixed"],
Cell[622136, 24355, 54, 1, 74, "Highlight",
  CellTags->"Fixed"],
Cell[622193, 24358, 137, 6, 43, "Usage",
  CellTags->"Fixed"],
Cell[622333, 24366, 82, 1, 33, "Notes",
  CellTags->"Fixed"],
Cell[622418, 24369, 149, 7, 33, "Notes",
  CellTags->"Fixed"],
Cell[622570, 24378, 52, 1, 42, "ObjectName",
  CellTags->"FLBound"],
Cell[622625, 24381, 56, 1, 74, "Highlight",
  CellTags->"FLBound"],
Cell[622684, 24384, 114, 4, 43, "Usage",
  CellTags->"FLBound"],
Cell[622801, 24390, 96, 1, 33, "Notes",
  CellTags->"FLBound"],
Cell[622900, 24393, 118, 5, 33, "Notes",
  CellTags->"FLBound"],
Cell[623021, 24400, 155, 7, 33, "Notes",
  CellTags->"FLBound"],
Cell[623179, 24409, 54, 1, 42, "ObjectName",
  CellTags->"Hopcroft"],
Cell[623236, 24412, 57, 1, 74, "Highlight",
  CellTags->"Hopcroft"],
Cell[623296, 24415, 157, 6, 43, "Usage",
  CellTags->"Hopcroft"],
Cell[623456, 24423, 162, 6, 33, "Notes",
  CellTags->"Hopcroft"],
Cell[623621, 24431, 145, 4, 33, "Notes",
  CellTags->"Hopcroft"],
Cell[623769, 24437, 66, 1, 42, "ObjectName",
  CellTags->"Implementation"],
Cell[623838, 24440, 63, 1, 74, "Highlight",
  CellTags->"Implementation"],
Cell[623904, 24443, 172, 6, 43, "Usage",
  CellTags->"Implementation"],
Cell[624079, 24451, 91, 1, 33, "Notes",
  CellTags->"Implementation"],
Cell[624173, 24454, 162, 7, 33, "Notes",
  CellTags->"Implementation"],
Cell[624338, 24463, 48, 1, 42, "ObjectName",
  CellTags->"IniLU"],
Cell[624389, 24466, 54, 1, 74, "Highlight",
  CellTags->"IniLU"],
Cell[624446, 24469, 163, 6, 43, "Usage",
  CellTags->"IniLU"],
Cell[624612, 24477, 79, 1, 33, "Notes",
  CellTags->"IniLU"],
Cell[624694, 24480, 165, 7, 33, "Notes",
  CellTags->"IniLU"],
Cell[624862, 24489, 54, 1, 42, "ObjectName",
  CellTags->"ListAble"],
Cell[624919, 24492, 57, 1, 74, "Highlight",
  CellTags->"ListAble"],
Cell[624979, 24495, 151, 6, 43, "Usage",
  CellTags->"ListAble"],
Cell[625133, 24503, 173, 7, 33, "Notes",
  CellTags->"ListAble"],
Cell[625309, 24512, 54, 1, 42, "ObjectName",
  CellTags->"MakeTrim"],
Cell[625366, 24515, 57, 1, 74, "Highlight",
  CellTags->"MakeTrim"],
Cell[625426, 24518, 154, 6, 43, "Usage",
  CellTags->"MakeTrim"],
Cell[625583, 24526, 147, 4, 33, "Notes",
  CellTags->"MakeTrim"],
Cell[625733, 24532, 161, 7, 33, "Notes",
  CellTags->"MakeTrim"],
Cell[625897, 24541, 58, 1, 42, "ObjectName",
  CellTags->"RegExpSimp"],
Cell[625958, 24544, 59, 1, 74, "Highlight",
  CellTags->"RegExpSimp"],
Cell[626020, 24547, 161, 6, 43, "Usage",
  CellTags->"RegExpSimp"],
Cell[626184, 24555, 167, 4, 54, "Notes",
  CellTags->"RegExpSimp"],
Cell[626354, 24561, 203, 7, 33, "Notes",
  CellTags->"RegExpSimp"],
Cell[626560, 24570, 52, 1, 42, "ObjectName",
  CellTags->"ShowAll"],
Cell[626615, 24573, 56, 1, 74, "Highlight",
  CellTags->"ShowAll"],
Cell[626674, 24576, 152, 6, 43, "Usage",
  CellTags->"ShowAll"],
Cell[626829, 24584, 100, 1, 33, "Notes",
  CellTags->"ShowAll"],
Cell[626932, 24587, 132, 5, 33, "Notes",
  CellTags->"ShowAll"],
Cell[627067, 24594, 174, 7, 33, "Notes",
  CellTags->"ShowAll"],
Cell[627244, 24603, 56, 1, 42, "ObjectName",
  CellTags->"ShowEdges"],
Cell[627303, 24606, 58, 1, 74, "Highlight",
  CellTags->"ShowEdges"],
Cell[627364, 24609, 154, 6, 43, "Usage",
  CellTags->"ShowEdges"],
Cell[627521, 24617, 140, 4, 33, "Notes",
  CellTags->"ShowEdges"],
Cell[627664, 24623, 176, 7, 33, "Notes",
  CellTags->"ShowEdges"],
Cell[627843, 24632, 54, 1, 42, "ObjectName",
  CellTags->"SizeOnly"],
Cell[627900, 24635, 57, 1, 74, "Highlight",
  CellTags->"SizeOnly"],
Cell[627960, 24638, 148, 5, 43, "Usage",
  CellTags->"SizeOnly"],
Cell[628111, 24645, 294, 10, 54, "Notes",
  CellTags->"SizeOnly"],
Cell[628408, 24657, 209, 7, 54, "Notes",
  CellTags->"SizeOnly"],
Cell[628620, 24666, 279, 11, 33, "Notes",
  CellTags->"SizeOnly"],

Cell[CellGroupData[{
Cell[628924, 24681, 66, 1, 59, "ExampleSection",
  CellTags->"SizeOnly"],
Cell[628993, 24684, 65, 1, 70, "ExampleText",
  CellTags->"SizeOnly"],
Cell[629061, 24687, 213, 5, 70, "Input",
  CellTags->"SizeOnly"],

Cell[CellGroupData[{
Cell[629299, 24696, 136, 3, 70, "Input",
  CellTags->"SizeOnly"],
Cell[629438, 24701, 126, 3, 70, "Output",
  CellTags->"SizeOnly"]
}, Open  ]]
}, Closed]],
Cell[629591, 24708, 46, 1, 31, "ObjectName",
  CellTags->"Some"],
Cell[629640, 24711, 53, 1, 74, "Highlight",
  CellTags->"Some"],
Cell[629696, 24714, 141, 6, 43, "Usage",
  CellTags->"Some"],
Cell[629840, 24722, 160, 7, 33, "Notes",
  CellTags->"Some"],
Cell[630003, 24731, 54, 1, 42, "ObjectName",
  CellTags->"Thompson"],
Cell[630060, 24734, 57, 1, 74, "Highlight",
  CellTags->"Thompson"],
Cell[630120, 24737, 156, 6, 43, "Usage",
  CellTags->"Thompson"],
Cell[630279, 24745, 213, 7, 54, "Notes",
  CellTags->"Thompson"],
Cell[630495, 24754, 183, 7, 33, "Notes",
  CellTags->"Thompson"],
Cell[630681, 24763, 54, 1, 42, "ObjectName",
  CellTags->"ToMatrix"],
Cell[630738, 24766, 57, 1, 74, "Highlight",
  CellTags->"ToMatrix"],
Cell[630798, 24769, 147, 6, 43, "Usage",
  CellTags->"ToMatrix"],
Cell[630948, 24777, 138, 4, 33, "Notes",
  CellTags->"ToMatrix"],
Cell[631089, 24783, 163, 7, 33, "Notes",
  CellTags->"ToMatrix"],
Cell[631255, 24792, 56, 1, 42, "ObjectName",
  CellTags->"TransOnly"],
Cell[631314, 24795, 58, 1, 74, "Highlight",
  CellTags->"TransOnly"],
Cell[631375, 24798, 145, 6, 43, "Usage",
  CellTags->"TransOnly"],
Cell[631523, 24806, 152, 5, 33, "Notes",
  CellTags->"TransOnly"],
Cell[631678, 24813, 156, 7, 33, "Notes",
  CellTags->"TransOnly"],

Cell[CellGroupData[{
Cell[631859, 24824, 67, 1, 59, "ExampleSection",
  CellTags->"TransOnly"],
Cell[631929, 24827, 73, 1, 70, "ExampleText",
  CellTags->"TransOnly"],
Cell[632005, 24830, 215, 5, 70, "Input",
  CellTags->"TransOnly"],

Cell[CellGroupData[{
Cell[632245, 24839, 94, 3, 70, "Input",
  CellTags->"TransOnly"],
Cell[632342, 24844, 213, 5, 70, "Print",
  CellTags->"TransOnly"],
Cell[632558, 24851, 213, 5, 70, "Print",
  CellTags->"TransOnly"],
Cell[632774, 24858, 231, 5, 70, "Print",
  CellTags->"TransOnly"],
Cell[633008, 24865, 112, 3, 70, "Print",
  CellTags->"TransOnly"],
Cell[633123, 24870, 112, 3, 70, "Print",
  CellTags->"TransOnly"],
Cell[633238, 24875, 2438, 76, 70, "Output",
  CellTags->"TransOnly"]
}, Open  ]],

Cell[CellGroupData[{
Cell[635713, 24956, 118, 3, 70, "Input",
  CellTags->"TransOnly"],
Cell[635834, 24961, 2438, 76, 70, "Output",
  CellTags->"TransOnly"]
}, Open  ]]
}, Closed]],
Cell[638299, 25041, 54, 1, 31, "ObjectName",
  CellTags->"Tropical"],
Cell[638356, 25044, 57, 1, 74, "Highlight",
  CellTags->"Tropical"],
Cell[638416, 25047, 154, 6, 43, "Usage",
  CellTags->"Tropical"],
Cell[638573, 25055, 112, 4, 33, "Notes",
  CellTags->"Tropical"],
Cell[638688, 25061, 340, 11, 33, "Notes",
  CellTags->"Tropical"],
Cell[639031, 25074, 56, 1, 42, "ObjectName",
  CellTags->"Unlabeled"],
Cell[639090, 25077, 58, 1, 74, "Highlight",
  CellTags->"Unlabeled"],
Cell[639151, 25080, 190, 6, 43, "Usage",
  CellTags->"Unlabeled"],
Cell[639344, 25088, 108, 5, 33, "Notes",
  CellTags->"Unlabeled"],
Cell[639455, 25095, 155, 7, 33, "Notes",
  CellTags->"Unlabeled"],

Cell[CellGroupData[{
Cell[639635, 25106, 67, 1, 59, "ExampleSection",
  CellTags->"Unlabeled"],
Cell[639705, 25109, 82, 1, 70, "ExampleText",
  CellTags->"Unlabeled"],
Cell[639790, 25112, 214, 5, 70, "Input",
  CellTags->"Unlabeled"],

Cell[CellGroupData[{
Cell[640029, 25121, 80, 2, 70, "Input",
  CellTags->"Unlabeled"],
Cell[640112, 25125, 274, 8, 70, "Output",
  CellTags->"Unlabeled"]
}, Open  ]],

Cell[CellGroupData[{
Cell[640423, 25138, 121, 3, 70, "Input",
  CellTags->"Unlabeled"],
Cell[640547, 25143, 347, 10, 70, "Output",
  CellTags->"Unlabeled"]
}, Open  ]]
}, Closed]],
Cell[640921, 25157, 52, 1, 31, "ObjectName",
  CellTags->"WordMap"],
Cell[640976, 25160, 56, 1, 74, "Highlight",
  CellTags->"WordMap"],
Cell[641035, 25163, 158, 4, 43, "Usage",
  CellTags->"WordMap"],
Cell[641196, 25169, 228, 10, 137, "Notes",
  CellTags->"WordMap"],

Cell[CellGroupData[{
Cell[641449, 25183, 65, 1, 59, "ExampleSection",
  CellTags->"WordMap"],
Cell[641517, 25186, 161, 4, 70, "ExampleText",
  CellTags->"WordMap"],
Cell[641681, 25192, 125, 3, 70, "Input",
  CellTags->"WordMap"],

Cell[CellGroupData[{
Cell[641831, 25199, 88, 3, 70, "Input",
  CellTags->"WordMap"],
Cell[641922, 25204, 48, 1, 70, "Print",
  CellTags->"WordMap"],
Cell[641973, 25207, 844, 27, 70, "Print",
  CellTags->"WordMap"]
}, Open  ]]
}, Closed]],
Cell[642844, 25238, 46, 1, 31, "ObjectName",
  CellTags->"BEFA"],
Cell[642893, 25241, 53, 1, 74, "Highlight",
  CellTags->"BEFA"],
Cell[642949, 25244, 321, 7, 85, "Usage",
  CellTags->"BEFA"],
Cell[643273, 25253, 201, 7, 33, "Notes",
  CellTags->"BEFA"],
Cell[643477, 25262, 196, 6, 36, "Notes",
  CellTags->"BEFA"],
Cell[643676, 25270, 95, 1, 33, "Notes",
  CellTags->"BEFA"],

Cell[CellGroupData[{
Cell[643796, 25275, 62, 1, 59, "ExampleSection",
  CellTags->"BEFA"],
Cell[643861, 25278, 193, 6, 70, "ExampleText",
  CellTags->"BEFA"],

Cell[CellGroupData[{
Cell[644079, 25288, 177, 4, 70, "Input",
  CellTags->"BEFA"],
Cell[644259, 25294, 205, 5, 70, "Output",
  CellTags->"BEFA"]
}, Open  ]]
}, Closed]],
Cell[644491, 25303, 42, 1, 31, "ObjectName",
  CellTags->"CA"],
Cell[644536, 25306, 51, 1, 74, "Highlight",
  CellTags->"CA"],
Cell[644590, 25309, 244, 8, 64, "Usage",
  CellTags->"CA"],
Cell[644837, 25319, 271, 10, 33, "Notes",
  CellTags->"CA"],

Cell[CellGroupData[{
Cell[645133, 25333, 60, 1, 59, "ExampleSection",
  CellTags->"CA"],
Cell[645196, 25336, 130, 4, 70, "ExampleText",
  CellTags->"CA"],

Cell[CellGroupData[{
Cell[645351, 25344, 68, 2, 70, "Input",
  CellTags->"CA"],
Cell[645422, 25348, 95, 3, 70, "Output",
  CellTags->"CA"]
}, Open  ]],
Cell[645532, 25354, 91, 1, 70, "ExampleText",
  CellTags->"CA"],

Cell[CellGroupData[{
Cell[645648, 25359, 79, 2, 70, "Input",
  CellTags->"CA"],
Cell[645730, 25363, 97, 3, 70, "Output",
  CellTags->"CA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[645864, 25371, 86, 3, 70, "Input",
  CellTags->"CA"],
Cell[645953, 25376, 809, 18, 70, "Output",
  CellTags->"CA"]
}, Open  ]]
}, Closed]],
Cell[646789, 25398, 44, 1, 31, "ObjectName",
  CellTags->"DFA"],
Cell[646836, 25401, 52, 1, 74, "Highlight",
  CellTags->"DFA"],
Cell[646891, 25404, 142, 4, 43, "Usage",
  CellTags->"DFA"],
Cell[647036, 25410, 319, 12, 54, "Notes",
  CellTags->"DFA"],
Cell[647358, 25424, 197, 9, 33, "Notes",
  CellTags->"DFA"],
Cell[647558, 25435, 188, 8, 33, "Notes",
  CellTags->"DFA"],
Cell[647749, 25445, 352, 9, 54, "Notes",
  CellTags->"DFA"],
Cell[648104, 25456, 164, 7, 33, "Notes",
  CellTags->"DFA"],

Cell[CellGroupData[{
Cell[648293, 25467, 61, 1, 59, "ExampleSection",
  CellTags->"DFA"],
Cell[648357, 25470, 350, 10, 70, "ExampleText",
  CellTags->"DFA"],
Cell[648710, 25482, 98, 3, 70, "Input",
  CellTags->"DFA"],

Cell[CellGroupData[{
Cell[648833, 25489, 199, 5, 70, "Input",
  CellTags->"DFA"],
Cell[649035, 25496, 159, 4, 70, "Output",
  CellTags->"DFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[649231, 25505, 117, 4, 70, "Input",
  CellTags->"DFA"],
Cell[649351, 25511, 100, 3, 70, "Output",
  CellTags->"DFA"],
Cell[649454, 25516, 89, 3, 70, "Output",
  CellTags->"DFA"]
}, Open  ]]
}, Closed]],
Cell[649570, 25523, 42, 1, 31, "ObjectName",
  CellTags->"FA"],
Cell[649615, 25526, 51, 1, 74, "Highlight",
  CellTags->"FA"],
Cell[649669, 25529, 124, 4, 43, "Usage",
  CellTags->"FA"],
Cell[649796, 25535, 231, 9, 33, "Notes",
  CellTags->"FA"],
Cell[650030, 25546, 168, 7, 33, "Notes",
  CellTags->"FA"],
Cell[650201, 25555, 261, 9, 33, "Notes",
  CellTags->"FA"],
Cell[650465, 25566, 183, 7, 33, "Notes",
  CellTags->"FA"],
Cell[650651, 25575, 303, 15, 33, "Notes",
  CellTags->"FA"],

Cell[CellGroupData[{
Cell[650979, 25594, 60, 1, 59, "ExampleSection",
  CellTags->"FA"],
Cell[651042, 25597, 52, 1, 70, "ExampleText",
  CellTags->"FA"],
Cell[651097, 25600, 207, 5, 70, "Input",
  CellTags->"FA"],

Cell[CellGroupData[{
Cell[651329, 25609, 142, 5, 70, "Input",
  CellTags->"FA"],
Cell[651474, 25616, 81, 3, 70, "Output",
  CellTags->"FA"],
Cell[651558, 25621, 81, 3, 70, "Output",
  CellTags->"FA"],
Cell[651642, 25626, 88, 3, 70, "Output",
  CellTags->"FA"]
}, Open  ]]
}, Closed]],
Cell[651757, 25633, 44, 1, 31, "ObjectName",
  CellTags->"NFA"],
Cell[651804, 25636, 52, 1, 74, "Highlight",
  CellTags->"NFA"],
Cell[651859, 25639, 136, 4, 43, "Usage",
  CellTags->"NFA"],
Cell[651998, 25645, 276, 11, 33, "Notes",
  CellTags->"NFA"],
Cell[652277, 25658, 169, 7, 33, "Notes",
  CellTags->"NFA"],
Cell[652449, 25667, 262, 9, 33, "Notes",
  CellTags->"NFA"],
Cell[652714, 25678, 184, 7, 33, "Notes",
  CellTags->"NFA"],
Cell[652901, 25687, 302, 15, 33, "Notes",
  CellTags->"NFA"],

Cell[CellGroupData[{
Cell[653228, 25706, 61, 1, 59, "ExampleSection",
  CellTags->"NFA"],
Cell[653292, 25709, 54, 1, 70, "ExampleText",
  CellTags->"NFA"],

Cell[CellGroupData[{
Cell[653371, 25714, 173, 5, 70, "Input",
  CellTags->"NFA"],
Cell[653547, 25721, 392, 12, 70, "Output",
  CellTags->"NFA"]
}, Open  ]],

Cell[CellGroupData[{
Cell[653976, 25738, 109, 3, 70, "Input",
  CellTags->"NFA"],
Cell[654088, 25743, 336, 9, 70, "Output",
  CellTags->"NFA"]
}, Open  ]]
}, Closed]],
Cell[654451, 25756, 46, 1, 31, "ObjectName",
  CellTags->"NNFA"],
Cell[654500, 25759, 53, 1, 74, "Highlight",
  CellTags->"NNFA"],
Cell[654556, 25762, 157, 4, 43, "Usage",
  CellTags->"NNFA"],
Cell[654716, 25768, 291, 6, 75, "Notes",
  CellTags->"NNFA"],
Cell[655010, 25776, 270, 11, 33, "Notes",
  CellTags->"NNFA"],

Cell[CellGroupData[{
Cell[655305, 25791, 62, 1, 59, "ExampleSection",
  CellTags->"NNFA"],
Cell[655370, 25794, 56, 1, 70, "ExampleText",
  CellTags->"NNFA"],

Cell[CellGroupData[{
Cell[655451, 25799, 104, 2, 70, "Input",
  CellTags->"NNFA"],
Cell[655558, 25803, 193, 5, 70, "Output",
  CellTags->"NNFA"]
}, Open  ]]
}, Closed]],
Cell[655778, 25812, 44, 1, 31, "ObjectName",
  CellTags->"REP"],
Cell[655825, 25815, 52, 1, 74, "Highlight",
  CellTags->"REP"],
Cell[655880, 25818, 130, 4, 43, "Usage",
  CellTags->"REP"],
Cell[656013, 25824, 97, 5, 33, "Notes",
  CellTags->"REP"],
Cell[656113, 25831, 379, 15, 33, "Notes",
  CellTags->"REP"],

Cell[CellGroupData[{
Cell[656517, 25850, 61, 1, 59, "ExampleSection",
  CellTags->"REP"],
Cell[656581, 25853, 279, 10, 70, "ExampleText",
  CellTags->"REP"],

Cell[CellGroupData[{
Cell[656885, 25867, 137, 5, 70, "Input",
  CellTags->"REP"],
Cell[657025, 25874, 89, 3, 70, "Output",
  CellTags->"REP"],
Cell[657117, 25879, 159, 5, 70, "Output",
  CellTags->"REP"]
}, Open  ]],

Cell[CellGroupData[{
Cell[657313, 25889, 111, 3, 70, "Input",
  CellTags->"REP"],
Cell[657427, 25894, 568, 15, 70, "Output",
  CellTags->"REP"]
}, Open  ]],

Cell[CellGroupData[{
Cell[658032, 25914, 98, 3, 70, "Input",
  CellTags->"REP"],
Cell[658133, 25919, 560, 9, 70, "Output",
  CellTags->"REP"]
}, Open  ]]
}, Closed]],
Cell[658720, 25932, 44, 1, 31, "ObjectName",
  CellTags->"RES"],
Cell[658767, 25935, 52, 1, 74, "Highlight",
  CellTags->"RES"],
Cell[658822, 25938, 136, 4, 43, "Usage",
  CellTags->"RES"],
Cell[658961, 25944, 94, 5, 33, "Notes",
  CellTags->"RES"],
Cell[659058, 25951, 379, 15, 33, "Notes",
  CellTags->"RES"],

Cell[CellGroupData[{
Cell[659462, 25970, 61, 1, 59, "ExampleSection",
  CellTags->"RES"],
Cell[659526, 25973, 279, 10, 70, "ExampleText",
  CellTags->"RES"],

Cell[CellGroupData[{
Cell[659830, 25987, 137, 5, 70, "Input",
  CellTags->"RES"],
Cell[659970, 25994, 89, 3, 70, "Output",
  CellTags->"RES"],
Cell[660062, 25999, 159, 5, 70, "Output",
  CellTags->"RES"]
}, Open  ]],

Cell[CellGroupData[{
Cell[660258, 26009, 111, 3, 70, "Input",
  CellTags->"RES"],
Cell[660372, 26014, 568, 15, 70, "Output",
  CellTags->"RES"]
}, Open  ]],

Cell[CellGroupData[{
Cell[660977, 26034, 98, 3, 70, "Input",
  CellTags->"RES"],
Cell[661078, 26039, 560, 9, 70, "Output",
  CellTags->"RES"]
}, Open  ]]
}, Closed]],
Cell[661665, 26052, 44, 1, 31, "ObjectName",
  CellTags->"RET"],
Cell[661712, 26055, 52, 1, 74, "Highlight",
  CellTags->"RET"],
Cell[661767, 26058, 138, 4, 43, "Usage",
  CellTags->"RET"],
Cell[661908, 26064, 97, 5, 33, "Notes",
  CellTags->"RET"],
Cell[662008, 26071, 379, 15, 33, "Notes",
  CellTags->"RET"],

Cell[CellGroupData[{
Cell[662412, 26090, 61, 1, 59, "ExampleSection",
  CellTags->"RET"],
Cell[662476, 26093, 279, 10, 70, "ExampleText",
  CellTags->"RET"],

Cell[CellGroupData[{
Cell[662780, 26107, 137, 5, 70, "Input",
  CellTags->"RET"],
Cell[662920, 26114, 89, 3, 70, "Output",
  CellTags->"RET"],
Cell[663012, 26119, 159, 5, 70, "Output",
  CellTags->"RET"]
}, Open  ]],

Cell[CellGroupData[{
Cell[663208, 26129, 111, 3, 70, "Input",
  CellTags->"RET"],
Cell[663322, 26134, 568, 15, 70, "Output",
  CellTags->"RET"]
}, Open  ]],

Cell[CellGroupData[{
Cell[663927, 26154, 98, 3, 70, "Input",
  CellTags->"RET"],
Cell[664028, 26159, 560, 9, 70, "Output",
  CellTags->"RET"]
}, Open  ]]
}, Closed]],
Cell[664615, 26172, 42, 1, 31, "ObjectName",
  CellTags->"SA"],
Cell[664660, 26175, 51, 1, 74, "Highlight",
  CellTags->"SA"],
Cell[664714, 26178, 109, 4, 43, "Usage",
  CellTags->"SA"],
Cell[664826, 26184, 231, 9, 33, "Notes",
  CellTags->"SA"],
Cell[665060, 26195, 166, 5, 33, "Notes",
  CellTags->"SA"],
Cell[665229, 26202, 79, 1, 33, "Notes",
  CellTags->"SA"],
Cell[665311, 26205, 183, 7, 33, "Notes",
  CellTags->"SA"],
Cell[665497, 26214, 303, 15, 33, "Notes",
  CellTags->"SA"],

Cell[CellGroupData[{
Cell[665825, 26233, 60, 1, 59, "ExampleSection",
  CellTags->"SA"],
Cell[665888, 26236, 63, 1, 70, "ExampleText",
  CellTags->"SA"],
Cell[665954, 26239, 212, 5, 70, "Input",
  CellTags->"SA"],

Cell[CellGroupData[{
Cell[666191, 26248, 141, 5, 70, "Input",
  CellTags->"SA"],
Cell[666335, 26255, 89, 3, 70, "Output",
  CellTags->"SA"],
Cell[666427, 26260, 89, 3, 70, "Output",
  CellTags->"SA"],
Cell[666519, 26265, 87, 3, 70, "Output",
  CellTags->"SA"]
}, Open  ]]
}, Closed]],
Cell[666633, 26272, 42, 1, 31, "ObjectName",
  CellTags->"TS"],
Cell[666678, 26275, 51, 1, 74, "Highlight",
  CellTags->"TS"],
Cell[666732, 26278, 196, 7, 43, "Usage",
  CellTags->"TS"],
Cell[666931, 26287, 318, 13, 33, "Notes",
  CellTags->"TS"],
Cell[667252, 26302, 253, 9, 54, "Notes",
  CellTags->"TS"],
Cell[667508, 26313, 372, 15, 33, "Notes",
  CellTags->"TS"],

Cell[CellGroupData[{
Cell[667905, 26332, 60, 1, 59, "ExampleSection",
  CellTags->"TS"],
Cell[667968, 26335, 79, 1, 70, "ExampleText",
  CellTags->"TS"],

Cell[CellGroupData[{
Cell[668072, 26340, 73, 2, 70, "Input",
  CellTags->"TS"],
Cell[668148, 26344, 78, 3, 70, "Output",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{
Cell[668263, 26352, 73, 2, 70, "Input",
  CellTags->"TS"],
Cell[668339, 26356, 78, 3, 70, "Output",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{
Cell[668454, 26364, 67, 2, 70, "Input",
  CellTags->"TS"],
Cell[668524, 26368, 78, 3, 70, "Output",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{
Cell[668639, 26376, 80, 2, 70, "Input",
  CellTags->"TS"],
Cell[668722, 26380, 78, 3, 70, "Output",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{
Cell[668837, 26388, 80, 2, 70, "Input",
  CellTags->"TS"],
Cell[668920, 26392, 133, 4, 70, "Output",
  CellTags->"TS"]
}, Open  ]],

Cell[CellGroupData[{
Cell[669090, 26401, 74, 2, 70, "Input",
  CellTags->"TS"],
Cell[669167, 26405, 133, 4, 70, "Output",
  CellTags->"TS"]
}, Open  ]]
}, Closed]],
Cell[669327, 26413, 55, 1, 31, "ObjectName",
  CellTags->"alphabet"],
Cell[669385, 26416, 57, 1, 74, "Highlight",
  CellTags->"alphabet"],
Cell[669445, 26419, 182, 5, 43, "Usage",
  CellTags->"alphabet"],
Cell[669630, 26426, 177, 6, 33, "Notes",
  CellTags->"alphabet"],
Cell[669810, 26434, 146, 4, 33, "Notes",
  CellTags->"alphabet"],

Cell[CellGroupData[{
Cell[669981, 26442, 66, 1, 59, "ExampleSection",
  CellTags->"alphabet"],
Cell[670050, 26445, 81, 1, 70, "ExampleText",
  CellTags->"alphabet"],

Cell[CellGroupData[{
Cell[670156, 26450, 75, 2, 70, "Input",
  CellTags->"alphabet"],
Cell[670234, 26454, 129, 3, 70, "Output",
  CellTags->"alphabet"]
}, Open  ]],

Cell[CellGroupData[{
Cell[670400, 26462, 119, 3, 70, "Input",
  CellTags->"alphabet"],
Cell[670522, 26467, 171, 4, 70, "Output",
  CellTags->"alphabet"]
}, Open  ]],

Cell[CellGroupData[{
Cell[670730, 26476, 136, 3, 70, "Input",
  CellTags->"alphabet"],
Cell[670869, 26481, 129, 3, 70, "Output",
  CellTags->"alphabet"]
}, Open  ]]
}, Closed]],
Cell[671025, 26488, 81, 1, 31, "ObjectName",
  CellTags->"automataReleaseNumber"],
Cell[671109, 26491, 70, 1, 74, "Highlight",
  CellTags->"automataReleaseNumber"],
Cell[671182, 26494, 169, 4, 43, "Usage",
  CellTags->"automataReleaseNumber"],
Cell[671354, 26500, 90, 1, 33, "Notes",
  CellTags->"automataReleaseNumber"],

Cell[CellGroupData[{
Cell[671469, 26505, 79, 1, 59, "ExampleSection",
  CellTags->"automataReleaseNumber"],
Cell[671551, 26508, 80, 1, 70, "ExampleText",
  CellTags->"automataReleaseNumber"],

Cell[CellGroupData[{
Cell[671656, 26513, 101, 2, 70, "Input",
  CellTags->"automataReleaseNumber"],
Cell[671760, 26517, 101, 3, 70, "Output",
  CellTags->"automataReleaseNumber"]
}, Open  ]]
}, Closed]],
Cell[671888, 26524, 51, 1, 31, "ObjectName",
  CellTags->"bottom"],
Cell[671942, 26527, 55, 1, 74, "Highlight",
  CellTags->"bottom"],
Cell[672000, 26530, 194, 6, 43, "Usage",
  CellTags->"bottom"],
Cell[672197, 26538, 59, 1, 33, "Notes",
  CellTags->"bottom"],
Cell[672259, 26541, 113, 4, 33, "Notes",
  CellTags->"bottom"],
Cell[672375, 26547, 159, 7, 33, "Notes",
  CellTags->"bottom"],

Cell[CellGroupData[{
Cell[672559, 26558, 64, 1, 59, "ExampleSection",
  CellTags->"bottom"],
Cell[672626, 26561, 104, 2, 70, "ExampleText",
  CellTags->"bottom"],
Cell[672733, 26565, 130, 3, 70, "Input",
  CellTags->"bottom"],

Cell[CellGroupData[{
Cell[672888, 26572, 89, 3, 70, "Input",
  CellTags->"bottom"],
Cell[672980, 26577, 111, 3, 70, "Output",
  CellTags->"bottom"]
}, Open  ]],

Cell[CellGroupData[{
Cell[673128, 26585, 121, 4, 70, "Input",
  CellTags->"bottom"],
Cell[673252, 26591, 538, 15, 70, "Output",
  CellTags->"bottom"],
Cell[673793, 26608, 119, 3, 70, "Output",
  CellTags->"bottom"]
}, Open  ]],

Cell[CellGroupData[{
Cell[673949, 26616, 162, 4, 70, "Input",
  CellTags->"bottom"],
Cell[674114, 26622, 538, 15, 70, "Output",
  CellTags->"bottom"],
Cell[674655, 26639, 123, 3, 70, "Output",
  CellTags->"bottom"]
}, Open  ]]
}, Closed]],
Cell[674805, 26646, 71, 1, 31, "ObjectName",
  CellTags->"defaultnormalize"],
Cell[674879, 26649, 65, 1, 74, "Highlight",
  CellTags->"defaultnormalize"],
Cell[674947, 26652, 199, 6, 43, "Usage",
  CellTags->"defaultnormalize"],
Cell[675149, 26660, 182, 5, 33, "Notes",
  CellTags->"defaultnormalize"],
Cell[675334, 26667, 327, 10, 54, "Notes",
  CellTags->"defaultnormalize"],
Cell[675664, 26679, 443, 12, 75, "Notes",
  CellTags->"defaultnormalize"],
Cell[676110, 26693, 257, 7, 54, "Notes",
  CellTags->"defaultnormalize"],
Cell[676370, 26702, 337, 7, 75, "Notes",
  CellTags->"defaultnormalize"],
Cell[676710, 26711, 265, 11, 33, "Notes",
  CellTags->"defaultnormalize"],

Cell[CellGroupData[{
Cell[677000, 26726, 74, 1, 59, "ExampleSection",
  CellTags->"defaultnormalize"],
Cell[677077, 26729, 94, 1, 70, "ExampleText",
  CellTags->"defaultnormalize"],

Cell[CellGroupData[{
Cell[677196, 26734, 111, 2, 70, "Input",
  CellTags->"defaultnormalize"],
Cell[677310, 26738, 116, 3, 70, "Output",
  CellTags->"defaultnormalize"]
}, Open  ]],
Cell[677441, 26744, 79, 1, 70, "ExampleText",
  CellTags->"defaultnormalize"],

Cell[CellGroupData[{
Cell[677545, 26749, 167, 4, 70, "Input",
  CellTags->"defaultnormalize"],
Cell[677715, 26755, 177, 4, 70, "Output",
  CellTags->"defaultnormalize"]
}, Open  ]],

Cell[CellGroupData[{
Cell[677929, 26764, 162, 4, 70, "Input",
  CellTags->"defaultnormalize"],
Cell[678094, 26770, 177, 4, 70, "Output",
  CellTags->"defaultnormalize"]
}, Open  ]]
}, Closed]],
Cell[678298, 26778, 45, 1, 31, "ObjectName",
  CellTags->"LLL"],
Cell[678346, 26781, 52, 1, 74, "Highlight",
  CellTags->"LLL"],
Cell[678401, 26784, 250, 8, 64, "Usage",
  CellTags->"LLL"],
Cell[678654, 26794, 62, 1, 33, "Notes",
  CellTags->"LLL"],
Cell[678719, 26797, 321, 13, 33, "Notes",
  CellTags->"LLL"],
Cell[679043, 26812, 84, 1, 33, "Notes",
  CellTags->"LLL"],

Cell[CellGroupData[{
Cell[679152, 26817, 61, 1, 59, "ExampleSection",
  CellTags->"LLL"],
Cell[679216, 26820, 171, 6, 70, "ExampleText",
  CellTags->"LLL"],
Cell[679390, 26828, 189, 5, 70, "Input",
  CellTags->"LLL"],
Cell[679582, 26835, 90, 1, 70, "ExampleText",
  CellTags->"LLL"],

Cell[CellGroupData[{
Cell[679697, 26840, 123, 3, 70, "Input",
  CellTags->"LLL"],
Cell[679823, 26845, 194, 4, 70, "Output",
  CellTags->"LLL"]
}, Closed]],
Cell[680032, 26852, 162, 5, 70, "ExampleText",
  CellTags->"LLL"],

Cell[CellGroupData[{
Cell[680219, 26861, 131, 3, 70, "Input",
  CellTags->"LLL"],
Cell[680353, 26866, 923, 23, 70, "Output",
  CellTags->"LLL"]
}, Closed]],
Cell[681291, 26892, 187, 6, 70, "ExampleText",
  CellTags->"LLL"],

Cell[CellGroupData[{
Cell[681503, 26902, 122, 3, 70, "Input",
  CellTags->"LLL"],
Cell[681628, 26907, 646, 18, 70, "Output",
  CellTags->"LLL"]
}, Closed]]
}, Closed]],
Cell[682301, 26929, 59, 1, 31, "ObjectName",
  CellTags->"regexrules"],
Cell[682363, 26932, 59, 1, 74, "Highlight",
  CellTags->"regexrules"],
Cell[682425, 26935, 214, 7, 43, "Usage",
  CellTags->"regexrules"],
Cell[682642, 26944, 140, 4, 33, "Notes",
  CellTags->"regexrules"],
Cell[682785, 26950, 163, 4, 54, "Notes",
  CellTags->"regexrules"],

Cell[CellGroupData[{
Cell[682973, 26958, 68, 1, 59, "ExampleSection",
  CellTags->"regexrules"],
Cell[683044, 26961, 136, 4, 70, "ExampleText",
  CellTags->"regexrules"],

Cell[CellGroupData[{
Cell[683205, 26969, 99, 2, 70, "Input",
  CellTags->"regexrules"],
Cell[683307, 26973, 98, 3, 70, "Output",
  CellTags->"regexrules"]
}, Open  ]],

Cell[CellGroupData[{
Cell[683442, 26981, 100, 2, 70, "Input",
  CellTags->"regexrules"],
Cell[683545, 26985, 92, 3, 70, "Output",
  CellTags->"regexrules"]
}, Open  ]]
}, Closed]],
Cell[683664, 26992, 59, 1, 31, "ObjectName",
  CellTags->"shortlines"],
Cell[683726, 26995, 59, 1, 74, "Highlight",
  CellTags->"shortlines"],
Cell[683788, 26998, 185, 5, 43, "Usage",
  CellTags->"shortlines"],
Cell[683976, 27005, 164, 5, 33, "Notes",
  CellTags->"shortlines"],
Cell[684143, 27012, 63, 1, 33, "Notes",
  CellTags->"shortlines"],
Cell[684209, 27015, 171, 7, 33, "Notes",
  CellTags->"shortlines"],

Cell[CellGroupData[{
Cell[684405, 27026, 68, 1, 59, "ExampleSection",
  CellTags->"shortlines"],
Cell[684476, 27029, 83, 1, 48, "ExampleText",
  CellTags->"shortlines"],

Cell[CellGroupData[{
Cell[684584, 27034, 112, 3, 37, "Input",
  CellTags->"shortlines"],
Cell[684699, 27039, 388, 12, 30, "Output",
  CellTags->"shortlines"]
}, Open  ]],

Cell[CellGroupData[{
Cell[685124, 27056, 126, 4, 60, "Input",
  CellTags->"shortlines"],
Cell[685253, 27062, 675, 17, 99, "Output",
  CellTags->"shortlines"]
}, Open  ]],
Cell[685943, 27082, 105, 3, 37, "Input",
  CellTags->"shortlines"]
}, Open  ]],
Cell[686063, 27088, 67, 1, 42, "ObjectName",
  CellTags->"transdispwidth"],
Cell[686133, 27091, 63, 1, 74, "Highlight",
  CellTags->"transdispwidth"],
Cell[686199, 27094, 199, 6, 43, "Usage",
  CellTags->"transdispwidth"],
Cell[686401, 27102, 61, 1, 33, "Notes",
  CellTags->"transdispwidth"],
Cell[686465, 27105, 156, 7, 33, "Notes",
  CellTags->"transdispwidth"],

Cell[CellGroupData[{
Cell[686646, 27116, 72, 1, 59, "ExampleSection",
  CellTags->"transdispwidth"],
Cell[686721, 27119, 87, 1, 48, "ExampleText",
  CellTags->"transdispwidth"],

Cell[CellGroupData[{
Cell[686833, 27124, 95, 2, 40, "Input",
  CellTags->"transdispwidth"],
Cell[686931, 27128, 392, 12, 30, "Output",
  CellTags->"transdispwidth"]
}, Open  ]],

Cell[CellGroupData[{
Cell[687360, 27145, 129, 3, 37, "Input",
  CellTags->"transdispwidth"],
Cell[687492, 27150, 220, 5, 30, "Print",
  CellTags->"transdispwidth"],
Cell[687715, 27157, 220, 5, 30, "Print",
  CellTags->"transdispwidth"],
Cell[687938, 27164, 236, 5, 30, "Print",
  CellTags->"transdispwidth"],
Cell[688177, 27171, 222, 5, 30, "Print",
  CellTags->"transdispwidth"],
Cell[688402, 27178, 224, 5, 30, "Print",
  CellTags->"transdispwidth"],
Cell[688629, 27185, 5983, 185, 264, "Output",
  CellTags->"transdispwidth"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

