(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    532732,      23831]*)
(*NotebookOutlinePosition[    733895,      29156]*)
(*  CellTagsIndexPosition[    725690,      28906]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["AccCoaccGraph", "ObjectName",
  CellTags->"AccCoaccGraph"],

Cell["Type: function", "Highlight",
  CellTags->"AccCoaccGraph"],

Cell[TextData[{
  StyleBox["AccCoaccGraph[G,S,T]", "MR"],
  "  constructs the subgraph of ",
  StyleBox["G", "MR"],
  " induced by the vertices reachable from ",
  StyleBox["S", "MR"],
  " and coreachable from ",
  StyleBox["T", "MR"],
  "."
}], "Usage",
  CellTags->"AccCoaccGraph"],

Cell["\<\
Both S and T are lists of integers, corresponding to vertices in G.\
\
\>", "Notes",
  CellTags->"AccCoaccGraph"],

Cell[TextData[{
  "Returns a ",
  StyleBox["Graph", "MR"],
  " object that maintains the corresponding vertex set of the original \
graph."
}], "Notes",
  CellTags->"AccCoaccGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["AccessibleGraph",
    ButtonData:>"AccessibleGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SubGraph",
    ButtonData:>"SubGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DegreeGraph",
    ButtonData:>"DegreeGraph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[",", "Text"],
  " ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AccCoaccGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AccCoaccGraph"],

Cell["\<\
A path graph. All points are accessible from vertex 1, and \
coaccessible from vertex 8.\
\>", "ExampleText",
  CellTags->"AccCoaccGraph"],

Cell[BoxData[
    \(\(g\  = \ 
        Graph[8, 7, 
          1, {{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 
              8}}];\)\)], "Input",
  CellLabel->"In[158]:=",
  CellTags->"AccCoaccGraph"],

Cell[CellGroupData[{

Cell["AccCoaccGraph[g,{1},{8}]", "Input",
  CellLabel->"In[159]:=",
  CellTags->"AccCoaccGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"8", ",", "7", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 
                8}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[159]=",
  CellTags->"AccCoaccGraph"]
}, Open  ]],

Cell["\<\
Only 3 points are accissible from vertex 3, and coaccessible from \
vertex 5.\
\>", "ExampleText",
  CellTags->"AccCoaccGraph"],

Cell[CellGroupData[{

Cell["\<\
AccCoaccGraph[g,{3},{5}]
VertexSet[%]\
\>", "Input",
  CellLabel->"In[166]:=",
  CellTags->"AccCoaccGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"3", ",", "2", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[166]=",
  CellTags->"AccCoaccGraph"],

Cell[BoxData[
    \({3, 4, 5}\)], "Output",
  CellLabel->"Out[167]=",
  CellTags->"AccCoaccGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AccessibleGraph", "ObjectName",
  CellTags->"AccessibleGraph"],

Cell["Type: function", "Highlight",
  CellTags->"AccessibleGraph"],

Cell[TextData[{
  StyleBox["AccessibleGraph[G,A]", "MR"],
  "  constructs the subgraph of G induced by the vertices reachable from set \
",
  StyleBox["A", "MR"],
  ".  ",
  StyleBox["AccessibleGraph", "MR"],
  " uses the function ",
  StyleBox["WeaklyConnectedComponents", "MR"],
  "."
}], "Usage",
  CellTags->"AccessibleGraph"],

Cell["\<\
A is a list of integers, corresponding to vertices in G in \
positional notation.\
\>", "Notes",
  CellTags->"AccessibleGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["AccCoaccGraph",
    ButtonData:>"AccCoaccGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SubGraph",
    ButtonData:>"SubGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DegreeGraph",
    ButtonData:>"DegreeGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AccessibleGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AccessibleGraph"],

Cell["A circulant graph. ", "ExampleText",
  CellTags->"AccessibleGraph"],

Cell[CellGroupData[{

Cell["g = CirculantGraph[10,{2,-2}]", "Input",
  CellLabel->"In[169]:=",
  CellTags->"AccessibleGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"10", ",", "20", ",", "1", ",", 
          
          TagBox[\({{1, 3}, {2, 4}, {3, 5}, {4, 6}, {5, 7}, {6, 8}, {7, 
                9}, {8, 10}, \[LeftSkeleton]4\[RightSkeleton], {3, 1}, {4, 
                2}, {5, 3}, {6, 4}, {7, 5}, {8, 6}, {9, 7}, {10, 8}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[169]=",
  CellTags->"AccessibleGraph"]
}, Open  ]],

Cell["Only the odd vertices are reachable from vertex 1.", "ExampleText",
  CellTags->"AccessibleGraph"],

Cell[CellGroupData[{

Cell["\<\
AccessibleGraph[g,1]
VertexSet[%]\
\>", "Input",
  CellLabel->"In[171]:=",
  CellTags->"AccessibleGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"5", ",", "10", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 1}, {1, 5}, {2, 
                1}, {3, 2}, {4, 3}, {5, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[171]=",
  CellTags->"AccessibleGraph"],

Cell[BoxData[
    \({1, 3, 5, 7, 9}\)], "Output",
  CellLabel->"Out[172]=",
  CellTags->"AccessibleGraph"]
}, Open  ]],

Cell["All vertices are reachable from {1,2}.", "ExampleText",
  CellTags->"AccessibleGraph"],

Cell[CellGroupData[{

Cell["AccessibleGraph[g,{1,2}] // VertexSet", "Input",
  CellLabel->"In[177]:=",
  CellTags->"AccessibleGraph"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10}\)], "Output",
  CellLabel->"Out[177]=",
  CellTags->"AccessibleGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AlgebraicForm", "ObjectName",
  CellTags->"AlgebraicForm"],

Cell["Type: function", "Highlight",
  CellTags->"AlgebraicForm"],

Cell[TextData[{
  StyleBox["AlgebraicForm[w]", "MR"],
  "  writes word ",
  StyleBox["w", "MR"],
  " in algebraic form using exponents for runs of a symbol."
}], "Usage",
  CellTags->"AlgebraicForm"],

Cell[TextData[{
  "Example:  ",
  StyleBox["AlgebraicForm[aaaaabbbcc] \[Rule] ", "MR"],
  StyleBox[Cell[BoxData[
      InterpretationBox[
        RowBox[{
          InterpretationBox[\("a"\^5\),
            Subscripted[ 
              "a"[ 5], 0, -1],
            Editable->False], "\[InvisibleSpace]", 
          InterpretationBox[\("b"\^3\),
            Subscripted[ 
              "b"[ 3], 0, -1],
            Editable->False], "\[InvisibleSpace]", 
          InterpretationBox[\("c"\^2\),
            Subscripted[ 
              "c"[ 2], 0, -1],
            Editable->False]}],
        SequenceForm[ 
          Automata`dimath`Private`algfrm[ "a", 5], 
          Automata`dimath`Private`algfrm[ "b", 3], 
          Automata`dimath`Private`algfrm[ "c", 2]],
        Editable->False]], "MR"], "MR"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"AlgebraicForm"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AllStringReplace", "ObjectName",
  CellTags->"AllStringReplace"],

Cell["Type: functional", "Highlight",
  CellTags->"AllStringReplace"],

Cell[TextData[{
  StyleBox["AllStringReplace[eq][w] ", "MR"],
  " generates all words obtainable from word ",
  StyleBox["w", "MR"],
  " by applying the rewrite equations in ",
  StyleBox["eq", "MR"],
  " once."
}], "Usage",
  CellTags->"AllStringReplace"],

Cell[TextData[{
  "The rewrite equations can be given as a list of pairs of the form ",
  StyleBox["{lhs,rhs}", "MR"],
  ", both words, or as a list of rules  ",
  StyleBox["lhs\[Rule]rhs", "MR"],
  "."
}], "Notes",
  CellTags->"AllStringReplace"],

Cell[TextData[{
  " ",
  StyleBox["w", "MR"],
  " can also be a list of words."
}], "Notes",
  CellTags->"AllStringReplace"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordQ",
    ButtonData:>"WordQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AllStringReplace"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AllStringReplace"],

Cell["All possible single substitutions are performed.", "ExampleText",
  CellTags->"AllStringReplace"],

Cell[CellGroupData[{

Cell["AllStringReplace[{{aa,c},{ab,d}}][aab]", "Input",
  CellLabel->"In[189]:=",
  CellTags->"AllStringReplace"],

Cell[BoxData[
    \({"ad", "cb"}\)], "Output",
  CellLabel->"Out[189]=",
  CellTags->"AllStringReplace"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AllStringReplace[{aa \[Rule] c, ab \[Rule] d}]\)[aab]\)], "Input",
  CellLabel->"In[24]:=",
  CellTags->"AllStringReplace"],

Cell[BoxData[
    \({"ad", "cb"}\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->"AllStringReplace"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AllStringReplace[a \[Rule] \[Epsilon]]\)[ababa]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"AllStringReplace"],

Cell[BoxData[
    \({"abab", "abba", "baba"}\)], "Output",
  CellLabel->"Out[7]=",
  CellTags->"AllStringReplace"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AllTimes", "ObjectName",
  CellTags->"AllTimes"],

Cell["Type: function", "Highlight",
  CellTags->"AllTimes"],

Cell[TextData[{
  StyleBox["AllTimes[L1,L2]", "MR"],
  "  computes all products between elements in ",
  StyleBox["L1", "MR"],
  " and ",
  StyleBox["L2", "MR"],
  " using ",
  StyleBox["NonCommutativeMultiply", "MR"],
  "."
}], "Usage",
  CellTags->"AllTimes"],

Cell["Repetitions in the output are not eliminated.", "Notes",
  CellTags->"AllTimes"],

Cell[TextData[{
  "See also ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AllTimes"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AllTimes"],

Cell["Transformations use NonCommutativeMultiply as composition.", \
"ExampleText",
  CellTags->"AllTimes"],

Cell[CellGroupData[{

Cell["AllTimes[ {T[2,3,1],T[2,1,3]}, {T[2,3,1],T[2,1,3]}]", "Input",
  CellLabel->"In[36]:=",
  CellTags->"AllTimes"],

Cell[BoxData[
    \({T[3, 1, 2], T[1, 3, 2], T[3, 2, 1], T[1, 2, 3]}\)], "Output",
  CellLabel->"Out[36]=",
  CellTags->"AllTimes"]
}, Open  ]],

Cell["\<\
Another application will generate the whole symmetric group on 3 \
letters.\
\>", "ExampleText",
  CellTags->"AllTimes"],

Cell[CellGroupData[{

Cell["\<\
AllTimes[ %, {T[2,3,1],T[2,1,3]}]
% // Union\
\>", "Input",
  CellLabel->"In[37]:=",
  CellTags->"AllTimes"],

Cell[BoxData[
    \({T[1, 2, 3], T[3, 2, 1], T[2, 1, 3], T[2, 3, 1], T[1, 3, 2], 
      T[3, 1, 2], T[2, 3, 1], T[2, 1, 3]}\)], "Output",
  CellLabel->"Out[37]=",
  CellTags->"AllTimes"],

Cell[BoxData[
    \({T[1, 2, 3], T[1, 3, 2], T[2, 1, 3], T[2, 3, 1], T[3, 1, 2], 
      T[3, 2, 1]}\)], "Output",
  CellLabel->"Out[38]=",
  CellTags->"AllTimes"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AlternatingGroupSG", "ObjectName",
  CellTags->"AlternatingGroupSG"],

Cell[TextData[{
  StyleBox["AlternatingGroupSG[n]", "MR"],
  "  returns the alternating group on ",
  StyleBox["n", "MR"],
  " elements. The group is returned as a semigroup object. "
}], "Usage",
  CellTags->"AlternatingGroupSG"],

Cell[TextData[{
  "Since the alternating group has ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)/2\)]],
  " elements, this can only be used for small ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Notes",
  CellTags->"AlternatingGroupSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["SymmetricGroupSG",
    ButtonData:>"SymmetricGroupSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AlternatingGroupSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AlternatingGroupSG"],

Cell["The alternating group on 4 elements. ", "ExampleText",
  CellTags->"AlternatingGroupSG"],

Cell[CellGroupData[{

Cell["\<\
AlternatingGroupSG[4]
Signature /@ ToList[%]\
\>", "Input",
  CellLabel->"In[47]:=",
  CellTags->"AlternatingGroupSG"],

Cell[BoxData[
    \(SG[T[1, 2, 3, 4], T[1, 3, 4, 2], T[1, 4, 2, 3], T[2, 1, 4, 3], 
      T[2, 3, 1, 4], T[2, 4, 3, 1], T[3, 1, 2, 4], T[3, 2, 4, 1], 
      T[3, 4, 1, 2], T[4, 1, 3, 2], T[4, 2, 1, 3], T[4, 3, 2, 1]]\)], "Output",\

  CellLabel->"Out[47]=",
  CellTags->"AlternatingGroupSG"],

Cell[BoxData[
    \({1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->"AlternatingGroupSG"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AnalyzeOrbit", "ObjectName",
  CellTags->"AnalyzeOrbit"],

Cell["Type: function", "Highlight",
  CellTags->"AnalyzeOrbit"],

Cell[TextData[{
  StyleBox["AnalyzeOrbit[f,x]", "MR"],
  "  returns ",
  StyleBox["{t,p}", "MR"],
  " where ",
  StyleBox["t", "MR"],
  " is the length of the transient part of the orbit of point ",
  StyleBox["x", "MR"],
  " under map ",
  StyleBox["f", "MR"],
  ", and ",
  StyleBox["p", "MR"],
  " is the length of the cyclic part.  Option  b is the entry point of the \
transient part on the cycle. Computation is memoryless. "
}], "Usage",
  CellTags->"AnalyzeOrbit"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Cycle", "\[Rule]", "None", \(False, True\)},
          {"Periodic", "\[Rule]", "False", "True"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"AnalyzeOrbit"],

Cell[TextData[{
  "Option ",
  StyleBox["Cycle->True", "MR"],
  " causes the limit cycle to be displayed, starting with the entry point, ",
  StyleBox["Cycle->False", "MR"],
  " displays only the entry point."
}], "Notes",
  CellTags->"AnalyzeOrbit"],

Cell[TextData[{
  "Option ",
  StyleBox["Periodic->True", "MR"],
  " does not affect the output, but improves speed for periodic orbits. "
}], "Notes",
  CellTags->"AnalyzeOrbit"],

Cell[TextData[{
  "If ",
  StyleBox["ff[x] = f[f[x]]", "MR"],
  " is slow to compute by composition, ",
  StyleBox["ff", "MR"],
  " can be supplied as a third argument: ",
  StyleBox["AnalyzeOrbit[f,a,ff]", "MR"],
  ". "
}], "Notes",
  CellTags->"AnalyzeOrbit"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrbitCA",
    ButtonData:>"OrbitCA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CA",
    ButtonData:>"CA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AnalyzeOrbit"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AnalyzeOrbit"],

Cell["A simple map on modular numbers. ", "ExampleText",
  CellTags->"AnalyzeOrbit"],

Cell["f[x_] := Mod[x^2,11]", "Input",
  CellLabel->"In[58]:=",
  CellTags->"AnalyzeOrbit"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnalyzeOrbit[f, 1]\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->"AnalyzeOrbit"],

Cell[BoxData[
    \({0, 1}\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnalyzeOrbit[f, 3]\)], "Input",
  CellLabel->"In[67]:=",
  CellTags->"AnalyzeOrbit"],

Cell[BoxData[
    \({0, 4}\)], "Output",
  CellLabel->"Out[67]=",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnalyzeOrbit[f, 3, Cycle \[Rule] True]\)], "Input",
  CellLabel->"In[66]:=",
  CellTags->"AnalyzeOrbit"],

Cell[BoxData[
    \({0, 4, {3, 9, 4, 5}}\)], "Output",
  CellLabel->"Out[66]=",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AnalyzeOrbit[f, 3, Cycle \[Rule] False]\)], "Input",
  CellLabel->"In[69]:=",
  CellTags->"AnalyzeOrbit"],

Cell[BoxData[
    \({0, 4, 3}\)], "Output",
  CellLabel->"Out[69]=",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],

Cell["\<\
The memoryless approach works well for larger objects such as \
configurations of cellular automata.\
\>", "ExampleText",
  CellTags->"AnalyzeOrbit"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X = \ SeedConfiguration[\ {1}, 19];\)\), "\n", 
    \(GlobalMapCA[f, CA[90]]\), "\n", 
    \(AnalyzeOrbit[\ f, \ X\ ]\)}], "Input",
  CellLabel->"In[113]:=",
  CellTags->"AnalyzeOrbit"],

Cell[BoxData[
    \({2, 12}\)], "Output",
  CellLabel->"Out[115]=",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],

Cell[BoxData[
    \(EvolutionCA[CA[90], X, 550, MultiCol \[Rule] True, 
      NRows \[Rule] 100]\)], "Input",
  CellLabel->"In[111]:=",
  CellTags->"AnalyzeOrbit"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AperiodicQSG", "ObjectName",
  CellTags->"AperiodicQSG"],

Cell["Type: function", "Highlight",
  CellTags->"AperiodicQSG"],

Cell[TextData[{
  StyleBox["AperiodicQSG[S]", "MR"],
  "  determines whether semigroup ",
  StyleBox["S", "MR"],
  " is aperiodic. "
}], "Usage",
  CellTags->"AperiodicQSG"],

Cell[TextData[{
  "Also allows as input a list or sequence of generators for ",
  StyleBox["S", "MR"],
  "."
}], "Notes",
  CellTags->"AperiodicQSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQT",
    ButtonData:>"AperiodicQT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AperiodicSG",
    ButtonData:>"AperiodicSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AperiodicQSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AperiodicQSG"],

Cell["\<\
An aperiodic transformation semigroup with lots of constants.\
\>", \
"ExampleText",
  CellTags->"AperiodicQSG"],

Cell[BoxData[
    \(\(S\  = \ 
        SG[T[1, 1, 1, 1, 1, 1, 1, 1], T[1, 4, 6, 8, 6, 8, 4, 1], 
          T[1, 8, 8, 1, 8, 1, 8, 1], T[2, 2, 2, 2, 2, 2, 2, 2], 
          T[2, 3, 5, 7, 5, 7, 3, 2], T[2, 7, 7, 2, 7, 2, 7, 2], 
          T[3, 3, 3, 3, 3, 3, 3, 3], T[3, 5, 5, 3, 5, 3, 5, 3], 
          T[4, 4, 4, 4, 4, 4, 4, 4], T[4, 6, 6, 4, 6, 4, 6, 4], 
          T[5, 5, 5, 5, 5, 5, 5, 5], T[6, 6, 6, 6, 6, 6, 6, 6], 
          T[7, 7, 7, 7, 7, 7, 7, 7], T[8, 8, 8, 8, 8, 8, 8, 8]];\)\)], "Input",\

  CellLabel->"In[129]:=",
  CellTags->"AperiodicQSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AperiodicQSG[S]\)], "Input",
  CellLabel->"In[130]:=",
  CellTags->"AperiodicQSG"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[130]=",
  CellTags->"AperiodicQSG"]
}, Open  ]],

Cell["But the symmetric group fails to be aperiodic.", "ExampleText",
  CellTags->"AperiodicQSG"],

Cell[CellGroupData[{

Cell["AperiodicQSG[{T[2,3,4,1],T[2,1,3,4]}]", "Input",
  CellLabel->"In[132]:=",
  CellTags->"AperiodicQSG"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[132]=",
  CellTags->"AperiodicQSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AperiodicQT", "ObjectName",
  CellTags->"AperiodicQT"],

Cell["Type: function", "Highlight",
  CellTags->"AperiodicQT"],

Cell[TextData[{
  StyleBox["AperiodicQT[x]", "MR"],
  "  determines whether transformation ",
  StyleBox["x", "MR"],
  " is aperiodic."
}], "Usage",
  CellTags->"AperiodicQT"],

Cell[TextData[{
  "Tests whether there exists ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(n + 1\) = \ x\^n\)]],
  "."
}], "Notes",
  CellTags->"AperiodicQT"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQSG",
    ButtonData:>"AperiodicQSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AperiodicSG",
    ButtonData:>"AperiodicSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AperiodicQT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AperiodicQT"],

Cell["Cyclic shifts fail to be aperiodic.", "ExampleText",
  CellTags->"AperiodicQT"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(LShiftT[5]\), "\n", 
    \(AperiodicQT[%]\)}], "Input",
  CellLabel->"In[135]:=",
  CellTags->"AperiodicQT"],

Cell[BoxData[
    \(T[2, 3, 4, 5, 1]\)], "Output",
  CellLabel->"Out[135]=",
  CellTags->"AperiodicQT"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[136]=",
  CellTags->"AperiodicQT"]
}, Open  ]],

Cell["But the predecessor transformation is aperiodic.", "ExampleText",
  CellTags->"AperiodicQT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AperiodicQT[T[1, 1, 2, 3, 4, 5]]\)], "Input",
  CellLabel->"In[140]:=",
  CellTags->"AperiodicQT"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[140]=",
  CellTags->"AperiodicQT"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AperiodicSG", "ObjectName",
  CellTags->"AperiodicSG"],

Cell["Type: function", "Highlight",
  CellTags->"AperiodicSG"],

Cell[TextData[{
  StyleBox["AperiodicSG[S]", "MR"],
  "  returns the aperiodic elements of semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"AperiodicSG"],

Cell[TextData[{
  "A transformation is aperiodic if ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(n + 1\) = x\^n\)]],
  " for some ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". "
}], "Notes",
  CellTags->"AperiodicSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQSG",
    ButtonData:>"AperiodicQSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AperiodicQT",
    ButtonData:>"AperiodicQT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AperiodicSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AperiodicSG"],

Cell["\<\
The full transformation semigroup on 3 elements contains 16 \
aperiodic elements. \
\>", "ExampleText",
  CellTags->"AperiodicSG"],

Cell[BoxData[
    \(\(S\  = \ TransformationSG[3];\)\)], "Input",
  CellLabel->"In[149]:=",
  CellTags->"AperiodicSG"],

Cell[CellGroupData[{

Cell["\<\
AperiodicSG[S]
% // Length\
\>", "Input",
  CellLabel->"In[151]:=",
  CellTags->"AperiodicSG"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 2], T[1, 1, 3], T[1, 2, 1], T[1, 2, 2], 
      T[1, 2, 3], T[1, 3, 1], T[1, 3, 3], T[2, 2, 1], T[2, 2, 2], T[2, 2, 3], 
      T[2, 3, 3], T[3, 1, 3], T[3, 2, 2], T[3, 2, 3], T[3, 3, 3]}\)], "Output",\

  CellLabel->"Out[151]=",
  CellTags->"AperiodicSG"],

Cell[BoxData[
    \(16\)], "Output",
  CellLabel->"Out[152]=",
  CellTags->"AperiodicSG"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["AssignFunction", "ObjectName",
  CellTags->"AssignFunction"],

Cell["Type: function", "Highlight",
  CellTags->"AssignFunction"],

Cell[TextData[{
  StyleBox["AssignFunction[h,P]", "MR"],
  "  defines h to be function with graph P, where P is a list of pairs, the \
graph of the function. "
}], "Usage",
  CellTags->"AssignFunction"],

Cell[TextData[{
  " ",
  StyleBox["AssignFunction[h,D,C]", "MR"],
  " defines the function that maps the i-th element of the domain list D to \
the i-th element of the codomain list C (D and C must have the same length). \
"
}], "Notes",
  CellTags->"AssignFunction"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Opts", "\[Rule]", \({}\), "-"},
          {"Kary", "\[Rule]", "False", "True"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"AssignFunction"],

Cell[TextData[{
  "Option ",
  StyleBox["Opts->attributes", "MR"],
  " assigns the new function the given attributes. "
}], "Notes",
  CellTags->"AssignFunction"],

Cell[TextData[{
  "Option ",
  StyleBox["Kary->True", "MR"],
  " makes the new function n-ary, assumes domain elements are lists."
}], "Notes",
  CellTags->"AssignFunction"],

Cell[TextData[{
  "Option ",
  StyleBox["Kary->True", "MR"],
  " makes the new function n-ary, assumes domain elements are lists."
}], "Notes",
  CellTags->"AssignFunction"],

Cell[TextData[{
  "See also  ",
  ButtonBox["Pairs",
    ButtonData:>"Pairs",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"AssignFunction"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"AssignFunction"],

Cell["A simple function on a domain of size 3.", "ExampleText",
  CellTags->"AssignFunction"],

Cell[CellGroupData[{

Cell["\<\
AssignFunction[ f, {1,2,3}, {a,b,c} ]
f[2]\
\>", "Input",
  CellLabel->"In[41]:=",
  CellTags->"AssignFunction"],

Cell[BoxData[
    \(b\)], "Output",
  CellLabel->"Out[42]=",
  CellTags->"AssignFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(AssignFunction[g, {{1, a}, {2, b}, {3, c}}, 
      Opts \[Rule] Listable]\), "\n", 
    \(g[{1, 2, 3}]\)}], "Input",
  CellLabel->"In[143]:=",
  CellTags->"AssignFunction"],

Cell[BoxData[
    \({a, b, c}\)], "Output",
  CellLabel->"Out[144]=",
  CellTags->"AssignFunction"]
}, Open  ]],

Cell["\<\
K-ary functions can be defined by handing over lists of arguments. \
\
\>", "ExampleText",
  CellTags->"AssignFunction"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(A\  = \ CartesianProduct[2, 2]\), "\n", 
    \(B\  = \ Range[4]\), "\n", 
    \(AssignFunction[\ h, \ A, B, \ Kary \[Rule] True\ ]\)}], "Input",
  CellLabel->"In[145]:=",
  CellTags->"AssignFunction"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {2, 1}, {2, 2}}\)], "Output",
  CellLabel->"Out[145]=",
  CellTags->"AssignFunction"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[146]=",
  CellTags->"AssignFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(?? h\)], "Input",
  CellLabel->"In[148]:=",
  CellTags->"AssignFunction"],

Cell["Global`h", "Print",
  CellTags->"AssignFunction"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(h[1, 1] = 1\)},
                {" "},
                {\(h[1, 2] = 2\)},
                {" "},
                {\(h[2, 1] = 3\)},
                {" "},
                {\(h[2, 2] = 4\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "h"],
      Editable->False]], "Print",
  CellTags->"AssignFunction"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BlocksToDClass", "ObjectName",
  CellTags->"BlocksToDClass"],

Cell["Type: function", "Highlight",
  CellTags->"BlocksToDClass"],

Cell[TextData[{
  StyleBox["BlocksToDClass[db,S]", "MR"],
  "  converts a D-class in semigroup ",
  StyleBox["S", "MR"],
  " from block representation to multiplier representation."
}], "Usage",
  CellTags->"BlocksToDClass"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"BlocksToDClass"],

Cell[TextData[{
  "The input is a matrix of the form  ",
  Cell[BoxData[
      \(TraditionalForm\`\((H\_\(i\[InvisibleComma]j\))\)\)]],
  "  where each H-class ",
  Cell[BoxData[
      \(TraditionalForm\`H\_\(i\[InvisibleComma]j\)\)]],
  " is given as a list of transformations. The output is of the form ",
  StyleBox["DC[L,R,A]. ", "MR"]
}], "Notes",
  CellTags->"BlocksToDClass"],

Cell[TextData[{
  "The dimensions of the tensor can be determined with ",
  StyleBox["DClassDimensions", "MR"],
  "."
}], "Notes",
  CellTags->"BlocksToDClass"],

Cell[TextData[{
  "See also ",
  ButtonBox["DClassToBlocks",
    ButtonData:>"DClassToBlocks",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DC",
    ButtonData:>"DC",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"BlocksToDClass"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BlocksToDClass"],

Cell["\<\
A small D-class represented by a matrix of H-classes, and the \
corresponding representation in standard form.\
\>", "ExampleText",
  CellTags->"BlocksToDClass"],

Cell[BoxData[
    \(\(d\  = \ {{{T[1, 4, 4, 4]}, {T[2, 4, 4, 4]}, {T[3, 4, 4, 4]}}, {{T[4, 
                4, 1, 4]}, {T[4, 4, 2, 4]}, {T[4, 4, 3, 4]}}, {{T[4, 1, 4, 
                4]}, {T[4, 2, 4, 4]}, {T[4, 3, 4, 4]}}};\)\)], "Input",
  CellLabel->"In[109]:=",
  CellTags->"BlocksToDClass"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[d]\)], "Input",
  CellLabel->"In[110]:=",
  CellTags->"BlocksToDClass"],

Cell[BoxData[
    \({3, 3, 1}\)], "Output",
  CellLabel->"Out[110]=",
  CellTags->"BlocksToDClass"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BlocksToDClass[d]\)], "Input",
  CellLabel->"In[111]:=",
  CellTags->"BlocksToDClass"],

Cell[BoxData[
    \(DC[{T[1, 4, 4, 4], T[4, 4, 1, 4], T[4, 1, 4, 4]}, {T[1, 4, 4, 4], 
        T[2, 4, 4, 4], T[3, 4, 4, 4]}, {T[1, 4, 4, 4]}]\)], "Output",
  CellLabel->"Out[111]=",
  CellTags->"BlocksToDClass"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanComplement", "ObjectName",
  CellTags->"BooleanComplement"],

Cell["Type: function", "Highlight",
  CellTags->"BooleanComplement"],

Cell[TextData[{
  StyleBox["BooleanComplement[M1,M2]", "MR"],
  "  computes the Boolean difference (pointwise) of two Boolean matrices ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  ", corresponding to relational complement. Also works with a single matrix. \
"
}], "Usage",
  CellTags->"BooleanComplement"],

Cell["\<\
Note that for  efficiency reasons Boolean matrices are implemented \
using 0/1-integer matrices. \
\>", "Notes",
  CellTags->"BooleanComplement"],

Cell[TextData[{
  "See ",
  ButtonBox["RelationToMatrix",
    ButtonData:>"RelationToMatrix",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanIntersection",
    ButtonData:>"BooleanIntersection",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanUnion",
    ButtonData:>"BooleanUnion",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanComposition",
    ButtonData:>"BooleanComposition",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanConverse",
    ButtonData:>"BooleanConverse",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanPower",
    ButtonData:>"BooleanPower",
    ButtonStyle->"AddOnsLink"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"BooleanComplement"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BooleanComplement"],

Cell["Two Boolean matrices, and their complement.", "ExampleText",
  CellTags->"BooleanComplement"],

Cell["\<\
M1 = {{1,1,1},{1,1,1},{1,1,1}};
M2 = {{0,1,1},{1,0,1},{1,1,0}};\
\>", "Input",
  CellLabel->"In[53]:=",
  CellTags->"BooleanComplement"],

Cell[CellGroupData[{

Cell["BooleanComplement[M1,M2]", "Input",
  CellLabel->"In[55]:=",
  CellTags->"BooleanComplement"],

Cell[BoxData[
    \({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"BooleanComplement"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanComplement[M1]", "Input",
  CellLabel->"In[56]:=",
  CellTags->"BooleanComplement"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[56]=",
  CellTags->"BooleanComplement"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanComposition", "ObjectName",
  CellTags->"BooleanComposition"],

Cell["Type: function", "Highlight",
  CellTags->"BooleanComposition"],

Cell[TextData[{
  StyleBox["BooleanComposition[M1,M2]", "MR"],
  "  computes the Boolean dot product of two Boolean matrices ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  ", corresponding to relational composition. "
}], "Usage",
  CellTags->"BooleanComposition"],

Cell["\<\
Note that for  efficiency reasons Boolean matrices are implemented \
using 0/1-integer matrices. \
\>", "Notes",
  CellTags->"BooleanComposition"],

Cell[TextData[{
  "See ",
  ButtonBox["RelationToMatrix",
    ButtonData:>"RelationToMatrix",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanIntersection",
    ButtonData:>"BooleanIntersection",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanComplement",
    ButtonData:>"BooleanComplement",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanUnion",
    ButtonData:>"BooleanUnion",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanConverse",
    ButtonData:>"BooleanConverse",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanPower",
    ButtonData:>"BooleanPower",
    ButtonStyle->"AddOnsLink"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"BooleanComposition"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BooleanComposition"],

Cell[TextData[{
  "The matrix representing the less-than relation on ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], 6}\)]],
  "."
}], "ExampleText",
  CellTags->"BooleanComposition"],

Cell[CellGroupData[{

Cell["L = RelationToMatrix[Less,Range[6]]", "Input",
  CellLabel->"In[74]:=",
  CellTags->"BooleanComposition"],

Cell[BoxData[
    \({{0, 1, 1, 1, 1, 1}, {0, 0, 1, 1, 1, 1}, {0, 0, 0, 1, 1, 1}, {0, 0, 0, 
        0, 1, 1}, {0, 0, 0, 0, 0, 1}, {0, 0, 0, 0, 0, 0}}\)], "Output",
  CellLabel->"Out[74]=",
  CellTags->"BooleanComposition"]
}, Open  ]],

Cell["\<\
Composing this matrix with itself produces the following matrices. \
\
\>", "ExampleText",
  CellTags->"BooleanComposition"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L2 = BooleanComposition[L, L];\)\), "\n", 
    \(L2\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[75]:=",
  CellTags->"BooleanComposition"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "1", "1", "1", "1"},
            {"0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[76]//MatrixForm=",
  CellTags->"BooleanComposition"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L5 = BooleanComposition[L, L, L, L, L];\)\), "\n", 
    \(L5\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[77]:=",
  CellTags->"BooleanComposition"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[78]//MatrixForm=",
  CellTags->"BooleanComposition"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanConverse", "ObjectName",
  CellTags->"BooleanConverse"],

Cell["Type: function", "Highlight",
  CellTags->"BooleanConverse"],

Cell[TextData[{
  StyleBox["BooleanConverse[M]", "MR"],
  "  computes the transpose of a Boolean matrix ",
  StyleBox["M", "MR"],
  ", corresponding to relational converse. "
}], "Usage",
  CellTags->"BooleanConverse"],

Cell[TextData[{
  "See ",
  ButtonBox["RelationToMatrix",
    ButtonData:>"RelationToMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"BooleanConverse"],

Cell["\<\
Note that for  efficiency reasons Boolean matrices are implemented \
using 0/1-integer matrices. \
\>", "Notes",
  CellTags->"BooleanConverse"],

Cell[TextData[{
  "See ",
  StyleBox["RelationToMatrix", "MR"],
  StyleBox[", ", "Text"],
  StyleBox["BooleanIntersection", "MR"],
  StyleBox[", ", "Text"],
  StyleBox["BooleanComplement", "MR"],
  StyleBox[", ", "Text"],
  StyleBox["BooleanComposition", "MR"],
  StyleBox[", ", "Text"],
  StyleBox["BooleanUnion", "MR"],
  StyleBox[", ", "Text"],
  StyleBox["BooleanPower", "MR"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"BooleanConverse"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BooleanConverse"],

Cell[TextData[{
  "The matrix representing the less-than relation on ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], 6}\)]],
  ", and its converse."
}], "ExampleText",
  CellTags->"BooleanConverse"],

Cell[CellGroupData[{

Cell["\<\
L = RelationToMatrix[Less,Range[6]];
L // MatrixForm\
\>", "Input",
  CellLabel->"In[79]:=",
  CellTags->"BooleanConverse"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1", "1", "1", "1", "1"},
            {"0", "0", "1", "1", "1", "1"},
            {"0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[80]//MatrixForm=",
  CellTags->"BooleanConverse"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanConverse[L] // MatrixForm", "Input",
  CellLabel->"In[81]:=",
  CellTags->"BooleanConverse"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "0"},
            {"1", "0", "0", "0", "0", "0"},
            {"1", "1", "0", "0", "0", "0"},
            {"1", "1", "1", "0", "0", "0"},
            {"1", "1", "1", "1", "0", "0"},
            {"1", "1", "1", "1", "1", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[81]//MatrixForm=",
  CellTags->"BooleanConverse"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanIntersection", "ObjectName",
  CellTags->"BooleanIntersection"],

Cell["Type: function", "Highlight",
  CellTags->"BooleanIntersection"],

Cell[TextData[{
  StyleBox["BooleanIntersection[M1,M2]", "MR"],
  "  computes the Boolean product (pointwise) of two Boolean matrices ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  ", corresponding to relational intersection. "
}], "Usage",
  CellTags->"BooleanIntersection"],

Cell["\<\
Note that for  efficiency reasons Boolean matrices are implemented \
using 0/1-integer matrices. \
\>", "Notes",
  CellTags->"BooleanIntersection"],

Cell[TextData[{
  "See ",
  ButtonBox["RelationToMatrix",
    ButtonData:>"RelationToMatrix",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanUnion",
    ButtonData:>"BooleanUnion",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanComplement",
    ButtonData:>"BooleanComplement",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanComposition",
    ButtonData:>"BooleanComposition",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanConverse",
    ButtonData:>"BooleanConverse",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanPower",
    ButtonData:>"BooleanPower",
    ButtonStyle->"AddOnsLink"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"BooleanIntersection"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BooleanIntersection"],

Cell["\<\
The intersection of less-than-equal and larger-than-equal is the \
identity. \
\>", "ExampleText",
  CellTags->"BooleanIntersection"],

Cell[CellGroupData[{

Cell["\<\
L1 = RelationToMatrix[LessEqual,Range[6]];
L1 // MatrixForm\
\>", "Input",
  CellLabel->"In[87]:=",
  CellTags->"BooleanIntersection"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1", "1"},
            {"0", "1", "1", "1", "1", "1"},
            {"0", "0", "1", "1", "1", "1"},
            {"0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[88]//MatrixForm=",
  CellTags->"BooleanIntersection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
L2 = RelationToMatrix[GreaterEqual,Range[6]];
L2 // MatrixForm\
\>", "Input",
  CellLabel->"In[89]:=",
  CellTags->"BooleanIntersection"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", "0"},
            {"1", "1", "0", "0", "0", "0"},
            {"1", "1", "1", "0", "0", "0"},
            {"1", "1", "1", "1", "0", "0"},
            {"1", "1", "1", "1", "1", "0"},
            {"1", "1", "1", "1", "1", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[90]//MatrixForm=",
  CellTags->"BooleanIntersection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanIntersection[L1,L2] // MatrixForm", "Input",
  CellLabel->"In[91]:=",
  CellTags->"BooleanIntersection"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0", "0"},
            {"0", "0", "1", "0", "0", "0"},
            {"0", "0", "0", "1", "0", "0"},
            {"0", "0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[91]//MatrixForm=",
  CellTags->"BooleanIntersection"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanPower", "ObjectName",
  CellTags->"BooleanPower"],

Cell["Type: function", "Highlight",
  CellTags->"BooleanPower"],

Cell[TextData[{
  StyleBox["BooleanPower[M,n]", "MR"],
  "  computes the ",
  StyleBox["n", "MR"],
  "-th power of the Boolean matrix ",
  StyleBox["M", "MR"],
  ", corresponding to relational iteration. "
}], "Usage",
  CellTags->"BooleanPower"],

Cell["\<\
Note that for  efficiency reasons Boolean matrices are implemented \
using 0/1-integer matrices. \
\>", "Notes",
  CellTags->"BooleanPower"],

Cell[TextData[{
  "See ",
  ButtonBox["RelationToMatrix",
    ButtonData:>"RelationToMatrix",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanIntersection",
    ButtonData:>"BooleanIntersection",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanComplement",
    ButtonData:>"BooleanComplement",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanComposition",
    ButtonData:>"BooleanComposition",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanConverse",
    ButtonData:>"BooleanConverse",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanUnion",
    ButtonData:>"BooleanUnion",
    ButtonStyle->"AddOnsLink"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"BooleanPower"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BooleanPower"],

Cell[TextData[{
  "The matrix representing the less-than relation on ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], 6}\)]],
  "."
}], "ExampleText",
  CellTags->"BooleanPower"],

Cell[CellGroupData[{

Cell["L = RelationToMatrix[Less,Range[6]]", "Input",
  CellLabel->"In[94]:=",
  CellTags->"BooleanPower"],

Cell[BoxData[
    \({{0, 1, 1, 1, 1, 1}, {0, 0, 1, 1, 1, 1}, {0, 0, 0, 1, 1, 1}, {0, 0, 0, 
        0, 1, 1}, {0, 0, 0, 0, 0, 1}, {0, 0, 0, 0, 0, 0}}\)], "Output",
  CellLabel->"Out[94]=",
  CellTags->"BooleanPower"]
}, Open  ]],

Cell["\<\
The 5th power of this matrix, only point 1 is related to point 6.\
\
\>", "ExampleText",
  CellTags->"BooleanPower"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L5 = BooleanPower[L, 5];\)\), "\n", 
    \(L5\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[95]:=",
  CellTags->"BooleanPower"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[96]//MatrixForm=",
  CellTags->"BooleanPower"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanUnion", "ObjectName",
  CellTags->"BooleanUnion"],

Cell["Type: function", "Highlight",
  CellTags->"BooleanUnion"],

Cell[TextData[{
  StyleBox["BooleanUnion[M1,M2]", "MR"],
  "  computes the Boolean sum (pointwise) of two Boolean matrices ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  ", corresponding to relational union."
}], "Usage",
  CellTags->"BooleanUnion"],

Cell["\<\
Note that for  efficiency reasons Boolean matrices are implemented \
using 0/1-integer matrices. \
\>", "Notes",
  CellTags->"BooleanUnion"],

Cell[TextData[{
  "See ",
  ButtonBox["RelationToMatrix",
    ButtonData:>"RelationToMatrix",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanIntersection",
    ButtonData:>"BooleanIntersection",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanComplement",
    ButtonData:>"BooleanComplement",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanComposition",
    ButtonData:>"BooleanComposition",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanConverse",
    ButtonData:>"BooleanConverse",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanPower",
    ButtonData:>"BooleanPower",
    ButtonStyle->"AddOnsLink"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"BooleanUnion"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"BooleanUnion"],

Cell["\<\
The union of less-than and larger-than is the complement of the \
identity. \
\>", "ExampleText",
  CellTags->"BooleanUnion"],

Cell[CellGroupData[{

Cell["\<\
L1 = RelationToMatrix[Less,Range[6]];
L1 // MatrixForm\
\>", "Input",
  CellLabel->"In[97]:=",
  CellTags->"BooleanUnion"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1", "1", "1", "1", "1"},
            {"0", "0", "1", "1", "1", "1"},
            {"0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[98]//MatrixForm=",
  CellTags->"BooleanUnion"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
L2 = RelationToMatrix[Greater,Range[6]];
L2 // MatrixForm\
\>", "Input",
  CellLabel->"In[99]:=",
  CellTags->"BooleanUnion"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "0"},
            {"1", "0", "0", "0", "0", "0"},
            {"1", "1", "0", "0", "0", "0"},
            {"1", "1", "1", "0", "0", "0"},
            {"1", "1", "1", "1", "0", "0"},
            {"1", "1", "1", "1", "1", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[100]//MatrixForm=",
  CellTags->"BooleanUnion"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BooleanUnion[L1,L2] // MatrixForm", "Input",
  CellLabel->"In[101]:=",
  CellTags->"BooleanUnion"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1", "1", "1", "1", "1"},
            {"1", "0", "1", "1", "1", "1"},
            {"1", "1", "0", "1", "1", "1"},
            {"1", "1", "1", "0", "1", "1"},
            {"1", "1", "1", "1", "0", "1"},
            {"1", "1", "1", "1", "1", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[101]//MatrixForm=",
  CellTags->"BooleanUnion"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CartesianProduct", "ObjectName",
  CellTags->"CartesianProduct"],

Cell["Type: function", "Highlight",
  CellTags->"CartesianProduct"],

Cell[TextData[{
  StyleBox["CartesianProduct[A,B]", "MR"],
  "  computes the Cartesian product of lists ",
  StyleBox["A", "MR"],
  StyleBox[" and ", "Text"],
  StyleBox["B", "MR"],
  "."
}], "Usage",
  CellTags->"CartesianProduct"],

Cell[TextData[{
  StyleBox["CartesianProduct", "MR"],
  " is polyadic."
}], "Notes",
  CellTags->"CartesianProduct"],

Cell[TextData[{
  StyleBox["CartesianProduct", "MR"],
  " returns a flat list of pairs (",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", Cell[""]}], TraditionalForm]]],
  "-tuples)."
}], "Notes",
  CellTags->"CartesianProduct"],

Cell[TextData[StyleBox["The length of the output list is the product of the \
lengths of all the input lists.", "Text"]], "Notes",
  CellTags->"CartesianProduct"],

Cell[TextData[{
  StyleBox["See also ", "Text"],
  ButtonBox["Pairs",
    ButtonData:>"Pairs",
    ButtonStyle->"AddOnsLink"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"CartesianProduct"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CartesianProduct"],

Cell["Some products. ", "ExampleText",
  CellTags->"CartesianProduct"],

Cell[CellGroupData[{

Cell["\<\
Clear[a,b,c,d]
CartesianProduct[{1,2,3},{a,b}]\
\>", "Input",
  CellLabel->"In[329]:=",
  CellTags->"CartesianProduct"],

Cell[BoxData[
    \({{1, a}, {1, b}, {2, a}, {2, b}, {3, a}, {3, b}}\)], "Output",
  CellLabel->"Out[330]=",
  CellTags->"CartesianProduct"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CartesianProduct[{1,2,3},{a,b},{c,d}]", "Input",
  CellLabel->"In[331]:=",
  CellTags->"CartesianProduct"],

Cell[BoxData[
    \({{1, a, c}, {1, a, d}, {1, b, c}, {1, b, d}, {2, a, c}, {2, a, d}, {2, 
        b, c}, {2, b, d}, {3, a, c}, {3, a, d}, {3, b, c}, {3, b, 
        d}}\)], "Output",
  CellLabel->"Out[331]=",
  CellTags->"CartesianProduct"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CartesianProduct[{1,2,3},{},{c,d}]", "Input",
  CellLabel->"In[332]:=",
  CellTags->"CartesianProduct"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[332]=",
  CellTags->"CartesianProduct"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CartesianProduct[]", "Input",
  CellLabel->"In[334]:=",
  CellTags->"CartesianProduct"],

Cell[BoxData[
    \({{}}\)], "Output",
  CellLabel->"Out[334]=",
  CellTags->"CartesianProduct"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CirculantGraph", "ObjectName",
  CellTags->"CirculantGraph"],

Cell["Type: function", "Highlight",
  CellTags->"CirculantGraph"],

Cell[TextData[{
  StyleBox["CirculantGraph[n,{d1,...,dr}]", "MR"],
  "  generates the circulant ",
  Cell[BoxData[
      \(TraditionalForm\`C(n; d\_1,  ... , d\_r)\)]],
  " in edge-list form."
}], "Usage",
  CellTags->"CirculantGraph"],

Cell[TextData[{
  "A circulant graphs can be construed as having vertex set modular numbers \
",
  Cell[BoxData[
      \(TraditionalForm\`{0, 1, \[Ellipsis], n - 1}\)]],
  " and edges  ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, x + d\_i\ mod\ n)\)\)]],
  ". "
}], "Notes",
  CellTags->"CirculantGraph"],

Cell[TextData[{
  "Circulant graphs are ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, r)\)\)]],
  "-regular."
}], "Notes",
  CellTags->"CirculantGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["PathGraph",
    ButtonData:>"PathGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"CirculantGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CirculantGraph"],

Cell["A circulant graph on 10 points.", "ExampleText",
  CellTags->"CirculantGraph"],

Cell[CellGroupData[{

Cell["g = CirculantGraph[10,{2,4}]", "Input",
  CellLabel->"In[175]:=",
  CellTags->"CirculantGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"10", ",", "20", ",", "1", ",", 
          TagBox[\(\[LeftSkeleton]1\[RightSkeleton]\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[175]=",
  CellTags->"CirculantGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[g]\)], "Input",
  CellLabel->"In[176]:=",
  CellTags->"CirculantGraph"],

Cell[BoxData[
    \({{1, 3, 5, 7, 9}, {2, 4, 6, 8, 10}}\)], "Output",
  CellLabel->"Out[176]=",
  CellTags->"CirculantGraph"]
}, Open  ]],

Cell["A transitive circulant graph on 10 points.", "ExampleText",
  CellTags->"CirculantGraph"],

Cell[CellGroupData[{

Cell["g = CirculantGraph[10,{2,3}]", "Input",
  CellLabel->"In[180]:=",
  CellTags->"CirculantGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"10", ",", "20", ",", "1", ",", 
          TagBox[\(\[LeftSkeleton]1\[RightSkeleton]\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[180]=",
  CellTags->"CirculantGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[g]\)], "Input",
  CellLabel->"In[181]:=",
  CellTags->"CirculantGraph"],

Cell[BoxData[
    \({{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}}\)], "Output",
  CellLabel->"Out[181]=",
  CellTags->"CirculantGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClosureSearch", "ObjectName",
  CellTags->"ClosureSearch"],

Cell["Type: function", "Highlight",
  CellTags->"ClosureSearch"],

Cell[TextData[{
  StyleBox["ClosureSearch[L,targ,ff]", "MR"],
  "  determines whether ",
  StyleBox["targ", "MR"],
  " occurs in the closure of list ",
  StyleBox["L", "MR"],
  " under the function ",
  StyleBox["ff", "MR"],
  "."
}], "Usage",
  CellTags->"ClosureSearch"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"SetClosure", "\[Rule]", "False", "-"},
          {"ClosureBound", "\[RuleDelayed]", "$closureSearchBound", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ClosureSearch"],

Cell[TextData[{
  "Input ",
  StyleBox["ff", "MR"],
  " can also be a sequence of functions."
}], "Notes",
  CellTags->"ClosureSearch"],

Cell[TextData[{
  "Option  ",
  StyleBox["SetClosure->True", "MR"],
  "  causes the intermediate results to be  properly flattened so that ",
  StyleBox["ff", "MR"],
  " can be of type   ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\ \[LongRightArrow]\ \(list(\[Tau])\)\)]],
  ". "
}], "Notes",
  CellTags->"ClosureSearch"],

Cell["\<\
If the target is found, the search is immediately truncated, so \
that computation of the full closure can sometimes be avoided.\
\>", "Notes",
  CellTags->"ClosureSearch"],

Cell[TextData[{
  "See also ",
  ButtonBox["Closure",
    ButtonData:>"Closure",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ClosureBound",
    ButtonData:>"ClosureBound",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["TransitiveClosure",
    ButtonData:>"TransitiveClosure",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"ClosureSearch"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ClosureSearch"],

Cell["Combining shift with shuffle produces all permutations.", "ExampleText",
  CellTags->"ClosureSearch"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(shuffle[L_List] := Flatten[Thread[Partition[L, 2]]];\)\), "\n", 
    \(shuffle[Range[8]]\)}], "Input",
  CellLabel->"In[357]:=",
  CellTags->"ClosureSearch"],

Cell[BoxData[
    \({1, 3, 5, 7, 2, 4, 6, 8}\)], "Output",
  CellLabel->"Out[358]=",
  CellTags->"ClosureSearch"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[Closure[{Range[6]}, RotateLeft, shuffle]]\)], "Input",
  CellLabel->"In[359]:=",
  CellTags->"ClosureSearch"],

Cell[BoxData[
    \(720\)], "Output",
  CellLabel->"Out[359]=",
  CellTags->"ClosureSearch"]
}, Open  ]],

Cell["The bound has to be large enough.", "ExampleText",
  CellTags->"ClosureSearch"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ClosureSearch[{Range[6]}, {6, 5, 4, 3, 2, 1}, RotateLeft, shuffle, 
      ClosureBound \[Rule] 1000]\)], "Input",
  CellLabel->"In[360]:=",
  CellTags->"ClosureSearch"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[360]=",
  CellTags->"ClosureSearch"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ClosureSearch[{Range[6]}, {1, 1, 1, 1, 1, 1}, RotateLeft, shuffle, 
      ClosureBound \[Rule] 1000]\)], "Input",
  CellLabel->"In[361]:=",
  CellTags->"ClosureSearch"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[361]=",
  CellTags->"ClosureSearch"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Closure", "ObjectName",
  CellTags->"Closure"],

Cell["Type: function", "Highlight",
  CellTags->"Closure"],

Cell[TextData[{
  StyleBox["Closure[L,ff]", "MR"],
  "  computes the closure of list L under the function ff  "
}], "Usage",
  CellTags->"Closure"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"SetClosure", "\[Rule]", "False", "-"},
          {"ClosureBound", "\[Rule]", "$closureBound", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"Closure"],

Cell[TextData[{
  "Input ",
  StyleBox["ff", "MR"],
  " can also be a sequence of functions."
}], "Notes",
  CellTags->"Closure"],

Cell[TextData[{
  "Option  ",
  StyleBox["SetClosure->True", "MR"],
  "  causes the intermediate results to be  properly flattened so that ",
  StyleBox["ff", "MR"],
  " can be of type   ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\ \[LongRightArrow]\ \(list(\[Tau])\)\)]],
  ". "
}], "Notes",
  CellTags->"Closure"],

Cell[TextData[{
  "See also ",
  ButtonBox["ClosureSearch",
    ButtonData:>"ClosureSearch",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ClosureBound",
    ButtonData:>"ClosureBound",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["TransitiveClosure",
    ButtonData:>"TransitiveClosure",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"Closure"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Closure"],

Cell["All possible cyclic shifts of a list.", "ExampleText",
  CellTags->"Closure"],

Cell[CellGroupData[{

Cell["Closure[ { Range[4] }, RotateLeft ]", "Input",
  CellLabel->"In[344]:=",
  CellTags->"Closure"],

Cell[BoxData[
    \({{1, 2, 3, 4}, {2, 3, 4, 1}, {3, 4, 1, 2}, {4, 1, 2, 3}}\)], "Output",
  CellLabel->"Out[344]=",
  CellTags->"Closure"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Closure[ {{1,2,1,2}}, RotateLeft ]", "Input",
  CellLabel->"In[345]:=",
  CellTags->"Closure"],

Cell[BoxData[
    \({{1, 2, 1, 2}, {2, 1, 2, 1}}\)], "Output",
  CellLabel->"Out[345]=",
  CellTags->"Closure"]
}, Open  ]],

Cell["Combining shift with shuffle produces all permutations.", "ExampleText",
  CellTags->"Closure"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(shuffle[L_List] := Flatten[Thread[Partition[L, 2]]];\)\), "\n", 
    \(shuffle[Range[8]]\)}], "Input",
  CellLabel->"In[346]:=",
  CellTags->"Closure"],

Cell[BoxData[
    \({1, 3, 5, 7, 2, 4, 6, 8}\)], "Output",
  CellLabel->"Out[347]=",
  CellTags->"Closure"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Closure[ { Range[4] }, RotateLeft, shuffle ]", "Input",
  CellLabel->"In[350]:=",
  CellTags->"Closure"],

Cell[BoxData[
    \({{1, 2, 3, 4}, {1, 2, 4, 3}, {1, 3, 2, 4}, {1, 3, 4, 2}, {1, 4, 2, 
        3}, {1, 4, 3, 2}, {2, 1, 3, 4}, {2, 1, 4, 3}, {2, 3, 1, 4}, {2, 3, 4, 
        1}, {2, 4, 1, 3}, {2, 4, 3, 1}, {3, 1, 2, 4}, {3, 1, 4, 2}, {3, 2, 1, 
        4}, {3, 2, 4, 1}, {3, 4, 1, 2}, {3, 4, 2, 1}, {4, 1, 2, 3}, {4, 1, 3, 
        2}, {4, 2, 1, 3}, {4, 2, 3, 1}, {4, 3, 1, 2}, {4, 3, 2, 
        1}}\)], "Output",
  CellLabel->"Out[350]=",
  CellTags->"Closure"]
}, Open  ]],

Cell["\<\
Sometimes the return type of the operation is naturally a list of \
objects. Here is the operation \"follow all edges in a cirulant \
graph\".\
\>", "ExampleText",
  CellTags->"Closure"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Closure[{0}, Mod[{#1 + 2, #1 + 4}, 20] &, 
      SetClosure \[Rule] True]\)], "Input",
  CellLabel->"In[362]:=",
  CellTags->"Closure"],

Cell[BoxData[
    \({0, 2, 4, 6, 8, 10, 12, 14, 16, 18}\)], "Output",
  CellLabel->"Out[362]=",
  CellTags->"Closure"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CollapseT", "ObjectName",
  CellTags->"CollapseT"],

Cell["Type: function", "Highlight",
  CellTags->"CollapseT"],

Cell[TextData[{
  StyleBox["CollapseT[t]", "MR"],
  "  produces the image transformation associated with transformation ",
  StyleBox["t", "MR"],
  ". "
}], "Usage",
  CellTags->"CollapseT"],

Cell[TextData[{
  "If ",
  StyleBox["t", "MR"],
  " lies in a group, ",
  StyleBox["CollapseT[t]", "MR"],
  " produces a permutation."
}], "Notes",
  CellTags->"CollapseT"],

Cell[TextData[{
  "All permutations are fixed points of  ",
  StyleBox["CollapseT", "MR"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"CollapseT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ImageT",
    ButtonData:>"ImageT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RankT",
    ButtonData:>"RankT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["KernelT",
    ButtonData:>"KernelT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["KernelImageToT",
    ButtonData:>"KernelImageToT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"CollapseT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CollapseT"],

Cell["A transformation and its collapse.", "ExampleText",
  CellTags->"CollapseT"],

Cell[CellGroupData[{

Cell["t = T[2,3,4,1,1]", "Input",
  CellLabel->"In[453]:=",
  CellTags->"CollapseT"],

Cell[BoxData[
    \(T[2, 3, 4, 1, 1]\)], "Output",
  CellLabel->"Out[453]=",
  CellTags->"CollapseT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ImageT[t]\), "\n", 
    \(KernelT[t]\)}], "Input",
  CellLabel->"In[457]:=",
  CellTags->"CollapseT"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[457]=",
  CellTags->"CollapseT"],

Cell[BoxData[
    \({{4, 5}, {1}, {2}, {3}}\)], "Output",
  CellLabel->"Out[458]=",
  CellTags->"CollapseT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CollapseT[t]\)], "Input",
  CellLabel->"In[454]:=",
  CellTags->"CollapseT"],

Cell[BoxData[
    \(T[2, 3, 4, 1]\)], "Output",
  CellLabel->"Out[454]=",
  CellTags->"CollapseT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ColorQ", "ObjectName",
  CellTags->"ColorQ"],

Cell["Type: function", "Highlight",
  CellTags->"ColorQ"],

Cell[TextData[{
  StyleBox["ColorQ[x]", "MR"],
  "  tests whether ",
  StyleBox["x", "MR"],
  " is a color specification."
}], "Usage",
  CellTags->"ColorQ"],

Cell["Used internally in some plotting commands. ", "Notes",
  CellTags->"ColorQ"],

Cell[TextData[{
  "See ",
  ButtonBox["GridLine",
    ButtonData:>"GridLine",
    ButtonStyle->"AddOnsLink"],
  StyleBox[",", "Text"],
  " ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ColorQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompCycles", "ObjectName",
  CellTags->"CompCycles"],

Cell["Type: function", "Highlight",
  CellTags->"CompCycles"],

Cell[TextData[{
  StyleBox["CompCycles[cyc1,cyc2]", "MR"],
  "  computes composition of two permutations in disjoint cycle \
representation, returns disjoint cycle representation."
}], "Usage",
  CellTags->"CompCycles"],

Cell[TextData[{
  "See ",
  ButtonBox["CycleDecompositionT",
    ButtonData:>"CycleDecompositionT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CycleToT",
    ButtonData:>"CycleToT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"CompCycles"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CompCycles"],

Cell["Composition in terms of cycles, and via transformations.", "ExampleText",
  CellTags->"CompCycles"],

Cell[BoxData[{
    \(\(t1 = {{1, 2, 3}, {4, 5}};\)\), "\n", 
    \(\(t2 = {{1, 2}};\)\)}], "Input",
  CellLabel->"In[446]:=",
  CellTags->"CompCycles"],

Cell[CellGroupData[{

Cell["CompCycles[t1,t2]", "Input",
  CellLabel->"In[448]:=",
  CellTags->"CompCycles"],

Cell[BoxData[
    \({{2, 3}, {4, 5}}\)], "Output",
  CellLabel->"Out[448]=",
  CellTags->"CompCycles"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CycleToT[t1, 5] ** CycleToT[t2, 5]\), "\n", 
    \(%\  // \ CycleDecompositionT\)}], "Input",
  CellLabel->"In[451]:=",
  CellTags->"CompCycles"],

Cell[BoxData[
    \(T[1, 3, 2, 5, 4]\)], "Output",
  CellLabel->"Out[451]=",
  CellTags->"CompCycles"],

Cell[BoxData[
    \({{2, 3}, {4, 5}}\)], "Output",
  CellLabel->"Out[4.1]=",
  CellTags->"CompCycles"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompCycles[{{1,2,3,4,5}},{{1,2,3,4,5}}]", "Input",
  CellLabel->"In[445]:=",
  CellTags->"CompCycles"],

Cell[BoxData[
    \({{1, 3, 5, 2, 4}}\)], "Output",
  CellLabel->"Out[445]=",
  CellTags->"CompCycles"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Concatenate", "ObjectName",
  CellTags->"Concatenate"],

Cell["Type: function", "Highlight",
  CellTags->"Concatenate"],

Cell[TextData[{
  StyleBox["Concatenate[u,v]", "MR"],
  "  concatenates words ",
  StyleBox["u", "MR"],
  " and ",
  StyleBox["v", "MR"],
  ". "
}], "Usage",
  CellTags->"Concatenate"],

Cell[TextData[{
  StyleBox["Concatenate", "MR"],
  " is polyadic. "
}], "Notes",
  CellTags->"Concatenate"],

Cell[TextData[{
  StyleBox["Concatenate", "MR"],
  "  behaves properly with respect to epsilon and symbols, but always returns \
a string."
}], "Notes",
  CellTags->"Concatenate"],

Cell[TextData[{
  StyleBox["Concatenate", "MR"],
  " distributes over lists of words."
}], "Notes",
  CellTags->"Concatenate"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordQ",
    ButtonData:>"WordQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Concatenate"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Concatenate"],

Cell["Concatenation of words.", "ExampleText",
  CellTags->"Concatenate"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Concatenate[aa, bb]\), "\n", 
    \(FullForm[%]\)}], "Input",
  CellLabel->"In[438]:=",
  CellTags->"Concatenate"],

Cell[BoxData[
    \("aabb"\)], "Output",
  CellLabel->"Out[438]=",
  CellTags->"Concatenate"],

Cell[BoxData[
    TagBox[
      StyleBox["\"\<aabb\>\"",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[439]//FullForm=",
  CellTags->"Concatenate"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Concatenate[aa, \[Epsilon]]\)], "Input",
  CellLabel->"In[440]:=",
  CellTags->"Concatenate"],

Cell[BoxData[
    \("aa"\)], "Output",
  CellLabel->"Out[440]=",
  CellTags->"Concatenate"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Concatenate[aa, {a, b, c}]\)], "Input",
  CellLabel->"In[441]:=",
  CellTags->"Concatenate"],

Cell[BoxData[
    \({"aaa", "aab", "aac"}\)], "Output",
  CellLabel->"Out[441]=",
  CellTags->"Concatenate"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Concatenate[{a, b, c}, {a, b, c}]\)], "Input",
  CellLabel->"In[4.1]:=",
  CellTags->"Concatenate"],

Cell[BoxData[
    \({"aa", "ab", "ac", "ba", "bb", "bc", "ca", "cb", "cc"}\)], "Output",
  CellLabel->"Out[4.1]=",
  CellTags->"Concatenate"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConsT", "ObjectName",
  CellTags->"ConsT"],

Cell["Type: function", "Highlight",
  CellTags->"ConsT"],

Cell[TextData[{
  StyleBox["ConsT[k,n]", "MR"],
  "  returns the constant transformation ",
  StyleBox["T[k,\[Ellipsis],k]", "MR"],
  " of length ",
  StyleBox["n", "MR"],
  "."
}], "Usage",
  CellTags->"ConsT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OneT",
    ButtonData:>"OneT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CycleToT",
    ButtonData:>"CycleToT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ConsT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ConsT"],

Cell["A constant transformation.", "ExampleText",
  CellTags->"ConsT"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ConsT[1, 5]\), "\n", 
    \(OrderT[%]\)}], "Input",
  CellLabel->"In[373]:=",
  CellTags->"ConsT"],

Cell[BoxData[
    \(T[1, 1, 1, 1, 1]\)], "Output",
  CellLabel->"Out[373]=",
  CellTags->"ConsT"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[374]=",
  CellTags->"ConsT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Curry", "ObjectName",
  CellTags->"Curry"],

Cell["Type: function", "Highlight",
  CellTags->"Curry"],

Cell[TextData[{
  StyleBox["Curry[f]", "MR"],
  "  curries a function ",
  StyleBox["f", "MR"],
  " of two variables."
}], "Usage",
  CellTags->"Curry"],

Cell[TextData[{
  "Thus ",
  StyleBox["Curry[f][y][x] = f[x,y]", "MR"],
  ". "
}], "Notes",
  CellTags->"Curry"],

Cell["\<\
This is useful on occasion when a function of two variables is to \
be used in postfix notation.\
\>", "Notes",
  CellTags->"Curry"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Curry"],

Cell["Using a functional in postfix notation.", "ExampleText",
  CellTags->"Curry"],

Cell[CellGroupData[{

Cell[BoxData[
    \({a, b, c}\  // \ \(Curry[Append]\)[0]\)], "Input",
  CellLabel->"In[372]:=",
  CellTags->"Curry"],

Cell[BoxData[
    \({a, b, c, 0}\)], "Output",
  CellLabel->"Out[372]=",
  CellTags->"Curry"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CycleDecompositionT", "ObjectName",
  CellTags->"CycleDecompositionT"],

Cell["Type: function", "Highlight",
  CellTags->"CycleDecompositionT"],

Cell[TextData[{
  StyleBox["CycleDecompositionT[t]", "MR"],
  "  returns the cycle decomposition of a permutation t. "
}], "Usage",
  CellTags->"CycleDecompositionT"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"CycleDecompositionT"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " causes fixed points to be displayed."
}], "Notes",
  CellTags->"CycleDecompositionT"],

Cell["\<\
No test is made whether the given transformation is in fact a \
permutation, for arbitrary transformations a list of some orbits is produced.\
\
\>", "Notes",
  CellTags->"CycleDecompositionT"],

Cell[TextData[{
  "See also ",
  ButtonBox["CycleToT",
    ButtonData:>"CycleToT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"CycleDecompositionT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CycleDecompositionT"],

Cell["A permutation and its cycle decomposition.", "ExampleText",
  CellTags->"CycleDecompositionT"],

Cell[CellGroupData[{

Cell["\<\
t = T[ 2, 3, 1, 5, 4, 6 ];
CycleDecompositionT[t]\
\>", "Input",
  CellLabel->"In[324]:=",
  CellTags->"CycleDecompositionT"],

Cell[BoxData[
    \({{1, 2, 3}, {4, 5}}\)], "Output",
  CellLabel->"Out[325]=",
  CellTags->"CycleDecompositionT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CycleDecompositionT[t, Full \[Rule] True]\)], "Input",
  CellLabel->"In[326]:=",
  CellTags->"CycleDecompositionT"],

Cell[BoxData[
    \({{1, 2, 3}, {4, 5}, {6}}\)], "Output",
  CellLabel->"Out[326]=",
  CellTags->"CycleDecompositionT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CycleToT", "ObjectName",
  CellTags->"CycleToT"],

Cell["Type: function", "Highlight",
  CellTags->"CycleToT"],

Cell[TextData[{
  StyleBox["CycleToT[cycles,n]", "MR"],
  "  converts a cycle decomposition to a permutation, given as a \
transformation."
}], "Usage",
  CellTags->"CycleToT"],

Cell["Fixed points are added automatically.", "Notes",
  CellTags->"CycleToT"],

Cell[TextData[{
  "See also ",
  ButtonBox["CycleDecompositionT",
    ButtonData:>"CycleDecompositionT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"CycleToT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CycleToT"],

Cell["A permutation with two cycles.", "ExampleText",
  CellTags->"CycleToT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(t = CycleToT[{{1, 2, 3}, {4, 5}}, 5]\)], "Input",
  CellLabel->"In[321]:=",
  CellTags->"CycleToT"],

Cell[BoxData[
    \(T[2, 3, 1, 5, 4]\)], "Output",
  CellLabel->"Out[321]=",
  CellTags->"CycleToT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(OrderT[t]\)], "Input",
  CellLabel->"In[322]:=",
  CellTags->"CycleToT"],

Cell[BoxData[
    \(6\)], "Output",
  CellLabel->"Out[322]=",
  CellTags->"CycleToT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotT[t, 6, DoTrace \[Rule] {1, 4}, Full \[Rule] True];\)\)], "Input",\

  CellLabel->"In[317]:=",
  CellTags->"CycleToT"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0263158 0.131579 -0.0220726 0.110363 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 g
.003 w
.10526 .08829 m
.23684 .19865 L
s
.10526 .19865 m
.23684 .30902 L
s
.10526 .30902 m
.23684 .08829 L
s
.10526 .41938 m
.23684 .52974 L
s
.10526 .52974 m
.23684 .41938 L
s
.23684 .08829 m
.36842 .19865 L
s
.23684 .19865 m
.36842 .30902 L
s
.23684 .30902 m
.36842 .08829 L
s
.23684 .41938 m
.36842 .52974 L
s
.23684 .52974 m
.36842 .41938 L
s
.36842 .08829 m
.5 .19865 L
s
.36842 .19865 m
.5 .30902 L
s
.36842 .30902 m
.5 .08829 L
s
.36842 .41938 m
.5 .52974 L
s
.36842 .52974 m
.5 .41938 L
s
.5 .08829 m
.63158 .19865 L
s
.5 .19865 m
.63158 .30902 L
s
.5 .30902 m
.63158 .08829 L
s
.5 .41938 m
.63158 .52974 L
s
.5 .52974 m
.63158 .41938 L
s
.63158 .08829 m
.76316 .19865 L
s
.63158 .19865 m
.76316 .30902 L
s
.63158 .30902 m
.76316 .08829 L
s
.63158 .41938 m
.76316 .52974 L
s
.63158 .52974 m
.76316 .41938 L
s
.76316 .08829 m
.89474 .19865 L
s
.76316 .19865 m
.89474 .30902 L
s
.76316 .30902 m
.89474 .08829 L
s
.76316 .41938 m
.89474 .52974 L
s
.76316 .52974 m
.89474 .41938 L
s
0 0 0 r
.005 w
.10526 .08829 m
.23684 .19865 L
s
.10526 .41938 m
.23684 .52974 L
s
.23684 .19865 m
.36842 .30902 L
s
.23684 .52974 m
.36842 .41938 L
s
.36842 .30902 m
.5 .08829 L
s
.36842 .41938 m
.5 .52974 L
s
.5 .08829 m
.63158 .19865 L
s
.5 .52974 m
.63158 .41938 L
s
.63158 .19865 m
.76316 .30902 L
s
.63158 .41938 m
.76316 .52974 L
s
.76316 .30902 m
.89474 .08829 L
s
.76316 .52974 m
.89474 .41938 L
s
0 0 1 r
.012 w
.10526 .19865 Mdot
.10526 .30902 Mdot
.10526 .52974 Mdot
.23684 .08829 Mdot
.23684 .30902 Mdot
.23684 .41938 Mdot
.36842 .08829 Mdot
.36842 .19865 Mdot
.36842 .52974 Mdot
.5 .19865 Mdot
.5 .30902 Mdot
.5 .41938 Mdot
.63158 .08829 Mdot
.63158 .30902 Mdot
.63158 .52974 Mdot
.76316 .08829 Mdot
.76316 .19865 Mdot
.76316 .41938 Mdot
.89474 .19865 Mdot
.89474 .30902 Mdot
.89474 .52974 Mdot
1 0 0 r
.0144 w
.10526 .08829 Mdot
.10526 .41938 Mdot
.23684 .19865 Mdot
.23684 .52974 Mdot
.36842 .30902 Mdot
.36842 .41938 Mdot
.5 .08829 Mdot
.5 .52974 Mdot
.63158 .19865 Mdot
.63158 .41938 Mdot
.76316 .30902 Mdot
.76316 .52974 Mdot
.89474 .08829 Mdot
.89474 .41938 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[317]:=",
  ImageSize->{293.938, 181.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"CycleToT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CycleToT[{{4, 5}}, 5]\)], "Input",
  CellLabel->"In[323]:=",
  CellTags->"CycleToT"],

Cell[BoxData[
    \(T[1, 2, 3, 5, 4]\)], "Output",
  CellLabel->"Out[323]=",
  CellTags->"CycleToT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CyclicQGraph", "ObjectName",
  CellTags->"CyclicQGraph"],

Cell["Type: function", "Highlight",
  CellTags->"CyclicQGraph"],

Cell[TextData[{
  StyleBox["CyclicQGraph[G]", "MR"],
  "  tests whether graph ",
  StyleBox["G", "MR"],
  " is cyclic."
}], "Usage",
  CellTags->"CyclicQGraph"],

Cell["Is linear time.", "Notes",
  CellTags->"CyclicQGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"CyclicQGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"CyclicQGraph"],

Cell["A plain cycle. ", "ExampleText",
  CellTags->"CyclicQGraph"],

Cell[BoxData[
    \(\(g = 
        Graph[8, 8, 
          1, {{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 8}, {8, 
              1}}];\)\)], "Input",
  CellLabel->"In[191]:=",
  CellTags->"CyclicQGraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CyclicQGraph[g]\)], "Input",
  CellLabel->"In[192]:=",
  CellTags->"CyclicQGraph"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[192]=",
  CellTags->"CyclicQGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gg\  = \ RemoveVertex[g, 1]\)], "Input",
  CellLabel->"In[196]:=",
  CellTags->"CyclicQGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"7", ",", "6", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[196]=",
  CellTags->"CyclicQGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CyclicQGraph[gg]\)], "Input",
  CellLabel->"In[197]:=",
  CellTags->"CyclicQGraph"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[197]=",
  CellTags->"CyclicQGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DClassDecomposition", "ObjectName",
  CellTags->"DClassDecomposition"],

Cell["Type: function", "Highlight",
  CellTags->"DClassDecomposition"],

Cell[TextData[{
  StyleBox["DClassDecomposition[S]", "MR"],
  "  generates a list of all regular D-classes of semigroup ",
  StyleBox["S", "MR"],
  ". "
}], "Usage",
  CellTags->"DClassDecomposition"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"RegularOnly", "\[Rule]", "True", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"DClassDecomposition"],

Cell[TextData[{
  "Option ",
  StyleBox["RegularOnly->False", "MR"],
  " causes all D-classes to be generated. "
}], "Notes",
  CellTags->"DClassDecomposition"],

Cell[TextData[{
  "Note that this involves computation of left and right ideals generated by \
irregular elements of ",
  StyleBox["S", "MR"],
  " and becomes quite slow for large ",
  StyleBox["S", "MR"],
  "."
}], "Notes",
  CellTags->"DClassDecomposition"],

Cell["\<\
At present, there is no external implementation of this \
operation.\
\>", "Notes",
  CellTags->"DClassDecomposition"],

Cell[TextData[{
  "Note that this involves computation of left and right ideals generated by \
irregular elements of ",
  StyleBox["S", "MR"],
  " and becomes quite slow for large ",
  StyleBox["S", "MR"],
  "."
}], "Notes",
  CellTags->"DClassDecomposition"],

Cell[TextData[{
  "See also ",
  ButtonBox["DClasses",
    ButtonData:>"DClasses",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DC",
    ButtonData:>"DC",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DClassDecomposition"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DClassDecomposition"],

Cell["\<\
The full transformation semigroup on four points, and its \
decomposition.\
\>", "ExampleText",
  CellTags->"DClassDecomposition"],

Cell[CellGroupData[{

Cell["\<\
S = TransformationSG[4];
S // Length\
\>", "Input",
  CellLabel->"In[112]:=",
  CellTags->"DClassDecomposition"],

Cell[BoxData[
    \(256\)], "Output",
  CellLabel->"Out[113]=",
  CellTags->"DClassDecomposition"]
}, Open  ]],

Cell[BoxData[
    \(\(dcl\  = \ DClassDecomposition[S];\)\)], "Input",
  CellLabel->"In[114]:=",
  CellTags->"DClassDecomposition"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DClassSize[dcl]\), "\n", 
    \(DClassDimensions[dcl]\)}], "Input",
  CellLabel->"In[121]:=",
  CellTags->"DClassDecomposition"],

Cell[BoxData[
    \({4, 84, 144, 24}\)], "Output",
  CellLabel->"Out[121]=",
  CellTags->"DClassDecomposition"],

Cell[BoxData[
    \({{1, 4, 1}, {7, 6, 2}, {6, 4, 6}, {1, 1, 24}}\)], "Output",
  CellLabel->"Out[122]=",
  CellTags->"DClassDecomposition"]
}, Open  ]],

Cell["The second D-class in the decomposition, in block form.", "ExampleText",
  CellTags->"DClassDecomposition"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(dcl[\([2]\)]\  // \ DClassToBlocks\)\ \  // \ MatrixForm\)], "Input",
  CellLabel->"In[126]:=",
  CellTags->"DClassDecomposition"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 1, 2]\)},
                    {\(T[2, 2, 2, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 1, 3]\)},
                    {\(T[3, 3, 3, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 1, 4]\)},
                    {\(T[4, 4, 4, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 2, 2, 3]\)},
                    {\(T[3, 3, 3, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 2, 2, 4]\)},
                    {\(T[4, 4, 4, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 3, 3, 4]\)},
                    {\(T[4, 4, 4, 3]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 2, 1]\)},
                    {\(T[2, 2, 1, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 3, 1]\)},
                    {\(T[3, 3, 1, 3]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 4, 1]\)},
                    {\(T[4, 4, 1, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 2, 3, 2]\)},
                    {\(T[3, 3, 2, 3]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 2, 4, 2]\)},
                    {\(T[4, 4, 2, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 3, 4, 3]\)},
                    {\(T[4, 4, 3, 4]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 2, 2]\)},
                    {\(T[2, 2, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 3, 3]\)},
                    {\(T[3, 3, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 4, 4]\)},
                    {\(T[4, 4, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 2, 3, 3]\)},
                    {\(T[3, 3, 2, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 2, 4, 4]\)},
                    {\(T[4, 4, 2, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 3, 4, 4]\)},
                    {\(T[4, 4, 3, 3]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 2, 1, 1]\)},
                    {\(T[2, 1, 2, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 3, 1, 1]\)},
                    {\(T[3, 1, 3, 3]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 4, 1, 1]\)},
                    {\(T[4, 1, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 3, 2, 2]\)},
                    {\(T[3, 2, 3, 3]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 4, 2, 2]\)},
                    {\(T[4, 2, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 4, 3, 3]\)},
                    {\(T[4, 3, 4, 4]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 2, 1, 2]\)},
                    {\(T[2, 1, 2, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 3, 1, 3]\)},
                    {\(T[3, 1, 3, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 4, 1, 4]\)},
                    {\(T[4, 1, 4, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 3, 2, 3]\)},
                    {\(T[3, 2, 3, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 4, 2, 4]\)},
                    {\(T[4, 2, 4, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 4, 3, 4]\)},
                    {\(T[4, 3, 4, 3]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 2, 2, 1]\)},
                    {\(T[2, 1, 1, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 3, 3, 1]\)},
                    {\(T[3, 1, 1, 3]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 4, 4, 1]\)},
                    {\(T[4, 1, 1, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 3, 3, 2]\)},
                    {\(T[3, 2, 2, 3]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 4, 4, 2]\)},
                    {\(T[4, 2, 2, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 4, 4, 3]\)},
                    {\(T[4, 3, 3, 4]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 2, 2, 2]\)},
                    {\(T[2, 1, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 3, 3, 3]\)},
                    {\(T[3, 1, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 4, 4, 4]\)},
                    {\(T[4, 1, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 3, 3, 3]\)},
                    {\(T[3, 2, 2, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 4, 4, 4]\)},
                    {\(T[4, 2, 2, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 4, 4, 4]\)},
                    {\(T[4, 3, 3, 3]\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        T[ 1, 1, 1, 2], 
        T[ 2, 2, 2, 1]}, {
        T[ 1, 1, 1, 3], 
        T[ 3, 3, 3, 1]}, {
        T[ 1, 1, 1, 4], 
        T[ 4, 4, 4, 1]}, {
        T[ 2, 2, 2, 3], 
        T[ 3, 3, 3, 2]}, {
        T[ 2, 2, 2, 4], 
        T[ 4, 4, 4, 2]}, {
        T[ 3, 3, 3, 4], 
        T[ 4, 4, 4, 3]}}, {{
        T[ 1, 1, 2, 1], 
        T[ 2, 2, 1, 2]}, {
        T[ 1, 1, 3, 1], 
        T[ 3, 3, 1, 3]}, {
        T[ 1, 1, 4, 1], 
        T[ 4, 4, 1, 4]}, {
        T[ 2, 2, 3, 2], 
        T[ 3, 3, 2, 3]}, {
        T[ 2, 2, 4, 2], 
        T[ 4, 4, 2, 4]}, {
        T[ 3, 3, 4, 3], 
        T[ 4, 4, 3, 4]}}, {{
        T[ 1, 1, 2, 2], 
        T[ 2, 2, 1, 1]}, {
        T[ 1, 1, 3, 3], 
        T[ 3, 3, 1, 1]}, {
        T[ 1, 1, 4, 4], 
        T[ 4, 4, 1, 1]}, {
        T[ 2, 2, 3, 3], 
        T[ 3, 3, 2, 2]}, {
        T[ 2, 2, 4, 4], 
        T[ 4, 4, 2, 2]}, {
        T[ 3, 3, 4, 4], 
        T[ 4, 4, 3, 3]}}, {{
        T[ 1, 2, 1, 1], 
        T[ 2, 1, 2, 2]}, {
        T[ 1, 3, 1, 1], 
        T[ 3, 1, 3, 3]}, {
        T[ 1, 4, 1, 1], 
        T[ 4, 1, 4, 4]}, {
        T[ 2, 3, 2, 2], 
        T[ 3, 2, 3, 3]}, {
        T[ 2, 4, 2, 2], 
        T[ 4, 2, 4, 4]}, {
        T[ 3, 4, 3, 3], 
        T[ 4, 3, 4, 4]}}, {{
        T[ 1, 2, 1, 2], 
        T[ 2, 1, 2, 1]}, {
        T[ 1, 3, 1, 3], 
        T[ 3, 1, 3, 1]}, {
        T[ 1, 4, 1, 4], 
        T[ 4, 1, 4, 1]}, {
        T[ 2, 3, 2, 3], 
        T[ 3, 2, 3, 2]}, {
        T[ 2, 4, 2, 4], 
        T[ 4, 2, 4, 2]}, {
        T[ 3, 4, 3, 4], 
        T[ 4, 3, 4, 3]}}, {{
        T[ 1, 2, 2, 1], 
        T[ 2, 1, 1, 2]}, {
        T[ 1, 3, 3, 1], 
        T[ 3, 1, 1, 3]}, {
        T[ 1, 4, 4, 1], 
        T[ 4, 1, 1, 4]}, {
        T[ 2, 3, 3, 2], 
        T[ 3, 2, 2, 3]}, {
        T[ 2, 4, 4, 2], 
        T[ 4, 2, 2, 4]}, {
        T[ 3, 4, 4, 3], 
        T[ 4, 3, 3, 4]}}, {{
        T[ 1, 2, 2, 2], 
        T[ 2, 1, 1, 1]}, {
        T[ 1, 3, 3, 3], 
        T[ 3, 1, 1, 1]}, {
        T[ 1, 4, 4, 4], 
        T[ 4, 1, 1, 1]}, {
        T[ 2, 3, 3, 3], 
        T[ 3, 2, 2, 2]}, {
        T[ 2, 4, 4, 4], 
        T[ 4, 2, 2, 2]}, {
        T[ 3, 4, 4, 4], 
        T[ 4, 3, 3, 3]}}}]]], "Output",
  CellLabel->"Out[126]//MatrixForm=",
  CellTags->"DClassDecomposition"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DClassDimensions", "ObjectName",
  CellTags->"DClassDimensions"],

Cell["Type: function", "Highlight",
  CellTags->"DClassDimensions"],

Cell[TextData[{
  StyleBox["DClassDimensions[dc]", "MR"],
  "  returns the dimensions of D-class ",
  StyleBox["dc", "MR"],
  ". "
}], "Usage",
  CellTags->"DClassDimensions"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"DClassDimensions"],

Cell["\<\
 Returns a triple:  number of R-classes, number of L-classes, size \
of H-classes.\
\>", "Notes",
  CellTags->"DClassDimensions"],

Cell[TextData[{
  " See also ",
  ButtonBox["DClassSize",
    ButtonData:>"DClassSize",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DC",
    ButtonData:>"DC",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DClassDimensions"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DClassDimensions"],

Cell["A D-class, in standard form.", "ExampleText",
  CellTags->"DClassDimensions"],

Cell[BoxData[
    \(\(d\  = \ 
        DC[{T[1, 1, 1, 4], T[1, 1, 4, 1], T[1, 1, 4, 4], T[1, 4, 1, 1], 
            T[1, 4, 1, 4], T[1, 4, 4, 1], T[1, 4, 4, 4]}, {T[1, 1, 1, 2], 
            T[1, 1, 1, 3], T[1, 1, 1, 4], T[2, 1, 1, 3], T[2, 1, 1, 4], 
            T[3, 1, 1, 4]}, {T[1, 1, 1, 4], T[4, 4, 4, 1]}];\)\)], "Input",
  CellLabel->"In[128]:=",
  CellTags->"DClassDimensions"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DClassDimensions[d]\)], "Input",
  CellLabel->"In[129]:=",
  CellTags->"DClassDimensions"],

Cell[BoxData[
    \({7, 6, 2}\)], "Output",
  CellLabel->"Out[129]=",
  CellTags->"DClassDimensions"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DClassSize", "ObjectName",
  CellTags->"DClassSize"],

Cell["Type: function", "Highlight",
  CellTags->"DClassSize"],

Cell[TextData[{
  StyleBox["DClassSize[dc]", "MR"],
  "  returns the size of D-class ",
  StyleBox["dc", "MR"],
  "."
}], "Usage",
  CellTags->"DClassSize"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"DClassSize"],

Cell["\<\
 Returns the product of:  number of R-classes, number of L-classes, \
size of H-classes.\
\>", "Notes",
  CellTags->"DClassSize"],

Cell[TextData[{
  "See also ",
  ButtonBox["DClassDimensions",
    ButtonData:>"DClassDimensions",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ".  "
}], "Notes",
  CellTags->"DClassSize"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DClassSize"],

Cell["A D-class, in standard form.", "ExampleText",
  CellTags->"DClassSize"],

Cell[BoxData[
    \(\(d\  = \ 
        DC[{T[1, 1, 1, 4], T[1, 1, 4, 1], T[1, 1, 4, 4], T[1, 4, 1, 1], 
            T[1, 4, 1, 4], T[1, 4, 4, 1], T[1, 4, 4, 4]}, {T[1, 1, 1, 2], 
            T[1, 1, 1, 3], T[1, 1, 1, 4], T[2, 1, 1, 3], T[2, 1, 1, 4], 
            T[3, 1, 1, 4]}, {T[1, 1, 1, 4], T[4, 4, 4, 1]}];\)\)], "Input",
  CellLabel->"In[128]:=",
  CellTags->"DClassSize"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DClassSize[d]\)], "Input",
  CellLabel->"In[130]:=",
  CellTags->"DClassSize"],

Cell[BoxData[
    \(84\)], "Output",
  CellLabel->"Out[130]=",
  CellTags->"DClassSize"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DClassToBlocks", "ObjectName",
  CellTags->"DClassToBlocks"],

Cell["Type: function", "Highlight",
  CellTags->"DClassToBlocks"],

Cell[TextData[{
  StyleBox["DClassToBlocks[dc]", "MR"],
  "  converts a D-class in standard form into a matrix of H-classes (a tensor \
of rank 3)."
}], "Usage",
  CellTags->"DClassToBlocks"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"DClassToBlocks"],

Cell[TextData[{
  "The output is a matrix of the form  ",
  Cell[BoxData[
      \(TraditionalForm\`\((H\_\(i\[InvisibleComma]j\))\)\)]],
  "  where each H-class ",
  Cell[BoxData[
      \(TraditionalForm\`H\_\(i\[InvisibleComma]j\)\)]],
  " is given as a list of transformations."
}], "Notes",
  CellTags->"DClassToBlocks"],

Cell[TextData[{
  "The dimensions of the tensor can be determined with ",
  StyleBox["DClassDimensions", "MR"],
  "."
}], "Notes",
  CellTags->"DClassToBlocks"],

Cell[TextData[{
  "See also ",
  ButtonBox["BlocksToClass",
    ButtonData:>"BlocksToClass",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DC",
    ButtonData:>"DC",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DClassToBlocks"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DClassToBlocks"],

Cell["A small D-class in standard representation.", "ExampleText",
  CellTags->"DClassToBlocks"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(d\  = \ 
        DC[{T[1, 2, 3, 4], T[2, 4, 1, 4], T[3, 1, 4, 4]}, {T[1, 2, 3, 4], 
            T[2, 4, 1, 4], T[3, 1, 4, 4]}, {T[1, 4, 4, 4]}];\)\), "\n", 
    \(\(d\  // \ ToList\)\  // \ TableForm\)}], "Input",
  CellLabel->"In[102]:=",
  CellTags->"DClassToBlocks"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(T[1, 2, 3, 4]\), \(T[2, 4, 1, 4]\), \(T[3, 1, 4, 4]\)},
          {\(T[1, 2, 3, 4]\), \(T[2, 4, 1, 4]\), \(T[3, 1, 4, 4]\)},
          {\(T[1, 4, 4, 4]\), "\<\"\"\>", "\<\"\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{
        T[ 1, 2, 3, 4], 
        T[ 2, 4, 1, 4], 
        T[ 3, 1, 4, 4]}, {
        T[ 1, 2, 3, 4], 
        T[ 2, 4, 1, 4], 
        T[ 3, 1, 4, 4]}, {
        T[ 1, 4, 4, 4]}}]]], "Output",
  CellLabel->"Out[103]//TableForm=",
  CellTags->"DClassToBlocks"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DClassToBlocks[d]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[104]:=",
  CellTags->"DClassToBlocks"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 4, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 4, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 4, 4, 4]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 4, 1, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 4, 2, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 4, 3, 4]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 1, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 2, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 3, 4, 4]\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        T[ 1, 4, 4, 4]}, {
        T[ 2, 4, 4, 4]}, {
        T[ 3, 4, 4, 4]}}, {{
        T[ 4, 4, 1, 4]}, {
        T[ 4, 4, 2, 4]}, {
        T[ 4, 4, 3, 4]}}, {{
        T[ 4, 1, 4, 4]}, {
        T[ 4, 2, 4, 4]}, {
        T[ 4, 3, 4, 4]}}}]]], "Output",
  CellLabel->"Out[104]//MatrixForm=",
  CellTags->"DClassToBlocks"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DClassT", "ObjectName",
  CellTags->"DClassT"],

Cell["Type: function", "Highlight",
  CellTags->"DClassT"],

Cell[TextData[{
  StyleBox["DClassT[x,S]", "MR"],
  "  determines the D-class of a regular element ",
  StyleBox["x", "MR"],
  " in a semigroup ",
  StyleBox["S", "MR"],
  ". "
}], "Usage",
  CellTags->"DClassT"],

Cell["Coordinates are given as left and right multipliers.", "Notes",
  CellTags->"DClassT"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DC",
    ButtonData:>"DC",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"DClassT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DClassT"],

Cell["The full transformation semigroup on 3 points. ", "ExampleText",
  CellTags->"DClassT"],

Cell[CellGroupData[{

Cell["\<\
S = TransformationSG[3];
S // Length\
\>", "Input",
  CellLabel->"In[132]:=",
  CellTags->"DClassT"],

Cell[BoxData[
    \(27\)], "Output",
  CellLabel->"Out[133]=",
  CellTags->"DClassT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DClassT[\ T[1, 1, 1], S]\), "\n", 
    \(\(%\  // \ DClassToBlocks\)\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[140]:=",
  CellTags->"DClassT"],

Cell[BoxData[
    \(DC[{T[1, 1, 1]}, {T[1, 1, 1], T[2, 1, 1], 
        T[3, 1, 1]}, {T[1, 1, 1]}]\)], "Output",
  CellLabel->"Out[140]=",
  CellTags->"DClassT"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 2, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 3, 3]\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        T[ 1, 1, 1]}, {
        T[ 2, 2, 2]}, {
        T[ 3, 3, 3]}}}]]], "Output",
  CellLabel->"Out[141]//MatrixForm=",
  CellTags->"DClassT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DClassT[\ T[1, 2, 2], S]\), "\n", 
    \(\(%\  // \ DClassToBlocks\)\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[142]:=",
  CellTags->"DClassT"],

Cell[BoxData[
    \(DC[{T[1, 1, 2], T[1, 2, 1], T[1, 2, 2]}, {T[1, 2, 1], T[1, 3, 1], 
        T[2, 3, 1]}, {T[1, 2, 2], T[2, 1, 1]}]\)], "Output",
  CellLabel->"Out[142]=",
  CellTags->"DClassT"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 2]\)},
                    {\(T[2, 2, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 1, 3]\)},
                    {\(T[3, 3, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 2, 3]\)},
                    {\(T[3, 3, 2]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 2, 1]\)},
                    {\(T[2, 1, 2]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 3, 1]\)},
                    {\(T[3, 1, 3]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 3, 2]\)},
                    {\(T[3, 2, 3]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 2, 2]\)},
                    {\(T[2, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 3, 3]\)},
                    {\(T[3, 1, 1]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 3, 3]\)},
                    {\(T[3, 2, 2]\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        T[ 1, 1, 2], 
        T[ 2, 2, 1]}, {
        T[ 1, 1, 3], 
        T[ 3, 3, 1]}, {
        T[ 2, 2, 3], 
        T[ 3, 3, 2]}}, {{
        T[ 1, 2, 1], 
        T[ 2, 1, 2]}, {
        T[ 1, 3, 1], 
        T[ 3, 1, 3]}, {
        T[ 2, 3, 2], 
        T[ 3, 2, 3]}}, {{
        T[ 1, 2, 2], 
        T[ 2, 1, 1]}, {
        T[ 1, 3, 3], 
        T[ 3, 1, 1]}, {
        T[ 2, 3, 3], 
        T[ 3, 2, 2]}}}]]], "Output",
  CellLabel->"Out[143]//MatrixForm=",
  CellTags->"DClassT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DClassT[\ T[1, 2, 3], S]\), "\n", 
    \(\(%\  // \ DClassToBlocks\)\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[144]:=",
  CellTags->"DClassT"],

Cell[BoxData[
    \(DC[{T[1, 2, 3]}, {T[1, 2, 3]}, {T[1, 2, 3], T[1, 3, 2], T[2, 1, 3], 
        T[2, 3, 1], T[3, 1, 2], T[3, 2, 1]}]\)], "Output",
  CellLabel->"Out[144]=",
  CellTags->"DClassT"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 2, 3]\)},
                    {\(T[1, 3, 2]\)},
                    {\(T[2, 1, 3]\)},
                    {\(T[2, 3, 1]\)},
                    {\(T[3, 1, 2]\)},
                    {\(T[3, 2, 1]\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        T[ 1, 2, 3], 
        T[ 1, 3, 2], 
        T[ 2, 1, 3], 
        T[ 2, 3, 1], 
        T[ 3, 1, 2], 
        T[ 3, 2, 1]}}}]]], "Output",
  CellLabel->"Out[145]//MatrixForm=",
  CellTags->"DClassT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DegreeGraph", "ObjectName",
  CellTags->"DegreeGraph"],

Cell["Type: function", "Highlight",
  CellTags->"DegreeGraph"],

Cell[TextData[{
  StyleBox["DegreeGraph[G,v]", "MR"],
  "  returns the degree of vertex ",
  StyleBox["v", "MR"],
  " in graph ",
  StyleBox["G", "MR"],
  ". "
}], "Usage",
  CellTags->"DegreeGraph"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"DegreeGraph"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " causes the pair ",
  StyleBox["{in-deg,out-deg}", "MR"],
  " to be returned."
}], "Notes",
  CellTags->"DegreeGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DegreeGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DegreeGraph"],

Cell["\<\
In a circulant graph, all vertices have the same in-degree and \
out-degree. \
\>", "ExampleText",
  CellTags->"DegreeGraph"],

Cell[CellGroupData[{

Cell["g = CirculantGraph[8,{1,3}]", "Input",
  CellLabel->"In[220]:=",
  CellTags->"DegreeGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"8", ",", "16", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 
                8}, \[LeftSkeleton]2\[RightSkeleton], {2, 5}, {3, 6}, {4, 
                7}, {5, 8}, {6, 1}, {7, 2}, {8, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[220]=",
  CellTags->"DegreeGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DegreeGraph[g, 5]\)], "Input",
  CellLabel->"In[221]:=",
  CellTags->"DegreeGraph"],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[221]=",
  CellTags->"DegreeGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DegreeGraph[g, 5, Full \[Rule] True\ ]\)], "Input",
  CellLabel->"In[222]:=",
  CellTags->"DegreeGraph"],

Cell[BoxData[
    \({2, 2}\)], "Output",
  CellLabel->"Out[222]=",
  CellTags->"DegreeGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ DegreeGraph[g, i, Full \[Rule] True\ ], {i, 8}]\  // \ 
      Union\)], "Input",
  CellLabel->"In[223]:=",
  CellTags->"DegreeGraph"],

Cell[BoxData[
    \({{2, 2}}\)], "Output",
  CellLabel->"Out[223]=",
  CellTags->"DegreeGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dependency", "ObjectName",
  CellTags->"Dependency"],

Cell["Type: function", "Highlight",
  CellTags->"Dependency"],

Cell[TextData[{
  StyleBox["Dependency[V,k]", "MR"],
  "  computes the indices of the variables on which the ",
  StyleBox["k", "MR"],
  "-ary function represented by the value list ",
  StyleBox["V", "MR"],
  " depends. "
}], "Usage",
  CellTags->"Dependency"],

Cell[TextData[{
  "Here ",
  StyleBox["V", "MR"],
  " must have length ",
  Cell[BoxData[
      \(TraditionalForm\`n\^\(\(\ \)\(k\)\)\)]],
  " and represents a function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " of the form ",
  Cell[BoxData[
      \(TraditionalForm\`A\^\(\(\ \)\(k\)\)\[LongRightArrow]B\)]],
  ". "
}], "Notes",
  CellTags->"Dependency"],

Cell[TextData[{
  "Parameter ",
  StyleBox["k", "MR"],
  " is optional and has default 2."
}], "Notes",
  CellTags->"Dependency"],

Cell[TextData[{
  "See also ",
  ButtonBox["DependencyCA",
    ButtonData:>"DependencyCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Dependency"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Dependency"],

Cell["A function of three variables depending only on two.", "ExampleText",
  CellTags->"Dependency"],

Cell["\<\
Clear[f]
f[x_,y_,z_] := Mod[x+z,2];\
\>", "Input",
  CellLabel->"In[88]:=",
  CellTags->"Dependency"],

Cell[CellGroupData[{

Cell[BoxData[
    \(V\  = \ Apply[f, CartesianProduct[2, 2, 2], {1}]\)], "Input",
  CellLabel->"In[93]:=",
  CellTags->"Dependency"],

Cell[BoxData[
    \({0, 1, 0, 1, 1, 0, 1, 0}\)], "Output",
  CellLabel->"Out[93]=",
  CellTags->"Dependency"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dependency[V]\)], "Input",
  CellLabel->"In[94]:=",
  CellTags->"Dependency"],

Cell[BoxData[
    \({1, 3}\)], "Output",
  CellLabel->"Out[94]=",
  CellTags->"Dependency"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DisjointQ", "ObjectName",
  CellTags->"DisjointQ"],

Cell["Type: function", "Highlight",
  CellTags->"DisjointQ"],

Cell[TextData[{
  StyleBox["DisjointQ[L1,L2]", "MR"],
  "  tests whether lists ",
  StyleBox["L1", "MR"],
  " and ",
  StyleBox["L2", "MR"],
  " are disjoint."
}], "Usage",
  CellTags->"DisjointQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["SubsetQ",
    ButtonData:>"SubsetQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DisjointQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DisjointQ"],

Cell["Only top level elments are considered.", "ExampleText",
  CellTags->"DisjointQ"],

Cell[CellGroupData[{

Cell[" DisjointQ[{1,2,3},{{1},4,5}]", "Input",
  CellLabel->"In[86]:=",
  CellTags->"DisjointQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->"DisjointQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" DisjointQ[{1,2,3},{1,4,5}]", "Input",
  CellLabel->"In[87]:=",
  CellTags->"DisjointQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[87]=",
  CellTags->"DisjointQ"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DoShow", "ObjectName",
  CellTags->"DoShow"],

Cell["Type: function", "Highlight",
  CellTags->"DoShow"],

Cell[TextData[{
  StyleBox["DoShow[gr]", "MR"],
  "  displays graphics object ",
  StyleBox["gr", "MR"],
  " by setting the ",
  StyleBox["DisplayFunction", "MR"],
  " to ",
  StyleBox["$DisplayFunction", "MR"],
  ". "
}], "Usage",
  CellTags->"DoShow"],

Cell[TextData[{
  "Used in conjunction with ",
  StyleBox["DisplayFunction->Identity", "MR"],
  "."
}], "Notes",
  CellTags->"DoShow"],

Cell[TextData[{
  "See also ",
  ButtonBox["ShowArray",
    ButtonData:>"ShowArray",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DoShow"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DoShow"],

Cell["Postponing the display of graphics.", "ExampleText",
  CellTags->"DoShow"],

Cell[BoxData[
    \(\(gr = 
        PlotT[T[2, 3, 4, 1, 4, 5, 6], 5, 
          DisplayFunction \[Rule] Identity];\)\)], "Input",
  CellLabel->"In[84]:=",
  CellTags->"DoShow"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DoShow[gr];\)\)], "Input",
  CellLabel->"In[85]:=",
  CellTags->"DoShow"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.030303 0.151515 -0.0162641 0.0813203 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
.12121 .06506 m
.27273 .14638 L
s
.12121 .14638 m
.27273 .2277 L
s
.12121 .2277 m
.27273 .30902 L
s
.12121 .30902 m
.27273 .06506 L
s
.12121 .39034 m
.27273 .30902 L
s
.12121 .47166 m
.27273 .39034 L
s
.12121 .55298 m
.27273 .47166 L
s
.27273 .06506 m
.42424 .14638 L
s
.27273 .14638 m
.42424 .2277 L
s
.27273 .2277 m
.42424 .30902 L
s
.27273 .30902 m
.42424 .06506 L
s
.27273 .39034 m
.42424 .30902 L
s
.27273 .47166 m
.42424 .39034 L
s
.42424 .06506 m
.57576 .14638 L
s
.42424 .14638 m
.57576 .2277 L
s
.42424 .2277 m
.57576 .30902 L
s
.42424 .30902 m
.57576 .06506 L
s
.42424 .39034 m
.57576 .30902 L
s
.57576 .06506 m
.72727 .14638 L
s
.57576 .14638 m
.72727 .2277 L
s
.57576 .2277 m
.72727 .30902 L
s
.57576 .30902 m
.72727 .06506 L
s
.72727 .06506 m
.87879 .14638 L
s
.72727 .14638 m
.87879 .2277 L
s
.72727 .2277 m
.87879 .30902 L
s
.72727 .30902 m
.87879 .06506 L
s
0 0 1 r
.012 w
.27273 .55298 Mdot
.42424 .47166 Mdot
.42424 .55298 Mdot
.57576 .39034 Mdot
.57576 .47166 Mdot
.57576 .55298 Mdot
.72727 .39034 Mdot
.72727 .47166 Mdot
.72727 .55298 Mdot
.87879 .39034 Mdot
.87879 .47166 Mdot
.87879 .55298 Mdot
1 0 0 r
.0144 w
.12121 .06506 Mdot
.12121 .14638 Mdot
.12121 .2277 Mdot
.12121 .30902 Mdot
.12121 .39034 Mdot
.12121 .47166 Mdot
.12121 .55298 Mdot
.27273 .06506 Mdot
.27273 .14638 Mdot
.27273 .2277 Mdot
.27273 .30902 Mdot
.27273 .39034 Mdot
.27273 .47166 Mdot
.42424 .06506 Mdot
.42424 .14638 Mdot
.42424 .2277 Mdot
.42424 .30902 Mdot
.42424 .39034 Mdot
.57576 .06506 Mdot
.57576 .14638 Mdot
.57576 .2277 Mdot
.57576 .30902 Mdot
.72727 .06506 Mdot
.72727 .14638 Mdot
.72727 .2277 Mdot
.72727 .30902 Mdot
.87879 .06506 Mdot
.87879 .14638 Mdot
.87879 .2277 Mdot
.87879 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[85]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"DoShow"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Drei", "ObjectName",
  CellTags->"Drei"],

Cell["Type: fctassg", "Highlight",
  CellTags->"Drei"],

Cell[TextData[{
  StyleBox["Drei[x]", "MR"],
  "  returns the third part of object ",
  StyleBox["x", "MR"],
  "."
}], "Usage",
  CellTags->"Drei"],

Cell[TextData[{
  "Thsu, ",
  StyleBox["Drei[x] = x[[3]]", "MR"],
  "."
}], "Notes",
  CellTags->"Drei"],

Cell[TextData[{
  "See also ",
  ButtonBox["Zwei",
    ButtonData:>"Zwei",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinusEins",
    ButtonData:>"MinusEins",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinusZwei",
    ButtonData:>"MinusZwei",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Drei"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EdgeQ", "ObjectName",
  CellTags->"EdgeQ"],

Cell["Type: function", "Highlight",
  CellTags->"EdgeQ"],

Cell[TextData[{
  StyleBox["EdgeQ[G,x,y]", "MR"],
  "  tests whether edge ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " is present in graph ",
  StyleBox["G", "MR"],
  "."
}], "Usage",
  CellTags->"EdgeQ"],

Cell[TextData[{
  "Both ",
  StyleBox["x", "MR"],
  " and ",
  StyleBox["y", "MR"],
  " must be in positional notation."
}], "Notes",
  CellTags->"EdgeQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"EdgeQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Edges", "ObjectName",
  CellTags->"Edges"],

Cell["Type: function", "Highlight",
  CellTags->"Edges"],

Cell[TextData[{
  StyleBox["Edges[G]", "MR"],
  "  returns the edges of a graph G"
}], "Usage",
  CellTags->"Edges"],

Cell["\<\
 The type of the output depends on type of graph and could be an \
edge list, an adjacency list, or an adjacency matrix.\
\>", "Notes",
  CellTags->"Edges"],

Cell[TextData[{
  "See ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["TypeGraph",
    ButtonData:>"TypeGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Edges"]
}, Open  ]],

Cell[CellGroupData[{

Cell["EnumForm", "ObjectName",
  CellTags->"EnumForm"],

Cell["Type: function", "Highlight",
  CellTags->"EnumForm"],

Cell[TextData[{
  StyleBox["EnumForm[L]", "MR"],
  "  displays list ",
  StyleBox["L", "MR"],
  " in ",
  StyleBox["ColumnForm", "MR"],
  " with line numbers starting at 1."
}], "Usage",
  CellTags->"EnumForm"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Index", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"EnumForm"],

Cell[TextData[{
  "Option ",
  StyleBox["Index->n", "MR"],
  "  changes the starting value to ",
  StyleBox["n", "MR"],
  "."
}], "Notes",
  CellTags->"EnumForm"],

Cell[TextData[{
  "Uses ",
  StyleBox["ColonForm", "MR"],
  " to generate the line numbers. "
}], "Notes",
  CellTags->"EnumForm"],

Cell[TextData[{
  "See ",
  ButtonBox["EnumForm0",
    ButtonData:>"EnumForm0",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"],
  " "
}], "Notes",
  CellTags->"EnumForm"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"EnumForm"],

Cell["Displaying a few words in a acceptance language.", "ExampleText",
  CellTags->"EnumForm"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = ModCounterDFA[a, 1, 3, 2];\)\), "\n", 
    \(L = LanguageFA[m, \(-5\)]\)}], "Input",
  CellLabel->"In[111]:=",
  CellTags->"EnumForm"],

Cell[BoxData[
    \({{}, {"a"}, {"ab", "ba"}, {"abb", "bab", "bba"}, {"aaaa", "abbb", 
        "babb", "bbab", "bbba"}, {"aaaab", "aaaba", "aabaa", "abaaa", 
        "abbbb", "baaaa", "babbb", "bbabb", "bbbab", "bbbba"}}\)], "Output",
  CellLabel->"Out[112]=",
  CellTags->"EnumForm"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EnumForm[L]\)], "Input",
  CellLabel->"In[114]:=",
  CellTags->"EnumForm"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(1 \(\(:\)\(\ \)\) {}\)},
          {\(2 \(\(:\)\(\ \)\) {"a"}\)},
          {\(3 \(\(:\)\(\ \)\) {"ab", "ba"}\)},
          {\(4 \(\(:\)\(\ \)\) {"abb", "bab", "bba"}\)},
          {\(5 \(\(:\)\(\ \)\) {"aaaa", "abbb", "babb", "bbab", "bbba"}\)},
          {\(6 \(\(:\)\(\ \)\) {"aaaab", "aaaba", "aabaa", "abaaa", "abbbb", 
                "baaaa", "babbb", "bbabb", "bbbab", "bbbba"}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {
        ColonForm[ 1, {}], 
        ColonForm[ 2, {"a"}], 
        ColonForm[ 3, {"ab", "ba"}], 
        ColonForm[ 4, {"abb", "bab", "bba"}], 
        ColonForm[ 5, {"aaaa", "abbb", "babb", "bbab", "bbba"}], 
        ColonForm[ 
        6, {"aaaab", "aaaba", "aabaa", "abaaa", "abbbb", "baaaa", "babbb", 
          "bbabb", "bbbab", "bbbba"}]}],
      Editable->False]], "Output",
  CellLabel->"Out[114]=",
  CellTags->"EnumForm"]
}, Open  ]],

Cell["It is more natural to start numbering at 0 in this case. ", \
"ExampleText",
  CellTags->"EnumForm"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EnumForm0[L]\)], "Input",
  CellLabel->"In[115]:=",
  CellTags->"EnumForm"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(0 \(\(:\)\(\ \)\) {}\)},
          {\(1 \(\(:\)\(\ \)\) {"a"}\)},
          {\(2 \(\(:\)\(\ \)\) {"ab", "ba"}\)},
          {\(3 \(\(:\)\(\ \)\) {"abb", "bab", "bba"}\)},
          {\(4 \(\(:\)\(\ \)\) {"aaaa", "abbb", "babb", "bbab", "bbba"}\)},
          {\(5 \(\(:\)\(\ \)\) {"aaaab", "aaaba", "aabaa", "abaaa", "abbbb", 
                "baaaa", "babbb", "bbabb", "bbbab", "bbbba"}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {
        ColonForm[ 0, {}], 
        ColonForm[ 1, {"a"}], 
        ColonForm[ 2, {"ab", "ba"}], 
        ColonForm[ 3, {"abb", "bab", "bba"}], 
        ColonForm[ 4, {"aaaa", "abbb", "babb", "bbab", "bbba"}], 
        ColonForm[ 
        5, {"aaaab", "aaaba", "aabaa", "abaaa", "abbbb", "baaaa", "babbb", 
          "bbabb", "bbbab", "bbbba"}]}],
      Editable->False]], "Output",
  CellLabel->"Out[115]=",
  CellTags->"EnumForm"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EquationsToWitnesses", "ObjectName",
  CellTags->"EquationsToWitnesses"],

Cell["Type: function", "Highlight",
  CellTags->"EquationsToWitnesses"],

Cell[TextData[{
  StyleBox["EquationsToWitnesses[eq,K]", "MR"],
  "  generates witnesses for the semigroup on generators ",
  StyleBox["K", "MR"],
  " with defining relationes given by ",
  StyleBox["eq", "MR"],
  ", a rewrite system. "
}], "Usage",
  CellTags->"EquationsToWitnesses"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"BoundETW", "\[Rule]", "500", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"EquationsToWitnesses"],

Cell[TextData[{
  "Option ",
  StyleBox["BoundETW->n", "MR"],
  " defines ",
  StyleBox["n", "MR"],
  " as upper for the number of witnesses produced, has default 500."
}], "Notes",
  CellTags->"EquationsToWitnesses"],

Cell["\<\
Note that the equations are only used in directed form left to \
right, no attempt is made to generate the Thue congruence. \
\>", "Notes",
  CellTags->"EquationsToWitnesses"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"EquationsToWitnesses"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"EquationsToWitnesses"],

Cell[TextData[{
  "A simple one-letter example:  rule ",
  Cell[BoxData[
      \(TraditionalForm\`a\^\(\(\ \)\(5\)\) \[Rule] \ a\)]],
  "."
}], "ExampleText",
  CellTags->"EquationsToWitnesses"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquationsToWitnesses[{{aaaaa, a}}, {a}]\)], "Input",
  CellLabel->"In[122]:=",
  AspectRatioFixed->True,
  CellTags->"EquationsToWitnesses"],

Cell[BoxData[
    \({"a", "aa", "aaa", "aaaa"}\)], "Output",
  CellLabel->"Out[122]=",
  CellTags->"EquationsToWitnesses"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EquationsToWitnesses[{{aaaaa, a}}, {a}, Full \[Rule] True]\)], "Input",
  CellLabel->"In[123]:=",
  AspectRatioFixed->True,
  CellTags->"EquationsToWitnesses"],

Cell[BoxData[
    \({\[Epsilon], "a", "aa", "aaa", "aaaa"}\)], "Output",
  CellLabel->"Out[123]=",
  CellTags->"EquationsToWitnesses"]
}, Open  ]],

Cell[TextData[{
  "An two-letter example: one rule ",
  Cell[BoxData[
      \(TraditionalForm\`a\^\(\(\ \)\(5\)\) \[Rule] \ a\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\^\(\(\ \)\(3\)\) \[Rule] b\^\(\(\ \)\(2\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\[VeryThinSpace]a \[Rule] a\[VeryThinSpace]b\)]],
  "."
}], "ExampleText",
  CellTags->"EquationsToWitnesses"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(eq = {{aaaaa, a}, {bbb, bb}, {ba, ab}};\)\), "\n", 
    \(S = EquationsToWitnesses[eq, {a, b}]\)}], "Input",
  CellLabel->"In[126]:=",
  CellTags->"EquationsToWitnesses"],

Cell[BoxData[
    \({"a", "b", "aa", "ab", "bb", "aaa", "aab", "abb", "aaaa", "aaab", 
      "aabb", "aaaab", "aaabb", "aaaabb"}\)], "Output",
  CellLabel->"Out[127]=",
  CellTags->"EquationsToWitnesses"]
}, Open  ]],

Cell["\<\
All products of these words are indeed reducible to an element in \
S.\
\>", "ExampleText",
  CellTags->"EquationsToWitnesses"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SS\  = \ Concatenate[S, S];\)\), "\n", 
    \(\(WordReduce[\ SS, \ eq\ ]\  // \ Union\)\  // \ WordSort\)}], "Input",
  CellLabel->"In[133]:=",
  CellTags->"EquationsToWitnesses"],

Cell[BoxData[
    \({"a", "aa", "ab", "bb", "aaa", "aab", "abb", "aaaa", "aaab", "aabb", 
      "aaaab", "aaabb", "aaaabb"}\)], "Output",
  CellLabel->"Out[134]=",
  CellTags->"EquationsToWitnesses"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubsetQ[%, S]\)], "Input",
  CellLabel->"In[132]:=",
  CellTags->"EquationsToWitnesses"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[132]=",
  CellTags->"EquationsToWitnesses"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FastPowerSet", "ObjectName",
  CellTags->"FastPowerSet"],

Cell["Type: function", "Highlight",
  CellTags->"FastPowerSet"],

Cell[TextData[{
  StyleBox["FastPowerSet[L]", "MR"],
  "   uses pattern matching to generate a power set."
}], "Usage",
  CellTags->"FastPowerSet"],

Cell[TextData[{
  "Is currently faster than the inductive method used in ",
  StyleBox["PowerSet", "MR"],
  "."
}], "Notes",
  CellTags->"FastPowerSet"],

Cell[TextData[{
  "See ",
  ButtonBox["PowerSet",
    ButtonData:>"PowerSet",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FastPowerSet"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FastPowerSet"],

Cell["\<\
Note that the methods produce the subsets in different order.\
\>", \
"ExampleText",
  CellTags->"FastPowerSet"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(P1 = FastPowerSet[Range[12]];\)]\)], "Input",
  CellLabel->"In[115]:=",
  CellTags->"FastPowerSet"],

Cell[BoxData[
    \({0.03000000000000002`\ Second, Null}\)], "Output",
  CellLabel->"Out[115]=",
  CellTags->"FastPowerSet"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(P2 = PowerSet[Range[12]];\)]\)], "Input",
  CellLabel->"In[116]:=",
  CellTags->"FastPowerSet"],

Cell[BoxData[
    \({0.11000000000000021`\ Second, Null}\)], "Output",
  CellLabel->"Out[116]=",
  CellTags->"FastPowerSet"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(P1\  === \ P2\), "\n", 
    \(Sort[P1]\  === \ P2\)}], "Input",
  CellLabel->"In[121]:=",
  CellTags->"FastPowerSet"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[121]=",
  CellTags->"FastPowerSet"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[122]=",
  CellTags->"FastPowerSet"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FlattenOne", "ObjectName",
  CellTags->"FlattenOne"],

Cell["Type: function", "Highlight",
  CellTags->"FlattenOne"],

Cell[TextData[{
  StyleBox["FlattenOne[x]", "MR"],
  "  is shorthand for ",
  StyleBox["Flatten[x,1]", "MR"],
  "."
}], "Usage",
  CellTags->"FlattenOne"],

Cell["Useful in postfix notation.", "Notes",
  CellTags->"FlattenOne"],

Cell[TextData[{
  "See also ",
  ButtonBox["Curry",
    ButtonData:>"Curry",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FlattenOne"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FlattenOne"],

Cell["A deeply nested list, and its flattenings.", "ExampleText",
  CellTags->"FlattenOne"],

Cell[CellGroupData[{

Cell["vN = Nest[ {#,{#}}&, {}, 2 ]", "Input",
  CellLabel->"In[73]:=",
  CellTags->"FlattenOne"],

Cell[BoxData[
    \({{{}, {{}}}, {{{}, {{}}}}}\)], "Output",
  CellLabel->"Out[73]=",
  CellTags->"FlattenOne"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[\ FlattenOne, \ vN, \ 5\ ]\  // \ ColumnForm\)], "Input",
  CellLabel->"In[74]:=",
  CellTags->"FlattenOne"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\({{{}, {{}}}, {{{}, {{}}}}}\)},
          {\({{}, {{}}, {{}, {{}}}}\)},
          {\({{}, {}, {{}}}\)},
          {\({{}}\)},
          {\({}\)},
          {\({}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{{{}, {{}}}, {{{}, {{}}}}}, {{}, {{}}, {{}, {{}}}}, {{}, \
{}, {{}}}, {{}}, {}, {}}],
      Editable->False]], "Output",
  CellLabel->"Out[74]=",
  CellTags->"FlattenOne"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Frequencies", "ObjectName",
  CellTags->"Frequencies"],

Cell["Type: function", "Highlight",
  CellTags->"Frequencies"],

Cell[TextData[{
  StyleBox["Frequencies[L]", "MR"],
  "  counts the occurrences of all elements in the list ",
  StyleBox["L", "MR"],
  StyleBox[".", "Text"]
}], "Usage",
  CellTags->"Frequencies"],

Cell[TextData[{
  "Returns a list of pairs  ",
  Cell[BoxData[
      \(TraditionalForm\`\((\ object, \ count\ )\)\)]],
  ". "
}], "Notes",
  CellTags->"Frequencies"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Frequencies"],

Cell["Frequencies of numbers in a random sequence.", "ExampleText",
  CellTags->"Frequencies"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L = Table[Random[Integer, {1, 5}], {500}];\)\), "\n", 
    \(Frequencies[L]\), "\n", 
    \(%\  // \ TableForm\)}], "Input",
  CellLabel->"In[58]:=",
  CellTags->"Frequencies"],

Cell[BoxData[
    \({{1, 89}, {2, 98}, {3, 103}, {4, 105}, {5, 105}}\)], "Output",
  CellLabel->"Out[59]=",
  CellTags->"Frequencies"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "89"},
          {"2", "98"},
          {"3", "103"},
          {"4", "105"},
          {"5", "105"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[60]//TableForm=",
  CellTags->"Frequencies"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FromBitVector", "ObjectName",
  CellTags->"FromBitVector"],

Cell["Type: function", "Highlight",
  CellTags->"FromBitVector"],

Cell[TextData[{
  StyleBox["FromBitVector[B,U]", "MR"],
  "  transforms bitvector ",
  StyleBox["B", "MR"],
  " into a subset of universe ",
  StyleBox["U", "MR"],
  ". "
}], "Usage",
  CellTags->"FromBitVector"],

Cell["A bitvector is understood to be a 0/1-integer list.", "Notes",
  CellTags->"FromBitVector"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToBitVector",
    ButtonData:>"ToBitVector",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FromBitVector"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FromBitVector"],

Cell["Conversion from a bitvector to an actual subset.", "ExampleText",
  CellTags->"FromBitVector"],

Cell[CellGroupData[{

Cell["all = Tuples[3,{0,1}]", "Input",
  CellLabel->"In[41]:=",
  CellTags->"FromBitVector"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 1}, {0, 1, 0}, {0, 1, 1}, {1, 0, 0}, {1, 0, 1}, {1, 
        1, 0}, {1, 1, 1}}\)], "Output",
  CellLabel->"Out[41]=",
  CellTags->"FromBitVector"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(FromBitVector[#, {a, b, c}] &\)\  /@ \ all\)], "Input",
  CellLabel->"In[43]:=",
  CellTags->"FromBitVector"],

Cell[BoxData[
    \({{}, {c}, {b}, {b, c}, {a}, {a, c}, {a, b}, {a, b, c}}\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->"FromBitVector"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FromEps", "ObjectName",
  CellTags->"FromEps"],

Cell["Type: function", "Highlight",
  CellTags->"FromEps"],

Cell[TextData[{
  StyleBox["FromEps[x]", "MR"],
  "  replaces all occurences of ",
  StyleBox["Eps", "MR"],
  StyleBox[",", "Text"],
  " ",
  StyleBox["\"Eps\"", "MR"],
  " and \[Epsilon]  in ",
  StyleBox["x", "MR"],
  " by the empty string."
}], "Usage",
  CellTags->"FromEps"],

Cell["Used internally as a clean up before further processing.", "Notes",
  CellTags->"FromEps"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToEps",
    ButtonData:>"ToEps",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FromEps"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FromEps"],

Cell["All versions of epsilon are recognized. ", "ExampleText",
  CellTags->"FromEps"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Eps, "\<Eps\>", "\<\>", \[Epsilon]}\  // \ FromEps\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->"FromEps"],

Cell[BoxData[
    \({\*"\<\"\"\>", \*"\<\"\"\>", \*"\<\"\"\>", \*"\<\"\"\>"}\)], "Output",
  CellLabel->"Out[40]=",
  CellTags->"FromEps"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FromIdentityString", "ObjectName",
  CellTags->"FromIdentityString"],

Cell["Type: function", "Highlight",
  CellTags->"FromIdentityString"],

Cell[TextData[{
  StyleBox["FromIdentityString[x]", "MR"],
  "  replaces all occurences of ",
  StyleBox["$identitystring", "MR"],
  " in ",
  StyleBox["x", "MR"],
  " by the empty string."
}], "Usage",
  CellTags->"FromIdentityString"],

Cell[TextData[{
  StyleBox["$identitystring", "MR"],
  " is by default \"1\"."
}], "Notes",
  CellTags->"FromIdentityString"],

Cell[TextData[StyleBox["Used internally to clean up rewrite systems in \
algebraic notation.", "Text"]], "Notes",
  CellTags->"FromIdentityString"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AlgebraicForm",
    ButtonData:>"AlgebraicForm",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["EquationsToWitnesses",
    ButtonData:>"EquationsToWitnesses",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["FromIdentityString",
    ButtonData:>"FromIdentityString",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["identitystring",
    ButtonData:>"identitystring",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["SimplifyRewriteSystem",
    ButtonData:>"SimplifyRewriteSystem",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["TableSG",
    ButtonData:>"TableSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ToIdentityString",
    ButtonData:>"ToIdentityString",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"FromIdentityString"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"FromIdentityString"],

Cell["Removing elements introduced for pretty-printing.", "ExampleText",
  CellTags->"FromIdentityString"],

Cell["eq = {{\"aaa\",\"1\"},{\"bbb\",\"1\"}}; ", "Input",
  CellLabel->"In[47]:=",
  CellTags->"FromIdentityString"],

Cell[CellGroupData[{

Cell["eq // PrintEquations", "Input",
  CellLabel->"In[50]:=",
  CellTags->"FromIdentityString"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("1" \(\(:\)\(\ \)\) \("aaa" \[Rule] "1"\)\)},
          {\("2" \(\(:\)\(\ \)\) \("bbb" \[Rule] "1"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ "1", "aaa" -> "1"], 
        ColonForm[ "2", "bbb" -> "1"]}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[50]//TableForm=",
  CellTags->"FromIdentityString"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FromIdentityString[eq] // PrintEquations", "Input",
  CellLabel->"In[51]:=",
  CellTags->"FromIdentityString"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("1" \(\(:\)\(\ \)\) \("aaa" \[Rule] \*"\<\"\"\>"\)\)},
          {\("2" \(\(:\)\(\ \)\) \("bbb" \[Rule] \*"\<\"\"\>"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ "1", "aaa" -> ""], 
        ColonForm[ "2", "bbb" -> ""]}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[51]//TableForm=",
  CellTags->"FromIdentityString"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GenerateCSM", "ObjectName",
  CellTags->"GenerateCSM"],

Cell["Type: function", "Highlight",
  CellTags->"GenerateCSM"],

Cell[TextData[{
  StyleBox["GenerateCSM[q0,dot,K,opts]", "MR"],
  "  produces the cyclic semimodule generated by ",
  StyleBox["q0", "MR"],
  " and operation ",
  StyleBox["dot", "MR"],
  ". "
}], "Usage",
  CellTags->"GenerateCSM"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Equations", "\[Rule]", "False", "-"},
          {"BoundCSM", "\[Rule]", "1000", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"GenerateCSM"],

Cell[TextData[{
  "Option ",
  StyleBox["Equations->True", "MR"],
  "  causes a list of witnesses and rewrite rules to be returned in addition \
to the cyclic semimodule. "
}], "Notes",
  CellTags->"GenerateCSM"],

Cell[TextData[{
  "Option ",
  StyleBox["BoundCSM->n", "MR"],
  "  allows to construct larger modules."
}], "Notes",
  CellTags->"GenerateCSM"],

Cell[TextData[{
  "The return object  ",
  StyleBox["dot[p,s]", "MR"],
  "  must be an element of the semimodule where ",
  StyleBox["p", "MR"],
  " is an element of the semimodule and ",
  StyleBox["s", "MR"],
  " is a symbol in the alphabet. "
}], "Notes",
  CellTags->"GenerateCSM"],

Cell["\<\
Can be used to construct the accessible parts of a variety of \
automata.\
\>", "Notes",
  CellTags->"GenerateCSM"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GenerateCSM"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"GenerateCSM"],

Cell["\<\
A small example over a one-letter alphabet: a lasso with a loop of \
size 2.\
\>", "ExampleText",
  CellTags->"GenerateCSM"],

Cell[BoxData[{
    \(op[p_, "\<a\>"] := p + 1 /; p < 7\), "\n", 
    \(op[_, "\<a\>"] := 5\)}], "Input",
  CellLabel->"In[194]:=",
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"GenerateCSM"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({Q, W, eq} = 
        GenerateCSM[0, op, {a}, Equations \[Rule] True];\)\), "\n", 
    \(Q\), "\n", 
    \(PrintWitnesses[Q, W]\), "\n", 
    \(PrintEquations[eq]\)}], "Input",
  CellLabel->"In[196]:=",
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"GenerateCSM"],

Cell[BoxData[
    \({0, 1, 2, 3, 4, 5, 6}\)], "Output",
  CellLabel->"Out[197]=",
  CellTags->"GenerateCSM"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\[Epsilon]", "0"},
          {"2", "\<\"a\"\>", "1"},
          {"3", "\<\"aa\"\>", "2"},
          {"4", "\<\"aaa\"\>", "3"},
          {"5", "\<\"aaaa\"\>", "4"},
          {"6", "\<\"aaaaa\"\>", "5"},
          {"7", "\<\"aaaaaa\"\>", "6"}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, None}, TableSpacing -> {1, 
          1}, TableDepth -> 2]]]], "Output",
  CellLabel->"Out[198]//TableForm=",
  CellTags->"GenerateCSM"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("1" \(\(:\)\(\ \)\) \("aaaaaaa" \[Rule] "aaaaa"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ "1", "aaaaaaa" -> "aaaaa"]}, TableSpacing -> {1, 
        1}]]], "Output",
  CellLabel->"Out[199]//TableForm=",
  CellTags->"GenerateCSM"]
}, Open  ]],

Cell["A two-letter example.", "ExampleText",
  CellTags->"GenerateCSM"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(dot[{p_, q_}, "\<a\>"] := {Mod[p + 2, 7], q};\)\), "\n", 
    \(\(dot[{p_, q_}, "\<b\>"] := {p, Mod[q + 1, 3]};\)\), "\n", 
    \(GenerateCSM[{0, 0}, dot, {a, b}]\)}], "Input",
  CellLabel->"In[214]:=",
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"GenerateCSM"],

Cell[BoxData[
    \({{0, 0}, {0, 1}, {0, 2}, {1, 0}, {1, 1}, {1, 2}, {2, 0}, {2, 1}, {2, 
        2}, {3, 0}, {3, 1}, {3, 2}, {4, 0}, {4, 1}, {4, 2}, {5, 0}, {5, 
        1}, {5, 2}, {6, 0}, {6, 1}, {6, 2}}\)], "Output",
  CellLabel->"Out[216]=",
  CellTags->"GenerateCSM"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GenerateSG", "ObjectName",
  CellTags->"GenerateSG"],

Cell["Type: function", "Highlight",
  CellTags->"GenerateSG"],

Cell[TextData[{
  StyleBox["GenerateSG[gen]", "MR"],
  "  produces the semigroup generated by the generators ",
  StyleBox["gen", "MR"],
  ".  "
}], "Usage",
  CellTags->"GenerateSG"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"Equations", "\[Rule]", "False", "-"},
          {"Filter", "\[Rule]", "Identity", "-"},
          {"DClasses", "\[Rule]", "False", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"GenerateSG"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " causes the corresponding monoid to be generated. "
}], "Notes",
  CellTags->"GenerateSG"],

Cell[TextData[{
  "Option ",
  StyleBox["Equations->True", "MR"],
  " returns a triple ",
  StyleBox["{S,W,eq}", "MR"],
  " where ",
  StyleBox["S", "MR"],
  " is the semigroup, ",
  StyleBox["W", "MR"],
  " is a list of corresponding witnesses, and ",
  StyleBox["eq", "MR"],
  " is the canonical rewrite system for  ",
  StyleBox["S", "MR"],
  ". "
}], "Notes",
  CellTags->"GenerateSG"],

Cell[TextData[{
  "Option ",
  StyleBox["DClasses->True", "MR"],
  " in addition returns the D-class decomposition of the semigroup."
}], "Notes",
  CellTags->"GenerateSG"],

Cell["\<\
Option Full->True causes the corresponding monoid to be generated. \
\
\>", "Notes",
  CellTags->"GenerateSG"],

Cell["\<\
With the internal implementation one can also generate semigroups \
of matrices. The operations for the matrix semiring must be overloaded on \
Plus and Times, operation Dot is used for matrix multiplication.\
\>", "Notes",\

  CellTags->"GenerateSG"],

Cell[TextData[{
  StyleBox["NonCommutativeMultiply", "MR"],
  " is used as multiplication for transformation semigroups. "
}], "Notes",
  CellTags->"GenerateSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["SyntacticSG",
    ButtonData:>"SyntacticSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GEN",
    ButtonData:>"GEN",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DC",
    ButtonData:>"DC",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"GenerateSG"],

Cell["\<\
Two generators suffice to produce the symmetric group, say, on 3 \
points.\
\>", "ExampleText",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{

Cell["\<\
g = GEN[3,2,{T[2,3,1],T[2,1,3]}];
GenerateSG[ g ]
% // Length\
\>", "Input",
  CellLabel->"In[1]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \(SG[T[1, 2, 3], T[1, 3, 2], T[2, 1, 3], T[2, 3, 1], T[3, 1, 2], 
      T[3, 2, 1]]\)], "Output",
  CellLabel->"Out[2]="],

Cell[BoxData[
    \(6\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExtAutomata[]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(LinkObject["./extaut", 2, 2]\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
We can produce additional information: witnesses and the \
corresponding equations.\
\>", "ExampleText",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \(\({S, W, eq}\  = \ GenerateSG[g, Equations \[Rule] True];\)\)], "Input",\

  CellLabel->"In[59]:=",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintWitnesses[S, W]\)], "Input",
  CellLabel->"In[60]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"a\"\>", \(T[2, 3, 1]\)},
          {"2", "\<\"b\"\>", \(T[2, 1, 3]\)},
          {"3", "\<\"aa\"\>", \(T[3, 1, 2]\)},
          {"4", "\<\"ab\"\>", \(T[1, 3, 2]\)},
          {"5", "\<\"ba\"\>", \(T[3, 2, 1]\)},
          {"6", "\<\"bb\"\>", \(T[1, 2, 3]\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, None}, TableSpacing -> {1, 
          1}, TableDepth -> 2]]]], "Output",
  CellLabel->"Out[60]//TableForm=",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell["\<\
The witnesses show how to multiply the generators to obain a \
certain element in the group.\
\>", "ExampleText",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T[2, 3, 1] ** T[2, 1, 3]\)], "Input",
  CellLabel->"In[61]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \(T[1, 3, 2]\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell["\<\
The equations, or rewrite rules, show how to simplify more \
complicated products of the generators symbolically.\
\>", "ExampleText",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintEquations[eq]\)], "Input",
  CellLabel->"In[62]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("1" \(\(:\)\(\ \)\) \("aaa" \[Rule] "bb"\)\)},
          {\("2" \(\(:\)\(\ \)\) \("aab" \[Rule] "ba"\)\)},
          {\("3" \(\(:\)\(\ \)\) \("aba" \[Rule] "b"\)\)},
          {\("4" \(\(:\)\(\ \)\) \("abb" \[Rule] "a"\)\)},
          {\("5" \(\(:\)\(\ \)\) \("baa" \[Rule] "ab"\)\)},
          {\("6" \(\(:\)\(\ \)\) \("bab" \[Rule] "aa"\)\)},
          {\("7" \(\(:\)\(\ \)\) \("bba" \[Rule] "a"\)\)},
          {\("8" \(\(:\)\(\ \)\) \("bbb" \[Rule] "b"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ "1", "aaa" -> "bb"], 
        ColonForm[ "2", "aab" -> "ba"], 
        ColonForm[ "3", "aba" -> "b"], 
        ColonForm[ "4", "abb" -> "a"], 
        ColonForm[ "5", "baa" -> "ab"], 
        ColonForm[ "6", "bab" -> "aa"], 
        ColonForm[ "7", "bba" -> "a"], 
        ColonForm[ "8", "bbb" -> "b"]}, TableSpacing -> {1, 1}]]], "Output",
  CellLabel->"Out[62]//TableForm=",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T[2, 3, 1]\^3 === T[2, 1, 3]\^2\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordReduce[\ aabababa, \ eq, \ DoTrace \[Rule] True\ ]\)], "Input",
  CellLabel->"In[64]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"aabababa\"\>", \({2, 1, 3}\)},
          {"2", "\<\"baababa\"\>", \({2, 2, 4}\)},
          {"3", "\<\"bbaaba\"\>", \({2, 3, 5}\)},
          {"4", "\<\"bbbaa\"\>", \({5, 3, 5}\)},
          {"5", "\<\"bbab\"\>", \({6, 2, 4}\)},
          {"6", "\<\"baa\"\>", \({5, 1, 3}\)},
          {"7", "\<\"ab\"\>", 
            InterpretationBox["\<\"\"\>",
              {}]}
          },
        RowSpacings->1,
        ColumnSpacings->5,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDepth -> 2, TableSpacing -> {1, 5}, 
          TableHeadings -> {Automatic, None}]]]], "Output",
  CellLabel->"Out[64]//TableForm=",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell["\<\
Here is a larger example, complete with D-class decomposition. \
There are 3 regular D-classes in this case. \
\>", "ExampleText",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \(\(g\  = \ GEN[4, 2, {T[2, 4, 1, 4], T[3, 1, 4, 4]}];\)\)], "Input",
  CellLabel->"In[392]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \(\({S, W, eq, dcl}\  = \ 
        GenerateSG[g, DClasses \[Rule] True];\)\)], "Input",
  CellLabel->"In[393]:=",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(S\  // \ Length\), "\n", 
    \(DClassDimensions[dcl]\)}], "Input",
  CellLabel->"In[394]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \(14\)], "Output",
  CellLabel->"Out[394]=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \({{2, 2, 1}, {3, 3, 1}, {1, 1, 1}}\)], "Output",
  CellLabel->"Out[395]=",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell[TextData[{
  "The second ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  "-class, once as a matrix of transformations, and once in witness form. "
}], "ExampleText",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"GenerateSG"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(AssignFunction[h, ToList[S], W, Opts \[Rule] Listable]; 
    D2\  = \ DClassToBlocks[
        dcl\[LeftDoubleBracket]2\[RightDoubleBracket]];\), "\n", 
    \(D2\  // \ MatrixForm\), "\n", 
    \(h[D2]\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[396]:=",
  AspectRatioFixed->True,
  CellTags->"GenerateSG"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[1, 4, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[2, 4, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[3, 4, 4, 4]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 4, 1, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 4, 2, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 4, 3, 4]\)}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 1, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 2, 4, 4]\)}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(T[4, 3, 4, 4]\)}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{
        T[ 1, 4, 4, 4]}, {
        T[ 2, 4, 4, 4]}, {
        T[ 3, 4, 4, 4]}}, {{
        T[ 4, 4, 1, 4]}, {
        T[ 4, 4, 2, 4]}, {
        T[ 4, 4, 3, 4]}}, {{
        T[ 4, 1, 4, 4]}, {
        T[ 4, 2, 4, 4]}, {
        T[ 4, 3, 4, 4]}}}]]], "Output",
  CellLabel->"Out[397]//MatrixForm=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"abba\"\>"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"baa\"\>"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"abb\"\>"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"aab\"\>"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"aa\"\>"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"aabb\"\>"}
                    }], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"bba\"\>"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"bbaa\"\>"}
                    }], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {"\<\"bb\"\>"}
                    }], "\[NoBreak]", ")"}]}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {{{"abba"}, {"baa"}, {"abb"}}, {{"aab"}, {"aa"}, {
        "aabb"}}, {{"bba"}, {"bbaa"}, {"bb"}}}]]], "Output",
  CellLabel->"Out[398]//MatrixForm=",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell[TextData[{
  "All the ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  "-classes have size 1, so the semigroup is aperiodic."
}], "ExampleText",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"GenerateSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AperiodicQSG[S]\)], "Input",
  CellLabel->"In[399]:=",
  CellTags->"GenerateSG"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[399]=",
  CellTags->"GenerateSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GreenHQT", "ObjectName",
  CellTags->"GreenHQT"],

Cell["Type: function", "Highlight",
  CellTags->"GreenHQT"],

Cell[TextData[{
  StyleBox["GreenRQT[x,y,S]", "MR"],
  "  tests whether transformations ",
  StyleBox["x", "MR"],
  " and ",
  StyleBox["y", "MR"],
  " are J-equivalent in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"GreenHQT"],

Cell[TextData[{
  "See also  ",
  ButtonBox["GreenJQT.xml",
    ButtonData:>"GreenJQT.xml",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GreenLQT.xml",
    ButtonData:>"GreenLQT.xml",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GreenRQT.xml",
    ButtonData:>"GreenRQT.xml",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"GreenHQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GreenJQT", "ObjectName",
  CellTags->"GreenJQT"],

Cell["Type: function", "Highlight",
  CellTags->"GreenJQT"],

Cell[TextData[{
  StyleBox["GreenRQT[x,y,S]", "MR"],
  "  tests whether transformations ",
  StyleBox["x", "MR"],
  " and ",
  StyleBox["y", "MR"],
  " are J-equivalent in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"GreenJQT"],

Cell[TextData[{
  "See also  ",
  ButtonBox["GreenHQT.xml",
    ButtonData:>"GreenHQT.xml",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GreenLQT.xml",
    ButtonData:>"GreenLQT.xml",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GreenRQT.xml",
    ButtonData:>"GreenRQT.xml",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"GreenJQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GreenLQT", "ObjectName",
  CellTags->"GreenLQT"],

Cell["Type: function", "Highlight",
  CellTags->"GreenLQT"],

Cell[TextData[{
  StyleBox["GreenRQT[x,y,S]", "MR"],
  "  tests whether transformations ",
  StyleBox["x", "MR"],
  " and ",
  StyleBox["y", "MR"],
  " are L-equivalent in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"GreenLQT"],

Cell[TextData[{
  "See also  ",
  ButtonBox["GreenHQT.xml",
    ButtonData:>"GreenHQT.xml",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GreenJQT.xml",
    ButtonData:>"GreenJQT.xml",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GreenRQT.xml",
    ButtonData:>"GreenRQT.xml",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"GreenLQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GreenRQT", "ObjectName",
  CellTags->"GreenRQT"],

Cell["Type: function", "Highlight",
  CellTags->"GreenRQT"],

Cell[TextData[{
  StyleBox["GreenRQT[x,y,S]", "MR"],
  "  tests whether transformations ",
  StyleBox["x", "MR"],
  " and ",
  StyleBox["y", "MR"],
  " are R-equivalent in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"GreenRQT"],

Cell[TextData[{
  "See also  ",
  ButtonBox["GreenHQT.xml",
    ButtonData:>"GreenHQT.xml",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GreenJQT.xml",
    ButtonData:>"GreenJQT.xml",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GreenLQT.xml",
    ButtonData:>"GreenLQT.xml",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"GreenRQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GridLine", "ObjectName",
  CellTags->"GridLine"],

Cell["Type: function", "Highlight",
  CellTags->"GridLine"],

Cell[TextData[{
  StyleBox["GridLine[n,m]", "MR"],
  "   generates a graphics object representing an ",
  StyleBox["n", "MR"],
  " by ",
  StyleBox["m", "MR"],
  " grid of points. "
}], "Usage",
  CellTags->"GridLine"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"PlotStyle", "\[Rule]", \({GrayLevel[0.8], $defthinline}\), "-"},
          {"GridOffset", "\[Rule]", \({0, 0}\), "-"},
          {"Full", "\[Rule]", "All", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"GridLine"],

Cell["Line size and color can be controlled by options.", "Notes",
  CellTags->"GridLine"],

Cell[TextData[{
  "See also ",
  ButtonBox["GridPoints",
    ButtonData:>"GridPoints",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GridLine"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"GridLine"],

Cell["The basic grid.", "ExampleText",
  CellTags->"GridLine"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(GridLine[5, 5]\  // \ Show;\)\)], "Input",
  CellLabel->"In[147]:=",
  CellTags->"GridLine"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.0220726 0.110363 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 g
.003 w
[ ] 0 setdash
.14286 .08829 m
.14286 .52974 L
s
.32143 .08829 m
.32143 .52974 L
s
.5 .08829 m
.5 .52974 L
s
.67857 .08829 m
.67857 .52974 L
s
.85714 .08829 m
.85714 .52974 L
s
.14286 .08829 m
.85714 .08829 L
s
.14286 .19865 m
.85714 .19865 L
s
.14286 .30902 m
.85714 .30902 L
s
.14286 .41938 m
.85714 .41938 L
s
.14286 .52974 m
.85714 .52974 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[147]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"GridLine"]
}, Open  ]],

Cell["Using options to control details.", "ExampleText",
  CellTags->"GridLine"],

Cell[BoxData[{
    \(\(gr1 = GridLine[4, 5];\)\), "\n", 
    \(\(gr2 = 
        GridLine[4, 5, PlotStyle \[Rule] {Red, 0.02}, 
          Full \[Rule] {{1, 1}, {1, 2}, {2, 2}, {2, 3}, {3, 3}, {4, 3}, {4, 
                4}, {5, 4}}];\)\)}], "Input",
  CellLabel->"In[167]:=",
  AspectRatioFixed->True,
  CellTags->"GridLine"],

Cell[CellGroupData[{

Cell["Show[gr1,gr2];", "Input",
  CellLabel->"In[169]:=",
  CellTags->"GridLine"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.026871 0.134355 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 g
.003 w
[ ] 0 setdash
.14286 .10748 m
.14286 .51055 L
s
.32143 .10748 m
.32143 .51055 L
s
.5 .10748 m
.5 .51055 L
s
.67857 .10748 m
.67857 .51055 L
s
.85714 .10748 m
.85714 .51055 L
s
.14286 .10748 m
.85714 .10748 L
s
.14286 .24184 m
.85714 .24184 L
s
.14286 .37619 m
.85714 .37619 L
s
.14286 .51055 m
.85714 .51055 L
s
1 0 0 r
.02 w
.14286 .10748 m
.14286 .24184 L
.32143 .24184 L
.32143 .37619 L
.5 .37619 L
.67857 .37619 L
.67857 .51055 L
.85714 .51055 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[169]:=",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"GridLine"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GridPoints", "ObjectName",
  CellTags->"GridPoints"],

Cell["Type: function", "Highlight",
  CellTags->"GridPoints"],

Cell[TextData[{
  StyleBox["GridPoints[n,m]", "MR"],
  "  generates a graphics object representing an ",
  StyleBox["n", "MR"],
  " by ",
  StyleBox["m", "MR"],
  " grid of points. "
}], "Usage",
  CellTags->"GridPoints"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"LabelGrid", "\[Rule]", "None", "-"},
          {"Full", "\[Rule]", "All", "-"},
          {"LabelPoints", "\[Rule]", "None", "-"},
          {"PlotStyle", 
            "\[RuleDelayed]", \({{Blue, $defpointsize}, {Red, 
                1.2  $defpointsize}}\), "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"GridPoints"],

Cell["Dot size and color can be controlled by options.", "Notes",
  CellTags->"GridPoints"],

Cell[TextData[{
  "See also ",
  ButtonBox["GridLine",
    ButtonData:>"GridLine",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GridPoints"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"GridPoints"],

Cell["The basic image.", "ExampleText",
  CellTags->"GridPoints"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(GridPoints[5, 5]\  // \ Show;\)\)], "Input",
  CellLabel->"In[144]:=",
  AspectRatioFixed->True,
  CellTags->"GridPoints"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.0220726 0.110363 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.012 w
.14286 .08829 Mdot
.14286 .19865 Mdot
.14286 .30902 Mdot
.14286 .41938 Mdot
.14286 .52974 Mdot
.32143 .08829 Mdot
.32143 .19865 Mdot
.32143 .30902 Mdot
.32143 .41938 Mdot
.32143 .52974 Mdot
.5 .08829 Mdot
.5 .19865 Mdot
.5 .30902 Mdot
.5 .41938 Mdot
.5 .52974 Mdot
.67857 .08829 Mdot
.67857 .19865 Mdot
.67857 .30902 Mdot
.67857 .41938 Mdot
.67857 .52974 Mdot
.85714 .08829 Mdot
.85714 .19865 Mdot
.85714 .30902 Mdot
.85714 .41938 Mdot
.85714 .52974 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[144]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"GridPoints"]
}, Open  ]],

Cell["Cum bells and whistles.", "ExampleText",
  CellTags->"GridPoints"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(GridPoints[20, 20, Full \[Rule] \((Mod[#1 + #2\^2, 7] == 0 &)\), 
          PlotStyle \[Rule] {{Cyan,  .02}, {Yellow,  .03}}, 
          Frame \[Rule] True, FrameTicks \[Rule] None, 
          Background \[Rule] LightSkyBlue]\ \  // \ Show;\)\)], "Input",
  CellLabel->"In[145]:=",
  AspectRatioFixed->True,
  CellTags->"GridPoints"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.529 .808 .98 r
MFill
% Scaling calculations
-0.00970874 0.0485437 -0.00600033 0.0300016 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 1 r
.02 w
.03883 .024 Mdot
.03883 .054 Mdot
.03883 .084 Mdot
.03883 .11401 Mdot
.03883 .14401 Mdot
.03883 .17401 Mdot
.03883 .20401 Mdot
.03883 .23401 Mdot
.03883 .26401 Mdot
.03883 .294.1 Mdot
.03883 .324.1 Mdot
.03883 .354.1 Mdot
.03883 .384.1 Mdot
.03883 .414.1 Mdot
.03883 .444.1 Mdot
.03883 .47403 Mdot
.03883 .50403 Mdot
.03883 .53403 Mdot
.03883 .56403 Mdot
.03883 .59403 Mdot
.08738 .024 Mdot
.08738 .054 Mdot
.08738 .084 Mdot
.08738 .11401 Mdot
.08738 .14401 Mdot
.08738 .17401 Mdot
.08738 .20401 Mdot
.08738 .23401 Mdot
.08738 .26401 Mdot
.08738 .294.1 Mdot
.08738 .324.1 Mdot
.08738 .354.1 Mdot
.08738 .384.1 Mdot
.08738 .414.1 Mdot
.08738 .444.1 Mdot
.08738 .47403 Mdot
.08738 .50403 Mdot
.08738 .53403 Mdot
.08738 .56403 Mdot
.08738 .59403 Mdot
.13592 .024 Mdot
.13592 .084 Mdot
.13592 .11401 Mdot
.13592 .17401 Mdot
.13592 .20401 Mdot
.13592 .23401 Mdot
.13592 .294.1 Mdot
.13592 .324.1 Mdot
.13592 .384.1 Mdot
.13592 .414.1 Mdot
.13592 .444.1 Mdot
.13592 .50403 Mdot
.13592 .53403 Mdot
.13592 .59403 Mdot
.18447 .024 Mdot
.18447 .054 Mdot
.18447 .084 Mdot
.18447 .11401 Mdot
.18447 .14401 Mdot
.18447 .17401 Mdot
.18447 .20401 Mdot
.18447 .23401 Mdot
.18447 .26401 Mdot
.18447 .294.1 Mdot
.18447 .324.1 Mdot
.18447 .354.1 Mdot
.18447 .384.1 Mdot
.18447 .414.1 Mdot
.18447 .444.1 Mdot
.18447 .47403 Mdot
.18447 .50403 Mdot
.18447 .53403 Mdot
.18447 .56403 Mdot
.18447 .59403 Mdot
.23301 .024 Mdot
.23301 .054 Mdot
.23301 .14401 Mdot
.23301 .17401 Mdot
.23301 .20401 Mdot
.23301 .23401 Mdot
.23301 .26401 Mdot
.23301 .354.1 Mdot
.23301 .384.1 Mdot
.23301 .414.1 Mdot
.23301 .444.1 Mdot
.23301 .47403 Mdot
.23301 .56403 Mdot
.23301 .59403 Mdot
.28155 .054 Mdot
.28155 .084 Mdot
.28155 .11401 Mdot
.28155 .14401 Mdot
.28155 .20401 Mdot
.28155 .26401 Mdot
.28155 .294.1 Mdot
.28155 .324.1 Mdot
.28155 .354.1 Mdot
.28155 .414.1 Mdot
.28155 .47403 Mdot
.28155 .50403 Mdot
.28155 .53403 Mdot
.28155 .56403 Mdot
.3301 .024 Mdot
.3301 .054 Mdot
.3301 .084 Mdot
.3301 .11401 Mdot
.3301 .14401 Mdot
.3301 .17401 Mdot
.3301 .23401 Mdot
.3301 .26401 Mdot
.3301 .294.1 Mdot
.3301 .324.1 Mdot
.3301 .354.1 Mdot
.3301 .384.1 Mdot
.3301 .444.1 Mdot
.3301 .47403 Mdot
.3301 .50403 Mdot
.3301 .53403 Mdot
.3301 .56403 Mdot
.3301 .59403 Mdot
.37864 .024 Mdot
.37864 .054 Mdot
.37864 .084 Mdot
.37864 .11401 Mdot
.37864 .14401 Mdot
.37864 .17401 Mdot
.37864 .20401 Mdot
.37864 .23401 Mdot
.37864 .26401 Mdot
.37864 .294.1 Mdot
.37864 .324.1 Mdot
.37864 .354.1 Mdot
.37864 .384.1 Mdot
.37864 .414.1 Mdot
.37864 .444.1 Mdot
.37864 .47403 Mdot
.37864 .50403 Mdot
.37864 .53403 Mdot
.37864 .56403 Mdot
.37864 .59403 Mdot
.42718 .024 Mdot
.42718 .054 Mdot
.42718 .084 Mdot
.42718 .11401 Mdot
.42718 .14401 Mdot
.42718 .17401 Mdot
.42718 .20401 Mdot
.42718 .23401 Mdot
.42718 .26401 Mdot
.42718 .294.1 Mdot
.42718 .324.1 Mdot
.42718 .354.1 Mdot
.42718 .384.1 Mdot
.42718 .414.1 Mdot
.42718 .444.1 Mdot
.42718 .47403 Mdot
.42718 .50403 Mdot
.42718 .53403 Mdot
.42718 .56403 Mdot
.42718 .59403 Mdot
.47573 .024 Mdot
.47573 .084 Mdot
.47573 .11401 Mdot
.47573 .17401 Mdot
.47573 .20401 Mdot
.47573 .23401 Mdot
.47573 .294.1 Mdot
.47573 .324.1 Mdot
.47573 .384.1 Mdot
.47573 .414.1 Mdot
.47573 .444.1 Mdot
.47573 .50403 Mdot
.47573 .53403 Mdot
.47573 .59403 Mdot
.52427 .024 Mdot
.52427 .054 Mdot
.52427 .084 Mdot
.52427 .11401 Mdot
.52427 .14401 Mdot
.52427 .17401 Mdot
.52427 .20401 Mdot
.52427 .23401 Mdot
.52427 .26401 Mdot
.52427 .294.1 Mdot
.52427 .324.1 Mdot
.52427 .354.1 Mdot
.52427 .384.1 Mdot
.52427 .414.1 Mdot
.52427 .444.1 Mdot
.52427 .47403 Mdot
.52427 .50403 Mdot
.52427 .53403 Mdot
.52427 .56403 Mdot
.52427 .59403 Mdot
.57282 .024 Mdot
.57282 .054 Mdot
.57282 .14401 Mdot
.57282 .17401 Mdot
.57282 .20401 Mdot
.57282 .23401 Mdot
.57282 .26401 Mdot
.57282 .354.1 Mdot
.57282 .384.1 Mdot
.57282 .414.1 Mdot
.57282 .444.1 Mdot
.57282 .47403 Mdot
.57282 .56403 Mdot
.57282 .59403 Mdot
.62136 .054 Mdot
.62136 .084 Mdot
.62136 .11401 Mdot
.62136 .14401 Mdot
.62136 .20401 Mdot
.62136 .26401 Mdot
.62136 .294.1 Mdot
.62136 .324.1 Mdot
.62136 .354.1 Mdot
.62136 .414.1 Mdot
.62136 .47403 Mdot
.62136 .50403 Mdot
.62136 .53403 Mdot
.62136 .56403 Mdot
.6699 .024 Mdot
.6699 .054 Mdot
.6699 .084 Mdot
.6699 .11401 Mdot
.6699 .14401 Mdot
.6699 .17401 Mdot
.6699 .23401 Mdot
.6699 .26401 Mdot
.6699 .294.1 Mdot
.6699 .324.1 Mdot
.6699 .354.1 Mdot
.6699 .384.1 Mdot
.6699 .444.1 Mdot
.6699 .47403 Mdot
.6699 .50403 Mdot
.6699 .53403 Mdot
.6699 .56403 Mdot
.6699 .59403 Mdot
.71845 .024 Mdot
.71845 .054 Mdot
.71845 .084 Mdot
.71845 .11401 Mdot
.71845 .14401 Mdot
.71845 .17401 Mdot
.71845 .20401 Mdot
.71845 .23401 Mdot
.71845 .26401 Mdot
.71845 .294.1 Mdot
.71845 .324.1 Mdot
.71845 .354.1 Mdot
.71845 .384.1 Mdot
.71845 .414.1 Mdot
.71845 .444.1 Mdot
.71845 .47403 Mdot
.71845 .50403 Mdot
.71845 .53403 Mdot
.71845 .56403 Mdot
.71845 .59403 Mdot
.76699 .024 Mdot
.76699 .054 Mdot
.76699 .084 Mdot
.76699 .11401 Mdot
.76699 .14401 Mdot
.76699 .17401 Mdot
.76699 .20401 Mdot
.76699 .23401 Mdot
.76699 .26401 Mdot
.76699 .294.1 Mdot
.76699 .324.1 Mdot
.76699 .354.1 Mdot
.76699 .384.1 Mdot
.76699 .414.1 Mdot
.76699 .444.1 Mdot
.76699 .47403 Mdot
.76699 .50403 Mdot
.76699 .53403 Mdot
.76699 .56403 Mdot
.76699 .59403 Mdot
.81553 .024 Mdot
.81553 .084 Mdot
.81553 .11401 Mdot
.81553 .17401 Mdot
.81553 .20401 Mdot
.81553 .23401 Mdot
.81553 .294.1 Mdot
.81553 .324.1 Mdot
.81553 .384.1 Mdot
.81553 .414.1 Mdot
.81553 .444.1 Mdot
.81553 .50403 Mdot
.81553 .53403 Mdot
.81553 .59403 Mdot
.86408 .024 Mdot
.86408 .054 Mdot
.86408 .084 Mdot
.86408 .11401 Mdot
.86408 .14401 Mdot
.86408 .17401 Mdot
.86408 .20401 Mdot
.86408 .23401 Mdot
.86408 .26401 Mdot
.86408 .294.1 Mdot
.86408 .324.1 Mdot
.86408 .354.1 Mdot
.86408 .384.1 Mdot
.86408 .414.1 Mdot
.86408 .444.1 Mdot
.86408 .47403 Mdot
.86408 .50403 Mdot
.86408 .53403 Mdot
.86408 .56403 Mdot
.86408 .59403 Mdot
.91262 .024 Mdot
.91262 .054 Mdot
.91262 .14401 Mdot
.91262 .17401 Mdot
.91262 .20401 Mdot
.91262 .23401 Mdot
.91262 .26401 Mdot
.91262 .354.1 Mdot
.91262 .384.1 Mdot
.91262 .414.1 Mdot
.91262 .444.1 Mdot
.91262 .47403 Mdot
.91262 .56403 Mdot
.91262 .59403 Mdot
.96117 .054 Mdot
.96117 .084 Mdot
.96117 .11401 Mdot
.96117 .14401 Mdot
.96117 .20401 Mdot
.96117 .26401 Mdot
.96117 .294.1 Mdot
.96117 .324.1 Mdot
.96117 .354.1 Mdot
.96117 .414.1 Mdot
.96117 .47403 Mdot
.96117 .50403 Mdot
.96117 .53403 Mdot
.96117 .56403 Mdot
1 1 0 r
.03 w
.13592 .054 Mdot
.13592 .14401 Mdot
.13592 .26401 Mdot
.13592 .354.1 Mdot
.13592 .47403 Mdot
.13592 .56403 Mdot
.23301 .084 Mdot
.23301 .11401 Mdot
.23301 .294.1 Mdot
.23301 .324.1 Mdot
.23301 .50403 Mdot
.23301 .53403 Mdot
.28155 .024 Mdot
.28155 .17401 Mdot
.28155 .23401 Mdot
.28155 .384.1 Mdot
.28155 .444.1 Mdot
.28155 .59403 Mdot
.3301 .20401 Mdot
.3301 .414.1 Mdot
.47573 .054 Mdot
.47573 .14401 Mdot
.47573 .26401 Mdot
.47573 .354.1 Mdot
.47573 .47403 Mdot
.47573 .56403 Mdot
.57282 .084 Mdot
.57282 .11401 Mdot
.57282 .294.1 Mdot
.57282 .324.1 Mdot
.57282 .50403 Mdot
.57282 .53403 Mdot
.62136 .024 Mdot
.62136 .17401 Mdot
.62136 .23401 Mdot
.62136 .384.1 Mdot
.62136 .444.1 Mdot
.62136 .59403 Mdot
.6699 .20401 Mdot
.6699 .414.1 Mdot
.81553 .054 Mdot
.81553 .14401 Mdot
.81553 .26401 Mdot
.81553 .354.1 Mdot
.81553 .47403 Mdot
.81553 .56403 Mdot
.91262 .084 Mdot
.91262 .11401 Mdot
.91262 .294.1 Mdot
.91262 .324.1 Mdot
.91262 .50403 Mdot
.91262 .53403 Mdot
.96117 .024 Mdot
.96117 .17401 Mdot
.96117 .23401 Mdot
.96117 .384.1 Mdot
.96117 .444.1 Mdot
.96117 .59403 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[145]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"GridPoints"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["HClassSize", "ObjectName",
  CellTags->"HClassSize"],

Cell["Type: function", "Highlight",
  CellTags->"HClassSize"],

Cell[TextData[{
  StyleBox["HClassSize[dc]", "MR"],
  "  returns the size of the H-classes of D-class ",
  StyleBox["dc", "MR"],
  "."
}], "Usage",
  CellTags->"HClassSize"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"HClassSize"],

Cell[TextData[{
  "See also ",
  ButtonBox["DClassDimensions",
    ButtonData:>"DClassDimensions",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DClassSize",
    ButtonData:>"DClassSize",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"HClassSize"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HClassT", "ObjectName",
  CellTags->"HClassT"],

Cell["Type: function", "Highlight",
  CellTags->"HClassT"],

Cell[TextData[{
  StyleBox["HClassT[x,S]", "MR"],
  "  returns the H-class of a regular element ",
  StyleBox["x", "MR"],
  " in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"HClassT"],

Cell["Returns a flat list of transformations.", "Notes",
  CellTags->"HClassT"],

Cell[TextData[{
  "See ",
  ButtonBox["DClassT",
    ButtonData:>"DClassT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"HClassT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HTrivialQSG", "ObjectName",
  CellTags->"HTrivialQSG"],

Cell["Type: function", "Highlight",
  CellTags->"HTrivialQSG"],

Cell[TextData[{
  StyleBox["HTrivialQSG[S]", "MR"],
  "  tests whether semigroup ",
  StyleBox["S", "MR"],
  " is H-trivial."
}], "Usage",
  CellTags->"HTrivialQSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQSG",
    ButtonData:>"AperiodicQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["JTrivialQSG",
    ButtonData:>"JTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyCommQSG",
    ButtonData:>"LocallyCommQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyIdemQSG",
    ButtonData:>"LocallyIdemQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["MonoidQSG",
    ButtonData:>"MonoidQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["NilpotentQSG",
    ButtonData:>"NilpotentQSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"HTrivialQSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell["HueRasterColors", "ObjectName",
  CellTags->"HueRasterColors"],

Cell["Type: function", "Highlight",
  CellTags->"HueRasterColors"],

Cell[TextData[{
  StyleBox["HueRasterColors[p]", "MR"],
  "  can be used in ",
  StyleBox["PlotMatrix", "MR"],
  " to control colors. "
}], "Usage",
  CellTags->"HueRasterColors"],

Cell[TextData[{
  "Provides an alternative to ",
  StyleBox["$rastercolor", "MR"],
  "."
}], "Notes",
  CellTags->"HueRasterColors"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["RasterStyle",
    ButtonData:>"RasterStyle",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"HueRasterColors"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"HueRasterColors"],

Cell["Exclusive or, in hues.", "ExampleText",
  CellTags->"HueRasterColors"],

Cell[BoxData[
    \(\(m = Table[BitXor[i, j], {i, 0, 31}, {j, 0, 31}];\)\)], "Input",
  CellLabel->"In[234]:=",
  CellTags->"HueRasterColors"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotMatrix[m, RasterStyle \[Rule] HueRasterColors[32]];\)\)], "Input",\

  CellLabel->"In[236]:=",
  CellTags->"HueRasterColors"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.0297619 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
96 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF0030FF0060FF0090FF00C0FF00F0E000FFB000FF8000FF5000FF2000FF0010FF0040FF
0070FF00A0FF00D0FF00FFFF00FFD000FFA000FF7000FF4000FF1020FF0050FF0080FF00
B0FF00E0FF00FFF000FFC000FF9000FF6000FF3000FF0000
FF0060FF0030FF00C0FF0090E000FFFF00F08000FFB000FF2000FF5000FF0040FF0010FF
00A0FF0070FF00FFFF00D0FF00FFA000FFD000FF4000FF7020FF0000FF1080FF0050FF00
E0FF00B0FF00FFC000FFF000FF6000FF9000FF0000FF3000
FF0090FF00C0FF0030FF0060B000FF8000FFFF00F0E000FF0010FF0040FF5000FF2000FF
00D0FF00FFFF0070FF00A0FF00FF7000FF4000FFD000FFA050FF0080FF0000FF1020FF00
FFF000FFC000B0FF00E0FF00FF3000FF0000FF9000FF6000
FF00C0FF0090FF0060FF00308000FFB000FFE000FFFF00F00040FF0010FF2000FF5000FF
00FFFF00D0FF00A0FF0070FF00FF4000FF7000FFA000FFD080FF0050FF0020FF0000FF10
FFC000FFF000E0FF00B0FF00FF0000FF3000FF6000FF9000
FF00F0E000FFB000FF8000FFFF0030FF0060FF0090FF00C00070FF00A0FF00D0FF00FFFF
5000FF2000FF0010FF0040FF00FF1020FF0050FF0080FF0000FFD000FFA000FF7000FF40
FF9000FF6000FF3000FF0000B0FF00E0FF00FFF000FFC000
E000FFFF00F08000FFB000FFFF0060FF0030FF00C0FF009000A0FF0070FF00FFFF00D0FF
2000FF5000FF0040FF0010FF20FF0000FF1080FF0050FF0000FFA000FFD000FF4000FF70
FF6000FF9000FF0000FF3000E0FF00B0FF00FFC000FFF000
B000FF8000FFFF00F0E000FFFF0090FF00C0FF0030FF006000D0FF00FFFF0070FF00A0FF
0010FF0040FF5000FF2000FF50FF0080FF0000FF1020FF0000FF7000FF4000FFD000FFA0
FF3000FF0000FF9000FF6000FFF000FFC000B0FF00E0FF00
8000FFB000FFE000FFFF00F0FF00C0FF0090FF0060FF003000FFFF00D0FF00A0FF0070FF
0040FF0010FF2000FF5000FF80FF0050FF0020FF0000FF1000FF4000FF7000FFA000FFD0
FF0000FF3000FF6000FF9000FFC000FFF000E0FF00B0FF00
5000FF2000FF0010FF0040FF0070FF00A0FF00D0FF00FFFFFF0030FF0060FF0090FF00C0
FF00F0E000FFB000FF8000FFB0FF00E0FF00FFF000FFC000FF9000FF6000FF3000FF0000
00FFD000FFA000FF7000FF4000FF1020FF0050FF0080FF00
2000FF5000FF0040FF0010FF00A0FF0070FF00FFFF00D0FFFF0060FF0030FF00C0FF0090
E000FFFF00F08000FFB000FFE0FF00B0FF00FFC000FFF000FF6000FF9000FF0000FF3000
00FFA000FFD000FF4000FF7020FF0000FF1080FF0050FF00
0010FF0040FF5000FF2000FF00D0FF00FFFF0070FF00A0FFFF0090FF00C0FF0030FF0060
B000FF8000FFFF00F0E000FFFFF000FFC000B0FF00E0FF00FF3000FF0000FF9000FF6000
00FF7000FF4000FFD000FFA050FF0080FF0000FF1020FF00
0040FF0010FF2000FF5000FF00FFFF00D0FF00A0FF0070FFFF00C0FF0090FF0060FF0030
8000FFB000FFE000FFFF00F0FFC000FFF000E0FF00B0FF00FF0000FF3000FF6000FF9000
00FF4000FF7000FFA000FFD080FF0050FF0020FF0000FF10
0070FF00A0FF00D0FF00FFFF5000FF2000FF0010FF0040FFFF00F0E000FFB000FF8000FF
FF0030FF0060FF0090FF00C0FF9000FF6000FF3000FF0000B0FF00E0FF00FFF000FFC000
00FF1020FF0050FF0080FF0000FFD000FFA000FF7000FF40
00A0FF0070FF00FFFF00D0FF2000FF5000FF0040FF0010FFE000FFFF00F08000FFB000FF
FF0060FF0030FF00C0FF0090FF6000FF9000FF0000FF3000E0FF00B0FF00FFC000FFF000
20FF0000FF1080FF0050FF0000FFA000FFD000FF4000FF70
00D0FF00FFFF0070FF00A0FF0010FF0040FF5000FF2000FFB000FF8000FFFF00F0E000FF
FF0090FF00C0FF0030FF0060FF3000FF0000FF9000FF6000FFF000FFC000B0FF00E0FF00
50FF0080FF0000FF1020FF0000FF7000FF4000FFD000FFA0
00FFFF00D0FF00A0FF0070FF0040FF0010FF2000FF5000FF8000FFB000FFE000FFFF00F0
FF00C0FF0090FF0060FF0030FF0000FF3000FF6000FF9000FFC000FFF000E0FF00B0FF00
80FF0050FF0020FF0000FF1000FF4000FF7000FFA000FFD0
00FFD000FFA000FF7000FF4000FF1020FF0050FF0080FF00B0FF00E0FF00FFF000FFC000
FF9000FF6000FF3000FF0000FF0030FF0060FF0090FF00C0FF00F0E000FFB000FF8000FF
5000FF2000FF0010FF0040FF0070FF00A0FF00D0FF00FFFF
00FFA000FFD000FF4000FF7020FF0000FF1080FF0050FF00E0FF00B0FF00FFC000FFF000
FF6000FF9000FF0000FF3000FF0060FF0030FF00C0FF0090E000FFFF00F08000FFB000FF
2000FF5000FF0040FF0010FF00A0FF0070FF00FFFF00D0FF
00FF7000FF4000FFD000FFA050FF0080FF0000FF1020FF00FFF000FFC000B0FF00E0FF00
FF3000FF0000FF9000FF6000FF0090FF00C0FF0030FF0060B000FF8000FFFF00F0E000FF
0010FF0040FF5000FF2000FF00D0FF00FFFF0070FF00A0FF
00FF4000FF7000FFA000FFD080FF0050FF0020FF0000FF10FFC000FFF000E0FF00B0FF00
FF0000FF3000FF6000FF9000FF00C0FF0090FF0060FF00308000FFB000FFE000FFFF00F0
0040FF0010FF2000FF5000FF00FFFF00D0FF00A0FF0070FF
00FF1020FF0050FF0080FF0000FFD000FFA000FF7000FF40FF9000FF6000FF3000FF0000
B0FF00E0FF00FFF000FFC000FF00F0E000FFB000FF8000FFFF0030FF0060FF0090FF00C0
0070FF00A0FF00D0FF00FFFF5000FF2000FF0010FF0040FF
20FF0000FF1080FF0050FF0000FFA000FFD000FF4000FF70FF6000FF9000FF0000FF3000
E0FF00B0FF00FFC000FFF000E000FFFF00F08000FFB000FFFF0060FF0030FF00C0FF0090
00A0FF0070FF00FFFF00D0FF2000FF5000FF0040FF0010FF
50FF0080FF0000FF1020FF0000FF7000FF4000FFD000FFA0FF3000FF0000FF9000FF6000
FFF000FFC000B0FF00E0FF00B000FF8000FFFF00F0E000FFFF0090FF00C0FF0030FF0060
00D0FF00FFFF0070FF00A0FF0010FF0040FF5000FF2000FF
80FF0050FF0020FF0000FF1000FF4000FF7000FFA000FFD0FF0000FF3000FF6000FF9000
FFC000FFF000E0FF00B0FF008000FFB000FFE000FFFF00F0FF00C0FF0090FF0060FF0030
00FFFF00D0FF00A0FF0070FF0040FF0010FF2000FF5000FF
B0FF00E0FF00FFF000FFC000FF9000FF6000FF3000FF000000FFD000FFA000FF7000FF40
00FF1020FF0050FF0080FF005000FF2000FF0010FF0040FF0070FF00A0FF00D0FF00FFFF
FF0030FF0060FF0090FF00C0FF00F0E000FFB000FF8000FF
E0FF00B0FF00FFC000FFF000FF6000FF9000FF0000FF300000FFA000FFD000FF4000FF70
20FF0000FF1080FF0050FF002000FF5000FF0040FF0010FF00A0FF0070FF00FFFF00D0FF
FF0060FF0030FF00C0FF0090E000FFFF00F08000FFB000FF
FFF000FFC000B0FF00E0FF00FF3000FF0000FF9000FF600000FF7000FF4000FFD000FFA0
50FF0080FF0000FF1020FF000010FF0040FF5000FF2000FF00D0FF00FFFF0070FF00A0FF
FF0090FF00C0FF0030FF0060B000FF8000FFFF00F0E000FF
FFC000FFF000E0FF00B0FF00FF0000FF3000FF6000FF900000FF4000FF7000FFA000FFD0
80FF0050FF0020FF0000FF100040FF0010FF2000FF5000FF00FFFF00D0FF00A0FF0070FF
FF00C0FF0090FF0060FF00308000FFB000FFE000FFFF00F0
FF9000FF6000FF3000FF0000B0FF00E0FF00FFF000FFC00000FF1020FF0050FF0080FF00
00FFD000FFA000FF7000FF400070FF00A0FF00D0FF00FFFF5000FF2000FF0010FF0040FF
FF00F0E000FFB000FF8000FFFF0030FF0060FF0090FF00C0
FF6000FF9000FF0000FF3000E0FF00B0FF00FFC000FFF00020FF0000FF1080FF0050FF00
00FFA000FFD000FF4000FF7000A0FF0070FF00FFFF00D0FF2000FF5000FF0040FF0010FF
E000FFFF00F08000FFB000FFFF0060FF0030FF00C0FF0090
FF3000FF0000FF9000FF6000FFF000FFC000B0FF00E0FF0050FF0080FF0000FF1020FF00
00FF7000FF4000FFD000FFA000D0FF00FFFF0070FF00A0FF0010FF0040FF5000FF2000FF
B000FF8000FFFF00F0E000FFFF0090FF00C0FF0030FF0060
FF0000FF3000FF6000FF9000FFC000FFF000E0FF00B0FF0080FF0050FF0020FF0000FF10
00FF4000FF7000FFA000FFD000FFFF00D0FF00A0FF0070FF0040FF0010FF2000FF5000FF
8000FFB000FFE000FFFF00F0FF00C0FF0090FF0060FF0030
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[236]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"HueRasterColors"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IdealT", "ObjectName",
  CellTags->"IdealT"],

Cell["Type: function", "Highlight",
  CellTags->"IdealT"],

Cell[TextData[{
  StyleBox["IdealT[x,S]", "MR"],
  "  computes the two-sided ideal generated by transformation ",
  StyleBox["x", "MR"],
  " in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"IdealT"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"IdealT"],

Cell[TextData[{
  "See also ",
  ButtonBox["LeftIdealT",
    ButtonData:>"LeftIdealT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RightIdealT",
    ButtonData:>"RightIdealT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IdealT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IdealT"],

Cell["\<\
The full transformation semigroup on 3 points, and some of its \
ideals.\
\>", "ExampleText",
  CellTags->"IdealT"],

Cell[BoxData[
    \(\(S = TransformationSG[3];\)\)], "Input",
  CellLabel->"In[70]:=",
  CellTags->"IdealT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IdealT[\ S[\([1]\)], \ S\ ]\)], "Input",
  CellLabel->"In[72]:=",
  CellTags->"IdealT"],

Cell[BoxData[
    \({T[1, 1, 1], T[2, 2, 2], T[3, 3, 3]}\)], "Output",
  CellLabel->"Out[72]=",
  CellTags->"IdealT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IdealT[\ S[\([2]\)], \ S\ ]\)], "Input",
  CellLabel->"In[73]:=",
  CellTags->"IdealT"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 2], T[1, 1, 3], T[1, 2, 1], T[1, 2, 2], 
      T[1, 3, 1], T[1, 3, 3], T[2, 1, 1], T[2, 1, 2], T[2, 2, 1], T[2, 2, 2], 
      T[2, 2, 3], T[2, 3, 2], T[2, 3, 3], T[3, 1, 1], T[3, 1, 3], T[3, 2, 2], 
      T[3, 2, 3], T[3, 3, 1], T[3, 3, 2], T[3, 3, 3]}\)], "Output",
  CellLabel->"Out[73]=",
  CellTags->"IdealT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IdemQT", "ObjectName",
  CellTags->"IdemQT"],

Cell["Type: function", "Highlight",
  CellTags->"IdemQT"],

Cell[TextData[{
  StyleBox["IdemQT[x]", "MR"],
  "  tests whether transformation ",
  StyleBox["x", "MR"],
  " is idempotent."
}], "Usage",
  CellTags->"IdemQT"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["InGroupSG",
    ButtonData:>"InGroupSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdemSG",
    ButtonData:>"IdemSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IdemQT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IdemQT"],

Cell["The full transformation semigroup on 3 points.", "ExampleText",
  CellTags->"IdemQT"],

Cell[BoxData[
    \(\(S = ToList@TransformationSG[3];\)\)], "Input",
  CellLabel->"In[66]:=",
  CellTags->"IdemQT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[S, IdemQT\ ]\)], "Input",
  CellLabel->"In[67]:=",
  CellTags->"IdemQT"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 3], T[1, 2, 1], T[1, 2, 2], T[1, 2, 3], 
      T[1, 3, 3], T[2, 2, 2], T[2, 2, 3], T[3, 2, 3], T[3, 3, 3]}\)], "Output",\

  CellLabel->"Out[67]=",
  CellTags->"IdemQT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IdemSG", "ObjectName",
  CellTags->"IdemSG"],

Cell["Type: function", "Highlight",
  CellTags->"IdemSG"],

Cell[TextData[{
  StyleBox["IdemSG[S]", "MR"],
  "  lists the idempotent elements of a semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"IdemSG"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"IdemSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["InGroupSG",
    ButtonData:>"InGroupSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdemQT",
    ButtonData:>"IdemQT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IdemSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IdemSG"],

Cell["The full transformation semigroup on 3 points.", "ExampleText",
  CellTags->"IdemSG"],

Cell[BoxData[
    \(\(S = TransformationSG[3];\)\)], "Input",
  CellLabel->"In[64]:=",
  CellTags->"IdemSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IdemSG[S]\)], "Input",
  CellLabel->"In[65]:=",
  CellTags->"IdemSG"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 3], T[1, 2, 1], T[1, 2, 2], T[1, 2, 3], 
      T[1, 3, 3], T[2, 2, 2], T[2, 2, 3], T[3, 2, 3], T[3, 3, 3]}\)], "Output",\

  CellLabel->"Out[65]=",
  CellTags->"IdemSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImageT", "ObjectName",
  CellTags->"ImageT"],

Cell["Type: function", "Highlight",
  CellTags->"ImageT"],

Cell[TextData[{
  StyleBox["ImageT[t]", "MR"],
  "  gives the range of transformation ",
  StyleBox["t", "MR"],
  " as an ordered list."
}], "Usage",
  CellTags->"ImageT"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"ImageT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CollapseT",
    ButtonData:>"CollapseT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RankT",
    ButtonData:>"RankT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["KernelT",
    ButtonData:>"KernelT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"ImageT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ImageT"],

Cell["The images of all transformations on 3 points.", "ExampleText",
  CellTags->"ImageT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#, ImageT[#]} &\) /@ 
        ToList@TransformationSG[3] // \ \(Curry[TableForm]\)[
        TableDepth \[Rule] 2]\)], "Input",
  CellLabel->"In[464]:=",
  CellTags->"ImageT"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(T[1, 1, 1]\), \({1}\)},
          {\(T[1, 1, 2]\), \({1, 2}\)},
          {\(T[1, 1, 3]\), \({1, 3}\)},
          {\(T[1, 2, 1]\), \({1, 2}\)},
          {\(T[1, 2, 2]\), \({1, 2}\)},
          {\(T[1, 2, 3]\), \({1, 2, 3}\)},
          {\(T[1, 3, 1]\), \({1, 3}\)},
          {\(T[1, 3, 2]\), \({1, 2, 3}\)},
          {\(T[1, 3, 3]\), \({1, 3}\)},
          {\(T[2, 1, 1]\), \({1, 2}\)},
          {\(T[2, 1, 2]\), \({1, 2}\)},
          {\(T[2, 1, 3]\), \({1, 2, 3}\)},
          {\(T[2, 2, 1]\), \({1, 2}\)},
          {\(T[2, 2, 2]\), \({2}\)},
          {\(T[2, 2, 3]\), \({2, 3}\)},
          {\(T[2, 3, 1]\), \({1, 2, 3}\)},
          {\(T[2, 3, 2]\), \({2, 3}\)},
          {\(T[2, 3, 3]\), \({2, 3}\)},
          {\(T[3, 1, 1]\), \({1, 3}\)},
          {\(T[3, 1, 2]\), \({1, 2, 3}\)},
          {\(T[3, 1, 3]\), \({1, 3}\)},
          {\(T[3, 2, 1]\), \({1, 2, 3}\)},
          {\(T[3, 2, 2]\), \({2, 3}\)},
          {\(T[3, 2, 3]\), \({2, 3}\)},
          {\(T[3, 3, 1]\), \({1, 3}\)},
          {\(T[3, 3, 2]\), \({2, 3}\)},
          {\(T[3, 3, 3]\), \({3}\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableDepth -> 2]]]], "Output",
  CellLabel->"Out[464]//TableForm=",
  CellTags->"ImageT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IndToWitnesses", "ObjectName",
  CellTags->"IndToWitnesses"],

Cell["Type: function", "Highlight",
  CellTags->"IndToWitnesses"],

Cell[TextData[{
  StyleBox["IndToWitnesses[ind]", "MR"],
  "   returns a bit vector for the  representatives for each class in an \\\n\
equivalence relation given by an  index  ",
  StyleBox["ind", "MR"],
  "."
}], "Usage",
  CellTags->"IndToWitnesses"],

Cell[TextData[{
  "As a transformation ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\[LongRightArrow]\([n]\)\)]],
  ", the index is required to be idempotent and deflationary."
}], "Notes",
  CellTags->"IndToWitnesses"],

Cell[TextData[{
  "See also ",
  ButtonBox["MakeIndex",
    ButtonData:>"MakeIndex",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["ToClasses",
    ButtonData:>"ToClasses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IndToWitnesses"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IndToWitnesses"],

Cell["An arbitrary relation. ", "ExampleText",
  CellTags->"IndToWitnesses"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IndToWitnesses[\ {1, 2, 1, 2, 5, 1, 2, 5}]\)], "Input",
  CellLabel->"In[49]:=",
  CellTags->"IndToWitnesses"],

Cell[BoxData[
    \({1, 1, 0, 0, 1, 0, 0, 1}\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InGroupQT", "ObjectName",
  CellTags->"InGroupQT"],

Cell["Type: function", "Highlight",
  CellTags->"InGroupQT"],

Cell[TextData[{
  StyleBox["InGroupQT[x]", "MR"],
  "  tests whether transformation ",
  StyleBox["x", "MR"],
  " lies in a group."
}], "Usage",
  CellTags->"InGroupQT"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdemSG",
    ButtonData:>"IdemSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["InGroupSG",
    ButtonData:>"InGroupSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"InGroupQT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"InGroupQT"],

Cell["The full transformation semigroup on 3 points.", "ExampleText",
  CellTags->"InGroupQT"],

Cell[BoxData[
    \(\(S = ToList@TransformationSG[3];\)\)], "Input",
  CellLabel->"In[60]:=",
  CellTags->"InGroupQT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[\ S, \ InGroupQT\ ]\)], "Input",
  CellLabel->"In[61]:=",
  CellTags->"InGroupQT"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 3], T[1, 2, 1], T[1, 2, 2], T[1, 2, 3], 
      T[1, 3, 2], T[1, 3, 3], T[2, 1, 1], T[2, 1, 2], T[2, 1, 3], T[2, 2, 2], 
      T[2, 2, 3], T[2, 3, 1], T[2, 3, 2], T[3, 1, 1], T[3, 1, 2], T[3, 2, 1], 
      T[3, 2, 3], T[3, 3, 1], T[3, 3, 2], T[3, 3, 3]}\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->"InGroupQT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InGroupSG", "ObjectName",
  CellTags->"InGroupSG"],

Cell["Type: function", "Highlight",
  CellTags->"InGroupSG"],

Cell[TextData[{
  StyleBox["InGroupSG[S]", "MR"],
  "  produces all elements in semigroup ",
  StyleBox["S", "MR"],
  " that belong to a subgroup of ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"InGroupSG"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"InGroupSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdemSG",
    ButtonData:>"IdemSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["InGroupQT",
    ButtonData:>"InGroupQT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"InGroupSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"InGroupSG"],

Cell["The full transformation semigroup on 3 points.", "ExampleText",
  CellTags->"InGroupSG"],

Cell[BoxData[
    \(\(S = TransformationSG[3];\)\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"InGroupSG"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(IdemSG[S]\), "\n", 
    \(InGroupSG[S]\)}], "Input",
  CellLabel->"In[56]:=",
  CellTags->"InGroupSG"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 3], T[1, 2, 1], T[1, 2, 2], T[1, 2, 3], 
      T[1, 3, 3], T[2, 2, 2], T[2, 2, 3], T[3, 2, 3], T[3, 3, 3]}\)], "Output",\

  CellLabel->"Out[56]=",
  CellTags->"InGroupSG"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 3], T[1, 2, 1], T[1, 2, 2], T[1, 2, 3], 
      T[1, 3, 2], T[1, 3, 3], T[2, 1, 1], T[2, 1, 2], T[2, 1, 3], T[2, 2, 2], 
      T[2, 2, 3], T[2, 3, 1], T[2, 3, 2], T[3, 1, 1], T[3, 1, 2], T[3, 2, 1], 
      T[3, 2, 3], T[3, 3, 1], T[3, 3, 2], T[3, 3, 3]}\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->"InGroupSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Complement[ToList[S], InGroupSG[S]]\)], "Input",
  CellLabel->"In[59]:=",
  CellTags->"InGroupSG"],

Cell[BoxData[
    \({T[1, 1, 2], T[1, 3, 1], T[2, 2, 1], T[2, 3, 3], T[3, 1, 3], 
      T[3, 2, 2]}\)], "Output",
  CellLabel->"Out[59]=",
  CellTags->"InGroupSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["InverseT", "ObjectName",
  CellTags->"InverseT"],

Cell["Type: function", "Highlight",
  CellTags->"InverseT"],

Cell[TextData[{
  StyleBox["InverseT[x]", "MR"],
  "  computes the inverse of a transformation ",
  StyleBox["x", "MR"],
  "."
}], "Usage",
  CellTags->"InverseT"],

Cell[TextData[{
  "The inverse is in the group generated by ",
  StyleBox["x", "MR"],
  ", if it exists."
}], "Notes",
  CellTags->"InverseT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CollapseT",
    ButtonData:>"CollapseT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"InverseT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"InverseT"],

Cell["The inverses of the symmetric group on 3 points.", "ExampleText",
  CellTags->"InverseT"],

Cell[CellGroupData[{

Cell["\<\
S = SymmetricGroupSG[3];
{#,InverseT[#]}& /@ ToList[S] // TableForm\
\>", "Input",
  CellLabel->"In[43]:=",
  CellTags->"InverseT"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(T[1, 2, 3]\), \(T[1, 2, 3]\)},
          {\(T[1, 3, 2]\), \(T[1, 3, 2]\)},
          {\(T[2, 1, 3]\), \(T[2, 1, 3]\)},
          {\(T[2, 3, 1]\), \(T[3, 1, 2]\)},
          {\(T[3, 1, 2]\), \(T[2, 3, 1]\)},
          {\(T[3, 2, 1]\), \(T[3, 2, 1]\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[44]//TableForm=",
  CellTags->"InverseT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IrreducibleQ", "ObjectName",
  CellTags->"IrreducibleQ"],

Cell["Type: function", "Highlight",
  CellTags->"IrreducibleQ"],

Cell[TextData[{
  StyleBox["IrreducibleQ[w,eq]", "MR"],
  "  test is word ",
  StyleBox["w", "MR"],
  " is irreducible with respect to the rewrite system ",
  StyleBox["eq", "MR"],
  ". "
}], "Usage",
  CellTags->"IrreducibleQ"],

Cell[TextData[{
  "Note that only the left hand sides of ",
  StyleBox["eq", "MR"],
  " are used."
}], "Notes",
  CellTags->"IrreducibleQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"IrreducibleQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"IrreducibleQ"],

Cell["A small rewrite system.", "ExampleText",
  CellTags->"IrreducibleQ"],

Cell[BoxData[
    \(\(eq = {aaa \[Rule] b, aba \[Rule] a};\)\)], "Input",
  CellLabel->"In[47]:=",
  CellTags->"IrreducibleQ"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(IrreducibleQ[\ abababa, \ eq\ ]\), "\n", 
    \(IrreducibleQ[\ abbabb, \ eq\ ]\)}], "Input",
  CellLabel->"In[49]:=",
  CellTags->"IrreducibleQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[49]=",
  CellTags->"IrreducibleQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[50]=",
  CellTags->"IrreducibleQ"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["JTrivialQSG", "ObjectName",
  CellTags->"JTrivialQSG"],

Cell["Type: function", "Highlight",
  CellTags->"JTrivialQSG"],

Cell[TextData[{
  StyleBox["JTrivialQSG[S]", "MR"],
  "  tests whether semigroup ",
  StyleBox["S", "MR"],
  " is J-trivial"
}], "Usage",
  CellTags->"JTrivialQSG"],

Cell["Tests whether all J-classes have cardinality 1. ", "Notes",
  CellTags->"JTrivialQSG"],

Cell[TextData[{
  "Since ",
  StyleBox["S", "MR"],
  " is finite this is the same as being D-trivial."
}], "Notes",
  CellTags->"JTrivialQSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQSG",
    ButtonData:>"AperiodicQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["HTrivialQSG",
    ButtonData:>"HTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyCommQSG",
    ButtonData:>"LocallyCommQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyIdemQSG",
    ButtonData:>"LocallyIdemQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["MonoidQSG",
    ButtonData:>"MonoidQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["NilpotentQSG",
    ButtonData:>"NilpotentQSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"JTrivialQSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell["JTrivialSG", "ObjectName",
  CellTags->"JTrivialSG"],

Cell["Type: function", "Highlight",
  CellTags->"JTrivialSG"],

Cell[TextData[{
  StyleBox["JTrivialSG[n]", "MR"],
  "  generates the J-trivial semigroup of all order preserving inflationary \
transformations. "
}], "Usage",
  CellTags->"JTrivialSG"],

Cell[TextData[{
  StyleBox["JTrivialSG[n,b]", "MR"],
  " generates only those transformations with values at least ",
  StyleBox["b", "MR"],
  "."
}], "Notes",
  CellTags->"JTrivialSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["JTrivialQSG",
    ButtonData:>"JTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["SymmetricGroupSG",
    ButtonData:>"SymmetricGroupSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["AlternatingGroupSG",
    ButtonData:>"AlternatingGroupSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"JTrivialSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"JTrivialSG"],

Cell["Some J-trivial semigroups.", "ExampleText",
  CellTags->"JTrivialSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(JTrivialSG[4]\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"JTrivialSG"],

Cell[BoxData[
    \(SG[T[1, 2, 3, 4], T[1, 2, 4, 4], T[1, 3, 3, 4], T[1, 3, 4, 4], 
      T[1, 4, 4, 4], T[2, 2, 3, 4], T[2, 2, 4, 4], T[2, 3, 3, 4], 
      T[2, 3, 4, 4], T[2, 4, 4, 4], T[3, 3, 3, 4], T[3, 3, 4, 4], 
      T[3, 4, 4, 4], T[4, 4, 4, 4]]\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"JTrivialSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(JTrivialSG[4, 2]\)], "Input",
  CellLabel->"In[47]:=",
  CellTags->"JTrivialSG"],

Cell[BoxData[
    \(SG[T[2, 2, 3, 4], T[2, 2, 4, 4], T[2, 3, 3, 4], T[2, 3, 4, 4], 
      T[2, 4, 4, 4], T[3, 3, 3, 4], T[3, 3, 4, 4], T[3, 4, 4, 4], 
      T[4, 4, 4, 4]]\)], "Output",
  CellLabel->"Out[47]=",
  CellTags->"JTrivialSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell["JTrivialQSG[%]", "Input",
  CellLabel->"In[48]:=",
  CellTags->"JTrivialSG"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->"JTrivialSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["KernelImageToT", "ObjectName",
  CellTags->"KernelImageToT"],

Cell["Type: function", "Highlight",
  CellTags->"KernelImageToT"],

Cell[TextData[{
  StyleBox["KernelImageToT[ker,im]", "MR"],
  "  reconstructs a transformation given its range and kernel. "
}], "Usage",
  CellTags->"KernelImageToT"],

Cell["\<\
Note that this works only because kernels and images are ordered \
lists rather than sets.\
\>", "Notes",
  CellTags->"KernelImageToT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CollapseT",
    ButtonData:>"CollapseT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ImageT",
    ButtonData:>"ImageT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["KernelT",
    ButtonData:>"KernelT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"KernelImageToT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"KernelImageToT"],

Cell["\<\
Given the image and kernel we can reconstruct the transformation.\
\
\>", "ExampleText",
  CellTags->"KernelImageToT"],

Cell[CellGroupData[{

Cell["t = RandomT[10]", "Input",
  CellLabel->"In[466]:=",
  CellTags->"KernelImageToT"],

Cell[BoxData[
    \(T[9, 2, 4, 10, 2, 7, 9, 6, 8, 9]\)], "Output",
  CellLabel->"Out[466]=",
  CellTags->"KernelImageToT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(it\  = \ ImageT[t]\), "\n", 
    \(kt\  = \ KernelT[t]\)}], "Input",
  CellLabel->"In[467]:=",
  CellTags->"KernelImageToT"],

Cell[BoxData[
    \({2, 4, 6, 7, 8, 9, 10}\)], "Output",
  CellLabel->"Out[467]=",
  CellTags->"KernelImageToT"],

Cell[BoxData[
    \({{2, 5}, {3}, {8}, {6}, {9}, {1, 7, 10}, {4}}\)], "Output",
  CellLabel->"Out[468]=",
  CellTags->"KernelImageToT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KernelImageToT[kt, it]\)], "Input",
  CellLabel->"In[469]:=",
  CellTags->"KernelImageToT"],

Cell[BoxData[
    \(T[9, 2, 4, 10, 2, 7, 9, 6, 8, 9]\)], "Output",
  CellLabel->"Out[469]=",
  CellTags->"KernelImageToT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["KernelT", "ObjectName",
  CellTags->"KernelT"],

Cell["Type: function", "Highlight",
  CellTags->"KernelT"],

Cell[TextData[{
  StyleBox["KernelT[t]", "MR"],
  "  gives the kernel of transformation ",
  StyleBox["t", "MR"],
  "."
}], "Usage",
  CellTags->"KernelT"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"KernelT"],

Cell[TextData[{
  "Note that the kernel classes are ordered according to ",
  StyleBox["ImageT[t]", "MR"],
  ". Hence, to compare two kernels as equivalence relations one has to sort \
them first."
}], "Notes",
  CellTags->"KernelT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CollapseT",
    ButtonData:>"CollapseT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ImageT",
    ButtonData:>"ImageT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["RankT",
    ButtonData:>"RankT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"KernelT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"KernelT"],

Cell["The kernels of all transformations on 3 points.", "ExampleText",
  CellTags->"KernelT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#, KernelT[#]} &\) /@ 
        ToList@TransformationSG[3] // \ \(Curry[TableForm]\)[
        TableDepth \[Rule] 2]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"KernelT"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(T[1, 1, 1]\), \({{1, 2, 3}}\)},
          {\(T[1, 1, 2]\), \({{1, 2}, {3}}\)},
          {\(T[1, 1, 3]\), \({{1, 2}, {3}}\)},
          {\(T[1, 2, 1]\), \({{1, 3}, {2}}\)},
          {\(T[1, 2, 2]\), \({{1}, {2, 3}}\)},
          {\(T[1, 2, 3]\), \({{1}, {2}, {3}}\)},
          {\(T[1, 3, 1]\), \({{1, 3}, {2}}\)},
          {\(T[1, 3, 2]\), \({{1}, {3}, {2}}\)},
          {\(T[1, 3, 3]\), \({{1}, {2, 3}}\)},
          {\(T[2, 1, 1]\), \({{2, 3}, {1}}\)},
          {\(T[2, 1, 2]\), \({{2}, {1, 3}}\)},
          {\(T[2, 1, 3]\), \({{2}, {1}, {3}}\)},
          {\(T[2, 2, 1]\), \({{3}, {1, 2}}\)},
          {\(T[2, 2, 2]\), \({{1, 2, 3}}\)},
          {\(T[2, 2, 3]\), \({{1, 2}, {3}}\)},
          {\(T[2, 3, 1]\), \({{3}, {1}, {2}}\)},
          {\(T[2, 3, 2]\), \({{1, 3}, {2}}\)},
          {\(T[2, 3, 3]\), \({{1}, {2, 3}}\)},
          {\(T[3, 1, 1]\), \({{2, 3}, {1}}\)},
          {\(T[3, 1, 2]\), \({{2}, {3}, {1}}\)},
          {\(T[3, 1, 3]\), \({{2}, {1, 3}}\)},
          {\(T[3, 2, 1]\), \({{3}, {2}, {1}}\)},
          {\(T[3, 2, 2]\), \({{2, 3}, {1}}\)},
          {\(T[3, 2, 3]\), \({{2}, {1, 3}}\)},
          {\(T[3, 3, 1]\), \({{3}, {1, 2}}\)},
          {\(T[3, 3, 2]\), \({{3}, {1, 2}}\)},
          {\(T[3, 3, 3]\), \({{1, 2, 3}}\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableDepth -> 2]]]], "Output",
  CellLabel->"Out[3]//TableForm=",
  CellTags->"KernelT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["KPermutationsR", "ObjectName",
  CellTags->"KPermutationsR"],

Cell["Type: function", "Highlight",
  CellTags->"KPermutationsR"],

Cell[TextData[{
  StyleBox["KPermutationsR[L,k]", "MR"],
  "  produces a list of all ",
  StyleBox["k", "MR"],
  "-permutations with replacements of elements taken from list ",
  StyleBox["L", "MR"],
  ". "
}], "Usage",
  CellTags->"KPermutationsR"],

Cell[TextData[{
  StyleBox["L = Range[r]", "MR"],
  " can be written as ",
  StyleBox["r", "MR"],
  ", default is ",
  StyleBox["r = 2", "MR"],
  ". "
}], "Notes",
  CellTags->"KPermutationsR"],

Cell[TextData[{
  "For negative values of ",
  StyleBox["k", "MR"],
  ", all ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  "-permutations, ",
  Cell[BoxData[
      \(TraditionalForm\`s\  \[LessEqual] r\)]],
  ",  are produced."
}], "Notes",
  CellTags->"KPermutationsR"],

Cell[TextData[{
  "See also ",
  ButtonBox["Permutations",
    ButtonData:>"Permutations",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"KPermutationsR"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"KPermutationsR"],

Cell["Permutations with replacement.", "ExampleText",
  CellTags->"KPermutationsR"],

Cell[CellGroupData[{

Cell["KPermutationsR[{a,b,c},3]", "Input",
  CellLabel->"In[53]:=",
  CellTags->"KPermutationsR"],

Cell[BoxData[
    \({{a, a, a}, {a, a, b}, {a, a, c}, {a, b, a}, {a, b, b}, {a, b, c}, {a, 
        c, a}, {a, c, b}, {a, c, c}, {b, a, a}, {b, a, b}, {b, a, c}, {b, b, 
        a}, {b, b, b}, {b, b, c}, {b, c, a}, {b, c, b}, {b, c, c}, {c, a, 
        a}, {c, a, b}, {c, a, c}, {c, b, a}, {c, b, b}, {c, b, c}, {c, c, 
        a}, {c, c, b}, {c, c, c}}\)], "Output",
  CellLabel->"Out[53]=",
  CellTags->"KPermutationsR"]
}, Open  ]],

Cell[CellGroupData[{

Cell["KPermutationsR[{a,b},-3]", "Input",
  CellLabel->"In[55]:=",
  CellTags->"KPermutationsR"],

Cell[BoxData[
    \({{a}, {b}, {a, a}, {a, b}, {b, a}, {b, b}, {a, a, a}, {a, a, b}, {a, b, 
        a}, {a, b, b}, {b, a, a}, {b, a, b}, {b, b, a}, {b, b, 
        b}}\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"KPermutationsR"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LabelEdgeList", "ObjectName",
  CellTags->"LabelEdgeList"],

Cell["Type: function", "Highlight",
  CellTags->"LabelEdgeList"],

Cell[TextData[{
  StyleBox["LabelEdgeList[E,lab]", "MR"],
  "  inserts labels into the edge list ",
  StyleBox["E", "MR"],
  " of a graph."
}], "Usage",
  CellTags->"LabelEdgeList"],

Cell["The labels should be given in positional notation.", "Notes",
  CellTags->"LabelEdgeList"],

Cell[TextData[{
  "See ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TypeGraph",
    ButtonData:>"TypeGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LabelEdgeList"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LabelEdgeList"],

Cell["A path gaph, and its labeled version.", "ExampleText",
  CellTags->"LabelEdgeList"],

Cell[CellGroupData[{

Cell["g = PathGraph[4]", "Input",
  CellLabel->"In[108]:=",
  CellTags->"LabelEdgeList"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"4", ",", "3", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}, {3, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[108]=",
  CellTags->"LabelEdgeList"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LabelEdgeList[\ g, {1, 1, 2}]\)], "Input",
  CellLabel->"In[112]:=",
  CellTags->"LabelEdgeList"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"4", ",", "3", ",", "2", ",", 
          TagBox[\({{1, 1, 2}, {2, 1, 3}, {3, 2, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[112]=",
  CellTags->"LabelEdgeList"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LeftIdealT", "ObjectName",
  CellTags->"LeftIdealT"],

Cell["Type: function", "Highlight",
  CellTags->"LeftIdealT"],

Cell[TextData[{
  StyleBox["LeftIdealT[x,S]", "MR"],
  "  computes the left ideal generated by transformation x in semigroup S."
}], "Usage",
  CellTags->"LeftIdealT"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"LeftIdealT"],

Cell[TextData[{
  "See also ",
  ButtonBox["IdealT",
    ButtonData:>"IdealT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RightIdealT",
    ButtonData:>"RightIdealT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LeftIdealT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LeftIdealT"],

Cell["\<\
The full transformation semigroup on 3 points, and some of its left \
ideals.\
\>", "ExampleText",
  CellTags->"LeftIdealT"],

Cell[BoxData[
    \(\(S = TransformationSG[3];\)\)], "Input",
  CellLabel->"In[79]:=",
  CellTags->"LeftIdealT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftIdealT[\ S[\([1]\)], \ S\ ]\)], "Input",
  CellLabel->"In[80]:=",
  CellTags->"LeftIdealT"],

Cell[BoxData[
    \({T[1, 1, 1]}\)], "Output",
  CellLabel->"Out[80]=",
  CellTags->"LeftIdealT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftIdealT[\ S[\([2]\)], \ S\ ]\)], "Input",
  CellLabel->"In[81]:=",
  CellTags->"LeftIdealT"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 2], T[1, 2, 1], T[1, 2, 2], T[2, 1, 1], 
      T[2, 1, 2], T[2, 2, 1], T[2, 2, 2]}\)], "Output",
  CellLabel->"Out[81]=",
  CellTags->"LeftIdealT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LeftNullQT", "ObjectName",
  CellTags->"LeftNullQT"],

Cell["Type: function", "Highlight",
  CellTags->"LeftNullQT"],

Cell[TextData[{
  StyleBox["LeftNullQT[x,S]", "MR"],
  "  tests whether transformation ",
  StyleBox["x", "MR"],
  " is a left null in ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"LeftNullQT"],

Cell["noteworthy", "Notes",
  CellTags->"LeftNullQT"],

Cell[TextData[{
  "See also ",
  ButtonBox["LeftNullSG",
    ButtonData:>"LeftNullSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LeftNullQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LeftNullSG", "ObjectName",
  CellTags->"LeftNullSG"],

Cell["Type: function", "Highlight",
  CellTags->"LeftNullSG"],

Cell[TextData[{
  StyleBox["LeftNullSG[S]", "MR"],
  "  lists the left nulls of a semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"LeftNullSG"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"LeftNullSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["OneSG",
    ButtonData:>"OneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RightNullSG",
    ButtonData:>"RightNullSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NullSG",
    ButtonData:>"NullSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LeftNullSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LeftNullSG"],

Cell["\<\
The full transformation semigroup on 3 points has no \
left-nulls.\
\>", "ExampleText",
  CellTags->"LeftNullSG"],

Cell["S = TransformationSG[3];", "Input",
  CellLabel->"In[99]:=",
  CellTags->"LeftNullSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftNullSG[S]\)], "Input",
  CellLabel->"In[100]:=",
  CellTags->"LeftNullSG"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[100]=",
  CellTags->"LeftNullSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LeftOneQT", "ObjectName",
  CellTags->"LeftOneQT"],

Cell["Type: function", "Highlight",
  CellTags->"LeftOneQT"],

Cell[TextData[{
  StyleBox["LeftOneQT[x,S]", "MR"],
  "  tests whether transformation ",
  StyleBox["x", "MR"],
  " is a left identity in ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"LeftOneQT"],

Cell[TextData[{
  "See also ",
  ButtonBox["LeftOneSG",
    ButtonData:>"LeftOneSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LeftOneQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LeftOneSG", "ObjectName",
  CellTags->"LeftOneSG"],

Cell["Type: function", "Highlight",
  CellTags->"LeftOneSG"],

Cell[TextData[{
  StyleBox["LeftOneSG[S]", "MR"],
  "  lists the left identities of a semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"LeftOneSG"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"LeftOneSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["LeftOneQT",
    ButtonData:>"LeftOneQT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OneSG",
    ButtonData:>"OneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RightOneSG",
    ButtonData:>"RightOneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NullSG",
    ButtonData:>"NullSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LeftOneSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LeftOneSG"],

Cell["\<\
The full transformation semigroup on 3 points has only the identity \
as left-one.\
\>", "ExampleText",
  CellTags->"LeftOneSG"],

Cell["S = TransformationSG[3];", "Input",
  CellLabel->"In[89]:=",
  CellTags->"LeftOneSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LeftOneSG[S]\)], "Input",
  CellLabel->"In[90]:=",
  CellTags->"LeftOneSG"],

Cell[BoxData[
    \({T[1, 2, 3]}\)], "Output",
  CellLabel->"Out[90]=",
  CellTags->"LeftOneSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LocallyCommQSG", "ObjectName",
  CellTags->"LocallyCommQSG"],

Cell["Type: function", "Highlight",
  CellTags->"LocallyCommQSG"],

Cell[TextData[{
  StyleBox["LocallyCommQSG[S]", "MR"],
  "  tests if semigroup ",
  StyleBox["S", "MR"],
  " is locally commutative"
}], "Usage",
  CellTags->"LocallyCommQSG"],

Cell[TextData[{
  "Tests if  ",
  Cell[BoxData[
      \(TraditionalForm\`e\ S\ e\)]],
  " is commutative for each idempotent element ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  "."
}], "Notes",
  CellTags->"LocallyCommQSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQSG",
    ButtonData:>"AperiodicQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["JTrivialQSG",
    ButtonData:>"JTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyCommQSG",
    ButtonData:>"LocallyCommQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyIdemQSG",
    ButtonData:>"LocallyIdemQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["MonoidQSG",
    ButtonData:>"MonoidQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["NilpotentQSG",
    ButtonData:>"NilpotentQSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"LocallyCommQSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LocallyIdemQSG", "ObjectName",
  CellTags->"LocallyIdemQSG"],

Cell["Type: function", "Highlight",
  CellTags->"LocallyIdemQSG"],

Cell[TextData[{
  StyleBox["LocallyIdemQSG[S]", "MR"],
  "  tests if semigroup S is locally idempotent:"
}], "Usage",
  CellTags->"LocallyIdemQSG"],

Cell[TextData[{
  "Tests if  ",
  Cell[BoxData[
      \(TraditionalForm\`e\ S\ e\)]],
  " is idempotent for each idempotent element ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  "."
}], "Notes",
  CellTags->"LocallyIdemQSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQSG",
    ButtonData:>"AperiodicQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["JTrivialQSG",
    ButtonData:>"JTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["HTrivialQSG",
    ButtonData:>"HTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyIdemQSG",
    ButtonData:>"LocallyIdemQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["MonoidQSG",
    ButtonData:>"MonoidQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["NilpotentQSG",
    ButtonData:>"NilpotentQSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"LocallyIdemQSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LongestPath", "ObjectName",
  CellTags->"LongestPath"],

Cell["Type: function", "Highlight",
  CellTags->"LongestPath"],

Cell[TextData[{
  StyleBox["LongestPath[G]", "MR"],
  "  determines the length of a longest path in an acyclic graph ",
  StyleBox["G", "MR"],
  ". "
}], "Usage",
  CellTags->"LongestPath"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"LongestPath"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " produces the lengths of such longest paths for all vertices."
}], "Notes",
  CellTags->"LongestPath"],

Cell[TextData[{
  StyleBox["LongestPath", "MR"],
  " returns the length of a path ending at the target vertex."
}], "Notes",
  CellTags->"LongestPath"],

Cell["\<\
These paths start at an indegree zero point and end at outdegree \
zero vertices or vertices belonging to a non-trivial strongly connected \
component. \
\>", "Notes",
  CellTags->"LongestPath"],

Cell[TextData[{
  "See also  ",
  ButtonBox["ToDAG",
    ButtonData:>"ToDAG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["StronglyConnectedComponents",
    ButtonData:>"StronglyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LongestPath"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"LongestPath"],

Cell["A small acyclic graph.", "ExampleText",
  CellTags->"LongestPath"],

Cell[BoxData[
    \(\(G\  = \ 
        Graph[6, 6, 
          1, {{1, 2}, {1, 5}, {2, 3}, {3, 4}, {3, 6}, {4, 5}}];\)\)], "Input",\

  CellLabel->"In[85]:=",
  CellTags->"LongestPath"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LongestPath[\ G\ ]\)], "Input",
  CellLabel->"In[86]:=",
  CellTags->"LongestPath"],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->"LongestPath"]
}, Open  ]],

Cell["The longest path ending at a vertex.", "ExampleText",
  CellTags->"LongestPath"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LongestPath[\ G, Full \[Rule] True]\)], "Input",
  CellLabel->"In[87]:=",
  CellTags->"LongestPath"],

Cell[BoxData[
    \({0, 1, 2, 3, 4, 3}\)], "Output",
  CellLabel->"Out[87]=",
  CellTags->"LongestPath"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["LShiftT", "ObjectName",
  CellTags->"LShiftT"],

Cell["Type: function", "Highlight",
  CellTags->"LShiftT"],

Cell[TextData[{
  StyleBox["LShiftT[n]", "MR"],
  "  returns the left shift transformation ",
  StyleBox["T[2,3,..,n,1]", "MR"],
  "."
}], "Usage",
  CellTags->"LShiftT"],

Cell[TextData[{
  "See also ",
  ButtonBox["RShiftT",
    ButtonData:>"RShiftT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["ConsT",
    ButtonData:>"ConsT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["OneT",
    ButtonData:>"OneT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["RandomT",
    ButtonData:>"RandomT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"LShiftT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeAlphabet", "ObjectName",
  CellTags->"MakeAlphabet"],

Cell["Type: function", "Highlight",
  CellTags->"MakeAlphabet"],

Cell[TextData[{
  StyleBox["MakeAlphabet[K]", "MR"],
  "  returns ",
  StyleBox["KK", "MR"],
  " where ",
  StyleBox["KK", "MR"],
  " the alphabet determined by ",
  StyleBox["K", "MR"],
  ". "
}], "Usage",
  CellTags->"MakeAlphabet"],

Cell[TextData[{
  " Raw alphabet ",
  StyleBox["K", "MR"],
  " may be an integer, a list of symbols or a list of characters."
}], "Notes",
  CellTags->"MakeAlphabet"],

Cell[TextData[{
  "See also ",
  ButtonBox["MakeFullAlphabet",
    ButtonData:>"MakeFullAlphabet",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Alphabet",
    ButtonData:>"Alphabet",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AlphabetSize",
    ButtonData:>"AlphabetSize",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FullAlphabet",
    ButtonData:>"FullAlphabet",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MakeAlphabet"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MakeAlphabet"],

Cell["Constructing a full alphabet from symbols.", "ExampleText",
  CellTags->"MakeAlphabet"],

Cell[CellGroupData[{

Cell["\<\
MakeAlphabet[{c,d}]
% // FullForm\
\>", "Input",
  CellLabel->"In[126]:=",
  CellTags->"MakeAlphabet"],

Cell[BoxData[
    \({"c", "d"}\)], "Output",
  CellLabel->"Out[126]=",
  CellTags->"MakeAlphabet"],

Cell[BoxData[
    TagBox[
      StyleBox[\(List["\<c\>", "\<d\>"]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[127]//FullForm=",
  CellTags->"MakeAlphabet"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeFullAlphabet", "ObjectName",
  CellTags->"MakeFullAlphabet"],

Cell["Type: function", "Highlight",
  CellTags->"MakeFullAlphabet"],

Cell[TextData[{
  StyleBox["MakeFullAlphabet[K]", "MR"],
  "  returns ",
  StyleBox["{k,KK}", "MR"],
  " where ",
  StyleBox["k", "MR"],
  " is the size of the proper alphabet given by ",
  StyleBox["K", "MR"],
  " and ",
  StyleBox["KK", "MR"],
  " is the proper alphabet."
}], "Usage",
  CellTags->"MakeFullAlphabet"],

Cell[TextData[{
  " Raw alphabet ",
  StyleBox["K", "MR"],
  " may be an integer, a list of symbols or a list of characters."
}], "Notes",
  CellTags->"MakeFullAlphabet"],

Cell[TextData[{
  "See also ",
  ButtonBox["MakeAlphabet",
    ButtonData:>"MakeAlphabet",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Alphabet",
    ButtonData:>"Alphabet",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AlphabetSize",
    ButtonData:>"AlphabetSize",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FullAlphabet",
    ButtonData:>"FullAlphabet",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MakeFullAlphabet"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MakeFullAlphabet"],

Cell["Constructing a full alphabet from symbols.", "ExampleText",
  CellTags->"MakeFullAlphabet"],

Cell[CellGroupData[{

Cell["\<\
MakeFullAlphabet[{c,d}]
% // FullForm\
\>", "Input",
  CellLabel->"In[123]:=",
  CellTags->"MakeFullAlphabet"],

Cell[BoxData[
    \({2, {"c", "d"}}\)], "Output",
  CellLabel->"Out[123]=",
  CellTags->"MakeFullAlphabet"],

Cell[BoxData[
    TagBox[
      StyleBox[\(List[2, List["\<c\>", "\<d\>"]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[124]//FullForm=",
  CellTags->"MakeFullAlphabet"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeIndex", "ObjectName",
  CellTags->"MakeIndex"],

Cell["Type: function", "Highlight",
  CellTags->"MakeIndex"],

Cell[TextData[{
  StyleBox["MakeIndex[L,R]", "MR"],
  "  computes an index of list ",
  StyleBox["L", "MR"],
  " with respect to equivalence relation ",
  StyleBox["R", "MR"],
  ". "
}], "Usage",
  CellTags->"MakeIndex"],

Cell[TextData[{
  StyleBox["R", "MR"],
  " has default ",
  StyleBox["SameQ", "MR"],
  ". "
}], "Notes",
  CellTags->"MakeIndex"],

Cell[TextData[StyleBox["Returns the index and the number of classes.", \
"Text"]], "Notes",
  CellTags->"MakeIndex"],

Cell[TextData[{
  "As a transformatino ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\[LongRightArrow]\([n]\)\)]],
  ", the index is idempotent and deflationary."
}], "Notes",
  CellTags->"MakeIndex"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToClasses",
    ButtonData:>"ToClasses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MakeIndex"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MakeIndex"],

Cell["A congruence relation. ", "ExampleText",
  CellTags->"MakeIndex"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeIndex[Range[0, 11], Mod[#1, 4] == Mod[#2, 4] &]\)], "Input",
  CellLabel->"In[120]:=",
  CellTags->"MakeIndex"],

Cell[BoxData[
    \({{1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4}, 4}\)], "Output",
  CellLabel->"Out[120]=",
  CellTags->"MakeIndex"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakeMonoidSG", "ObjectName",
  CellTags->"MakeMonoidSG"],

Cell["Type: function", "Highlight",
  CellTags->"MakeMonoidSG"],

Cell[TextData[{
  StyleBox["MakeMonoidSG[S]", "MR"],
  "  turns semigroup ",
  StyleBox["S", "MR"],
  " into a monoid by adjoining a unit, if necessary."
}], "Usage",
  CellTags->"MakeMonoidSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["MonoidQSG",
    ButtonData:>"MonoidQSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MakeMonoidSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"MakeMonoidSG"],

Cell["A semigroup without a unit.", "ExampleText",
  CellTags->"MakeMonoidSG"],

Cell[BoxData[
    \(\(S = SG[T[1, 1, 1], T[2, 2, 2], T[3, 3, 3]];\)\)], "Input",
  CellLabel->"In[115]:=",
  CellTags->"MakeMonoidSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MakeMonoidSG[S]\)], "Input",
  CellLabel->"In[116]:=",
  CellTags->"MakeMonoidSG"],

Cell[BoxData[
    \(SG[T[1, 2, 3], T[1, 1, 1], T[2, 2, 2], T[3, 3, 3]]\)], "Output",
  CellLabel->"Out[116]=",
  CellTags->"MakeMonoidSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MakePlotRange", "ObjectName",
  CellTags->"MakePlotRange"],

Cell["Type: function", "Highlight",
  CellTags->"MakePlotRange"],

Cell[TextData[{
  StyleBox["MakePlotRange[x1,x2,y1,y2]", "MR"],
  "  constructs ",
  StyleBox["PlotRange", "MR"],
  " option, adds proper margins. "
}], "Usage",
  CellTags->"MakePlotRange"],

Cell["Used mostly internally in plotting functions.", "Notes",
  CellTags->"MakePlotRange"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Merge12T", "ObjectName",
  CellTags->"Merge12T"],

Cell["Type: function", "Highlight",
  CellTags->"Merge12T"],

Cell[TextData[{
  StyleBox["Merge12T[n]", "MR"],
  "  returns the transformation ",
  StyleBox["T[1,1,3,..,n]", "MR"],
  "."
}], "Usage",
  CellTags->"Merge12T"],

Cell["Useful as a generator for the full transformation semigroup.", "Notes",
  CellTags->"Merge12T"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RShiftT",
    ButtonData:>"RShiftT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TranspositionT",
    ButtonData:>"TranspositionT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Merge12T"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MinusEins", "ObjectName",
  CellTags->"MinusEins"],

Cell["Type: fctassg", "Highlight",
  CellTags->"MinusEins"],

Cell[TextData[{
  StyleBox["MinusEins", "MR"],
  "  returns the last ",
  "part of object ",
  StyleBox["x", "MR"],
  "."
}], "Usage",
  CellTags->"MinusEins"],

Cell[TextData[{
  "Thus ",
  StyleBox["MinusEins[x] = x[[-1]]", "MR"],
  "."
}], "Notes",
  CellTags->"MinusEins"],

Cell[TextData[{
  "See also ",
  ButtonBox["Zwei",
    ButtonData:>"Zwei",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Drei",
    ButtonData:>"Drei",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinusZwei",
    ButtonData:>"MinusZwei",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"MinusEins"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MinusZwei", "ObjectName",
  CellTags->"MinusZwei"],

Cell["Type: fctassg", "Highlight",
  CellTags->"MinusZwei"],

Cell[TextData[{
  StyleBox["MinusZwei[x]", "MR"],
  "  returns the second to the last part of object ",
  StyleBox["x", "MR"],
  "."
}], "Usage",
  CellTags->"MinusZwei"],

Cell[TextData[{
  "Thus ",
  StyleBox["MinusZwei[x] = x[[-2]]", "MR"],
  "."
}], "Notes",
  CellTags->"MinusZwei"],

Cell[TextData[{
  "See also ",
  ButtonBox["Zwei",
    ButtonData:>"Zwei",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Drei",
    ButtonData:>"Drei",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinusEins",
    ButtonData:>"MinusEins",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"MinusZwei"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MonoidQSG", "ObjectName",
  CellTags->"MonoidQSG"],

Cell["Type: function", "Highlight",
  CellTags->"MonoidQSG"],

Cell[TextData[{
  StyleBox["MonoidQSG[S]", "MR"],
  "  tests whether semigroup ",
  StyleBox["S", "MR"],
  " is a monoid."
}], "Usage",
  CellTags->"MonoidQSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQSG",
    ButtonData:>"AperiodicQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["JTrivialQSG",
    ButtonData:>"JTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyCommQSG",
    ButtonData:>"LocallyCommQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyIdemQSG",
    ButtonData:>"LocallyIdemQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["HTrivialQSG",
    ButtonData:>"HTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["NilpotentQSG",
    ButtonData:>"NilpotentQSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"MonoidQSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NilpotentQSG", "ObjectName",
  CellTags->"NilpotentQSG"],

Cell["Type: function", "Highlight",
  CellTags->"NilpotentQSG"],

Cell[TextData[{
  StyleBox["NilpotentQSG[S]", "MR"],
  "  tests whether semigroup ",
  StyleBox["S", "MR"],
  " is nilpotent, i.e., whether null is the only idempotent element."
}], "Usage",
  CellTags->"NilpotentQSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["AperiodicQSG",
    ButtonData:>"AperiodicQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["JTrivialQSG",
    ButtonData:>"JTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyCommQSG",
    ButtonData:>"LocallyCommQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LocallyIdemQSG",
    ButtonData:>"LocallyIdemQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["MonoidQSG",
    ButtonData:>"MonoidQSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["HTrivialQSG",
    ButtonData:>"HTrivialQSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"NilpotentQSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NonDecreasing", "ObjectName",
  CellTags->"NonDecreasing"],

Cell["Type: function", "Highlight",
  CellTags->"NonDecreasing"],

Cell[TextData[{
  StyleBox["NonDecreasing[n,k]", "MR"],
  "  generates all non-decreasing sequences of length ",
  StyleBox["k", "MR"],
  " over ",
  Cell[BoxData[
      FormBox[
        StyleBox[\([n]\),
          "MR"], TraditionalForm]]],
  "."
}], "Usage",
  CellTags->"NonDecreasing"],

Cell[TextData[{
  "See also ",
  ButtonBox["KPermutationsR",
    ButtonData:>"KPermutationsR",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CartesianProduct",
    ButtonData:>"CartesianProduct",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NonDecreasing"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NonDecreasing"],

Cell[TextData[{
  "All non-decreasing sequences over ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, 3}\)]],
  " of lengt 5."
}], "ExampleText",
  CellTags->"NonDecreasing"],

Cell[CellGroupData[{

Cell["NonDecreasing[3,5]", "Input",
  CellLabel->"In[227]:=",
  CellTags->"NonDecreasing"],

Cell[BoxData[
    \({{1, 1, 1, 1, 1}, {1, 1, 1, 1, 2}, {1, 1, 1, 1, 3}, {1, 1, 1, 2, 
        2}, {1, 1, 1, 2, 3}, {1, 1, 1, 3, 3}, {1, 1, 2, 2, 2}, {1, 1, 2, 2, 
        3}, {1, 1, 2, 3, 3}, {1, 1, 3, 3, 3}, {1, 2, 2, 2, 2}, {1, 2, 2, 2, 
        3}, {1, 2, 2, 3, 3}, {1, 2, 3, 3, 3}, {1, 3, 3, 3, 3}, {2, 2, 2, 2, 
        2}, {2, 2, 2, 2, 3}, {2, 2, 2, 3, 3}, {2, 2, 3, 3, 3}, {2, 3, 3, 3, 
        3}, {3, 3, 3, 3, 3}}\)], "Output",
  CellLabel->"Out[227]=",
  CellTags->"NonDecreasing"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NonTransientGraph", "ObjectName",
  CellTags->"NonTransientGraph"],

Cell["Type: function", "Highlight",
  CellTags->"NonTransientGraph"],

Cell[TextData[{
  StyleBox["NonTransientGraph[G]", "MR"],
  "  returns the non-transient subgraph of ",
  StyleBox["G", "MR"],
  "."
}], "Usage",
  CellTags->"NonTransientGraph"],

Cell[TextData[{
  " ",
  StyleBox["NonTransientGraph[G]", "MR"],
  "  removes all transient points; only strongly connected components that \
lie on a biinfinite path are retained and collapsed into a single point."
}], "Notes",
  CellTags->"NonTransientGraph"],

Cell[TextData[{
  " ",
  StyleBox["The vertex set of the resulting graph is always structured.", 
    "Text"]
}], "Notes",
  CellTags->"NonTransientGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["WeaklyConnectedComponents",
    ButtonData:>"WeaklyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["StronglyConnectedComponents",
    ButtonData:>"StronglyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NonTransientGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NonTransientGraph"],

Cell["A graph with several transient points.", "ExampleText",
  CellTags->"NonTransientGraph"],

Cell[BoxData[
    \(\(g\  = \ 
        Graph[9, 10, 
          1, {{1, 2}, {2, 3}, {3, 4}, {4, 2}, {3, 5}, {5, 6}, {5, 9}, {6, 
              7}, {7, 6}, {7, 8}}];\)\)], "Input",
  CellLabel->"In[200]:=",
  CellTags->"NonTransientGraph"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(NonTransientGraph[g]\), "\n", 
    \(VertexSet[%]\)}], "Input",
  CellLabel->"In[202]:=",
  CellTags->"NonTransientGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"3", ",", "2", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[202]=",
  CellTags->"NonTransientGraph"],

Cell[BoxData[
    \({{2, 3, 4}, {5}, {6, 7}}\)], "Output",
  CellLabel->"Out[203]=",
  CellTags->"NonTransientGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NormalizeGraph", "ObjectName",
  CellTags->"NormalizeGraph"],

Cell["Type: function", "Highlight",
  CellTags->"NormalizeGraph"],

Cell[TextData[{
  StyleBox["NormalizeGraph[M]", "MR"],
  "  normalizes graph ",
  StyleBox["G", "MR"],
  " to have vertex set [n]."
}], "Usage",
  CellTags->"NormalizeGraph"],

Cell["\<\
The structured vertex set in a normalized graph is the empty list. \
Thus, normalization may significantly reduce the size of the datastructure.\
\
\>", "Notes",
  CellTags->"NormalizeGraph"],

Cell["\<\
Depending on the formatting level, the structured part may be \
invisible. \
\>", "Notes",
  CellTags->"NormalizeGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["VertexSet",
    ButtonData:>"VertexSet",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["FormatAutomata",
    ButtonData:>"FormatAutomata",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NormalizeGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NormalizeGraph"],

Cell[TextData[{
  "A graph with a structured vertex set, obtained from a ",
  StyleBox["NonTransientGraph", "MR"],
  " operation."
}], "ExampleText",
  CellTags->"NormalizeGraph"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(g\  = \ 
      Graph[3, 2, 1, {{1, 2}, {2, 3}}, {{2, 3, 4}, {5}, {6, 7}}]\), "\n", 
    \(VertexSet[g]\)}], "Input",
  CellLabel->"In[207]:=",
  CellTags->"NormalizeGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"3", ",", "2", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[207]=",
  CellTags->"NormalizeGraph"],

Cell[BoxData[
    \({{2, 3, 4}, {5}, {6, 7}}\)], "Output",
  CellLabel->"Out[208]=",
  CellTags->"NormalizeGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(gg\  = \ NormalizeGraph[g]\), "\n", 
    \(VertexSet[gg]\)}], "Input",
  CellLabel->"In[211]:=",
  CellTags->"NormalizeGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"3", ",", "2", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[211]=",
  CellTags->"NormalizeGraph"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output",
  CellLabel->"Out[212]=",
  CellTags->"NormalizeGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NullQT", "ObjectName",
  CellTags->"NullQT"],

Cell["Type: function", "Highlight",
  CellTags->"NullQT"],

Cell[TextData[{
  StyleBox["NullQT[x,S]", "MR"],
  "  tests whether transformation ",
  StyleBox["x", "MR"],
  " is a null in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"NullQT"],

Cell[TextData[{
  "See ",
  ButtonBox["NullQSG",
    ButtonData:>"NullQSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NullQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NullSG", "ObjectName",
  CellTags->"NullSG"],

Cell["Type: function", "Highlight",
  CellTags->"NullSG"],

Cell[TextData[{
  StyleBox["NullSG[S]", "MR"],
  "  lists the null element of a semigroup ",
  StyleBox["S", "MR"],
  ", if it exists."
}], "Usage",
  CellTags->"NullSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NullQT",
    ButtonData:>"NullQT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LeftNullSG",
    ButtonData:>"LeftNullSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RightNullSG",
    ButtonData:>"RightNullSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NullSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"NullSG"],

Cell["A semigroup with a null.", "ExampleText",
  CellTags->"NullSG"],

Cell[BoxData[
    \(\(S = 
        SG[T[1, 1, 4, 4, 5, 6], T[1, 1, 6, 6, 5, 4], T[1, 4, 5, 6, 5, 4], 
          T[1, 6, 5, 4, 5, 6], T[2, 2, 3, 3, 5, 6], T[2, 2, 6, 6, 5, 3], 
          T[2, 3, 5, 6, 5, 3], T[2, 6, 5, 3, 5, 6], T[3, 3, 3, 3, 5, 5], 
          T[3, 3, 5, 5, 5, 3], T[3, 5, 5, 3, 5, 5], T[4, 4, 4, 4, 5, 5], 
          T[4, 4, 5, 5, 5, 4], T[4, 5, 5, 4, 5, 5], T[5, 5, 5, 5, 5, 5], 
          T[6, 5, 5, 6, 5, 5], T[6, 6, 5, 5, 5, 6], 
          T[6, 6, 6, 6, 5, 5]];\)\)], "Input",
  CellLabel->"In[245]:=",
  CellTags->"NullSG"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(NullSG[S]\), "\n", 
    \(IdemSG[S]\)}], "Input",
  CellLabel->"In[257]:=",
  CellTags->"NullSG"],

Cell[BoxData[
    \({T[5, 5, 5, 5, 5, 5]}\)], "Output",
  CellLabel->"Out[257]=",
  CellTags->"NullSG"],

Cell[BoxData[
    \({T[1, 1, 4, 4, 5, 6], T[1, 6, 5, 4, 5, 6], T[2, 2, 3, 3, 5, 6], 
      T[3, 3, 3, 3, 5, 5], T[4, 4, 4, 4, 5, 5], T[4, 5, 5, 4, 5, 5], 
      T[5, 5, 5, 5, 5, 5], T[6, 6, 5, 5, 5, 6]}\)], "Output",
  CellLabel->"Out[258]=",
  CellTags->"NullSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumEdges", "ObjectName",
  CellTags->"NumEdges"],

Cell["Type: function", "Highlight",
  CellTags->"NumEdges"],

Cell[TextData[{
  StyleBox["NumEdges[G]", "MR"],
  "  returns the number of edges of a graph ",
  StyleBox["G", "MR"],
  "."
}], "Usage",
  CellTags->"NumEdges"],

Cell[TextData[{
  "See ",
  ButtonBox["NumVertices",
    ButtonData:>"NumVertices",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Edges",
    ButtonData:>"Edges",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["VertexSet",
    ButtonData:>"VertexSet",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NumEdges"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NumVertices", "ObjectName",
  CellTags->"NumVertices"],

Cell["Type: function", "Highlight",
  CellTags->"NumVertices"],

Cell[TextData[{
  StyleBox["NumVertices[G]", "MR"],
  "  returns the number of vertices of a graph ",
  StyleBox["G", "MR"],
  "."
}], "Usage",
  CellTags->"NumVertices"],

Cell[TextData[{
  "See ",
  ButtonBox["NumEdges",
    ButtonData:>"NumEdges",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Edges",
    ButtonData:>"Edges",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["VertexSet",
    ButtonData:>"VertexSet",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NumVertices"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OneQT", "ObjectName",
  CellTags->"OneQT"],

Cell["Type: function", "Highlight",
  CellTags->"OneQT"],

Cell[TextData[{
  StyleBox["OneQT[t,S]", "MR"],
  "  tests whether transformation ",
  StyleBox["t", "MR"],
  " is the identity in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"OneQT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OneT",
    ButtonData:>"OneT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OneSG",
    ButtonData:>"OneSG",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"OneQT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"OneQT"],

Cell["A small semigroup with no apparent identity element.", "ExampleText",
  CellTags->"OneQT"],

Cell[BoxData[
    \(\(S\  = \ 
        SG[T[1, 1, 3, 4], T[1, 1, 4, 3], T[3, 3, 1, 4], T[3, 3, 4, 1], 
          T[4, 4, 1, 3], T[4, 4, 3, 1]];\)\)], "Input",
  CellLabel->"In[4.1]:=",
  CellTags->"OneQT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[\ OneQT[S[\([i]\)], S], \ {i, 6}\ ]\)], "Input",
  CellLabel->"In[429]:=",
  CellTags->"OneQT"],

Cell[BoxData[
    \({True, False, False, False, False, False}\)], "Output",
  CellLabel->"Out[429]=",
  CellTags->"OneQT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["OneSG", "ObjectName",
  CellTags->"OneSG"],

Cell["Type: function", "Highlight",
  CellTags->"OneSG"],

Cell[TextData[{
  StyleBox["OneSG[S]", "MR"],
  "  lists the identity of a semigroup ",
  StyleBox["S", "MR"],
  ", if it exists."
}], "Usage",
  CellTags->"OneSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["OneT",
    ButtonData:>"OneT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OneQT",
    ButtonData:>"OneQT",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"OneSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"OneSG"],

Cell["The identity of the alternating group on 4 points.", "ExampleText",
  CellTags->"OneSG"],

Cell[CellGroupData[{

Cell["S = AlternatingGroupSG[4]", "Input",
  CellLabel->"In[382]:=",
  CellTags->"OneSG"],

Cell[BoxData[
    \(SG[T[1, 2, 3, 4], T[1, 3, 4, 2], T[1, 4, 2, 3], T[2, 1, 4, 3], 
      T[2, 3, 1, 4], T[2, 4, 3, 1], T[3, 1, 2, 4], T[3, 2, 4, 1], 
      T[3, 4, 1, 2], T[4, 1, 3, 2], T[4, 2, 1, 3], T[4, 3, 2, 1]]\)], "Output",\

  CellLabel->"Out[382]=",
  CellTags->"OneSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(OneSG[S]\)], "Input",
  CellLabel->"In[383]:=",
  CellTags->"OneSG"],

Cell[BoxData[
    \({T[1, 2, 3, 4]}\)], "Output",
  CellLabel->"Out[383]=",
  CellTags->"OneSG"]
}, Open  ]],

Cell["The following semigroup has no identity, only right-nulls.", \
"ExampleText",
  CellTags->"OneSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(S\ \  = \ SG @@ Table[ConsT[i, 3], {i, 3}]\)], "Input",
  CellLabel->"In[389]:=",
  CellTags->"OneSG"],

Cell[BoxData[
    \(SG[T[1, 1, 1], T[2, 2, 2], T[3, 3, 3]]\)], "Output",
  CellLabel->"Out[389]=",
  CellTags->"OneSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(OneSG[S]\)], "Input",
  CellLabel->"In[390]:=",
  CellTags->"OneSG"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[390]=",
  CellTags->"OneSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RightNullSG[S]\)], "Input",
  CellLabel->"In[391]:=",
  CellTags->"OneSG"],

Cell[BoxData[
    \({T[1, 1, 1], T[2, 2, 2], T[3, 3, 3]}\)], "Output",
  CellLabel->"Out[391]=",
  CellTags->"OneSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["OneT", "ObjectName",
  CellTags->"OneT"],

Cell["Type: function", "Highlight",
  CellTags->"OneT"],

Cell[TextData[{
  StyleBox["OneT[t]", "MR"],
  "  produces the identity transformation of size ",
  StyleBox["Length[t]", "MR"],
  " where ",
  StyleBox["t", "MR"],
  " is any transformation. "
}], "Usage",
  CellTags->"OneT"],

Cell[TextData[{
  StyleBox["OneT[k]", "MR"],
  "  for an integer ",
  StyleBox["k", "MR"],
  StyleBox[" also return the appropriate identity transformation.", "Text"]
}], "Notes",
  CellTags->"OneT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OneQT",
    ButtonData:>"OneQT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OneSG",
    ButtonData:>"OneSG",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"OneT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"OneT"],

Cell["The identity transformation on 5 points.", "ExampleText",
  CellTags->"OneT"],

Cell[CellGroupData[{

Cell[" OneT[5]", "Input",
  CellLabel->"In[377]:=",
  CellTags->"OneT"],

Cell[BoxData[
    \(T[1, 2, 3, 4, 5]\)], "Output",
  CellLabel->"Out[377]=",
  CellTags->"OneT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(OneQT[%, \ SymmetricGroupSG[5]\ ]\)], "Input",
  CellLabel->"In[378]:=",
  CellTags->"OneT"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[378]=",
  CellTags->"OneT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["OrderT", "ObjectName",
  CellTags->"OrderT"],

Cell["Type: function", "Highlight",
  CellTags->"OrderT"],

Cell[TextData[{
  StyleBox["OrderT[x]", "MR"],
  "  returns the order of a permutation x."
}], "Usage",
  CellTags->"OrderT"],

Cell[TextData[{
  "See also ",
  ButtonBox["InGroupT",
    ButtonData:>"InGroupT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["InverseT",
    ButtonData:>"InverseT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"OrderT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"OrderT"],

Cell["\<\
The alternating group on 5 points, and the orders of its \
elements.\
\>", "ExampleText",
  CellTags->"OrderT"],

Cell["S = AlternatingGroupSG[5];", "Input",
  CellLabel->"In[130]:=",
  CellTags->"OrderT"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(OrderT\  /@ \ ToList[S]\), "\n", 
    \(Frequencies[%]\  // \ TableForm\)}], "Input",
  CellLabel->"In[133]:=",
  CellTags->"OrderT"],

Cell[BoxData[
    \({1, 3, 3, 2, 3, 3, 3, 3, 2, 3, 3, 2, 2, 2, 2, 3, 5, 5, 5, 3, 5, 5, 3, 
      5, 3, 5, 5, 2, 3, 3, 2, 5, 5, 2, 5, 5, 5, 3, 5, 3, 3, 2, 5, 2, 5, 5, 5, 
      2, 5, 3, 5, 3, 3, 2, 5, 2, 5, 5, 5, 2}\)], "Output",
  CellLabel->"Out[133]=",
  CellTags->"OrderT"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1"},
          {"2", "15"},
          {"3", "20"},
          {"5", "24"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[134]//TableForm=",
  CellTags->"OrderT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PairsToRules", "ObjectName",
  CellTags->"PairsToRules"],

Cell["Type: function", "Highlight",
  CellTags->"PairsToRules"],

Cell[TextData[{
  StyleBox["PairsToRules[rw]", "MR"],
  "  replaces word pairs by rules."
}], "Usage",
  CellTags->"PairsToRules"],

Cell[TextData[{
  "See also ",
  ButtonBox["RulesToPairs",
    ButtonData:>"RulesToPairs",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["SimplifyRewriteSystem",
    ButtonData:>"SimplifyRewriteSystem",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"PairsToRules"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PairsToRules"],

Cell["Rewrite systems can be displayed as lists of rules. ", "ExampleText",
  CellTags->"PairsToRules"],

Cell[BoxData[
    \(\(rw\  = \ {{"\<bc\>", "\<c\>"}, {"\<cc\>", "\<c\>"}, {"\<aaa\>", "\<bb\
\>"}, {"\<aab\>", "\<ba\>"}, {"\<aba\>", "\<b\>"}};\)\)], "Input",
  CellLabel->"In[47]:=",
  CellTags->"PairsToRules"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PairsToRules[rw]\  // \ TableForm\)], "Input",
  CellLabel->"In[48]:=",
  CellTags->"PairsToRules"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\("bc" \[Rule] "c"\)},
          {\("cc" \[Rule] "c"\)},
          {\("aaa" \[Rule] "bb"\)},
          {\("aab" \[Rule] "ba"\)},
          {\("aba" \[Rule] "b"\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {"bc" -> "c", "cc" -> "c", "aaa" -> "bb", "aab" -> "ba", 
        "aba" -> "b"}]]], "Output",
  CellLabel->"Out[48]//TableForm=",
  CellTags->"PairsToRules"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pairs", "ObjectName",
  CellTags->"Pairs"],

Cell["Type: function", "Highlight",
  CellTags->"Pairs"],

Cell[TextData[{
  StyleBox["Pairs[A,B]", "MR"],
  "  generates a list of pairs with elements taken from lists ",
  StyleBox["A", "MR"],
  " and ",
  StyleBox["B", "MR"],
  StyleBox[".", "Text"]
}], "Usage",
  CellTags->"Pairs"],

Cell[TextData[{
  StyleBox["Pairs", "MR"],
  " is polyadic."
}], "Notes",
  CellTags->"Pairs"],

Cell[TextData[{
  "All the input lists must have the same length, ",
  StyleBox["Pairs", "MR"],
  " does not check. "
}], "Notes",
  CellTags->"Pairs"],

Cell["The output list has the same length as the input lists.", "Notes",
  CellTags->"Pairs"],

Cell[TextData[{
  StyleBox["See also ", "Text"],
  ButtonBox["CartesianProduct",
    ButtonData:>"CartesianProduct",
    ButtonStyle->"AddOnsLink"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"Pairs"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Pairs"],

Cell["Generating tuples.", "ExampleText",
  CellTags->"Pairs"],

Cell[CellGroupData[{

Cell["Pairs[{1,2,3},{a,b,c}]", "Input",
  CellLabel->"In[335]:=",
  CellTags->"Pairs"],

Cell[BoxData[
    \({{1, a}, {2, b}, {3, c}}\)], "Output",
  CellLabel->"Out[335]=",
  CellTags->"Pairs"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pairs[{1,2,3},{a,b,c},{1,2,3}]", "Input",
  CellLabel->"In[336]:=",
  CellTags->"Pairs"],

Cell[BoxData[
    \({{1, a, 1}, {2, b, 2}, {3, c, 3}}\)], "Output",
  CellLabel->"Out[336]=",
  CellTags->"Pairs"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pairs[{},{}]", "Input",
  CellLabel->"In[337]:=",
  CellTags->"Pairs"],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[337]=",
  CellTags->"Pairs"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pairs[{1},{}]", "Input",
  CellLabel->"In[338]:=",
  CellTags->"Pairs"],

Cell[BoxData[
    \(Thread::"tdlen" \(\(:\)\(\ \)\) 
      "Objects of unequal length in \!\({\(\({1}\)\), \(\({}\)\)}\) cannot be \
combined."\)], "Message",
  CellLabel->"From In[338]:=",
  CellTags->"Pairs"],

Cell[BoxData[
    \({{1}, {}}\)], "Output",
  CellLabel->"Out[338]=",
  CellTags->"Pairs"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PartitionCumRest", "ObjectName",
  CellTags->"PartitionCumRest"],

Cell["Type: function", "Highlight",
  CellTags->"PartitionCumRest"],

Cell[TextData[{
  StyleBox["PartitionCumRest[L,p]", "MR"],
  "  partitions list ",
  StyleBox["L", "MR"],
  " into blocks of length ",
  StyleBox["p", "MR"],
  " plus a possible rest of length less than ",
  StyleBox["p", "MR"],
  "."
}], "Usage",
  CellTags->"PartitionCumRest"],

Cell[TextData[{
  "Deprecated, now realized via  ",
  StyleBox["Partition[L, p, p, 1, {}]", "MR"],
  "."
}], "Notes",
  CellTags->"PartitionCumRest"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Partitions", "ObjectName",
  CellTags->"Partitions"],

Cell["Type: function", "Highlight",
  CellTags->"Partitions"],

Cell[TextData[{
  StyleBox["Partitions[n]", "MR"],
  "  returns the partitions of ",
  StyleBox["n", "MR"],
  ". "
}], "Usage",
  CellTags->"Partitions"],

Cell[TextData[{
  StyleBox["Partitions[n,m]", "MR"],
  " returns the partitions of ",
  StyleBox["n", "MR"],
  " whose largest component is at most ",
  StyleBox["m", "MR"],
  "."
}], "Notes",
  CellTags->"Partitions"],

Cell[TextData[{
  "See also ",
  ButtonBox["PartitionsP",
    ButtonData:>"PartitionsP",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PartitionQ",
    ButtonData:>"PartitionQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Partitions"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Partitions"],

Cell[TextData[{
  "All partitions of ",
  Cell[BoxData[
      \(TraditionalForm\`\([5]\)\)]],
  "."
}], "ExampleText",
  CellTags->"Partitions"],

Cell[CellGroupData[{

Cell["Partitions[5]", "Input",
  CellLabel->"In[190]:=",
  CellTags->"Partitions"],

Cell[BoxData[
    \({{5}, {4, 1}, {3, 2}, {3, 1, 1}, {2, 2, 1}, {2, 1, 1, 1}, {1, 1, 1, 1, 
        1}}\)], "Output",
  CellLabel->"Out[190]=",
  CellTags->"Partitions"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PathGraph", "ObjectName",
  CellTags->"PathGraph"],

Cell["Type: function", "Highlight",
  CellTags->"PathGraph"],

Cell[TextData[{
  StyleBox["PathGraph[n]", "MR"],
  "  generates a path of length ",
  StyleBox["n", "MR"],
  " in edge-list form. "
}], "Usage",
  CellTags->"PathGraph"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PathGraph"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  "  adds a self-loop at the last vertex."
}], "Notes",
  CellTags->"PathGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["CirculantGraph",
    ButtonData:>"CirculantGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PathGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PathGraph"],

Cell["A path graph on 10 points.", "ExampleText",
  CellTags->"PathGraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = PathGraph[10]\)], "Input",
  CellLabel->"In[182]:=",
  CellTags->"PathGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"10", ",", "9", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 
                8}, {8, 9}, {9, 10}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[182]=",
  CellTags->"PathGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WeaklyConnectedComponents[g, 3]\)], "Input",
  CellLabel->"In[183]:=",
  CellTags->"PathGraph"],

Cell[BoxData[
    \({3, 4, 5, 6, 7, 8, 9, 10}\)], "Output",
  CellLabel->"Out[183]=",
  CellTags->"PathGraph"]
}, Open  ]],

Cell["The modified version with self-loop.", "ExampleText",
  CellTags->"PathGraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = PathGraph[10, Full \[Rule] True]\)], "Input",
  CellLabel->"In[184]:=",
  CellTags->"PathGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"10", ",", "10", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 
                8}, {8, 9}, {9, 10}, {10, 10}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[184]=",
  CellTags->"PathGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[g, NonTrivial \[Rule] True]\)], "Input",
  CellLabel->"In[185]:=",
  CellTags->"PathGraph"],

Cell[BoxData[
    \({{10}}\)], "Output",
  CellLabel->"Out[185]=",
  CellTags->"PathGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PermuteGraph", "ObjectName",
  CellTags->"PermuteGraph"],

Cell["Type: function", "Highlight",
  CellTags->"PermuteGraph"],

Cell[TextData[{
  StyleBox["PermuteGraph[G,p]", "MR"],
  "  applies isomorphism ",
  StyleBox["p", "MR"],
  " to ",
  StyleBox["G", "MR"],
  ". "
}], "Usage",
  CellTags->"PermuteGraph"],

Cell[TextData[{
  "List ",
  StyleBox["p", "MR"],
  " must be a permutation on [n]."
}], "Notes",
  CellTags->"PermuteGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PermuteGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PermuteGraph"],

Cell["\<\
A path graph in standard form and after permuting the vertex set.\
\
\>", "ExampleText",
  CellTags->"PermuteGraph"],

Cell[CellGroupData[{

Cell["g = PathGraph[6]", "Input",
  CellLabel->"In[213]:=",
  CellTags->"PermuteGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"6", ",", "5", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[213]=",
  CellTags->"PermuteGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gg\  = \ PermuteGraph[g, {2, 1, 3, 4, 6, 5}]\)], "Input",
  CellLabel->"In[219]:=",
  CellTags->"PermuteGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"6", ",", "5", ",", "1", ",", 
          TagBox[\({{1, 3}, {2, 1}, {3, 4}, {4, 6}, {6, 5}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[219]=",
  CellTags->"PermuteGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotFunction", "ObjectName",
  CellTags->"PlotFunction"],

Cell["Type: function", "Highlight",
  CellTags->"PlotFunction"],

Cell[TextData[{
  StyleBox["PlotFunction[f,A,n,opts]", "MR"],
  "  plots a picture of a function ",
  StyleBox["f", "MR"],
  " on domain ",
  StyleBox["A", "MR"],
  ", iterated ",
  StyleBox["n", "MR"],
  " steps. "
}], "Usage",
  CellTags->"PlotFunction"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Frame", "\[Rule]", "True", "-"},
          {"Full", "\[Rule]", "False", "-"},
          {"DoTrace", "\[Rule]", "All", "-"},
          {"LineStyle", 
            "\[RuleDelayed]", \({{GrayLevel[ .5], $defthinline}, {Black, \
$deffatline}}\), "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PlotFunction"],

Cell[TextData[{
  " See also ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PlotFunction"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PlotFunction"],

Cell["A modular polynomial, iterated 5 times.", "ExampleText",
  CellTags->"PlotFunction"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f[x_] := Mod[x\^2 + 1, 11];\)\), "\n", 
    \(\(PlotFunction[f, Range[0, 10], 5];\)\)}], "Input",
  CellLabel->"In[188]:=",
  CellTags->"PlotFunction"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.030303 0.151515 -0.0106558 0.0532788 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.12121 .04262 m
.27273 .0959 L
s
.12121 .0959 m
.27273 .14918 L
s
.12121 .14918 m
.27273 .30902 L
s
.12121 .20246 m
.27273 .57541 L
s
.12121 .25574 m
.27273 .3623 L
s
.12121 .30902 m
.27273 .25574 L
s
.12121 .3623 m
.27273 .25574 L
s
.12121 .41557 m
.27273 .3623 L
s
.12121 .46885 m
.27273 .57541 L
s
.12121 .52213 m
.27273 .30902 L
s
.12121 .57541 m
.27273 .14918 L
s
.27273 .0959 m
.42424 .14918 L
s
.27273 .14918 m
.42424 .30902 L
s
.27273 .25574 m
.42424 .3623 L
s
.27273 .30902 m
.42424 .25574 L
s
.27273 .3623 m
.42424 .25574 L
s
.27273 .57541 m
.42424 .14918 L
s
.42424 .14918 m
.57576 .30902 L
s
.42424 .25574 m
.57576 .3623 L
s
.42424 .30902 m
.57576 .25574 L
s
.42424 .3623 m
.57576 .25574 L
s
.57576 .25574 m
.72727 .3623 L
s
.57576 .30902 m
.72727 .25574 L
s
.57576 .3623 m
.72727 .25574 L
s
.72727 .25574 m
.87879 .3623 L
s
.72727 .3623 m
.87879 .25574 L
s
0 0 1 r
.012 w
.27273 .04262 Mdot
.27273 .20246 Mdot
.27273 .41557 Mdot
.27273 .46885 Mdot
.27273 .52213 Mdot
.42424 .04262 Mdot
.42424 .0959 Mdot
.42424 .20246 Mdot
.42424 .41557 Mdot
.42424 .46885 Mdot
.42424 .52213 Mdot
.42424 .57541 Mdot
.57576 .04262 Mdot
.57576 .0959 Mdot
.57576 .14918 Mdot
.57576 .20246 Mdot
.57576 .41557 Mdot
.57576 .46885 Mdot
.57576 .52213 Mdot
.57576 .57541 Mdot
.72727 .04262 Mdot
.72727 .0959 Mdot
.72727 .14918 Mdot
.72727 .20246 Mdot
.72727 .30902 Mdot
.72727 .41557 Mdot
.72727 .46885 Mdot
.72727 .52213 Mdot
.72727 .57541 Mdot
.87879 .04262 Mdot
.87879 .0959 Mdot
.87879 .14918 Mdot
.87879 .20246 Mdot
.87879 .30902 Mdot
.87879 .41557 Mdot
.87879 .46885 Mdot
.87879 .52213 Mdot
.87879 .57541 Mdot
1 0 0 r
.0144 w
.12121 .04262 Mdot
.12121 .0959 Mdot
.12121 .14918 Mdot
.12121 .20246 Mdot
.12121 .25574 Mdot
.12121 .30902 Mdot
.12121 .3623 Mdot
.12121 .41557 Mdot
.12121 .46885 Mdot
.12121 .52213 Mdot
.12121 .57541 Mdot
.27273 .0959 Mdot
.27273 .14918 Mdot
.27273 .25574 Mdot
.27273 .30902 Mdot
.27273 .3623 Mdot
.27273 .57541 Mdot
.42424 .14918 Mdot
.42424 .25574 Mdot
.42424 .30902 Mdot
.42424 .3623 Mdot
.57576 .25574 Mdot
.57576 .30902 Mdot
.57576 .3623 Mdot
.72727 .25574 Mdot
.72727 .3623 Mdot
.87879 .25574 Mdot
.87879 .3623 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[188]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"PlotFunction"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotMatrix", "ObjectName",
  CellTags->"PlotMatrix"],

Cell["Type: function", "Highlight",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  StyleBox["PlotMatrix[M,opts]", "MR"],
  "  plots a raster image of matrix ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Frame", "\[Rule]", "True", "-"},
          {"GridLines", "\[Rule]", "False", "-"},
          {"MultiCol", "\[Rule]", "False", "-"},
          {"NRows", "\[Rule]", "30", "-"},
          {"RView", "\[Rule]", "False", "-"},
          {"NoRest", "\[Rule]", "False", "-"},
          {"RasterStyle", "\[RuleDelayed]", "$rastercolors", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "The default colors are controlled by ",
  StyleBox["$rastercolors", "MR"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "Option ",
  StyleBox["RasterStyle->Automatic", "MR"],
  " uses HueRasterColors. "
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "Option ",
  StyleBox["GridLines->True", "MR"],
  " superimposes a light gray grid. "
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "Option ",
  StyleBox["Frame->False", "MR"],
  " turns off the surrounding frame. "
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "Option ",
  StyleBox["MultiCol->Turns", "MR"],
  " turns on multi-column mode and chops the matrix into several blocks. "
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "Default number of rows in each block (except perhaps the last) is 30, can \
be changed with option ",
  StyleBox["NRow->nrows", "MR"],
  ". "
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "Option ",
  StyleBox["RView->True", "MR"],
  " rotates the blocks sideways, and prints them in a single column. "
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "Option ",
  StyleBox["NoRest->True", "MR"],
  " supresses trailing blocks of size less than ",
  StyleBox["NRows", "MR"],
  "."
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[TextData[{
  "See also ",
  ButtonBox["$rastercolors",
    ButtonData:>"$rastercolors",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["HueRasterColors",
    ButtonData:>"HueRasterColors",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PlotMatrix"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PlotMatrix"],

Cell["A random matrix, and its visual representation.", "ExampleText",
  CellTags->"PlotMatrix"],

Cell["M = Table[Random[Integer,{0,4}],{8},{8}];", "Input",
  CellLabel->"In[177]:=",
  CellTags->"PlotMatrix"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotMatrix[M];\)\)], "Input",
  CellLabel->"In[178]:=",
  CellTags->"PlotMatrix"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.119048 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
24 string
8 8 8 [8 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF73FF000000FF73FF00CCFFFF73FF000000FF
CCFFFF73FF00FFFF00FFFF00FFFF000000FFFF00FF73FF00
0000FF73FF00FFFF00FFFF00FF00FFFF00FFFF00FF0000FF
FFFF000000FF0000FFFFFF000000FF0000FF0000FFFF00FF
FFFF000000FFFFFF000000FFFFFF00CCFFFFFFFF000000FF
FFFF00FF00FF73FF0073FF00FF00FF73FF0073FF00FFFF00
CCFFFFFFFF00FF00FFFFFF00FF00FF0000FF0000FFFFFF00
FF00FFFFFF00FF00FFFF00FF0000FFFFFF00FFFF00FFFF00
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[178]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"PlotMatrix"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotRelation", "ObjectName",
  CellTags->"PlotRelation"],

Cell["Type: function", "Highlight",
  CellTags->"PlotRelation"],

Cell[TextData[{
  StyleBox["PlotRelation[R,A,n,opts]", "MR"],
  "  plots a picture of a binary relation ",
  StyleBox["R", "MR"],
  " on domain ",
  StyleBox["A", "MR"],
  ", iterated ",
  StyleBox["n", "MR"],
  " steps. "
}], "Usage",
  CellTags->"PlotRelation"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "All", "-"},
          {"Full", "\[Rule]", "False", "-"},
          {"PlotStyle", 
            "\[RuleDelayed]", \({{Blue, $defpointsize}, {Red, 
                1.2  $defpointsize}}\), "-"},
          {"LineStyle", 
            "\[RuleDelayed]", \({{GrayLevel[ .5], $defthinline}, {Black, \
$deffatline}}\), "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PlotRelation"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotT",
    ButtonData:>"PlotT",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"PlotRelation"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PlotRelation"],

Cell["A relation based on squaring modulo 20.", "ExampleText",
  CellTags->"PlotRelation"],

Cell[BoxData[
    \(\(\[Rho][x_, y_]\  := \ Mod[x\^2, 20]\  \[Equal] \ y;\)\)], "Input",
  CellLabel->"In[167]:=",
  CellTags->"PlotRelation"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotRelation[\ \[Rho], \ Range[19], 3\ ];\)\)], "Input",
  CellLabel->"In[169]:=",
  CellTags->"PlotRelation"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0434783 0.217391 -0.00630647 0.0315323 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.17391 .02523 m
.3913 .02523 L
s
.17391 .05676 m
.3913 .11982 L
s
.17391 .08829 m
.3913 .27748 L
s
.17391 .11982 m
.3913 .49821 L
s
.17391 .15136 m
.3913 .15136 L
s
.17391 .18289 m
.3913 .49821 L
s
.17391 .214.1 m
.3913 .27748 L
s
.17391 .24595 m
.3913 .11982 L
s
.17391 .27748 m
.3913 .02523 L
s
.17391 .34055 m
.3913 .02523 L
s
.17391 .37208 m
.3913 .11982 L
s
.17391 .40361 m
.3913 .27748 L
s
.17391 .43515 m
.3913 .49821 L
s
.17391 .46668 m
.3913 .15136 L
s
.17391 .49821 m
.3913 .49821 L
s
.17391 .52974 m
.3913 .27748 L
s
.17391 .56128 m
.3913 .11982 L
s
.17391 .59281 m
.3913 .02523 L
s
.3913 .02523 m
.6087 .02523 L
s
.3913 .11982 m
.6087 .49821 L
s
.3913 .15136 m
.6087 .15136 L
s
.3913 .27748 m
.6087 .02523 L
s
.3913 .49821 m
.6087 .49821 L
s
.6087 .02523 m
.82609 .02523 L
s
.6087 .15136 m
.82609 .15136 L
s
.6087 .49821 m
.82609 .49821 L
s
0 0 1 r
.012 w
.17391 .30902 Mdot
.3913 .05676 Mdot
.3913 .08829 Mdot
.3913 .18289 Mdot
.3913 .214.1 Mdot
.3913 .24595 Mdot
.3913 .30902 Mdot
.3913 .34055 Mdot
.3913 .37208 Mdot
.3913 .40361 Mdot
.3913 .43515 Mdot
.3913 .46668 Mdot
.3913 .52974 Mdot
.3913 .56128 Mdot
.3913 .59281 Mdot
.6087 .05676 Mdot
.6087 .08829 Mdot
.6087 .11982 Mdot
.6087 .18289 Mdot
.6087 .214.1 Mdot
.6087 .24595 Mdot
.6087 .27748 Mdot
.6087 .30902 Mdot
.6087 .34055 Mdot
.6087 .37208 Mdot
.6087 .40361 Mdot
.6087 .43515 Mdot
.6087 .46668 Mdot
.6087 .52974 Mdot
.6087 .56128 Mdot
.6087 .59281 Mdot
.82609 .05676 Mdot
.82609 .08829 Mdot
.82609 .11982 Mdot
.82609 .18289 Mdot
.82609 .214.1 Mdot
.82609 .24595 Mdot
.82609 .27748 Mdot
.82609 .30902 Mdot
.82609 .34055 Mdot
.82609 .37208 Mdot
.82609 .40361 Mdot
.82609 .43515 Mdot
.82609 .46668 Mdot
.82609 .52974 Mdot
.82609 .56128 Mdot
.82609 .59281 Mdot
1 0 0 r
.0144 w
.17391 .02523 Mdot
.17391 .05676 Mdot
.17391 .08829 Mdot
.17391 .11982 Mdot
.17391 .15136 Mdot
.17391 .18289 Mdot
.17391 .214.1 Mdot
.17391 .24595 Mdot
.17391 .27748 Mdot
.17391 .34055 Mdot
.17391 .37208 Mdot
.17391 .40361 Mdot
.17391 .43515 Mdot
.17391 .46668 Mdot
.17391 .49821 Mdot
.17391 .52974 Mdot
.17391 .56128 Mdot
.17391 .59281 Mdot
.3913 .02523 Mdot
.3913 .11982 Mdot
.3913 .15136 Mdot
.3913 .27748 Mdot
.3913 .49821 Mdot
.6087 .02523 Mdot
.6087 .15136 Mdot
.6087 .49821 Mdot
.82609 .02523 Mdot
.82609 .15136 Mdot
.82609 .49821 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[169]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"PlotRelation"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotTDGraph", "ObjectName",
  CellTags->"PlotTDGraph"],

Cell["Type: function", "Highlight",
  CellTags->"PlotTDGraph"],

Cell[TextData[{
  StyleBox["PlotTDGraph[gr,n]", "MR"],
  "  plots a picture of a time dependent graph ",
  StyleBox["gr", "MR"],
  " over ground set ",
  Cell[BoxData[
      \(TraditionalForm\`\([n]\)\)]],
  ". "
}], "Usage",
  CellTags->"PlotTDGraph"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "All", "-"},
          {"Full", "\[Rule]", "False", "-"},
          {"PlotStyle", 
            "\[RuleDelayed]", \({{Blue, $defpointsize}, {Red, 
                1.2  $defpointsize}}\), "-"},
          {"LineStyle", 
            "\[RuleDelayed]", \({{GrayLevel[ .5], $defthinline}, {Black, \
$deffatline}}\), "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PlotTDGraph"],

Cell[TextData[{
  "Option are ",
  StyleBox["Full->False", "MR"],
  StyleBox[" shows all potential paths.", "Text"]
}], "Notes",
  CellTags->"PlotTDGraph"],

Cell[TextData[{
  "Option are ",
  StyleBox["DoTrace->A", "MR"],
  StyleBox["  only follows paths starting at vertices in ", "Text"],
  StyleBox["A", "MR"],
  StyleBox[". ", "Text"]
}], "Notes",
  CellTags->"PlotTDGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToTDGraph",
    ButtonData:>"ToTDGraph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["PlotT",
    ButtonData:>"PlotT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"PlotTDGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PlotTDGraph"],

Cell[TextData[{
  "Two relations based on proper divisibility on ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], 8}\)]],
  ". "
}], "ExampleText",
  CellTags->"PlotTDGraph"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R1 = 
        Select[Tuples[2, 8], 
          Mod[#\[LeftDoubleBracket]2\[RightDoubleBracket], #\
\[LeftDoubleBracket]1\[RightDoubleBracket]] == 
                0 && #\[LeftDoubleBracket]1\[RightDoubleBracket] \[NotEqual] \
#\[LeftDoubleBracket]2\[RightDoubleBracket] &];\)\), "\n", 
    \(\(R2 = Reverse /@ R1;\)\), "\n", 
    \(g = ToTDGraph[{R1, R2}, 8]\)}], "Input",
  CellLabel->"In[300]:=",
  CellTags->"PlotTDGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"24", ",", "24", ",", "1", ",", 
          
          TagBox[\({{1, 10}, {1, 11}, {1, 12}, {1, 13}, {1, 14}, {1, 15}, {1, 
                16}, {2, 12}, \[LeftSkeleton]9\[RightSkeleton], {15, 
                17}, {16, 17}, {12, 18}, {14, 18}, {16, 18}, {14, 19}, {16, 
                20}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[302]=",
  CellTags->"PlotTDGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotTDGraph[g, 8];\)\)], "Input",
  CellLabel->"In[303]:=",
  CellTags->"PlotTDGraph"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0555556 0.277778 -0.0143729 0.0718644 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.22222 .05749 m
.5 .12936 L
s
.22222 .05749 m
.5 .20122 L
s
.22222 .05749 m
.5 .27308 L
s
.22222 .05749 m
.5 .34495 L
s
.22222 .05749 m
.5 .41681 L
s
.22222 .05749 m
.5 .48868 L
s
.22222 .05749 m
.5 .56054 L
s
.22222 .12936 m
.5 .27308 L
s
.22222 .12936 m
.5 .41681 L
s
.22222 .12936 m
.5 .56054 L
s
.22222 .20122 m
.5 .41681 L
s
.22222 .27308 m
.5 .56054 L
s
.5 .12936 m
.77778 .05749 L
s
.5 .20122 m
.77778 .05749 L
s
.5 .27308 m
.77778 .05749 L
s
.5 .34495 m
.77778 .05749 L
s
.5 .41681 m
.77778 .05749 L
s
.5 .48868 m
.77778 .05749 L
s
.5 .56054 m
.77778 .05749 L
s
.5 .27308 m
.77778 .12936 L
s
.5 .41681 m
.77778 .12936 L
s
.5 .56054 m
.77778 .12936 L
s
.5 .41681 m
.77778 .20122 L
s
.5 .56054 m
.77778 .27308 L
s
0 0 1 r
.012 w
.22222 .34495 Mdot
.22222 .41681 Mdot
.22222 .48868 Mdot
.22222 .56054 Mdot
.5 .05749 Mdot
.77778 .34495 Mdot
.77778 .41681 Mdot
.77778 .48868 Mdot
.77778 .56054 Mdot
1 0 0 r
.0144 w
.22222 .05749 Mdot
.22222 .12936 Mdot
.22222 .20122 Mdot
.22222 .27308 Mdot
.5 .12936 Mdot
.5 .20122 Mdot
.5 .27308 Mdot
.5 .34495 Mdot
.5 .41681 Mdot
.5 .48868 Mdot
.5 .56054 Mdot
.77778 .05749 Mdot
.77778 .12936 Mdot
.77778 .20122 Mdot
.77778 .27308 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[303]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"PlotTDGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotTDGraph[g, 8, \ DoTrace \[Rule] {1}, \ 
        Full \[Rule] True\ ];\)\)], "Input",
  CellLabel->"In[304]:=",
  CellTags->"PlotTDGraph"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0555556 0.277778 -0.0143729 0.0718644 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 g
.003 w
[ ] 0 setdash
.22222 .05749 m
.5 .12936 L
s
.22222 .05749 m
.5 .20122 L
s
.22222 .05749 m
.5 .27308 L
s
.22222 .05749 m
.5 .34495 L
s
.22222 .05749 m
.5 .41681 L
s
.22222 .05749 m
.5 .48868 L
s
.22222 .05749 m
.5 .56054 L
s
.22222 .12936 m
.5 .27308 L
s
.22222 .12936 m
.5 .41681 L
s
.22222 .12936 m
.5 .56054 L
s
.22222 .20122 m
.5 .41681 L
s
.22222 .27308 m
.5 .56054 L
s
.5 .12936 m
.77778 .05749 L
s
.5 .20122 m
.77778 .05749 L
s
.5 .27308 m
.77778 .05749 L
s
.5 .34495 m
.77778 .05749 L
s
.5 .41681 m
.77778 .05749 L
s
.5 .48868 m
.77778 .05749 L
s
.5 .56054 m
.77778 .05749 L
s
.5 .27308 m
.77778 .12936 L
s
.5 .41681 m
.77778 .12936 L
s
.5 .56054 m
.77778 .12936 L
s
.5 .41681 m
.77778 .20122 L
s
.5 .56054 m
.77778 .27308 L
s
0 0 0 r
.005 w
.22222 .05749 m
.5 .12936 L
s
.22222 .05749 m
.5 .20122 L
s
.22222 .05749 m
.5 .27308 L
s
.22222 .05749 m
.5 .34495 L
s
.22222 .05749 m
.5 .41681 L
s
.22222 .05749 m
.5 .48868 L
s
.22222 .05749 m
.5 .56054 L
s
.5 .12936 m
.77778 .05749 L
s
.5 .20122 m
.77778 .05749 L
s
.5 .27308 m
.77778 .05749 L
s
.5 .34495 m
.77778 .05749 L
s
.5 .41681 m
.77778 .05749 L
s
.5 .48868 m
.77778 .05749 L
s
.5 .56054 m
.77778 .05749 L
s
.5 .27308 m
.77778 .12936 L
s
.5 .41681 m
.77778 .12936 L
s
.5 .56054 m
.77778 .12936 L
s
.5 .41681 m
.77778 .20122 L
s
.5 .56054 m
.77778 .27308 L
s
0 0 1 r
.012 w
.22222 .12936 Mdot
.22222 .20122 Mdot
.22222 .27308 Mdot
.22222 .34495 Mdot
.22222 .41681 Mdot
.22222 .48868 Mdot
.22222 .56054 Mdot
.5 .05749 Mdot
.77778 .34495 Mdot
.77778 .41681 Mdot
.77778 .48868 Mdot
.77778 .56054 Mdot
1 0 0 r
.0144 w
.22222 .05749 Mdot
.5 .12936 Mdot
.5 .20122 Mdot
.5 .27308 Mdot
.5 .34495 Mdot
.5 .41681 Mdot
.5 .48868 Mdot
.5 .56054 Mdot
.77778 .05749 Mdot
.77778 .12936 Mdot
.77778 .20122 Mdot
.77778 .27308 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[304]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"PlotTDGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotT", "ObjectName",
  CellTags->"PlotT"],

Cell["Type: function", "Highlight",
  CellTags->"PlotT"],

Cell[TextData[{
  StyleBox["PlotT[x,n]", "MR"],
  "  plots the first ",
  StyleBox["n", "MR"],
  " powers of transformation ",
  StyleBox["x", "MR"],
  ". "
}], "Usage",
  CellTags->"PlotT"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoShow", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PlotT"],

Cell[TextData[{
  "Option ",
  StyleBox["DoShow->True", "MR"],
  " will  draw a grid. "
}], "Notes",
  CellTags->"PlotT"],

Cell[TextData[{
  "Default for ",
  StyleBox["n", "MR"],
  " is 8."
}], "Notes",
  CellTags->"PlotT"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GridLine",
    ButtonData:>"GridLine",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GridPoints",
    ButtonData:>"GridPoints",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PlotT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PlotT"],

Cell["A random transformation and its visual representation.", "ExampleText",
  CellTags->"PlotT"],

Cell[CellGroupData[{

Cell["t = RandomT[10]", "Input",
  CellLabel->"In[155]:=",
  CellTags->"PlotT"],

Cell[BoxData[
    \(T[7, 3, 6, 7, 4, 7, 9, 7, 10, 5]\)], "Output",
  CellLabel->"Out[155]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotT[t];\)\)], "Input",
  CellLabel->"In[157]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0208333 0.104167 -0.011661 0.0583051 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
.08333 .04664 m
.1875 .39647 L
s
.08333 .10495 m
.1875 .16325 L
s
.08333 .16325 m
.1875 .33817 L
s
.08333 .22156 m
.1875 .39647 L
s
.08333 .27986 m
.1875 .22156 L
s
.08333 .33817 m
.1875 .39647 L
s
.08333 .39647 m
.1875 .51308 L
s
.08333 .45478 m
.1875 .39647 L
s
.08333 .51308 m
.1875 .57139 L
s
.08333 .57139 m
.1875 .27986 L
s
.1875 .16325 m
.29167 .33817 L
s
.1875 .22156 m
.29167 .39647 L
s
.1875 .27986 m
.29167 .22156 L
s
.1875 .33817 m
.29167 .39647 L
s
.1875 .39647 m
.29167 .51308 L
s
.1875 .51308 m
.29167 .57139 L
s
.1875 .57139 m
.29167 .27986 L
s
.29167 .22156 m
.39583 .39647 L
s
.29167 .27986 m
.39583 .22156 L
s
.29167 .33817 m
.39583 .39647 L
s
.29167 .39647 m
.39583 .51308 L
s
.29167 .51308 m
.39583 .57139 L
s
.29167 .57139 m
.39583 .27986 L
s
.39583 .22156 m
.5 .39647 L
s
.39583 .27986 m
.5 .22156 L
s
.39583 .39647 m
.5 .51308 L
s
.39583 .51308 m
.5 .57139 L
s
.39583 .57139 m
.5 .27986 L
s
.5 .22156 m
.60417 .39647 L
s
.5 .27986 m
.60417 .22156 L
s
.5 .39647 m
.60417 .51308 L
s
.5 .51308 m
.60417 .57139 L
s
.5 .57139 m
.60417 .27986 L
s
.60417 .22156 m
.70833 .39647 L
s
.60417 .27986 m
.70833 .22156 L
s
.60417 .39647 m
.70833 .51308 L
s
.60417 .51308 m
.70833 .57139 L
s
.60417 .57139 m
.70833 .27986 L
s
.70833 .22156 m
.8125 .39647 L
s
.70833 .27986 m
.8125 .22156 L
s
.70833 .39647 m
.8125 .51308 L
s
.70833 .51308 m
.8125 .57139 L
s
.70833 .57139 m
.8125 .27986 L
s
.8125 .22156 m
.91667 .39647 L
s
.8125 .27986 m
.91667 .22156 L
s
.8125 .39647 m
.91667 .51308 L
s
.8125 .51308 m
.91667 .57139 L
s
.8125 .57139 m
.91667 .27986 L
s
0 0 1 r
.012 w
.1875 .04664 Mdot
.1875 .10495 Mdot
.1875 .45478 Mdot
.29167 .04664 Mdot
.29167 .10495 Mdot
.29167 .16325 Mdot
.29167 .45478 Mdot
.39583 .04664 Mdot
.39583 .10495 Mdot
.39583 .16325 Mdot
.39583 .33817 Mdot
.39583 .45478 Mdot
.5 .04664 Mdot
.5 .10495 Mdot
.5 .16325 Mdot
.5 .33817 Mdot
.5 .45478 Mdot
.60417 .04664 Mdot
.60417 .10495 Mdot
.60417 .16325 Mdot
.60417 .33817 Mdot
.60417 .45478 Mdot
.70833 .04664 Mdot
.70833 .10495 Mdot
.70833 .16325 Mdot
.70833 .33817 Mdot
.70833 .45478 Mdot
.8125 .04664 Mdot
.8125 .10495 Mdot
.8125 .16325 Mdot
.8125 .33817 Mdot
.8125 .45478 Mdot
.91667 .04664 Mdot
.91667 .10495 Mdot
.91667 .16325 Mdot
.91667 .33817 Mdot
.91667 .45478 Mdot
1 0 0 r
.0144 w
.08333 .04664 Mdot
.08333 .10495 Mdot
.08333 .16325 Mdot
.08333 .22156 Mdot
.08333 .27986 Mdot
.08333 .33817 Mdot
.08333 .39647 Mdot
.08333 .45478 Mdot
.08333 .51308 Mdot
.08333 .57139 Mdot
.1875 .16325 Mdot
.1875 .22156 Mdot
.1875 .27986 Mdot
.1875 .33817 Mdot
.1875 .39647 Mdot
.1875 .51308 Mdot
.1875 .57139 Mdot
.29167 .22156 Mdot
.29167 .27986 Mdot
.29167 .33817 Mdot
.29167 .39647 Mdot
.29167 .51308 Mdot
.29167 .57139 Mdot
.39583 .22156 Mdot
.39583 .27986 Mdot
.39583 .39647 Mdot
.39583 .51308 Mdot
.39583 .57139 Mdot
.5 .22156 Mdot
.5 .27986 Mdot
.5 .39647 Mdot
.5 .51308 Mdot
.5 .57139 Mdot
.60417 .22156 Mdot
.60417 .27986 Mdot
.60417 .39647 Mdot
.60417 .51308 Mdot
.60417 .57139 Mdot
.70833 .22156 Mdot
.70833 .27986 Mdot
.70833 .39647 Mdot
.70833 .51308 Mdot
.70833 .57139 Mdot
.8125 .22156 Mdot
.8125 .27986 Mdot
.8125 .39647 Mdot
.8125 .51308 Mdot
.8125 .57139 Mdot
.91667 .22156 Mdot
.91667 .27986 Mdot
.91667 .39647 Mdot
.91667 .51308 Mdot
.91667 .57139 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[157]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PositionList", "ObjectName",
  CellTags->"PositionList"],

Cell["Type: function", "Highlight",
  CellTags->"PositionList"],

Cell[TextData[{
  StyleBox["PositionList[A,B]", "MR"],
  "  generates a flattened list of the positions of the elements of list ",
  StyleBox["B", "MR"],
  " in list ",
  StyleBox["A", "MR"],
  ".  "
}], "Usage",
  CellTags->"PositionList"],

Cell[TextData[{
  "All elements in ",
  StyleBox["B", "MR"],
  " must occur in ",
  StyleBox["A", "MR"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"PositionList"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PositionList"],

Cell["\<\
A random list of integers, and the positions of the occurring \
elements.\
\>", "ExampleText",
  CellTags->"PositionList"],

Cell[CellGroupData[{

Cell["A = Table[Random[Integer,{1,5}],{20}]", "Input",
  CellLabel->"In[152]:=",
  CellTags->"PositionList"],

Cell[BoxData[
    \({4, 2, 4, 3, 4, 2, 5, 4, 3, 1, 5, 4, 4, 1, 4, 3, 4, 2, 4, 
      4}\)], "Output",
  CellLabel->"Out[152]=",
  CellTags->"PositionList"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = \ Union[A];\)\), "\n", 
    \(PositionList[A, B]\)}], "Input",
  CellLabel->"In[153]:=",
  CellTags->"PositionList"],

Cell[BoxData[
    \({10, 14, 2, 6, 18, 4, 9, 16, 1, 3, 5, 8, 12, 13, 15, 17, 19, 20, 7, 
      11}\)], "Output",
  CellLabel->"Out[154]=",
  CellTags->"PositionList"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PositionOne", "ObjectName",
  CellTags->"PositionOne"],

Cell["Type: function", "Highlight",
  CellTags->"PositionOne"],

Cell[TextData[{
  StyleBox["PositionOne[x,y]", "MR"],
  "  evaluates to ",
  StyleBox["Position[x,y][[1,1]]", "MR"],
  "."
}], "Usage",
  CellTags->"PositionOne"],

Cell["Use internally.", "Notes",
  CellTags->"PositionOne"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PowerSet", "ObjectName",
  CellTags->"PowerSet"],

Cell["Type: function", "Highlight",
  CellTags->"PowerSet"],

Cell[TextData[{
  StyleBox["PowerSet[L,k]", "MR"],
  "  produces all ",
  StyleBox["k", "MR"],
  "-element subsets of ",
  StyleBox["L", "MR"],
  "."
}], "Usage",
  CellTags->"PowerSet"],

Cell[TextData[{
  " If ",
  StyleBox["k", "MR"],
  " is omitted, the full power set is generated. "
}], "Notes",
  CellTags->"PowerSet"],

Cell[TextData[{
  StyleBox["Range[n]", "MR"],
  " can be denoted by ",
  StyleBox["n", "MR"],
  "."
}], "Notes",
  CellTags->"PowerSet"],

Cell[TextData[{
  StyleBox["See also ", "Text"],
  ButtonBox["FastPowerSet",
    ButtonData:>"FastPowerSet",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"PowerSet"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PowerSet"],

Cell[TextData[{
  "The power set of ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c, d}\)]],
  "."
}], "ExampleText",
  CellTags->"PowerSet"],

Cell[CellGroupData[{

Cell["PowerSet[{a,b,c,d}]", "Input",
  CellLabel->"In[148]:=",
  CellTags->"PowerSet"],

Cell[BoxData[
    \({{}, {a}, {b}, {c}, {d}, {a, b}, {a, c}, {a, d}, {b, c}, {b, d}, {c, 
        d}, {a, b, c}, {a, b, d}, {a, c, d}, {b, c, d}, {a, b, c, 
        d}}\)], "Output",
  CellLabel->"Out[148]=",
  CellTags->"PowerSet"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PowerSet[{a,b,c,d},2]", "Input",
  CellLabel->"In[149]:=",
  CellTags->"PowerSet"],

Cell[BoxData[
    \({{a, b}, {a, c}, {a, d}, {b, c}, {b, d}, {c, d}}\)], "Output",
  CellLabel->"Out[149]=",
  CellTags->"PowerSet"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PrintDClass", "ObjectName",
  CellTags->"PrintDClass"],

Cell["Type: function", "Highlight",
  CellTags->"PrintDClass"],

Cell[TextData[{
  StyleBox["PrintDClass[dc]", "MR"],
  "  pretty prints a D-class ",
  StyleBox["dc", "MR"],
  "."
}], "Usage",
  CellTags->"PrintDClass"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"PrintDClass"],

Cell["\<\
Produces a rather verbose listing of the D-class, ordered by images \
and kernels.\
\>", "Notes",
  CellTags->"PrintDClass"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DClassDecomposition",
    ButtonData:>"DClassDecomposition",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DC",
    ButtonData:>"DC",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PrintDClass"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrintDClass"],

Cell["A D-class, in standard form.", "ExampleText",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \(\(d\  = \ 
        DC[{T[1, 1, 1, 4], T[1, 1, 4, 1], T[1, 1, 4, 4], T[1, 4, 1, 1], 
            T[1, 4, 1, 4], T[1, 4, 4, 1], T[1, 4, 4, 4]}, {T[1, 1, 1, 2], 
            T[1, 1, 1, 3], T[1, 1, 1, 4], T[2, 1, 1, 3], T[2, 1, 1, 4], 
            T[3, 1, 1, 4]}, {T[1, 1, 1, 4], T[4, 4, 4, 1]}];\)\)], "Input",
  CellLabel->"In[146]:=",
  CellTags->"PrintDClass"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintDClass[d]\)], "Input",
  CellLabel->"In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \("---------------------------------------------------------"\)], "Print",\

  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("dimensions:  "\[InvisibleSpace]7\[InvisibleSpace]" \
by "\[InvisibleSpace]6\[InvisibleSpace]" by "\[InvisibleSpace]2\),
      SequenceForm[ "dimensions:  ", 7, " by ", 6, " by ", 2],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("H: "\[InvisibleSpace]{T[1, 1, 1, 4], 
          T[4, 4, 4, 1]}\),
      SequenceForm[ "H: ", {
        T[ 1, 1, 1, 4], 
        T[ 4, 4, 4, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \("---------------------------------------------------------"\)], "Print",\

  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \("  "\)], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("image: "\[InvisibleSpace]{1, 2}\),
      SequenceForm[ "image: ", {1, 2}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 3}, {4}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 3}, {4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 1, 2], 
          T[2, 2, 2, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 1, 2], 
        T[ 2, 2, 2, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 4}, {3}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 4}, {3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 2, 1], 
          T[2, 2, 1, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 2, 1], 
        T[ 2, 2, 1, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2}, {3, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 2}, {3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 2, 2], 
          T[2, 2, 1, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 2, 2], 
        T[ 2, 2, 1, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3, 4}, {2}}\),
      SequenceForm[ "   kernel: ", {{1, 3, 4}, {2}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 2, 1, 1], 
          T[2, 1, 2, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 2, 1, 1], 
        T[ 2, 1, 2, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3}, {2, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 3}, {2, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 2, 1, 2], 
          T[2, 1, 2, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 2, 1, 2], 
        T[ 2, 1, 2, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 4}, {2, 3}}\),
      SequenceForm[ "   kernel: ", {{1, 4}, {2, 3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 2, 2, 1], 
          T[2, 1, 1, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 2, 2, 1], 
        T[ 2, 1, 1, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1}, {2, 3, 4}}\),
      SequenceForm[ "   kernel: ", {{1}, {2, 3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 2, 2, 2], 
          T[2, 1, 1, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 2, 2, 2], 
        T[ 2, 1, 1, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("image: "\[InvisibleSpace]{1, 3}\),
      SequenceForm[ "image: ", {1, 3}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 3}, {4}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 3}, {4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 1, 3], 
          T[3, 3, 3, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 1, 3], 
        T[ 3, 3, 3, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 4}, {3}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 4}, {3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 3, 1], 
          T[3, 3, 1, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 3, 1], 
        T[ 3, 3, 1, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2}, {3, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 2}, {3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 3, 3], 
          T[3, 3, 1, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 3, 3], 
        T[ 3, 3, 1, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3, 4}, {2}}\),
      SequenceForm[ "   kernel: ", {{1, 3, 4}, {2}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 3, 1, 1], 
          T[3, 1, 3, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 3, 1, 1], 
        T[ 3, 1, 3, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3}, {2, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 3}, {2, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 3, 1, 3], 
          T[3, 1, 3, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 3, 1, 3], 
        T[ 3, 1, 3, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 4}, {2, 3}}\),
      SequenceForm[ "   kernel: ", {{1, 4}, {2, 3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 3, 3, 1], 
          T[3, 1, 1, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 3, 3, 1], 
        T[ 3, 1, 1, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1}, {2, 3, 4}}\),
      SequenceForm[ "   kernel: ", {{1}, {2, 3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 3, 3, 3], 
          T[3, 1, 1, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 3, 3, 3], 
        T[ 3, 1, 1, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("image: "\[InvisibleSpace]{1, 4}\),
      SequenceForm[ "image: ", {1, 4}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 3}, {4}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 3}, {4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 1, 4], 
          T[4, 4, 4, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 1, 4], 
        T[ 4, 4, 4, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 4}, {3}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 4}, {3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 4, 1], 
          T[4, 4, 1, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 4, 1], 
        T[ 4, 4, 1, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2}, {3, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 2}, {3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 1, 4, 4], 
          T[4, 4, 1, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 1, 4, 4], 
        T[ 4, 4, 1, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3, 4}, {2}}\),
      SequenceForm[ "   kernel: ", {{1, 3, 4}, {2}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 4, 1, 1], 
          T[4, 1, 4, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 4, 1, 1], 
        T[ 4, 1, 4, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3}, {2, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 3}, {2, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 4, 1, 4], 
          T[4, 1, 4, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 4, 1, 4], 
        T[ 4, 1, 4, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 4}, {2, 3}}\),
      SequenceForm[ "   kernel: ", {{1, 4}, {2, 3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 4, 4, 1], 
          T[4, 1, 1, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 4, 4, 1], 
        T[ 4, 1, 1, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1}, {2, 3, 4}}\),
      SequenceForm[ "   kernel: ", {{1}, {2, 3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[1, 4, 4, 4], 
          T[4, 1, 1, 1]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 1, 4, 4, 4], 
        T[ 4, 1, 1, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("image: "\[InvisibleSpace]{2, 3}\),
      SequenceForm[ "image: ", {2, 3}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 3}, {4}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 3}, {4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 2, 2, 3], 
          T[3, 3, 3, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 2, 2, 3], 
        T[ 3, 3, 3, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 4}, {3}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 4}, {3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 2, 3, 2], 
          T[3, 3, 2, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 2, 3, 2], 
        T[ 3, 3, 2, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2}, {3, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 2}, {3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 2, 3, 3], 
          T[3, 3, 2, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 2, 3, 3], 
        T[ 3, 3, 2, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3, 4}, {2}}\),
      SequenceForm[ "   kernel: ", {{1, 3, 4}, {2}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 3, 2, 2], 
          T[3, 2, 3, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 3, 2, 2], 
        T[ 3, 2, 3, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3}, {2, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 3}, {2, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 3, 2, 3], 
          T[3, 2, 3, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 3, 2, 3], 
        T[ 3, 2, 3, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 4}, {2, 3}}\),
      SequenceForm[ "   kernel: ", {{1, 4}, {2, 3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 3, 3, 2], 
          T[3, 2, 2, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 3, 3, 2], 
        T[ 3, 2, 2, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1}, {2, 3, 4}}\),
      SequenceForm[ "   kernel: ", {{1}, {2, 3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 3, 3, 3], 
          T[3, 2, 2, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 3, 3, 3], 
        T[ 3, 2, 2, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("image: "\[InvisibleSpace]{2, 4}\),
      SequenceForm[ "image: ", {2, 4}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 3}, {4}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 3}, {4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 2, 2, 4], 
          T[4, 4, 4, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 2, 2, 4], 
        T[ 4, 4, 4, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 4}, {3}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 4}, {3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 2, 4, 2], 
          T[4, 4, 2, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 2, 4, 2], 
        T[ 4, 4, 2, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2}, {3, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 2}, {3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 2, 4, 4], 
          T[4, 4, 2, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 2, 4, 4], 
        T[ 4, 4, 2, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3, 4}, {2}}\),
      SequenceForm[ "   kernel: ", {{1, 3, 4}, {2}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 4, 2, 2], 
          T[4, 2, 4, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 4, 2, 2], 
        T[ 4, 2, 4, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3}, {2, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 3}, {2, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 4, 2, 4], 
          T[4, 2, 4, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 4, 2, 4], 
        T[ 4, 2, 4, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 4}, {2, 3}}\),
      SequenceForm[ "   kernel: ", {{1, 4}, {2, 3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 4, 4, 2], 
          T[4, 2, 2, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 4, 4, 2], 
        T[ 4, 2, 2, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1}, {2, 3, 4}}\),
      SequenceForm[ "   kernel: ", {{1}, {2, 3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[2, 4, 4, 4], 
          T[4, 2, 2, 2]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 2, 4, 4, 4], 
        T[ 4, 2, 2, 2]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("image: "\[InvisibleSpace]{3, 4}\),
      SequenceForm[ "image: ", {3, 4}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 3}, {4}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 3}, {4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[3, 3, 3, 4], 
          T[4, 4, 4, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 3, 3, 3, 4], 
        T[ 4, 4, 4, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2, 4}, {3}}\),
      SequenceForm[ "   kernel: ", {{1, 2, 4}, {3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[3, 3, 4, 3], 
          T[4, 4, 3, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 3, 3, 4, 3], 
        T[ 4, 4, 3, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 2}, {3, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 2}, {3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[3, 3, 4, 4], 
          T[4, 4, 3, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 3, 3, 4, 4], 
        T[ 4, 4, 3, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3, 4}, {2}}\),
      SequenceForm[ "   kernel: ", {{1, 3, 4}, {2}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[3, 4, 3, 3], 
          T[4, 3, 4, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 3, 4, 3, 3], 
        T[ 4, 3, 4, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 3}, {2, 4}}\),
      SequenceForm[ "   kernel: ", {{1, 3}, {2, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[3, 4, 3, 4], 
          T[4, 3, 4, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 3, 4, 3, 4], 
        T[ 4, 3, 4, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1, 4}, {2, 3}}\),
      SequenceForm[ "   kernel: ", {{1, 4}, {2, 3}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[3, 4, 4, 3], 
          T[4, 3, 3, 4]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 3, 4, 4, 3], 
        T[ 4, 3, 3, 4]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("   kernel: "\[InvisibleSpace]{{1}, {2, 3, 4}}\),
      SequenceForm[ "   kernel: ", {{1}, {2, 3, 4}}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    InterpretationBox[\("       H-class:  "\[InvisibleSpace]{T[3, 4, 4, 4], 
          T[4, 3, 3, 3]}\),
      SequenceForm[ "       H-class:  ", {
        T[ 3, 4, 4, 4], 
        T[ 4, 3, 3, 3]}],
      Editable->False]], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print",
  CellLabel->"From In[147]:=",
  CellTags->"PrintDClass"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PrintEquations", "ObjectName",
  CellTags->"PrintEquations"],

Cell["Type: function", "Highlight",
  CellTags->"PrintEquations"],

Cell[TextData[{
  StyleBox["PrintEquations[eq]", "MR"],
  "  pretty prints a list of equations in word form. "
}], "Usage",
  CellTags->"PrintEquations"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Cols", "\[Rule]", "None", "-"},
          {"Algebraic", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"PrintEquations"],

Cell[TextData[{
  "Option ",
  StyleBox["Algebraic->True", "MR"],
  " writes words in algebraic notation."
}], "Notes",
  CellTags->"PrintEquations"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SyntacticSG",
    ButtonData:>"SyntacticSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Equations",
    ButtonData:>"Equations",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PrintWitnesses",
    ButtonData:>"PrintWitnesses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PrintEquations"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrintEquations"],

Cell["\<\
The full transformation semigroup on 3 points, and the \
corresponding equations.\
\>", "ExampleText",
  CellTags->"PrintEquations"],

Cell[BoxData[
    \(\({S, W, eq} = 
        TransformationSG[3, Equations \[Rule] True];\)\)], "Input",
  CellLabel->"In[138]:=",
  CellTags->"PrintEquations"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[eq]\)], "Input",
  CellLabel->"In[145]:=",
  CellTags->"PrintEquations"],

Cell[BoxData[
    \(57\)], "Output",
  CellLabel->"Out[145]=",
  CellTags->"PrintEquations"]
}, Open  ]],

Cell["The rewrite rules can be simplified considerably.", "ExampleText",
  CellTags->"PrintEquations"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(eqs\  = \ SimplifyEquations[S, W, eq];\)\), "\n", 
    \(PrintEquations[eqs]\)}], "Input",
  CellLabel->"In[146]:=",
  CellTags->"PrintEquations"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(" 1" \(\(:\)\(\ \)\) \("bb" \[Rule] "1"\)\)},
          {\(" 2" \(\(:\)\(\ \)\) \("bc" \[Rule] "c"\)\)},
          {\(" 3" \(\(:\)\(\ \)\) \("cc" \[Rule] "c"\)\)},
          {\(" 4" \(\(:\)\(\ \)\) \("aaa" \[Rule] "1"\)\)},
          {\(" 5" \(\(:\)\(\ \)\) \("aab" \[Rule] "ba"\)\)},
          {\(" 6" \(\(:\)\(\ \)\) \("aba" \[Rule] "b"\)\)},
          {\(" 7" \(\(:\)\(\ \)\) \("baa" \[Rule] "ab"\)\)},
          {\(" 8" \(\(:\)\(\ \)\) \("bab" \[Rule] "aa"\)\)},
          {\(" 9" \(\(:\)\(\ \)\) \("bac" \[Rule] "aac"\)\)},
          {\("10" \(\(:\)\(\ \)\) \("cac" \[Rule] "cab"\)\)},
          {\("11" \(\(:\)\(\ \)\) \("acaac" \[Rule] "caac"\)\)},
          {\("12" \(\(:\)\(\ \)\) \("caacaa" \[Rule] "caacb"\)\)},
          {\("13" \(\(:\)\(\ \)\) \("caacab" \[Rule] "caaca"\)\)},
          {\("14" \(\(:\)\(\ \)\) \("caacba" \[Rule] "caac"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ " 1", "bb" -> "1"], 
        ColonForm[ " 2", "bc" -> "c"], 
        ColonForm[ " 3", "cc" -> "c"], 
        ColonForm[ " 4", "aaa" -> "1"], 
        ColonForm[ " 5", "aab" -> "ba"], 
        ColonForm[ " 6", "aba" -> "b"], 
        ColonForm[ " 7", "baa" -> "ab"], 
        ColonForm[ " 8", "bab" -> "aa"], 
        ColonForm[ " 9", "bac" -> "aac"], 
        ColonForm[ "10", "cac" -> "cab"], 
        ColonForm[ "11", "acaac" -> "caac"], 
        ColonForm[ "12", "caacaa" -> "caacb"], 
        ColonForm[ "13", "caacab" -> "caaca"], 
        ColonForm[ "14", "caacba" -> "caac"]}, TableSpacing -> {1, 
        1}]]], "Output",
  CellLabel->"Out[147]//TableForm=",
  CellTags->"PrintEquations"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PrintWitnesses", "ObjectName",
  CellTags->"PrintWitnesses"],

Cell["Type: function", "Highlight",
  CellTags->"PrintWitnesses"],

Cell[TextData[{
  StyleBox["PrintWitnesses[S,wit]", "MR"],
  "  prints a table of witnesses and semigroup elements for semigroup ",
  StyleBox["S", "MR"],
  ". "
}], "Usage",
  CellTags->"PrintWitnesses"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SyntacticSG",
    ButtonData:>"SyntacticSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Equations",
    ButtonData:>"Equations",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PrintEquations",
    ButtonData:>"PrintEquations",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"PrintWitnesses"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"PrintWitnesses"],

Cell["\<\
The full transformation semigroup on 3 points, and the \
corresponding witnesses.\
\>", "ExampleText",
  CellTags->"PrintWitnesses"],

Cell[BoxData[
    \(\({S, W, eq} = 
        TransformationSG[3, Equations \[Rule] True];\)\)], "Input",
  CellLabel->"In[138]:=",
  CellTags->"PrintWitnesses"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintWitnesses[S, W]\)], "Input",
  CellLabel->"In[139]:=",
  CellTags->"PrintWitnesses"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"a\"\>", \(T[3, 1, 2]\)},
          {"2", "\<\"b\"\>", \(T[2, 1, 3]\)},
          {"3", "\<\"c\"\>", \(T[1, 1, 3]\)},
          {"4", "\<\"aa\"\>", \(T[2, 3, 1]\)},
          {"5", "\<\"ab\"\>", \(T[3, 2, 1]\)},
          {"6", "\<\"ac\"\>", \(T[3, 1, 1]\)},
          {"7", "\<\"ba\"\>", \(T[1, 3, 2]\)},
          {"8", "\<\"bb\"\>", \(T[1, 2, 3]\)},
          {"9", "\<\"ca\"\>", \(T[3, 3, 2]\)},
          {"10", "\<\"cb\"\>", \(T[2, 2, 3]\)},
          {"11", "\<\"aac\"\>", \(T[1, 3, 1]\)},
          {"12", "\<\"aca\"\>", \(T[2, 3, 3]\)},
          {"13", "\<\"acb\"\>", \(T[3, 2, 2]\)},
          {"14", "\<\"caa\"\>", \(T[2, 2, 1]\)},
          {"15", "\<\"cab\"\>", \(T[3, 3, 1]\)},
          {"16", "\<\"cba\"\>", \(T[1, 1, 2]\)},
          {"17", "\<\"aaca\"\>", \(T[3, 2, 3]\)},
          {"18", "\<\"aacb\"\>", \(T[2, 3, 2]\)},
          {"19", "\<\"acaa\"\>", \(T[1, 2, 2]\)},
          {"20", "\<\"acab\"\>", \(T[1, 3, 3]\)},
          {"21", "\<\"acba\"\>", \(T[2, 1, 1]\)},
          {"22", "\<\"caac\"\>", \(T[1, 1, 1]\)},
          {"23", "\<\"aacaa\"\>", \(T[2, 1, 2]\)},
          {"24", "\<\"aacab\"\>", \(T[3, 1, 3]\)},
          {"25", "\<\"aacba\"\>", \(T[1, 2, 1]\)},
          {"26", "\<\"caaca\"\>", \(T[3, 3, 3]\)},
          {"27", "\<\"caacb\"\>", \(T[2, 2, 2]\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {Automatic, None}, TableSpacing -> {1, 
          1}, TableDepth -> 2]]]], "Output",
  CellLabel->"Out[139]//TableForm=",
  CellTags->"PrintWitnesses"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ProductGraph", "ObjectName",
  CellTags->"ProductGraph"],

Cell["Type: function", "Highlight",
  CellTags->"ProductGraph"],

Cell[TextData[{
  StyleBox["ProductGraph[G1,G2]", "MR"],
  "  computes the Cartesian product of two  graphs ",
  StyleBox["G1", "MR"],
  " and ",
  StyleBox["G2", "MR"],
  StyleBox[".", "Text"]
}], "Usage",
  CellTags->"ProductGraph"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "True", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ProductGraph"],

Cell[TextData[{
  "The result graph has as vertex set the Cartesian product of ",
  StyleBox["V1", "MR"],
  " and ",
  StyleBox["V2", "MR"],
  ", and has an edge ",
  Cell[BoxData[
      \(TraditionalForm\`\((\((p, q)\), \((p', q')\))\)\)]],
  " whenever ",
  Cell[BoxData[
      \(TraditionalForm\`p = p'\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((q, q')\)\ \  \[Element] \ E\_2\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, p')\)\ \  \[Element] \ E\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q = q'\)]],
  ". "
}], "Notes",
  CellTags->"ProductGraph"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->False", "MR"],
  " produces the strict product instead:  ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, p')\)\  \[Element] \ E\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((q, q')\)\  \[Element] \ E\_2\)]],
  "."
}], "Notes",
  CellTags->"ProductGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["ProductLabeledGraph",
    ButtonData:>"ProductLabeledGraph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"ProductGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ProductGraph"],

Cell["Two small graphs and their product, a cylinder.", "ExampleText",
  CellTags->"ProductGraph"],

Cell[BoxData[{
    \(\(g1 = PathGraph[4];\)\), "\n", 
    \(\(g2 = CirculantGraph[3, {1}];\)\)}], "Input",
  CellLabel->"In[228]:=",
  CellTags->"ProductGraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = ProductGraph[g1, g2]\)], "Input",
  CellLabel->"In[232]:=",
  CellTags->"ProductGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"12", ",", "21", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {1, 4}, {2, 3}, {2, 5}, {3, 1}, {3, 
                6}, \[LeftSkeleton]9\[RightSkeleton], {8, 11}, {9, 7}, {9, 
                12}, {10, 11}, {11, 12}, {12, 10}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[232]=",
  CellTags->"ProductGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VertexSet[g]\)], "Input",
  CellLabel->"In[233]:=",
  CellTags->"ProductGraph"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {1, 3}, {2, 1}, {2, 2}, {2, 3}, {3, 1}, {3, 2}, {3, 
        3}, {4, 1}, {4, 2}, {4, 3}}\)], "Output",
  CellLabel->"Out[233]=",
  CellTags->"ProductGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WeaklyConnectedComponents[g, 1]\)], "Input",
  CellLabel->"In[234]:=",
  CellTags->"ProductGraph"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}\)], "Output",
  CellLabel->"Out[234]=",
  CellTags->"ProductGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WeaklyConnectedComponents[g, 7]\)], "Input",
  CellLabel->"In[235]:=",
  CellTags->"ProductGraph"],

Cell[BoxData[
    \({7, 8, 9, 10, 11, 12}\)], "Output",
  CellLabel->"Out[235]=",
  CellTags->"ProductGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[g]\)], "Input",
  CellLabel->"In[236]:=",
  CellTags->"ProductGraph"],

Cell[BoxData[
    \({{1, 2, 3}, {4, 5, 6}, {7, 8, 9}, {10, 11, 12}}\)], "Output",
  CellLabel->"Out[236]=",
  CellTags->"ProductGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ProductLabeledGraph", "ObjectName",
  CellTags->"ProductLabeledGraph"],

Cell["Type: function", "Highlight",
  CellTags->"ProductLabeledGraph"],

Cell[TextData[{
  StyleBox["ProductLabeledGraph[G1,G2]", "MR"],
  "  computes the product of two labeled graphs ",
  StyleBox["G1", "MR"],
  " and ",
  StyleBox["G2", "MR"],
  "."
}], "Usage",
  CellTags->"ProductLabeledGraph"],

Cell[TextData[{
  "The result graph has as vertex set the Cartesian product of ",
  StyleBox["V1", "MR"],
  " and ",
  StyleBox["V2", "MR"],
  ", and has an edge ",
  Cell[BoxData[
      \(TraditionalForm\`\((\((p, q)\), a, \((p', q')\))\)\)]],
  " whenever  ",
  Cell[BoxData[
      \(TraditionalForm\`\((p, a, p')\)\ \  \[Element] \ E\_1\)]],
  "  and   ",
  Cell[BoxData[
      \(TraditionalForm\`\((q, a, q')\)\ \  \[Element] \ E\_2\)]],
  "."
}], "Notes",
  CellTags->"ProductLabeledGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["ProductGraph",
    ButtonData:>"ProductGraph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"ProductLabeledGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ProductLabeledGraph"],

Cell["\<\
A labeled graph on 4 points, whose product with itself had two \
strongly connected components that are isolated in the collapse of the graph.\
\
\>", "ExampleText",
  CellTags->"ProductLabeledGraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\  = \ 
      Graph[4, 8, 
        2, {{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 1}, {3, 1, 
            2}, {4, 2, 3}, {4, 1, 4}}]\)], "Input",
  CellLabel->"In[283]:=",
  CellTags->"ProductLabeledGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"4", ",", "8", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 2, 2}, {2, 1, 3}, {2, 2, 4}, {3, 2, 
                1}, {3, 1, 2}, {4, 2, 3}, {4, 1, 4}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[283]=",
  CellTags->"ProductLabeledGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gg\  = \ ProductLabeledGraph[g, g]\)], "Input",
  CellLabel->"In[286]:=",
  CellTags->"ProductLabeledGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"16", ",", "32", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {2, 1, 3}, {3, 1, 2}, {4, 1, 4}, {5, 1, 
                9}, {6, 1, 11}, \[LeftSkeleton]20\[RightSkeleton], {11, 2, 
                1}, {12, 2, 3}, {13, 2, 10}, {14, 2, 12}, {15, 2, 9}, {16, 2, 
                11}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[286]=",
  CellTags->"ProductLabeledGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[gg]\)], "Input",
  CellLabel->"In[287]:=",
  CellTags->"ProductLabeledGraph"],

Cell[BoxData[
    \({{1, 2, 3, 5, 6, 8, 9, 11, 12, 14, 15, 16}, {4, 7, 10, 13}}\)], "Output",\

  CellLabel->"Out[287]=",
  CellTags->"ProductLabeledGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToDAG[gg]\)], "Input",
  CellLabel->"In[288]:=",
  CellTags->"ProductLabeledGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"2", ",", "0", ",", "1", ",", 
          TagBox[\({}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[288]=",
  CellTags->"ProductLabeledGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RandomPermutation", "ObjectName",
  CellTags->"RandomPermutation"],

Cell["Type: function", "Highlight",
  CellTags->"RandomPermutation"],

Cell[TextData[{
  StyleBox["RandomPermutation[k]", "MR"],
  "  produces a random permutation of ",
  Cell[BoxData[
      \(TraditionalForm\`\([k]\)\)]]
}], "Usage",
  CellTags->"RandomPermutation"],

Cell[TextData[{
  "See also ",
  ButtonBox["KPermutationsR",
    ButtonData:>"KPermutationsR",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RandomPermutation"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RandomPermutation"],

Cell[TextData[{
  "A random permutation of ",
  Cell[BoxData[
      \(TraditionalForm\`\([10]\)\)]],
  ". "
}], "ExampleText",
  CellTags->"RandomPermutation"],

Cell[CellGroupData[{

Cell["RandomPermutation[10]", "Input",
  CellLabel->"In[47]:=",
  CellTags->"RandomPermutation"],

Cell[BoxData[
    \({3, 5, 7, 4, 9, 8, 1, 2, 6, 10}\)], "Output",
  CellLabel->"Out[47]=",
  CellTags->"RandomPermutation"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RandomT", "ObjectName",
  CellTags->"RandomT"],

Cell["Type: function", "Highlight",
  CellTags->"RandomT"],

Cell[TextData[{
  StyleBox["RandomT[n]", "MR"],
  "  generates a random transformation on [n]. "
}], "Usage",
  CellTags->"RandomT"],

Cell["The entries are chosen uniformly.", "Notes",
  CellTags->"RandomT"],

Cell[TextData[{
  "See also ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RandomT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RandomT"],

Cell["Some random transformations.", "ExampleText",
  CellTags->"RandomT"],

Cell[CellGroupData[{

Cell["Table[ RandomT[8], {5} ]", "Input",
  CellLabel->"In[87]:=",
  CellTags->"RandomT"],

Cell[BoxData[
    \({T[3, 1, 6, 4, 1, 1, 4, 7], T[1, 7, 3, 4, 3, 6, 5, 8], 
      T[6, 7, 7, 8, 5, 4, 8, 6], T[6, 1, 3, 4, 4, 1, 5, 4], 
      T[1, 1, 5, 6, 2, 2, 1, 5]}\)], "Output",
  CellLabel->"Out[87]=",
  CellTags->"RandomT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RankT", "ObjectName",
  CellTags->"RankT"],

Cell["Type: function", "Highlight",
  CellTags->"RankT"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"RankT"],

Cell[TextData[{
  StyleBox["RankT[t]", "MR"],
  "  gives the rank of transformation ",
  StyleBox["t", "MR"],
  ", i.e., the cardinality of its image and kernel."
}], "Usage",
  CellTags->"RankT"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["Listable", "MR"],
  "."
}], "Notes",
  CellTags->"RankT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CollapseT",
    ButtonData:>"CollapseT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ImageT",
    ButtonData:>"ImageT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["KernelT",
    ButtonData:>"KernelT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"RankT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RankT"],

Cell["The images of all transformations on 3 points.", "ExampleText",
  CellTags->"RankT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({#, RankT[#]} &\) /@ ToList@TransformationSG[3] // \ 
      TableForm\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"RankT"],

Cell[BoxData[
    TagBox[GridBox[{
          {\(T[1, 1, 1]\), "1"},
          {\(T[1, 1, 2]\), "2"},
          {\(T[1, 1, 3]\), "2"},
          {\(T[1, 2, 1]\), "2"},
          {\(T[1, 2, 2]\), "2"},
          {\(T[1, 2, 3]\), "3"},
          {\(T[1, 3, 1]\), "2"},
          {\(T[1, 3, 2]\), "3"},
          {\(T[1, 3, 3]\), "2"},
          {\(T[2, 1, 1]\), "2"},
          {\(T[2, 1, 2]\), "2"},
          {\(T[2, 1, 3]\), "3"},
          {\(T[2, 2, 1]\), "2"},
          {\(T[2, 2, 2]\), "1"},
          {\(T[2, 2, 3]\), "2"},
          {\(T[2, 3, 1]\), "3"},
          {\(T[2, 3, 2]\), "2"},
          {\(T[2, 3, 3]\), "2"},
          {\(T[3, 1, 1]\), "2"},
          {\(T[3, 1, 2]\), "3"},
          {\(T[3, 1, 3]\), "2"},
          {\(T[3, 2, 1]\), "3"},
          {\(T[3, 2, 2]\), "2"},
          {\(T[3, 2, 3]\), "2"},
          {\(T[3, 3, 1]\), "2"},
          {\(T[3, 3, 2]\), "2"},
          {\(T[3, 3, 3]\), "1"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[5]//TableForm=",
  CellTags->"RankT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RegularQT", "ObjectName",
  CellTags->"RegularQT"],

Cell["Type: function", "Highlight",
  CellTags->"RegularQT"],

Cell[TextData[{
  StyleBox["RegularQT[x,S]", "MR"],
  "  tests whether ",
  StyleBox["x", "MR"],
  " is a regular element in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"RegularQT"],

Cell[TextData[{
  "See ",
  ButtonBox["RegularSG",
    ButtonData:>"RegularSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RegularQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RegularSG", "ObjectName",
  CellTags->"RegularSG"],

Cell["Type: function", "Highlight",
  CellTags->"RegularSG"],

Cell[TextData[{
  StyleBox["RegularSG[S]", "MR"],
  "  returns the regular elements in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"RegularSG"],

Cell["Returns a flat list of transformations.", "Notes",
  CellTags->"RegularSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RegularQT",
    ButtonData:>"RegularQT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RegularSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RegularSG"],

Cell["A three-element semigroup with only one regular element.", "ExampleText",
  CellTags->"RegularSG"],

Cell[BoxData[
    \(\(S\  = \ SG[T[2, 2, 1, 1], T[2, 2, 1, 2], T[2, 2, 2, 2]];\)\)], "Input",\

  CellLabel->"In[84]:=",
  CellTags->"RegularSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RegularSG[S]\)], "Input",
  CellLabel->"In[85]:=",
  CellTags->"RegularSG"],

Cell[BoxData[
    \({T[2, 2, 2, 2]}\)], "Output",
  CellLabel->"Out[85]=",
  CellTags->"RegularSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSG[S]\)], "Input",
  CellLabel->"In[86]:=",
  CellTags->"RegularSG"],

Cell[BoxData[
    \({T[2, 2, 2, 2]}\)], "Output",
  CellLabel->"Out[86]=",
  CellTags->"RegularSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RelationToMatrix", "ObjectName",
  CellTags->"RelationToMatrix"],

Cell["Type: function", "Highlight",
  CellTags->"RelationToMatrix"],

Cell[TextData[{
  StyleBox["RelationToMatrix[rel,A]", "MR"],
  "  converts a binary relation ",
  StyleBox["rel", "MR"],
  " on carrier set ",
  StyleBox["A ", "MR"],
  "into a square Boolean matrix."
}], "Usage",
  CellTags->"RelationToMatrix"],

Cell["The relation must be given by a Boolean function.", "Notes",
  CellTags->"RelationToMatrix"],

Cell["For efficiency reasons, the output is a 0/1-integer matrix.", "Notes",
  CellTags->"RelationToMatrix"],

Cell[TextData[{
  "See also  ",
  ButtonBox["BooleanComplement",
    ButtonData:>"BooleanComplement",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["BooleanComposition",
    ButtonData:>"BooleanComposition",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["BooleanConverse",
    ButtonData:>"BooleanConverse",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["BooleanIntersection",
    ButtonData:>"BooleanIntersection",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["BooleanPower",
    ButtonData:>"BooleanPower",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["BooleanUnion",
    ButtonData:>"BooleanUnion",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["Boolean",
    ButtonData:>"Boolean",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"RelationToMatrix"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RelationToMatrix"],

Cell["Converting to a Boolean matrix.", "ExampleText",
  CellTags->"RelationToMatrix"],

Cell[CellGroupData[{

Cell["RelationToMatrix[ Less, Range[8] ]", "Input",
  CellLabel->"In[46]:=",
  CellTags->"RelationToMatrix"],

Cell[BoxData[
    \({{0, 1, 1, 1, 1, 1, 1, 1}, {0, 0, 1, 1, 1, 1, 1, 1}, {0, 0, 0, 1, 1, 1, 
        1, 1}, {0, 0, 0, 0, 1, 1, 1, 1}, {0, 0, 0, 0, 0, 1, 1, 1}, {0, 0, 0, 
        0, 0, 0, 1, 1}, {0, 0, 0, 0, 0, 0, 0, 1}, {0, 0, 0, 0, 0, 0, 0, 
        0}}\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"RelationToMatrix"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RemoveDuplicates", "ObjectName",
  CellTags->"RemoveDuplicates"],

Cell["Type: function", "Highlight",
  CellTags->"RemoveDuplicates"],

Cell[TextData[{
  StyleBox["RemoveDuplicates[L]", "MR"],
  "  removes duplicates from list ",
  StyleBox["L", "MR"],
  ". "
}], "Usage",
  CellTags->"RemoveDuplicates"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"OutPairs", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"RemoveDuplicates"],

Cell[TextData[{
  "Option ",
  StyleBox["OutPairs->True", "MR"],
  "  generates output in pair form. Only applies to the two-list situation."
}], "Notes",
  CellTags->"RemoveDuplicates"],

Cell[TextData[{
  StyleBox["RemoveDuplicates[L1,L2]", "MR"],
  " removes duplicates from list ",
  StyleBox["L1", "MR"],
  " and corresponding elements from list ",
  StyleBox["L2", "MR"],
  ".  Both lists must have the same length."
}], "Notes",
  CellTags->"RemoveDuplicates"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RemoveDuplicates"],

Cell["A list with repetitions.", "ExampleText",
  CellTags->"RemoveDuplicates"],

Cell[CellGroupData[{

Cell["L = Mod[ Range[10], 4 ]", "Input",
  CellLabel->"In[56]:=",
  CellTags->"RemoveDuplicates"],

Cell[BoxData[
    \({1, 2, 3, 0, 1, 2, 3, 0, 1, 2}\)], "Output",
  CellLabel->"Out[56]=",
  CellTags->"RemoveDuplicates"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RemoveDuplicates[L]\)], "Input",
  CellLabel->"In[57]:=",
  CellTags->"RemoveDuplicates"],

Cell[BoxData[
    \({1, 2, 3, 0}\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->"RemoveDuplicates"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RemoveDuplicates[L, Range[10]]\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->"RemoveDuplicates"],

Cell[BoxData[
    \({{0, 1, 2, 3}, {4, 1, 2, 3}}\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->"RemoveDuplicates"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RemoveDuplicates[L, Range[10], OutPairs \[Rule] True\ ]\)], "Input",
  CellLabel->"In[60]:=",
  CellTags->"RemoveDuplicates"],

Cell[BoxData[
    \({{0, 4}, {1, 1}, {2, 2}, {3, 3}}\)], "Output",
  CellLabel->"Out[60]=",
  CellTags->"RemoveDuplicates"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RemoveVertex", "ObjectName",
  CellTags->"RemoveVertex"],

Cell["Type: function", "Highlight",
  CellTags->"RemoveVertex"],

Cell[TextData[{
  StyleBox["RemoveVertex[G,x]", "MR"],
  "  removes vertex ",
  StyleBox["x", "MR"],
  " from graph ",
  StyleBox["G", "MR"],
  ". "
}], "Usage",
  CellTags->"RemoveVertex"],

Cell[TextData[{
  "Vertex ",
  StyleBox["x", "MR"],
  " must be given in positional notation."
}], "Notes",
  CellTags->"RemoveVertex"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RemoveVertex"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RemoveVertex"],

Cell["A path, and a disconnected graph after removal of one point.", \
"ExampleText",
  CellTags->"RemoveVertex"],

Cell[CellGroupData[{

Cell["G = PathGraph[8]", "Input",
  CellLabel->"In[51]:=",
  CellTags->"RemoveVertex"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"8", ",", "7", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 
                8}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[51]=",
  CellTags->"RemoveVertex"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GG\  = \ RemoveVertex[G, 5]\)], "Input",
  CellLabel->"In[53]:=",
  CellTags->"RemoveVertex"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"7", ",", "5", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {5, 6}, {6, 7}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[53]=",
  CellTags->"RemoveVertex"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(WeaklyConnectedComponents[G, 1]\), "\n", 
    \(WeaklyConnectedComponents[GG, 1]\)}], "Input",
  CellLabel->"In[54]:=",
  CellTags->"RemoveVertex"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8}\)], "Output",
  CellLabel->"Out[54]=",
  CellTags->"RemoveVertex"],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"RemoveVertex"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RenumberRules", "ObjectName",
  CellTags->"RenumberRules"],

Cell["Type: function", "Highlight",
  CellTags->"RenumberRules"],

Cell[TextData[{
  StyleBox["RenumberRules[L]", "MR"],
  "  produces a list of rules that renumber the elements of list ",
  StyleBox["L", "MR"],
  " from 1 to ",
  StyleBox["Length[L]", "MR"],
  ". "
}], "Usage",
  CellTags->"RenumberRules"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Type", "\[Rule]", "Forward", "-"},
          {"Index", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"RenumberRules"],

Cell[TextData[{
  "Option ",
  StyleBox["Index->n", "MR"],
  " starts numbering at ",
  StyleBox["n", "MR"],
  ". "
}], "Notes",
  CellTags->"RenumberRules"],

Cell[TextData[{
  "Option ",
  StyleBox["Type->Backwards", "MR"],
  " generates rules for conversion from integers to list items."
}], "Notes",
  CellTags->"RenumberRules"],

Cell[TextData[{
  "See also ",
  ButtonBox["EnumForm",
    ButtonData:>"EnumForm",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RenumberRules"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RenumberRules"],

Cell["Renumbering elements of a set.", "ExampleText",
  CellTags->"RenumberRules"],

Cell[CellGroupData[{

Cell["P = Permutations[Range[4]]", "Input",
  CellLabel->"In[262]:=",
  CellTags->"RenumberRules"],

Cell[BoxData[
    \({{1, 2, 3, 4}, {1, 2, 4, 3}, {1, 3, 2, 4}, {1, 3, 4, 2}, {1, 4, 2, 
        3}, {1, 4, 3, 2}, {2, 1, 3, 4}, {2, 1, 4, 3}, {2, 3, 1, 4}, {2, 3, 4, 
        1}, {2, 4, 1, 3}, {2, 4, 3, 1}, {3, 1, 2, 4}, {3, 1, 4, 2}, {3, 2, 1, 
        4}, {3, 2, 4, 1}, {3, 4, 1, 2}, {3, 4, 2, 1}, {4, 1, 2, 3}, {4, 1, 3, 
        2}, {4, 2, 1, 3}, {4, 2, 3, 1}, {4, 3, 1, 2}, {4, 3, 2, 
        1}}\)], "Output",
  CellLabel->"Out[262]=",
  CellTags->"RenumberRules"]
}, Open  ]],

Cell[BoxData[
    \(\(rules\  = \ RenumberRules[P];\)\)], "Input",
  CellLabel->"In[263]:=",
  CellTags->"RenumberRules"],

Cell[CellGroupData[{

Cell[BoxData[
    \(P\  /. \ rules\)], "Input",
  CellLabel->"In[264]:=",
  CellTags->"RenumberRules"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
      21, 22, 23, 24}\)], "Output",
  CellLabel->"Out[264]=",
  CellTags->"RenumberRules"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Select[P, Signature[#] \[Equal] 1 &]\  /. \ rules\)], "Input",
  CellLabel->"In[266]:=",
  CellTags->"RenumberRules"],

Cell[BoxData[
    \({1, 4, 5, 8, 9, 12, 13, 16, 17, 20, 21, 24}\)], "Output",
  CellLabel->"Out[266]=",
  CellTags->"RenumberRules"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReplaceParts", "ObjectName",
  CellTags->"ReplaceParts"],

Cell["Type: function", "Highlight",
  CellTags->"ReplaceParts"],

Cell[TextData[{
  StyleBox["ReplaceParts[x,r1,p1,r2,p2]", "MR"],
  "  performs two consecutive replacements."
}], "Usage",
  CellTags->"ReplaceParts"],

Cell["Only used internally. ", "Notes",
  CellTags->"ReplaceParts"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ReverseGraph", "ObjectName",
  CellTags->"ReverseGraph"],

Cell["Type: function", "Highlight",
  CellTags->"ReverseGraph"],

Cell[TextData[{
  StyleBox["ReverseGraph[G]", "MR"],
  "  reverses all edges in a graph ",
  StyleBox["G", "MR"],
  "."
}], "Usage",
  CellTags->"ReverseGraph"],

Cell[TextData[{
  StyleBox["ReverseGraph", "MR"],
  " retains the type of the graph."
}], "Notes",
  CellTags->"ReverseGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PermuteGraph",
    ButtonData:>"PermuteGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ReverseGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ReverseGraph"],

Cell["A path graph and its reversal.", "ExampleText",
  CellTags->"ReverseGraph"],

Cell[CellGroupData[{

Cell["g = PathGraph[6]", "Input",
  CellLabel->"In[224]:=",
  CellTags->"ReverseGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"6", ",", "5", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[224]=",
  CellTags->"ReverseGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReverseGraph[g]\)], "Input",
  CellLabel->"In[225]:=",
  CellTags->"ReverseGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"6", ",", "5", ",", "1", ",", 
          TagBox[\({{2, 1}, {3, 2}, {4, 3}, {5, 4}, {6, 5}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[225]=",
  CellTags->"ReverseGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g\  // \ ToAdjMatrix\)\  // \ ReverseGraph\)], "Input",
  CellLabel->"In[226]:=",
  CellTags->"ReverseGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"6", ",", "5", ",", "3", ",", 
          
          TagBox[\({{0, 0, 0, 0, 0, 0}, {1, 0, 0, 0, 0, 0}, {0, 1, 0, 0, 0, 
                0}, {0, 0, 1, 0, 0, 0}, {0, 0, 0, 1, 0, 0}, {0, 0, 0, 0, 1, 
                0}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[226]=",
  CellTags->"ReverseGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RightIdealT", "ObjectName",
  CellTags->"RightIdealT"],

Cell["Type: function", "Highlight",
  CellTags->"RightIdealT"],

Cell[TextData[{
  StyleBox["RightIdealT[x,T]", "MR"],
  "  computes the right ideal generated by transformation x in semigroup S."
}], "Usage",
  CellTags->"RightIdealT"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"RightIdealT"],

Cell[TextData[{
  "See also ",
  ButtonBox["LeftIdealT",
    ButtonData:>"LeftIdealT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IdealT",
    ButtonData:>"IdealT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RightIdealT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RightIdealT"],

Cell["\<\
The full transformation semigroup on 3 points, and some of its \
right ideals.\
\>", "ExampleText",
  CellTags->"RightIdealT"],

Cell[BoxData[
    \(\(S = TransformationSG[3];\)\)], "Input",
  CellLabel->"In[70]:=",
  CellTags->"RightIdealT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RightIdealT[\ S[\([1]\)], \ S\ ]\)], "Input",
  CellLabel->"In[77]:=",
  CellTags->"RightIdealT"],

Cell[BoxData[
    \({T[1, 1, 1], T[2, 2, 2], T[3, 3, 3]}\)], "Output",
  CellLabel->"Out[77]=",
  CellTags->"RightIdealT"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RightIdealT[\ S[\([2]\)], \ S\ ]\)], "Input",
  CellLabel->"In[76]:=",
  CellTags->"RightIdealT"],

Cell[BoxData[
    \({T[1, 1, 1], T[1, 1, 2], T[1, 1, 3], T[2, 2, 1], T[2, 2, 2], 
      T[2, 2, 3], T[3, 3, 1], T[3, 3, 2], T[3, 3, 3]}\)], "Output",
  CellLabel->"Out[76]=",
  CellTags->"RightIdealT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RightNullQT", "ObjectName",
  CellTags->"RightNullQT"],

Cell["Type: function", "Highlight",
  CellTags->"RightNullQT"],

Cell[TextData[{
  StyleBox["RightNullQT[x,S]", "MR"],
  "  tests whether transformation ",
  StyleBox["x", "MR"],
  " is a right null in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"RightNullQT"],

Cell[TextData[{
  "See also ",
  ButtonBox["LeftOneQT",
    ButtonData:>"LeftOneQT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OneSG",
    ButtonData:>"OneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RightOneSG",
    ButtonData:>"RightOneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NullSG",
    ButtonData:>"NullSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RightNullQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RightNullSG", "ObjectName",
  CellTags->"RightNullSG"],

Cell["Type: function", "Highlight",
  CellTags->"RightNullSG"],

Cell[TextData[{
  StyleBox["LeftNullSG[S]", "MR"],
  "  lists the right nulls of a semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"RightNullSG"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"RightNullSG"],

Cell[TextData[{
  "See also  ",
  ButtonBox["OneSG",
    ButtonData:>"OneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LeftNullSG",
    ButtonData:>"LeftNullSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NullSG",
    ButtonData:>"NullSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["RightNullQT",
    ButtonData:>"RightNullQT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"RightNullSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RightNullSG"],

Cell["\<\
The full transformation semigroup on 3 points has 3 right-nulls, \
the constant transformations.\
\>", "ExampleText",
  CellTags->"RightNullSG"],

Cell["S = TransformationSG[3];", "Input",
  CellLabel->"In[104]:=",
  CellTags->"RightNullSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RightNullSG[S]\)], "Input",
  CellLabel->"In[102]:=",
  CellTags->"RightNullSG"],

Cell[BoxData[
    \({T[1, 1, 1], T[2, 2, 2], T[3, 3, 3]}\)], "Output",
  CellLabel->"Out[102]=",
  CellTags->"RightNullSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RightOneQT", "ObjectName",
  CellTags->"RightOneQT"],

Cell["Type: function", "Highlight",
  CellTags->"RightOneQT"],

Cell[TextData[{
  StyleBox["RightOneQT[x,S]", "MR"],
  "  tests whether transformation ",
  StyleBox["x", "MR"],
  " is a right identity in semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"RightOneQT"],

Cell[TextData[{
  "See also ",
  ButtonBox["LeftOneQT",
    ButtonData:>"LeftOneQT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OneSG",
    ButtonData:>"OneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RightOneSG",
    ButtonData:>"RightOneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NullSG",
    ButtonData:>"NullSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RightOneQT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RightOneSG", "ObjectName",
  CellTags->"RightOneSG"],

Cell["Type: function", "Highlight",
  CellTags->"RightOneSG"],

Cell[TextData[{
  StyleBox["RightOneSG[S]", "MR"],
  "  lists the right identities of a semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"RightOneSG"],

Cell["Returns a list of transformations.", "Notes",
  CellTags->"RightOneSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["RightOneQT",
    ButtonData:>"RightOneQT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OneSG",
    ButtonData:>"OneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LeftOneSG",
    ButtonData:>"LeftOneSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NullSG",
    ButtonData:>"NullSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RightOneSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RightOneSG"],

Cell["\<\
The full transformation semigroup on 3 points has only the identity \
as right-one.\
\>", "ExampleText",
  CellTags->"RightOneSG"],

Cell["S = TransformationSG[3];", "Input",
  CellLabel->"In[96]:=",
  CellTags->"RightOneSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RightOneSG[S]\)], "Input",
  CellLabel->"In[97]:=",
  CellTags->"RightOneSG"],

Cell[BoxData[
    \({T[1, 2, 3]}\)], "Output",
  CellLabel->"Out[97]=",
  CellTags->"RightOneSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RootList", "ObjectName",
  CellTags->"RootList"],

Cell["Type: function", "Highlight",
  CellTags->"RootList"],

Cell[TextData[{
  StyleBox["RootList[L]", "MR"],
  "  computes the root of a list L, i.e., the shortest list ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`L\  = \ K\^\(\(\ \)\(i\)\)\)]],
  " for some ",
  Cell[BoxData[
      \(TraditionalForm\`i > 0\)]],
  "."
}], "Usage",
  CellTags->"RootList"],

Cell[TextData[{
  "Unlike ",
  StyleBox["WordRoot", "MR"],
  ", uses a brute force algorithm."
}], "Notes",
  CellTags->"RootList"],

Cell[TextData[{
  "See also ",
  ButtonBox["PrimitiveCount",
    ButtonData:>"PrimitiveCount",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PrimitiveQ",
    ButtonData:>"PrimitiveQ",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RootList"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RootList"],

Cell["A repetitive list, and its root.", "ExampleText",
  CellTags->"RootList"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L = Flatten[Table[{1, 2, 3}, {5}]]\)], "Input",
  CellLabel->"In[48]:=",
  CellTags->"RootList"],

Cell[BoxData[
    \({1, 2, 3, 1, 2, 3, 1, 2, 3, 1, 2, 3, 1, 2, 3}\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->"RootList"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RootList[L]\)], "Input",
  CellLabel->"In[49]:=",
  CellTags->"RootList"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output",
  CellLabel->"Out[49]=",
  CellTags->"RootList"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["RShiftT", "ObjectName",
  CellTags->"RShiftT"],

Cell["Type: function", "Highlight",
  CellTags->"RShiftT"],

Cell[TextData[{
  StyleBox["RShiftT[n]", "MR"],
  "  returns the right shift transformation ",
  StyleBox["T[n,1,2,..,n-1]", "MR"],
  "."
}], "Usage",
  CellTags->"RShiftT"],

Cell[TextData[{
  "See also ",
  ButtonBox["LShiftT",
    ButtonData:>"LShiftT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["ConsT",
    ButtonData:>"ConsT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["OneT",
    ButtonData:>"OneT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["RandomT",
    ButtonData:>"RandomT",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"RShiftT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RulesToPairs", "ObjectName",
  CellTags->"RulesToPairs"],

Cell["Type: function", "Highlight",
  CellTags->"RulesToPairs"],

Cell[TextData[{
  StyleBox["RulesToPairs[rw]", "MR"],
  "  replaces rewrite rules by word pairs."
}], "Usage",
  CellTags->"RulesToPairs"],

Cell[TextData[{
  "See also ",
  ButtonBox["PairsToRules",
    ButtonData:>"PairsToRules",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["SimplifyRewriteSystem",
    ButtonData:>"SimplifyRewriteSystem",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"RulesToPairs"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"RulesToPairs"],

Cell["A rewrite systems using rules, and its pair form.", "ExampleText",
  CellTags->"RulesToPairs"],

Cell[BoxData[
    \(\(eq\  = \ {"\<bc\>" \[Rule] "\<c\>", "\<cc\>" \[Rule] "\<c\>", \
"\<aaa\>" \[Rule] "\<bb\>", "\<aab\>" \[Rule] "\<ba\>", "\<aba\>" \[Rule] \
"\<Eps\>"};\)\)], "Input",
  CellLabel->"In[53]:=",
  CellTags->"RulesToPairs"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RulesToPairs[eq]\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->"RulesToPairs"],

Cell[BoxData[
    \({{"bc", "c"}, {"cc", "c"}, {"aaa", "bb"}, {"aab", 
        "ba"}, {"aba", \[Epsilon]}}\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"RulesToPairs"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SeedConfiguration", "ObjectName",
  CellTags->"SeedConfiguration"],

Cell["Type: function", "Highlight",
  CellTags->"SeedConfiguration"],

Cell[TextData[{
  StyleBox["SeedConfiguration[{w},n,z]", "MR"],
  "  produces a seed configuration of length n with w at the center. "
}], "Usage",
  CellTags->"SeedConfiguration"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Where", "\[Rule]", "Center", \(Left, Right\)}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SeedConfiguration"],

Cell["\<\
Symbol z is used in place of 0. Also works with words rather than \
lists.\
\>", "Notes",
  CellTags->"SeedConfiguration"],

Cell["This is useful mostly in connection with cellular automata.", "Notes",
  CellTags->"SeedConfiguration"],

Cell[TextData[{
  "See also ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OrbitCA",
    ButtonData:>"OrbitCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SeedConfiguration"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SeedConfiguration"],

Cell["Some seed configurations.", "ExampleText",
  CellTags->"SeedConfiguration"],

Cell[CellGroupData[{

Cell["SeedConfiguration[{1,2},10]", "Input",
  CellLabel->"In[69]:=",
  CellTags->"SeedConfiguration"],

Cell[BoxData[
    \({0, 0, 0, 0, 1, 2, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[69]=",
  CellTags->"SeedConfiguration"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SeedConfiguration[{1,2},10,Where->Left]", "Input",
  CellLabel->"In[70]:=",
  CellTags->"SeedConfiguration"],

Cell[BoxData[
    \({1, 2, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[70]=",
  CellTags->"SeedConfiguration"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SelectOptions", "ObjectName",
  CellTags->"SelectOptions"],

Cell["Type: function", "Highlight",
  CellTags->"SelectOptions"],

Cell[TextData[{
  StyleBox["SelectOptions[cmd,opts]", "MR"],
  "  selects those options from ",
  StyleBox["opts", "MR"],
  " that make sense for ",
  StyleBox["cmd", "MR"],
  ". "
}], "Usage",
  CellTags->"SelectOptions"],

Cell[TextData[{
  StyleBox["SelectOptions[cmd,opts,{excl}]", "MR"],
  " exludes options whose names are listed in ",
  StyleBox["{excl}", "MR"],
  "."
}], "Notes",
  CellTags->"SelectOptions"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SelectorQ", "ObjectName",
  CellTags->"SelectorQ"],

Cell["Type: function", "Highlight",
  CellTags->"SelectorQ"],

Cell[TextData[{
  StyleBox["SelectorQ[A,P]", "MR"],
  "  tests whether list ",
  StyleBox["A", "MR"],
  " selects precisely one element of each of the lists in ",
  StyleBox["P", "MR"],
  "."
}], "Usage",
  CellTags->"SelectorQ"],

Cell[TextData[{
  "If ",
  StyleBox["P", "MR"],
  " is in particular a partition this tests whether ",
  StyleBox["A", "MR"],
  " is a set of representatives for ",
  StyleBox["P", "MR"],
  "."
}], "Notes",
  CellTags->"SelectorQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["Partitions",
    ButtonData:>"Partitions",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SelectorQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SelectorQ"],

Cell[TextData[{
  "A partition of ",
  Cell[BoxData[
      \(TraditionalForm\`\([12]\)\)]],
  ", and a system of representatives."
}], "ExampleText",
  CellTags->"SelectorQ"],

Cell[BoxData[
    \(\(P = {{1, 4, 7, 10}, {2, 5, 8, 11}, {3, 6, 9, 12}};\)\)], "Input",
  CellLabel->"In[89]:=",
  CellTags->"SelectorQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SelectorQ[\ {10, 11, 12}, \ P\ ]\)], "Input",
  CellLabel->"In[91]:=",
  CellTags->"SelectorQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[91]=",
  CellTags->"SelectorQ"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SelectorQ[\ {9, 11, 12}, \ P\ ]\)], "Input",
  CellLabel->"In[94]:=",
  CellTags->"SelectorQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[94]=",
  CellTags->"SelectorQ"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShortestPath", "ObjectName",
  CellTags->"ShortestPath"],

Cell["Type: function", "Highlight",
  CellTags->"ShortestPath"],

Cell[TextData[{
  StyleBox["ShortestPath[G,s]", "MR"],
  "  constructs a shortest path from source vertex ",
  StyleBox["s", "MR"],
  " in graph ",
  StyleBox["G", "MR"],
  " to all vertices reachable from ",
  StyleBox["s", "MR"],
  "."
}], "Usage",
  CellTags->"ShortestPath"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ShortestPath"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->True", "MR"],
  " will produce the actual paths."
}], "Notes",
  CellTags->"ShortestPath"],

Cell[TextData[{
  "Output is of the form ",
  StyleBox["(u,d)", "MR"],
  " where ",
  StyleBox["u", "MR"],
  " is a vertex and ",
  StyleBox["d", "MR"],
  " is its distance from ",
  StyleBox["s", "MR"],
  "."
}], "Notes",
  CellTags->"ShortestPath"],

Cell[TextData[{
  "See also ",
  ButtonBox["WeaklyConnectedComponents",
    ButtonData:>"WeaklyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LongestPath",
    ButtonData:>"LongestPath",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ShortestPath"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ShortestPath"],

Cell["\<\
A circulant graph and the shortest path associated with vertex 1. \
\
\>", "ExampleText",
  CellTags->"ShortestPath"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G = CirculantGraph[10, {1, \(-3\)}]\)], "Input",
  CellLabel->"In[82]:=",
  CellTags->"ShortestPath"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"10", ",", "20", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 
                8}, \[LeftSkeleton]6\[RightSkeleton], {4, 1}, {5, 2}, {6, 
                3}, {7, 4}, {8, 5}, {9, 6}, {10, 7}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[82]=",
  CellTags->"ShortestPath"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShortestPath[G, 1]\)], "Input",
  CellLabel->"In[83]:=",
  CellTags->"ShortestPath"],

Cell[BoxData[
    \({{1, 0}, {2, 1}, {3, 2}, {4, 3}, {5, 2}, {6, 3}, {7, 4}, {8, 1}, {9, 
        2}, {10, 3}}\)], "Output",
  CellLabel->"Out[83]=",
  CellTags->"ShortestPath"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShortestPath[G, 1, Full \[Rule] True]\)], "Input",
  CellLabel->"In[84]:=",
  CellTags->"ShortestPath"],

Cell[BoxData[
    \({{1}, {1, 2}, {1, 2, 3}, {1, 2, 3, 4}, {1, 8, 5}, {1, 2, 9, 6}, {1, 2, 
        3, 10, 7}, {1, 8}, {1, 2, 9}, {1, 2, 3, 10}}\)], "Output",
  CellLabel->"Out[84]=",
  CellTags->"ShortestPath"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowArray", "ObjectName",
  CellTags->"ShowArray"],

Cell["Type: function", "Highlight",
  CellTags->"ShowArray"],

Cell[TextData[{
  StyleBox["ShowArray[L,k]", "MR"],
  "  produces a graphics array of width ",
  StyleBox["k", "MR"],
  " from a linear list ",
  StyleBox["L", "MR"],
  " of graphics objects. "
}], "Usage",
  CellTags->"ShowArray"],

Cell[TextData[{
  "Parameter ",
  StyleBox["k", "MR"],
  " has the default value ",
  StyleBox["Ceiling[Sqrt[Length[L]]]", "MR"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"ShowArray"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ShowArray"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ShowArray"],

Cell["Arranging images in a grid.", "ExampleText",
  CellTags->"ShowArray"],

Cell[BoxData[
    \(\(gr = \((PlotT[#1, 4, PlotStyle \[Rule] {0.04, 0.04}, 
                DisplayFunction \[Rule] Identity] &)\) /@ 
          ToList[SymmetricGroupSG[3]];\)\)], "Input",
  CellLabel->"In[79]:=",
  CellTags->"ShowArray"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowArray[gr];\)\)], "Input",
  CellLabel->"In[80]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .40558 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00965678 0.31746 [
[ 0 0 0 0 ]
[ 1 .40558 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .40558 L
0 .40558 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00965678 0.321429 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.0343352 0.171676 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
.14286 .13734 m
.32143 .30902 L
s
.14286 .30902 m
.32143 .48069 L
s
.14286 .48069 m
.32143 .13734 L
s
.32143 .13734 m
.5 .30902 L
s
.32143 .30902 m
.5 .48069 L
s
.32143 .48069 m
.5 .13734 L
s
.5 .13734 m
.67857 .30902 L
s
.5 .30902 m
.67857 .48069 L
s
.5 .48069 m
.67857 .13734 L
s
.67857 .13734 m
.85714 .30902 L
s
.67857 .30902 m
.85714 .48069 L
s
.67857 .48069 m
.85714 .13734 L
s
1 0 0 r
.04 w
.14286 .13734 Mdot
.14286 .30902 Mdot
.14286 .48069 Mdot
.32143 .13734 Mdot
.32143 .30902 Mdot
.32143 .48069 Mdot
.5 .13734 Mdot
.5 .30902 Mdot
.5 .48069 Mdot
.67857 .13734 Mdot
.67857 .30902 Mdot
.67857 .48069 Mdot
.85714 .13734 Mdot
.85714 .30902 Mdot
.85714 .48069 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00965678 0.64881 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.0343352 0.171676 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
.14286 .13734 m
.32143 .48069 L
s
.14286 .30902 m
.32143 .13734 L
s
.14286 .48069 m
.32143 .30902 L
s
.32143 .13734 m
.5 .48069 L
s
.32143 .30902 m
.5 .13734 L
s
.32143 .48069 m
.5 .30902 L
s
.5 .13734 m
.67857 .48069 L
s
.5 .30902 m
.67857 .13734 L
s
.5 .48069 m
.67857 .30902 L
s
.67857 .13734 m
.85714 .48069 L
s
.67857 .30902 m
.85714 .13734 L
s
.67857 .48069 m
.85714 .30902 L
s
1 0 0 r
.04 w
.14286 .13734 Mdot
.14286 .30902 Mdot
.14286 .48069 Mdot
.32143 .13734 Mdot
.32143 .30902 Mdot
.32143 .48069 Mdot
.5 .13734 Mdot
.5 .30902 Mdot
.5 .48069 Mdot
.67857 .13734 Mdot
.67857 .30902 Mdot
.67857 .48069 Mdot
.85714 .13734 Mdot
.85714 .30902 Mdot
.85714 .48069 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00965678 0.97619 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.0343352 0.171676 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
.14286 .13734 m
.32143 .48069 L
s
.14286 .30902 m
.32143 .30902 L
s
.14286 .48069 m
.32143 .13734 L
s
.32143 .13734 m
.5 .48069 L
s
.32143 .30902 m
.5 .30902 L
s
.32143 .48069 m
.5 .13734 L
s
.5 .13734 m
.67857 .48069 L
s
.5 .30902 m
.67857 .30902 L
s
.5 .48069 m
.67857 .13734 L
s
.67857 .13734 m
.85714 .48069 L
s
.67857 .30902 m
.85714 .30902 L
s
.67857 .48069 m
.85714 .13734 L
s
1 0 0 r
.04 w
.14286 .13734 Mdot
.14286 .30902 Mdot
.14286 .48069 Mdot
.32143 .13734 Mdot
.32143 .30902 Mdot
.32143 .48069 Mdot
.5 .13734 Mdot
.5 .30902 Mdot
.5 .48069 Mdot
.67857 .13734 Mdot
.67857 .30902 Mdot
.67857 .48069 Mdot
.85714 .13734 Mdot
.85714 .30902 Mdot
.85714 .48069 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.211989 0.321429 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.0343352 0.171676 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
.14286 .13734 m
.32143 .13734 L
s
.14286 .30902 m
.32143 .30902 L
s
.14286 .48069 m
.32143 .48069 L
s
.32143 .13734 m
.5 .13734 L
s
.32143 .30902 m
.5 .30902 L
s
.32143 .48069 m
.5 .48069 L
s
.5 .13734 m
.67857 .13734 L
s
.5 .30902 m
.67857 .30902 L
s
.5 .48069 m
.67857 .48069 L
s
.67857 .13734 m
.85714 .13734 L
s
.67857 .30902 m
.85714 .30902 L
s
.67857 .48069 m
.85714 .48069 L
s
1 0 0 r
.04 w
.14286 .13734 Mdot
.14286 .30902 Mdot
.14286 .48069 Mdot
.32143 .13734 Mdot
.32143 .30902 Mdot
.32143 .48069 Mdot
.5 .13734 Mdot
.5 .30902 Mdot
.5 .48069 Mdot
.67857 .13734 Mdot
.67857 .30902 Mdot
.67857 .48069 Mdot
.85714 .13734 Mdot
.85714 .30902 Mdot
.85714 .48069 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.211989 0.64881 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.0343352 0.171676 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
.14286 .13734 m
.32143 .13734 L
s
.14286 .30902 m
.32143 .48069 L
s
.14286 .48069 m
.32143 .30902 L
s
.32143 .13734 m
.5 .13734 L
s
.32143 .30902 m
.5 .48069 L
s
.32143 .48069 m
.5 .30902 L
s
.5 .13734 m
.67857 .13734 L
s
.5 .30902 m
.67857 .48069 L
s
.5 .48069 m
.67857 .30902 L
s
.67857 .13734 m
.85714 .13734 L
s
.67857 .30902 m
.85714 .48069 L
s
.67857 .48069 m
.85714 .30902 L
s
1 0 0 r
.04 w
.14286 .13734 Mdot
.14286 .30902 Mdot
.14286 .48069 Mdot
.32143 .13734 Mdot
.32143 .30902 Mdot
.32143 .48069 Mdot
.5 .13734 Mdot
.5 .30902 Mdot
.5 .48069 Mdot
.67857 .13734 Mdot
.67857 .30902 Mdot
.67857 .48069 Mdot
.85714 .13734 Mdot
.85714 .30902 Mdot
.85714 .48069 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.211989 0.97619 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0357143 0.178571 -0.0343352 0.171676 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
.14286 .13734 m
.32143 .30902 L
s
.14286 .30902 m
.32143 .13734 L
s
.14286 .48069 m
.32143 .48069 L
s
.32143 .13734 m
.5 .30902 L
s
.32143 .30902 m
.5 .13734 L
s
.32143 .48069 m
.5 .48069 L
s
.5 .13734 m
.67857 .30902 L
s
.5 .30902 m
.67857 .13734 L
s
.5 .48069 m
.67857 .48069 L
s
.67857 .13734 m
.85714 .30902 L
s
.67857 .30902 m
.85714 .13734 L
s
.67857 .48069 m
.85714 .48069 L
s
1 0 0 r
.04 w
.14286 .13734 Mdot
.14286 .30902 Mdot
.14286 .48069 Mdot
.32143 .13734 Mdot
.32143 .30902 Mdot
.32143 .48069 Mdot
.5 .13734 Mdot
.5 .30902 Mdot
.5 .48069 Mdot
.67857 .13734 Mdot
.67857 .30902 Mdot
.67857 .48069 Mdot
.85714 .13734 Mdot
.85714 .30902 Mdot
.85714 .48069 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[80]:=",
  ImageSize->{416.062, 168.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shuffle", "ObjectName",
  CellTags->"Shuffle"],

Cell["Type: function", "Highlight",
  CellTags->"Shuffle"],

Cell[TextData[{
  StyleBox["Shuffle[A,B]", "MR"],
  "  shuffles two lists ",
  StyleBox["A", "MR"],
  " and ",
  StyleBox["B", "MR"],
  StyleBox[".", "Text"],
  " "
}], "Usage",
  CellTags->"Shuffle"],

Cell[TextData[{
  "Also accepts input ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " for ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Range[n]\),
          "MR"], TraditionalForm]]],
  "."
}], "Notes",
  CellTags->"Shuffle"],

Cell[TextData[{
  "See also ",
  ButtonBox["WordShuffle",
    ButtonData:>"WordShuffle",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ShuffleProductFA",
    ButtonData:>"ShuffleProductFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Shuffle"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Shuffle"],

Cell["All possible order preserving interleavings of two lists.", \
"ExampleText",
  CellTags->"Shuffle"],

Cell[CellGroupData[{

Cell["Shuffle[ {1,2,3}, {a,b} ]", "Input",
  CellLabel->"In[63]:=",
  CellTags->"Shuffle"],

Cell[BoxData[
    \({{1, 2, 3, a, b}, {1, 2, a, 3, b}, {1, 2, a, b, 3}, {1, a, 2, 3, 
        b}, {1, a, 2, b, 3}, {1, a, b, 2, 3}, {a, 1, 2, 3, b}, {a, 1, 2, b, 
        3}, {a, 1, b, 2, 3}, {a, b, 1, 2, 3}}\)], "Output",
  CellLabel->"Out[63]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SimplifyEquations", "ObjectName",
  CellTags->"SimplifyEquations"],

Cell["Type: function", "Highlight",
  CellTags->"SimplifyEquations"],

Cell[TextData[{
  StyleBox["SimplifyEquations[S,wit,eq]", "MR"],
  "  simplifies the rewrite system associated with a semigroup produces by ",
  StyleBox["GenerateSG", "MR"],
  "."
}], "Usage",
  CellTags->"SimplifyEquations"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "True", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SimplifyEquations"],

Cell[TextData[{
  " Also rewrites null as ",
  StyleBox["$nullstring", "MR"],
  " (default: 0) and one as ",
  StyleBox["$identitystring", "MR"],
  " (default: 1), if there is a null and/or one in ",
  StyleBox["S", "MR"],
  ". "
}], "Notes",
  CellTags->"SimplifyEquations"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SimplifyRewriteSystem",
    ButtonData:>"SimplifyRewriteSystem",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SimplifyEquations"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SimplifyEquations"],

Cell["\<\
The full transformation semigroup on 3 points has an identity, but \
no null.\
\>", "ExampleText",
  CellTags->"SimplifyEquations"],

Cell[BoxData[
    \(\({S, W, rw} = 
        TransformationSG[3, Equations \[Rule] True];\)\)], "Input",
  CellLabel->"In[57]:=",
  CellTags->"SimplifyEquations"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rw\  // \ Length\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(57\)], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SimplifyEquations[S, W, rw]\  // \ PrintEquations\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(" 1" \(\(:\)\(\ \)\) \("bb" \[Rule] "1"\)\)},
          {\(" 2" \(\(:\)\(\ \)\) \("bc" \[Rule] "c"\)\)},
          {\(" 3" \(\(:\)\(\ \)\) \("cc" \[Rule] "c"\)\)},
          {\(" 4" \(\(:\)\(\ \)\) \("aaa" \[Rule] "1"\)\)},
          {\(" 5" \(\(:\)\(\ \)\) \("aab" \[Rule] "ba"\)\)},
          {\(" 6" \(\(:\)\(\ \)\) \("aba" \[Rule] "b"\)\)},
          {\(" 7" \(\(:\)\(\ \)\) \("baa" \[Rule] "ab"\)\)},
          {\(" 8" \(\(:\)\(\ \)\) \("bab" \[Rule] "aa"\)\)},
          {\(" 9" \(\(:\)\(\ \)\) \("bac" \[Rule] "aac"\)\)},
          {\("10" \(\(:\)\(\ \)\) \("cac" \[Rule] "cab"\)\)},
          {\("11" \(\(:\)\(\ \)\) \("acaac" \[Rule] "caac"\)\)},
          {\("12" \(\(:\)\(\ \)\) \("caacaa" \[Rule] "caacb"\)\)},
          {\("13" \(\(:\)\(\ \)\) \("caacab" \[Rule] "caaca"\)\)},
          {\("14" \(\(:\)\(\ \)\) \("caacba" \[Rule] "caac"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ " 1", "bb" -> "1"], 
        ColonForm[ " 2", "bc" -> "c"], 
        ColonForm[ " 3", "cc" -> "c"], 
        ColonForm[ " 4", "aaa" -> "1"], 
        ColonForm[ " 5", "aab" -> "ba"], 
        ColonForm[ " 6", "aba" -> "b"], 
        ColonForm[ " 7", "baa" -> "ab"], 
        ColonForm[ " 8", "bab" -> "aa"], 
        ColonForm[ " 9", "bac" -> "aac"], 
        ColonForm[ "10", "cac" -> "cab"], 
        ColonForm[ "11", "acaac" -> "caac"], 
        ColonForm[ "12", "caacaa" -> "caacb"], 
        ColonForm[ "13", "caacab" -> "caaca"], 
        ColonForm[ "14", "caacba" -> "caac"]}, TableSpacing -> {1, 
        1}]]], "Output",
  CellLabel->"Out[61]//TableForm="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SimplifyRewriteSystem", "ObjectName",
  CellTags->"SimplifyRewriteSystem"],

Cell["Type: function", "Highlight",
  CellTags->"SimplifyRewriteSystem"],

Cell[TextData[{
  StyleBox["SimplifyRewriteSystem[eq]", "MR"],
  "  normalizes a rewrite system given by the directed equations ",
  StyleBox["eq", "MR"],
  ". "
}], "Usage",
  CellTags->"SimplifyRewriteSystem"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SimplifyRewriteSystem"],

Cell[TextData[{
  "In the output, both the LHS and the RHS of all equations will be \
irreducible. The Thue congruence determined by ",
  StyleBox["eq", "MR"],
  " is not affected by this transformation."
}], "Notes",
  CellTags->"SimplifyRewriteSystem"],

Cell[TextData[{
  "Note that ",
  StyleBox["SimplifyRewriteSystem", "MR"],
  " is implemented only internally and rather slow; do not use on more than \
50 equations. "
}], "Notes",
  CellTags->"SimplifyRewriteSystem"],

Cell[TextData[{
  "See also ",
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SimplifyRewriteSystem"],

Cell["\<\
The rewrite system produced by generating the full transformation \
semigroup on 3 points is rather large, but can be simplified.\
\>", \
"ExampleText",
  CellTags->"SimplifyRewriteSystem"],

Cell[BoxData[
    \(\({S, W, eq} = 
        TransformationSG[3, Equations \[Rule] True];\)\)], "Input",
  CellLabel->"In[85]:=",
  CellTags->"SimplifyRewriteSystem"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq\  // \ Length\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(57\)], "Output",
  CellLabel->"Out[86]="]
}, Open  ]],

Cell[BoxData[
    \(\(eqs\  = \ SimplifyRewriteSystem[eq];\)\)], "Input",
  CellLabel->"In[88]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintEquations[eqs]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(" 1" \(\(:\)\(\ \)\) \("bc" \[Rule] "c"\)\)},
          {\(" 2" \(\(:\)\(\ \)\) \("cc" \[Rule] "c"\)\)},
          {\(" 3" \(\(:\)\(\ \)\) \("aaa" \[Rule] "bb"\)\)},
          {\(" 4" \(\(:\)\(\ \)\) \("aab" \[Rule] "ba"\)\)},
          {\(" 5" \(\(:\)\(\ \)\) \("aba" \[Rule] "b"\)\)},
          {\(" 6" \(\(:\)\(\ \)\) \("abb" \[Rule] "a"\)\)},
          {\(" 7" \(\(:\)\(\ \)\) \("baa" \[Rule] "ab"\)\)},
          {\(" 8" \(\(:\)\(\ \)\) \("bab" \[Rule] "aa"\)\)},
          {\(" 9" \(\(:\)\(\ \)\) \("bac" \[Rule] "aac"\)\)},
          {\("10" \(\(:\)\(\ \)\) \("bba" \[Rule] "a"\)\)},
          {\("11" \(\(:\)\(\ \)\) \("bbb" \[Rule] "b"\)\)},
          {\("12" \(\(:\)\(\ \)\) \("cac" \[Rule] "cab"\)\)},
          {\("13" \(\(:\)\(\ \)\) \("cbb" \[Rule] "c"\)\)},
          {\("14" \(\(:\)\(\ \)\) \("acaac" \[Rule] "caac"\)\)},
          {\("15" \(\(:\)\(\ \)\) \("caacaa" \[Rule] "caacb"\)\)},
          {\("16" \(\(:\)\(\ \)\) \("caacab" \[Rule] "caaca"\)\)},
          {\("17" \(\(:\)\(\ \)\) \("caacba" \[Rule] "caac"\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        ColonForm[ " 1", "bc" -> "c"], 
        ColonForm[ " 2", "cc" -> "c"], 
        ColonForm[ " 3", "aaa" -> "bb"], 
        ColonForm[ " 4", "aab" -> "ba"], 
        ColonForm[ " 5", "aba" -> "b"], 
        ColonForm[ " 6", "abb" -> "a"], 
        ColonForm[ " 7", "baa" -> "ab"], 
        ColonForm[ " 8", "bab" -> "aa"], 
        ColonForm[ " 9", "bac" -> "aac"], 
        ColonForm[ "10", "bba" -> "a"], 
        ColonForm[ "11", "bbb" -> "b"], 
        ColonForm[ "12", "cac" -> "cab"], 
        ColonForm[ "13", "cbb" -> "c"], 
        ColonForm[ "14", "acaac" -> "caac"], 
        ColonForm[ "15", "caacaa" -> "caacb"], 
        ColonForm[ "16", "caacab" -> "caaca"], 
        ColonForm[ "17", "caacba" -> "caac"]}, TableSpacing -> {1, 
        1}]]], "Output",
  CellLabel->"Out[89]//TableForm="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SolveSG", "ObjectName",
  CellTags->"SolveSG"],

Cell["Type: function", "Highlight",
  CellTags->"SolveSG"],

Cell[TextData[{
  StyleBox["SolveSG[a,b,S]", "MR"],
  "  returns a list of all solutions of equation  ",
  StyleBox["a**x = b", "MR"],
  "  in a transformation semigroup ",
  StyleBox["S", "MR"],
  "."
}], "Usage",
  CellTags->"SolveSG"],

Cell[TextData[{
  "Options\n",
  Cell[BoxData[
      FormBox[GridBox[{
            {"Full", "\[Rule]", "True", "-"},
            {"Where", "\[Rule]", "Right", "Left"}
            },
          ColumnWidths->Automatic,
          ColumnAlignments->{Left}], TraditionalForm]]]
}], "Notes",
  CellTags->"SolveSG"],

Cell[TextData[{
  "Option ",
  StyleBox["Full->False", "MR"],
  " returns only the first solution, or ",
  StyleBox["$Failed", "MR"],
  " if none is exists."
}], "Notes",
  CellTags->"SolveSG"],

Cell[TextData[{
  "Option ",
  StyleBox["Where->Left", "MR"],
  " solves   ",
  StyleBox["x**a = b", "MR"],
  "  instead."
}], "Notes",
  CellTags->"SolveSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SolveSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SolveSG"],

Cell["In a group all equations have unique solutions.", "ExampleText",
  CellTags->"SolveSG"],

Cell[CellGroupData[{

Cell["S = SymmetricGroupSG[3]", "Input",
  CellLabel->"In[155]:=",
  CellTags->"SolveSG"],

Cell[BoxData[
    \(SG[T[1, 2, 3], T[1, 3, 2], T[2, 1, 3], T[2, 3, 1], T[3, 1, 2], 
      T[3, 2, 1]]\)], "Output",
  CellLabel->"Out[155]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SolveSG[\ T[1, 3, 2], T[2, 3, 1], S]\), "\n", 
    \(SolveSG[\ T[1, 3, 2], T[2, 3, 1], S, \ Where \[Rule] Left]\)}], "Input",\

  CellLabel->"In[156]:="],

Cell[BoxData[
    \({T[2, 1, 3]}\)], "Output",
  CellLabel->"Out[156]="],

Cell[BoxData[
    \({T[3, 2, 1]}\)], "Output",
  CellLabel->"Out[157]="]
}, Open  ]],

Cell["But in general semigroups the situation is more complicated.", \
"ExampleText",
  CellTags->"SolveSG"],

Cell["S = TransformationSG[3];", "Input",
  CellLabel->"In[158]:=",
  CellTags->"SolveSG"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SolveSG[\ T[1, 2, 2], T[2, 3, 3], S\ ]\), "\n", 
    \(SolveSG[\ T[1, 2, 2], T[2, 3, 3], S, \ Where \[Rule] Left]\)}], "Input",\

  CellLabel->"In[159]:="],

Cell[BoxData[
    \({T[2, 3, 1], T[2, 3, 2], T[2, 3, 3]}\)], "Output",
  CellLabel->"Out[159]="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[160]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StaircasePlot", "ObjectName",
  CellTags->"StaircasePlot"],

Cell["Type: function", "Highlight",
  CellTags->"StaircasePlot"],

Cell[TextData[{
  StyleBox["StaircasePlot[L,opts]", "MR"],
  "  generates a staircase plot of the data in the numerical list L. "
}], "Usage",
  CellTags->"StaircasePlot"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"},
          {"PlotStyle", "\[Rule]", "Blue", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"StaircasePlot"],

Cell[TextData[{
  "All options are forwarded to ",
  StyleBox["Graphics", "MR"],
  "."
}], "Notes",
  CellTags->"StaircasePlot"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotT",
    ButtonData:>"PlotT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GridLine",
    ButtonData:>"GridLine",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GridPoints",
    ButtonData:>"GridPoints",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"StaircasePlot"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"StaircasePlot"],

Cell["A staircase plot of the first 20 primes.", "ExampleText",
  CellTags->"StaircasePlot"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StaircasePlot[\ Prime[Range[20]], Frame \[Rule] True, 
        FrameTicks \[Rule] None];\)\)], "Input",
  CellLabel->"In[100]:=",
  CellTags->"StaircasePlot"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.38778e-17 0.0454545 0.0167036 0.00835181 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.04545 .03341 m
.09091 .03341 L
.09091 .04176 L
.13636 .04176 L
.13636 .05846 L
.18182 .05846 L
.18182 .07517 L
.22727 .07517 L
.22727 .10857 L
.27273 .10857 L
.27273 .12528 L
.31818 .12528 L
.31818 .15868 L
.36364 .15868 L
.36364 .17539 L
.40909 .17539 L
.40909 .2088 L
.45455 .2088 L
.45455 .25891 L
.5 .25891 L
.5 .27561 L
.54545 .27561 L
.54545 .32572 L
.59091 .32572 L
.59091 .35913 L
.63636 .35913 L
.63636 .37583 L
.68182 .37583 L
.68182 .40924 L
.72727 .40924 L
.72727 .45935 L
.77273 .45935 L
.77273 .50946 L
.81818 .50946 L
.81818 .52616 L
.86364 .52616 L
.86364 .57627 L
.90909 .57627 L
.90909 .60968 L
.95455 .60968 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[100]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Status", "ObjectName",
  CellTags->"Status"],

Cell["Type: function", "Highlight",
  CellTags->"Status"],

Cell[TextData[{
  StyleBox["Status[]", "MR"],
  "  displays some information about the ongoing session."
}], "Usage",
  CellTags->"Status"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Status"],

Cell["A status message.", "ExampleText",
  CellTags->"Status"],

Cell[CellGroupData[{

Cell["Status[]", "Input",
  CellLabel->"In[100]:=",
  CellTags->"Status"],

Cell[BoxData[
    InterpretationBox[\("4.1 for Linux (February 28, \
2002)"\[InvisibleSpace]", RN: "\[InvisibleSpace]0\[InvisibleSpace]"\n"\
\[InvisibleSpace]"dimath:     "\[InvisibleSpace]"4.6"\[InvisibleSpace]"\n"\
\[InvisibleSpace]"automata:   "\[InvisibleSpace]"4.5"\[InvisibleSpace]"\n"\
\[InvisibleSpace]"time:       "\[InvisibleSpace]"2:33:33  2002/6/22"\
\[InvisibleSpace]"\n"\[InvisibleSpace]"time used:  "\[InvisibleSpace]6.67`\
\[InvisibleSpace]"\n"\[InvisibleSpace]"memory:     \
"\[InvisibleSpace]4.62646865844  .166`\[InvisibleSpace]"\n\
"\[InvisibleSpace]"packages:   "\[InvisibleSpace]{"Automata`dimath`", 
          "Automata`automata`"}\[InvisibleSpace]"\n"\[InvisibleSpace]"links:  \
    "\[InvisibleSpace]{LinkObject["ParentLink", 1, 1]}\),
      SequenceForm[ 
      "4.1 for Linux (February 28, 2002)", ", RN: ", 0, "\n", "dimath:     ", 
        "4.6", "\n", "automata:   ", "4.5", "\n", "time:       ", 
        "2:33:33  2002/6/22", "\n", "time used:  ", 6.6699999999999999, "\n", 
        "memory:     ", 
        Times[ 4.6264686584400003, 0.1656], "\n", "packages:   ", {
        "Automata`dimath`", "Automata`automata`"}, "\n", "links:      ", {
        LinkObject[ "ParentLink", 1, 1]}],
      Editable->False]], "Print",
  CellLabel->"From In[100]:="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StronglyConnectedComponents", "ObjectName",
  CellTags->"StronglyConnectedComponents"],

Cell["Type: function", "Highlight",
  CellTags->"StronglyConnectedComponents"],

Cell[TextData[{
  StyleBox["StronglyConnectedComponents[G,X]", "MR"],
  "  computes the strongly connected components of graph G using a linear \
algorithm. Option NonTrivial->True only returns the nontrivial components. \
Uses external code."
}], "Usage",
  CellTags->"StronglyConnectedComponents"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"NonTrivial", "\[Rule]", "False", "-"},
          {"External", "\[RuleDelayed]", "$defaultexternal", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"StronglyConnectedComponents"],

Cell[TextData[{
  "Option ",
  StyleBox["NonTrivial->True", "MR"],
  " causes only nontrivial components (containing at least one edge) to be \
returned."
}], "Notes",
  CellTags->"StronglyConnectedComponents"],

Cell["Uses Tarjan's linear time algorithm.", "Notes",
  CellTags->"StronglyConnectedComponents"],

Cell[TextData[{
  "See also ",
  ButtonBox["WeaklyConnectedComponents",
    ButtonData:>"WeaklyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NonTransientGraph",
    ButtonData:>"NonTransientGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LongestPath",
    ButtonData:>"LongestPath",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"StronglyConnectedComponents"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"StronglyConnectedComponents"],

Cell["A graph with several strongly connected components.", "ExampleText",
  CellTags->"StronglyConnectedComponents"],

Cell[BoxData[
    \(\(g\  = \ 
        Graph[9, 10, 
          1, {{1, 2}, {2, 3}, {3, 4}, {4, 2}, {3, 5}, {5, 6}, {5, 9}, {6, 
              7}, {7, 6}, {7, 8}}];\)\)], "Input",
  CellLabel->"In[62]:=",
  CellTags->"StronglyConnectedComponents"],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[g]\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->"StronglyConnectedComponents"],

Cell[BoxData[
    \({{1}, {2, 3, 4}, {5}, {6, 7}, {8}, {9}}\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->"StronglyConnectedComponents"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[g, NonTrivial \[Rule] True]\)], "Input",
  CellLabel->"In[64]:=",
  CellTags->"StronglyConnectedComponents"],

Cell[BoxData[
    \({{2, 3, 4}, {6, 7}}\)], "Output",
  CellLabel->"Out[64]=",
  CellTags->"StronglyConnectedComponents"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SubGraph", "ObjectName",
  CellTags->"SubGraph"],

Cell["Type: function", "Highlight",
  CellTags->"SubGraph"],

Cell[TextData[{
  StyleBox["SubGraph[G,L]", "MR"],
  "  constructs the subgraph of ",
  StyleBox["G", "MR"],
  " induced by vertex set ",
  StyleBox["L", "MR"],
  ". "
}], "Usage",
  CellTags->"SubGraph"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"SubGraph"],

Cell[TextData[{
  StyleBox["L", "MR"],
  " must be given in positional notation."
}], "Notes",
  CellTags->"SubGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["PermuteGraph",
    ButtonData:>"PermuteGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SubGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SubGraph"],

Cell["\<\
A path graph, and a vertex induced subgraph with two components. \
\
\>", "ExampleText",
  CellTags->"SubGraph"],

Cell[CellGroupData[{

Cell["g = PathGraph[8]", "Input",
  CellLabel->"In[238]:=",
  CellTags->"SubGraph"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"8", ",", "7", ",", "1", ",", 
          
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 
                8}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[238]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gg\  = \ SubGraph[g, {1, 2, 3, 6, 7, 8}]\)], "Input",
  CellLabel->"In[239]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"6", ",", "4", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}, {4, 5}, {5, 6}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[239]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(VertexSet[gg]\)], "Input",
  CellLabel->"In[241]:="],

Cell[BoxData[
    \({1, 2, 3, 6, 7, 8}\)], "Output",
  CellLabel->"Out[241]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(WeaklyConnectedComponents[gg, 1]\), "\n", 
    \(WeaklyConnectedComponents[gg, 4]\)}], "Input",
  CellLabel->"In[242]:="],

Cell[BoxData[
    \({1, 2, 3}\)], "Output",
  CellLabel->"Out[242]="],

Cell[BoxData[
    \({4, 5, 6}\)], "Output",
  CellLabel->"Out[243]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SubsetQ", "ObjectName",
  CellTags->"SubsetQ"],

Cell["Type: function", "Highlight",
  CellTags->"SubsetQ"],

Cell[TextData[{
  StyleBox["SubsetQ[S1,S2]", "MR"],
  "  tests whether ",
  StyleBox["S1", "MR"],
  " is a subset of ",
  StyleBox["S2", "MR"],
  StyleBox[".", "Text"]
}], "Usage",
  CellTags->"SubsetQ"],

Cell[TextData[{
  "Multiplicities are disregarded by ",
  StyleBox["SubsetQ", "MR"],
  "."
}], "Notes",
  CellTags->"SubsetQ"],

Cell[TextData[{
  "See also ",
  ButtonBox["PowerSet",
    ButtonData:>"PowerSet",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SubsetQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SubsetQ"],

Cell["Lists are being treated as sets.", "ExampleText",
  CellTags->"SubsetQ"],

Cell[CellGroupData[{

Cell["SubsetQ[ {1,5}, Range[5] ]", "Input",
  CellLabel->"In[98]:=",
  CellTags->"SubsetQ"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["SubsetQ[ {1,6}, Range[5] ]", "Input",
  CellLabel->"In[99]:=",
  CellTags->"SubsetQ"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[99]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymbolList", "ObjectName",
  CellTags->"SymbolList"],

Cell["Type: function", "Highlight",
  CellTags->"SymbolList"],

Cell[TextData[{
  StyleBox["SymbolList[sym,k]", "MR"],
  "  generates a list of symbols of the form ",
  StyleBox["sym1", "MR"],
  ", ",
  StyleBox["sym2", "MR"],
  ", \[Ellipsis], ",
  StyleBox["symk", "MR"],
  StyleBox[".", "Text"]
}], "Usage",
  CellTags->"SymbolList"],

Cell[TextData[{
  StyleBox["k", "MR"],
  " can also be replaced by a list."
}], "Notes",
  CellTags->"SymbolList"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SymbolList"],

Cell["A list of symbols.", "ExampleText",
  CellTags->"SymbolList"],

Cell[CellGroupData[{

Cell["\<\
SymbolList[ \"fred\", 5 ]
% // FullForm\
\>", "Input",
  CellLabel->"In[94]:=",
  CellTags->"SymbolList"],

Cell[BoxData[
    \({fred1, fred2, fred3, fred4, fred5}\)], "Output",
  CellLabel->"Out[94]="],

Cell[BoxData[
    TagBox[
      StyleBox[\(List[fred1, fred2, fred3, fred4, fred5]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[95]//FullForm="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SymmetricGroupSG", "ObjectName",
  CellTags->"SymmetricGroupSG"],

Cell["Type: function", "Highlight",
  CellTags->"SymmetricGroupSG"],

Cell[TextData[{
  StyleBox["SymmetricGroupSG[n]", "MR"],
  "  returns the symmetric group on n points."
}], "Usage",
  CellTags->"SymmetricGroupSG"],

Cell[TextData[{
  "Since the symmetric group has  ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\)]],
  "  elements, this can only be used for small ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Notes",
  CellTags->"SymmetricGroupSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TransformationSG",
    ButtonData:>"TransformationSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AlternatingGroupSG",
    ButtonData:>"AlternatingGroupSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SymmetricGroupSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SymmetricGroupSG"],

Cell["The symmetric group on 4 points.", "ExampleText",
  CellTags->"SymmetricGroupSG"],

Cell[CellGroupData[{

Cell["SymmetricGroupSG[4]", "Input",
  CellLabel->"In[90]:=",
  CellTags->"SymmetricGroupSG"],

Cell[BoxData[
    \(SG[T[1, 2, 3, 4], T[1, 2, 4, 3], T[1, 3, 2, 4], T[1, 3, 4, 2], 
      T[1, 4, 2, 3], T[1, 4, 3, 2], T[2, 1, 3, 4], T[2, 1, 4, 3], 
      T[2, 3, 1, 4], T[2, 3, 4, 1], T[2, 4, 1, 3], T[2, 4, 3, 1], 
      T[3, 1, 2, 4], T[3, 1, 4, 2], T[3, 2, 1, 4], T[3, 2, 4, 1], 
      T[3, 4, 1, 2], T[3, 4, 2, 1], T[4, 1, 2, 3], T[4, 1, 3, 2], 
      T[4, 2, 1, 3], T[4, 2, 3, 1], T[4, 3, 1, 2], T[4, 3, 2, 1]]\)], "Output",\

  CellLabel->"Out[90]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TableSG", "ObjectName",
  CellTags->"TableSG"],

Cell["Type: function", "Highlight",
  CellTags->"TableSG"],

Cell[TextData[{
  StyleBox["TableSG[S,W]", "MR"],
  "  prints the multiplication table of semigroup S using witnesses W."
}], "Usage",
  CellTags->"TableSG"],

Cell[TextData[{
  " Substitutes ",
  StyleBox["$identitystring", "MR"],
  " and ",
  StyleBox["$nullstring", "MR"],
  "  for identity and null, if they exist."
}], "Notes",
  CellTags->"TableSG"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TableSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TableSG"],

Cell["\<\
The multiplication table for the symmetric group on 3 points.\
\>", \
"ExampleText",
  CellTags->"TableSG"],

Cell[BoxData[
    \(\({S, W, eq} = 
        SymmetricGroupSG[3, Equations \[Rule] True];\)\)], "Input",
  CellLabel->"In[155]:=",
  CellTags->"TableSG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableSG[\ S, W]\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"a\"\>", "\<\"b\"\>", "\<\"aa\"\>", "\<\"ab\"\>", \
"\<\"ba\"\>", "\<\"1\"\>"},
          {"\<\"a\"\>", "\<\"aa\"\>", "\<\"ab\"\>", "\<\"1\"\>", \
"\<\"ba\"\>", "\<\"b\"\>", "\<\"a\"\>"},
          {"\<\"b\"\>", "\<\"ba\"\>", "\<\"1\"\>", "\<\"ab\"\>", \
"\<\"aa\"\>", "\<\"a\"\>", "\<\"b\"\>"},
          {"\<\"aa\"\>", "\<\"1\"\>", "\<\"ba\"\>", "\<\"a\"\>", "\<\"b\"\>", \
"\<\"ab\"\>", "\<\"aa\"\>"},
          {"\<\"ab\"\>", "\<\"b\"\>", "\<\"a\"\>", "\<\"ba\"\>", "\<\"1\"\>", \
"\<\"aa\"\>", "\<\"ab\"\>"},
          {"\<\"ba\"\>", "\<\"ab\"\>", "\<\"aa\"\>", "\<\"b\"\>", \
"\<\"a\"\>", "\<\"1\"\>", "\<\"ba\"\>"},
          {"\<\"1\"\>", "\<\"a\"\>", "\<\"b\"\>", "\<\"aa\"\>", "\<\"ab\"\>", \
"\<\"ba\"\>", "\<\"1\"\>"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDepth -> 2, TableHeadings -> {{"a", "b", "aa", "ab", 
          "ba", "1"}, {"a", "b", "aa", "ab", "ba", "1"}}]]]], "Output",
  CellLabel->"Out[156]//TableForm="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToAdjList", "ObjectName",
  CellTags->"ToAdjList"],

Cell["Type: function", "Highlight",
  CellTags->"ToAdjList"],

Cell[TextData[{
  StyleBox["ToAdjList[G]", "MR"],
  "  converts a graph ",
  StyleBox["G", "MR"],
  " into adjacency list form."
}], "Usage",
  CellTags->"ToAdjList"],

Cell["\<\
The size of the data structure is slightly less than in edge list \
form.\
\>", "Notes",
  CellTags->"ToAdjList"],

Cell["\<\
Note that in out-degree 2 regular graphs one could confuse edge \
list form with adjacency list form.\
\>", "Notes",
  CellTags->"ToAdjList"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToAdjMatrix",
    ButtonData:>"ToAdjMatrix",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToEdgeList",
    ButtonData:>"ToEdgeList",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToAdjList"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToAdjList"],

Cell["Converting from edge list to adjacency lists.", "ExampleText",
  CellTags->"ToAdjList"],

Cell[CellGroupData[{

Cell["g = DeBruijnGraph[3,2]", "Input",
  CellLabel->"In[149]:=",
  CellTags->"ToAdjList"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"8", ",", "16", ",", "1", ",", 
          
          TagBox[\({{1, 1}, {1, 2}, {2, 3}, {2, 4}, {3, 5}, {3, 6}, {4, 
                7}, \[LeftSkeleton]2\[RightSkeleton], {5, 2}, {6, 3}, {6, 
                4}, {7, 5}, {7, 6}, {8, 7}, {8, 8}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[149]=",
  CellTags->"ToAdjList"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ToAdjList[g]\  // \ Edges\)\  // \ MatrixForm\)], "Input",
  CellLabel->"In[150]:=",
  CellTags->"ToAdjList"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2"},
            {"3", "4"},
            {"5", "6"},
            {"7", "8"},
            {"1", "2"},
            {"3", "4"},
            {"5", "6"},
            {"7", "8"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[150]//MatrixForm=",
  CellTags->"ToAdjList"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToAdjMatrix", "ObjectName",
  CellTags->"ToAdjMatrix"],

Cell["Type: function", "Highlight",
  CellTags->"ToAdjMatrix"],

Cell[TextData[{
  StyleBox["ToAdjMatrix[G]", "MR"],
  "  converts a graph ",
  StyleBox["G", "MR"],
  " into adjacency matrix form."
}], "Usage",
  CellTags->"ToAdjMatrix"],

Cell["\<\
Note that the size of the data structure may increase quadratically \
in this conversion.\
\>", "Notes",
  CellTags->"ToAdjMatrix"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToAdjList",
    ButtonData:>"ToAdjList",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToEdgeList",
    ButtonData:>"ToEdgeList",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToAdjMatrix"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToAdjMatrix"],

Cell["Converting from edge list to adjacency matrix.", "ExampleText",
  CellTags->"ToAdjMatrix"],

Cell[CellGroupData[{

Cell["g = DeBruijnGraph[3,2]", "Input",
  CellLabel->"In[147]:=",
  CellTags->"ToAdjMatrix"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"8", ",", "16", ",", "1", ",", 
          
          TagBox[\({{1, 1}, {1, 2}, {2, 3}, {2, 4}, {3, 5}, {3, 6}, {4, 
                7}, \[LeftSkeleton]2\[RightSkeleton], {5, 2}, {6, 3}, {6, 
                4}, {7, 5}, {7, 6}, {8, 7}, {8, 8}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[147]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ToAdjMatrix[g]\  // \ Edges\)\  // \ MatrixForm\)], "Input",
  CellLabel->"In[148]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "1", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1"},
            {"1", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "1", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[148]//MatrixForm="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToBitVector", "ObjectName",
  CellTags->"ToBitVector"],

Cell["Type: function", "Highlight",
  CellTags->"ToBitVector"],

Cell[TextData[{
  StyleBox["ToBitVector[S,U]", "MR"],
  "  transforms set ",
  StyleBox["S", "MR"],
  " into a bitvector over universe ",
  StyleBox["U", "MR"],
  "."
}], "Usage",
  CellTags->"ToBitVector"],

Cell["A bitvector is understood to be a 0/1-integer list.", "Notes",
  CellTags->"ToBitVector"],

Cell[TextData[{
  "See also ",
  ButtonBox["FromBitVector",
    ButtonData:>"FromBitVector",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToBitVector"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToBitVector"],

Cell["Conversion from  an actual subset to a bitvector.", "ExampleText",
  CellTags->"ToBitVector"],

Cell[CellGroupData[{

Cell["all = PowerSet[{a,b,c}]", "Input",
  CellLabel->"In[45]:=",
  CellTags->"ToBitVector"],

Cell[BoxData[
    \({{}, {a}, {b}, {c}, {a, b}, {a, c}, {b, c}, {a, b, c}}\)], "Output",
  CellLabel->"Out[45]=",
  CellTags->"ToBitVector"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ToBitVector[#, {a, b, c}] &\)\  /@ \ all\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->"ToBitVector"],

Cell[BoxData[
    \({{0, 0, 0}, {1, 0, 0}, {0, 1, 0}, {0, 0, 1}, {1, 1, 0}, {1, 0, 1}, {0, 
        1, 1}, {1, 1, 1}}\)], "Output",
  CellLabel->"Out[46]=",
  CellTags->"ToBitVector"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToClasses", "ObjectName",
  CellTags->"ToClasses"],

Cell["Type: function", "Highlight",
  CellTags->"ToClasses"],

Cell[TextData[{
  StyleBox["ToClasses[L,R]", "MR"],
  "  generates the equivalence classes of list ",
  StyleBox["L", "MR"],
  " with respect to equivalence relation ",
  StyleBox["R", "MR"],
  ". "
}], "Usage",
  CellTags->"ToClasses"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Type", "\[Rule]", "Relation", \(Matrix, Function, Index\)}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToClasses"],

Cell[TextData[{
  "The relation ",
  StyleBox["R", "MR"],
  " can be given as a binary relation, a Boolean function (option ",
  StyleBox["Type->Function", "MR"],
  "), a binary matrix (option ",
  StyleBox["Type->Matrix", "MR"],
  "), or an index (option ",
  StyleBox["Type->Index", "MR"],
  "). "
}], "Notes",
  CellTags->"ToClasses"],

Cell[TextData[{
  "In the last case, ",
  StyleBox["R", "MR"],
  " must be a list of integers of length ",
  StyleBox["Length[L]", "MR"],
  "."
}], "Notes"],

Cell[TextData[{
  "See ",
  ButtonBox["MakeIndex",
    ButtonData:>"MakeIndex",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RelationToMatrix",
    ButtonData:>"RelationToMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToClasses"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToClasses"],

Cell["\<\
An equivalence relation represented by a Boolean-valued function. \
\
\>", "ExampleText",
  CellTags->"ToClasses"],

Cell[BoxData[
    \(\(\[Rho][x_, y_]\  := \ Mod[x, 5] \[Equal] Mod[y, 5];\)\)], "Input",
  CellLabel->"In[134]:=",
  CellTags->"ToClasses"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToClasses[\ Range[12], \ \[Rho]\ ]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \({{1, 6, 11}, {2, 7, 12}, {3, 8}, {4, 9}, {5, 10}}\)], "Output",
  CellLabel->"Out[135]="]
}, Open  ]],

Cell["Here is the Boolean matrix representation.", "ExampleText",
  CellTags->"ToClasses"],

Cell[CellGroupData[{

Cell[BoxData[
    \(M\  = \ RelationToMatrix[\[Rho], Range[12]]\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \({{1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0}, {0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 
        0, 1}, {0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0}, {0, 0, 0, 1, 0, 0, 0, 0, 
        1, 0, 0, 0}, {0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0}, {1, 0, 0, 0, 0, 1, 
        0, 0, 0, 0, 1, 0}, {0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1}, {0, 0, 1, 0, 
        0, 0, 0, 1, 0, 0, 0, 0}, {0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0}, {0, 0, 
        0, 0, 1, 0, 0, 0, 0, 1, 0, 0}, {1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 
        0}, {0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1}}\)], "Output",
  CellLabel->"Out[137]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToClasses[\ Range[12], \ M, \ Type \[Rule] Matrix\ ]\)], "Input",
  CellLabel->"In[138]:="],

Cell[BoxData[
    \({{3, 8}, {4, 9}, {5, 10}, {1, 6, 11}, {2, 7, 12}}\)], "Output",
  CellLabel->"Out[138]="]
}, Open  ]],

Cell["The function representation.", "ExampleText",
  CellTags->"ToClasses"],

Cell[BoxData[
    \(\(f[x_]\  := \ Mod[x, 5];\)\)], "Input",
  CellLabel->"In[139]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToClasses[\ Range[12], \ f, \ Type \[Rule] Function\ ]\)], "Input",
  CellLabel->"In[140]:="],

Cell[BoxData[
    \({{5, 10}, {1, 6, 11}, {2, 7, 12}, {3, 8}, {4, 9}}\)], "Output",
  CellLabel->"Out[140]="]
}, Open  ]],

Cell["Lastly, the index.", "ExampleText",
  CellTags->"ToClasses"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ind\  = \ \(MakeIndex[Range[12], \[Rho]]\)[\([1]\)]\)], "Input",
  CellLabel->"In[144]:="],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 1, 2, 3, 4, 5, 1, 2}\)], "Output",
  CellLabel->"Out[144]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToClasses[\ Range[12], \ ind, \ Type \[Rule] Index\ ]\)], "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    \({{1, 6, 11}, {2, 7, 12}, {3, 8}, {4, 9}, {5, 10}}\)], "Output",
  CellLabel->"Out[145]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToDAG", "ObjectName",
  CellTags->"ToDAG"],

Cell["Type: function", "Highlight",
  CellTags->"ToDAG"],

Cell[TextData[{
  StyleBox["ToDAG[G]", "MR"],
  "  computes the directed acyclic graph obtained from ",
  StyleBox["G", "MR"],
  " by collapsing its strongly connected components into points and \
preserving edges between these points."
}], "Usage",
  CellTags->"ToDAG"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToDAG"],

Cell[TextData[{
  "See also ",
  ButtonBox["StronglyConnectedComponents",
    ButtonData:>"StronglyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NonTransientGraph",
    ButtonData:>"NonTransientGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["LongestPath",
    ButtonData:>"LongestPath",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToDAG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToDAG"],

Cell["A graph with several strongly connected components.", "ExampleText",
  CellTags->"NonTransientGraph"],

Cell[BoxData[
    \(\(g\  = \ 
        Graph[9, 10, 
          1, {{1, 2}, {2, 3}, {3, 4}, {4, 2}, {3, 5}, {5, 6}, {5, 9}, {6, 
              7}, {7, 6}, {7, 8}}];\)\)], "Input",
  CellLabel->"In[247]:=",
  CellTags->"NonTransientGraph"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ToDAG[g]\), "\n", 
    \(VertexSet[%]\)}], "Input",
  CellLabel->"In[250]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"6", ",", "5", ",", "1", ",", 
          TagBox[\({{1, 2}, {2, 3}, {3, 4}, {3, 6}, {4, 5}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[250]="],

Cell[BoxData[
    \({{1}, {2, 3, 4}, {5}, {6, 7}, {8}, {9}}\)], "Output",
  CellLabel->"Out[251]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToEdgeList", "ObjectName",
  CellTags->"ToEdgeList"],

Cell["Type: function", "Highlight",
  CellTags->"ToEdgeList"],

Cell[TextData[{
  StyleBox["ToEdgeList[G]", "MR"],
  "  converts a graph ",
  StyleBox["G", "MR"],
  " into edge list form."
}], "Usage",
  CellTags->"ToEdgeList"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToAdjList",
    ButtonData:>"ToAdjList",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToAdjMatrix",
    ButtonData:>"ToAdjMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToEdgeList"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToEdgeList"],

Cell["A graph with an adjacency matrix, and its edgelist form.", "ExampleText",
  CellTags->"ToEdgeList"],

Cell[BoxData[
    \(\(g = 
        Graph[8, 16, 
          3, {{1, 1, 0, 0, 0, 0, 0, 0}, {0, 0, 1, 1, 0, 0, 0, 0}, {0, 0, 0, 
              0, 1, 1, 0, 0}, {0, 0, 0, 0, 0, 0, 1, 1}, {1, 1, 0, 0, 0, 0, 0, 
              0}, {0, 0, 1, 1, 0, 0, 0, 0}, {0, 0, 0, 0, 1, 1, 0, 0}, {0, 0, 
              0, 0, 0, 0, 1, 1}}];\)\)], "Input",
  CellLabel->"In[130]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Edges[g]\  // \ MatrixForm\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "1", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1"},
            {"1", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "1", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[131]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToEdgeList[g]\  // \ Edges\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {2, 3}, {2, 4}, {3, 5}, {3, 6}, {4, 7}, {4, 8}, {5, 
        1}, {5, 2}, {6, 3}, {6, 4}, {7, 5}, {7, 6}, {8, 7}, {8, 
        8}}\)], "Output",
  CellLabel->"Out[132]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToEps", "ObjectName",
  CellTags->"ToEps"],

Cell["Type: function", "Highlight",
  CellTags->"ToEps"],

Cell[TextData[{
  StyleBox["ToEps[x]", "MR"],
  "  replaces all occurences of the empty string in ",
  StyleBox["x", "MR"],
  " by ",
  StyleBox["\"Eps\"", "MR"],
  "."
}], "Usage",
  CellTags->"ToEps"],

Cell["Used before printing to remove the internal form of epsilon.", "Notes",
  CellTags->"ToEps"],

Cell[TextData[{
  "See also ",
  ButtonBox["FromEps",
    ButtonData:>"FromEps",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToEps"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToEps"],

Cell["\<\
Note that the empty string prints as \[Epsilon] in standard \
formatting.\
\>", "ExampleText",
  CellTags->"FromEps"],

Cell[CellGroupData[{

Cell[BoxData[
    \("\<\>"\  // \ ToEps\)], "Input",
  CellLabel->"In[39]:=",
  CellTags->"FromEps"],

Cell[BoxData[
    \(\[Epsilon]\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToIdentityString", "ObjectName",
  CellTags->"ToIdentityString"],

Cell["Type: function", "Highlight",
  CellTags->"ToIdentityString"],

Cell[TextData[{
  StyleBox["ToIdentityString[x]", "MR"],
  "  replaces all occurrences of the empty string in ",
  StyleBox["x", "MR"],
  " by ",
  StyleBox["$identitystring", "MR"],
  "."
}], "Usage",
  CellTags->"ToIdentityString"],

Cell[TextData[{
  "See also ",
  ButtonBox["$identitystring",
    ButtonData:>"$identitystring",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ToIdentityString"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToIdentityString"],

Cell["Cleaning up rewrite systems.", "ExampleText",
  CellTags->"ToIdentityString"],

Cell[CellGroupData[{

Cell["ToIdentityString[ \"aaaa\"->\"\" ]", "Input",
  CellLabel->"In[125]:=",
  CellTags->"ToIdentityString"],

Cell[BoxData[
    \("aaaa" \[Rule] "1"\)], "Output",
  CellLabel->"Out[125]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToList", "ObjectName",
  CellTags->"ToList"],

Cell["Type: function", "Highlight",
  CellTags->"ToList"],

Cell[TextData[{
  StyleBox["ToList[S]", "MR"],
  "  replaces the head of object ",
  StyleBox["S", "MR"],
  " by ",
  StyleBox["List", "MR"],
  "."
}], "Usage",
  CellTags->"ToList"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ToTDGraph", "ObjectName",
  CellTags->"ToTDGraph"],

Cell["Type: function", "Highlight",
  CellTags->"ToTDGraph"],

Cell[TextData[{
  StyleBox["ToTDGraph[{RR},m]", "MR"],
  "  converts a sequence of relations ",
  StyleBox["RR", "MR"],
  " to a time dependent graph over ground set ",
  Cell[BoxData[
      \(TraditionalForm\`\([m]\)\)]],
  "."
}], "Usage",
  CellTags->"ToTDGraph"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "0", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ToTDGraph"],

Cell["This is useful mostly for plotting.", "Notes",
  CellTags->"ToTDGraph"],

Cell[TextData[{
  "See ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"ToTDGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"ToTDGraph"],

Cell[TextData[{
  "Two relations based on proper divisibility on ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], 8}\)]],
  ". "
}], "ExampleText",
  CellTags->"ToTDGraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(R1 = 
      Select[Tuples[2, 8], 
        Mod[#\[LeftDoubleBracket]2\[RightDoubleBracket], \
#\[LeftDoubleBracket]1\[RightDoubleBracket]] == 
              0 && #\[LeftDoubleBracket]1\[RightDoubleBracket] \[NotEqual] #\
\[LeftDoubleBracket]2\[RightDoubleBracket] &]\)], "Input",
  CellLabel->"In[270]:="],

Cell[BoxData[
    \({{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {2, 4}, {2, 
        6}, {2, 8}, {3, 6}, {4, 8}}\)], "Output",
  CellLabel->"Out[270]="]
}, Open  ]],

Cell[BoxData[
    \(\(R2\  = \ Reverse\  /@ \ R1;\)\)], "Input",
  CellLabel->"In[271]:="],

Cell[CellGroupData[{

Cell["ToTDGraph[{R1,R2}, 8]", "Input",
  CellLabel->"In[272]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"24", ",", "24", ",", "1", ",", 
          
          TagBox[\({{1, 10}, {1, 11}, {1, 12}, {1, 13}, {1, 14}, {1, 15}, {1, 
                16}, \[LeftSkeleton]10\[RightSkeleton], {15, 17}, {16, 
                17}, {12, 18}, {14, 18}, {16, 18}, {14, 19}, {16, 20}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[272]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotTDGraph[%, 8];\)\)], "Input",
  CellLabel->"In[273]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0555556 0.277778 -0.0143729 0.0718644 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.22222 .05749 m
.5 .12936 L
s
.22222 .05749 m
.5 .20122 L
s
.22222 .05749 m
.5 .27308 L
s
.22222 .05749 m
.5 .34495 L
s
.22222 .05749 m
.5 .41681 L
s
.22222 .05749 m
.5 .48868 L
s
.22222 .05749 m
.5 .56054 L
s
.22222 .12936 m
.5 .27308 L
s
.22222 .12936 m
.5 .41681 L
s
.22222 .12936 m
.5 .56054 L
s
.22222 .20122 m
.5 .41681 L
s
.22222 .27308 m
.5 .56054 L
s
.5 .12936 m
.77778 .05749 L
s
.5 .20122 m
.77778 .05749 L
s
.5 .27308 m
.77778 .05749 L
s
.5 .34495 m
.77778 .05749 L
s
.5 .41681 m
.77778 .05749 L
s
.5 .48868 m
.77778 .05749 L
s
.5 .56054 m
.77778 .05749 L
s
.5 .27308 m
.77778 .12936 L
s
.5 .41681 m
.77778 .12936 L
s
.5 .56054 m
.77778 .12936 L
s
.5 .41681 m
.77778 .20122 L
s
.5 .56054 m
.77778 .27308 L
s
0 0 1 r
.012 w
.22222 .34495 Mdot
.22222 .41681 Mdot
.22222 .48868 Mdot
.22222 .56054 Mdot
.5 .05749 Mdot
.77778 .34495 Mdot
.77778 .41681 Mdot
.77778 .48868 Mdot
.77778 .56054 Mdot
1 0 0 r
.0144 w
.22222 .05749 Mdot
.22222 .12936 Mdot
.22222 .20122 Mdot
.22222 .27308 Mdot
.5 .12936 Mdot
.5 .20122 Mdot
.5 .27308 Mdot
.5 .34495 Mdot
.5 .41681 Mdot
.5 .48868 Mdot
.5 .56054 Mdot
.77778 .05749 Mdot
.77778 .12936 Mdot
.77778 .20122 Mdot
.77778 .27308 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[273]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransformationSG", "ObjectName",
  CellTags->"TransformationSG"],

Cell["Type: function", "Highlight",
  CellTags->"TransformationSG"],

Cell[TextData[{
  StyleBox["TransformationSG[n]", "MR"],
  "  returns the transformation semigroup on ",
  StyleBox["n", "MR"],
  " points. "
}], "Usage",
  CellTags->"TransformationSG"],

Cell[TextData[{
  " Since the full transformation semigroup has ",
  Cell[BoxData[
      \(TraditionalForm\`n\^\(\(\ \)\(n\)\)\)]],
  " elements, this can only be used for small ",
  StyleBox["n", "MR"],
  "."
}], "Notes",
  CellTags->"TransformationSG"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SymmetricGroupSG",
    ButtonData:>"SymmetricGroupSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AlternatingGroupSG",
    ButtonData:>"AlternatingGroupSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TransformationSG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransformationSG"],

Cell["The full transformation semigroup on 3 points.", "ExampleText",
  CellTags->"TransformationSG"],

Cell[CellGroupData[{

Cell["S = TransformationSG[3]", "Input",
  CellLabel->"In[123]:=",
  CellTags->"TransformationSG"],

Cell[BoxData[
    \(SG[T[1, 1, 1], T[1, 1, 2], T[1, 1, 3], T[1, 2, 1], T[1, 2, 2], 
      T[1, 2, 3], T[1, 3, 1], T[1, 3, 2], T[1, 3, 3], T[2, 1, 1], T[2, 1, 2], 
      T[2, 1, 3], T[2, 2, 1], T[2, 2, 2], T[2, 2, 3], T[2, 3, 1], T[2, 3, 2], 
      T[2, 3, 3], T[3, 1, 1], T[3, 1, 2], T[3, 1, 3], T[3, 2, 1], T[3, 2, 2], 
      T[3, 2, 3], T[3, 3, 1], T[3, 3, 2], T[3, 3, 3]]\)], "Output",
  CellLabel->"Out[123]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(S\  // \ Length\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(27\)], "Output",
  CellLabel->"Out[124]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransientPeriodicT", "ObjectName",
  CellTags->"TransientPeriodicT"],

Cell["Type: function", "Highlight",
  CellTags->"TransientPeriodicT"],

Cell[TextData[{
  StyleBox["TransientPeriodicT[x]", "MR"],
  "  returns the length of the transient and periodic part of the semigroup \
generated by transformation ",
  StyleBox["x", "MR"],
  ". "
}], "Usage",
  CellTags->"TransientPeriodicT"],

Cell["\<\
If x is a permutation, the length of the periodic part is the order \
of x in the group generated by it.\
\>", "Notes",
  CellTags->"TransientPeriodicT"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TransientPeriodicT"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransientPeriodicT"],

Cell["\<\
The transients and periods for all elements of the full \
transformation semigroup on 3 points.\
\>", "ExampleText",
  CellTags->"TransientPeriodicT"],

Cell[BoxData[
    \(\(S = TransformationSG[3];\)\)], "Input",
  CellLabel->"In[109]:=",
  CellTags->"TransientPeriodicT"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TransientPeriodicT\  /@ \ ToList[S]\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \({{1, 1}, {2, 1}, {1, 1}, {1, 1}, {1, 1}, {0, 1}, {2, 1}, {0, 2}, {1, 
        1}, {1, 2}, {1, 2}, {0, 2}, {2, 1}, {1, 1}, {1, 1}, {0, 3}, {1, 
        2}, {2, 1}, {1, 2}, {0, 3}, {2, 1}, {0, 2}, {2, 1}, {1, 1}, {1, 
        2}, {1, 2}, {1, 1}}\)], "Output",
  CellLabel->"Out[118]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Frequencies[%]\  // \ \(Curry[TableForm]\)[
        TableDepth \[Rule] 2]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {\({0, 1}\), "1"},
          {\({0, 2}\), "3"},
          {\({0, 3}\), "2"},
          {\({1, 1}\), "9"},
          {\({1, 2}\), "6"},
          {\({2, 1}\), "6"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$, TableDepth -> 2]]]], "Output",
  CellLabel->"Out[119]//TableForm="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransitiveClosure", "ObjectName",
  CellTags->"TransitiveClosure"],

Cell["Type: function", "Highlight",
  CellTags->"TransitiveClosure"],

Cell[TextData[{
  StyleBox["TransitiveClosure[B]", "MR"],
  "  determines the transitive closure of Boolean matrix ",
  StyleBox["B", "MR"],
  ". "
}], "Usage",
  CellTags->"TransitiveClosure"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Reflexive", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"TransitiveClosure"],

Cell[TextData[{
  "Option ",
  StyleBox["Reflexive->True", "MR"],
  " causes the transitive reflexive closure to be computed."
}], "Notes",
  CellTags->"TransitiveClosure"],

Cell[TextData[{
  "For efficiency reasons, ",
  StyleBox["B", "MR"],
  " is a 0/1-integer matrix."
}], "Notes",
  CellTags->"TransitiveClosure"],

Cell[TextData[{
  "See also ",
  ButtonBox["Closure",
    ButtonData:>"Closure",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ClosureSearch",
    ButtonData:>"ClosureSearch",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["BooleanPower",
    ButtonData:>"BooleanPower",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"TransitiveClosure"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TransitiveClosure"],

Cell["A circulant matrix and its closure.", "ExampleText",
  CellTags->"TransitiveClosure"],

Cell[BoxData[
    \(\(M = {{0, 0, 1, 0, 1, 0, 0, 0}, {0, 0, 0, 1, 0, 1, 0, 0}, {0, 0, 0, 0, 
            1, 0, 1, 0}, {0, 0, 0, 0, 0, 1, 0, 1}, {1, 0, 0, 0, 0, 0, 1, 
            0}, {0, 1, 0, 0, 0, 0, 0, 1}, {1, 0, 1, 0, 0, 0, 0, 0}, {0, 1, 0, 
            1, 0, 0, 0, 0}};\)\)], "Input",
  CellLabel->"In[367]:=",
  CellTags->"TransitiveClosure"],

Cell[CellGroupData[{

Cell[BoxData[
    \(M\  // \ MatrixForm\)], "Input",
  CellLabel->"In[368]:=",
  CellTags->"TransitiveClosure"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "1", "0", "1", "0", "0", "0"},
            {"0", "0", "0", "1", "0", "1", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "1", "0"},
            {"0", "0", "0", "0", "0", "1", "0", "1"},
            {"1", "0", "0", "0", "0", "0", "1", "0"},
            {"0", "1", "0", "0", "0", "0", "0", "1"},
            {"1", "0", "1", "0", "0", "0", "0", "0"},
            {"0", "1", "0", "1", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[368]//MatrixForm=",
  CellTags->"TransitiveClosure"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TransitiveClosure[M] // \ MatrixForm\)], "Input",
  CellLabel->"In[369]:=",
  CellTags->"TransitiveClosure"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "1", "0", "1", "0", "1", "0"},
            {"0", "1", "0", "1", "0", "1", "0", "1"},
            {"1", "0", "1", "0", "1", "0", "1", "0"},
            {"0", "1", "0", "1", "0", "1", "0", "1"},
            {"1", "0", "1", "0", "1", "0", "1", "0"},
            {"0", "1", "0", "1", "0", "1", "0", "1"},
            {"1", "0", "1", "0", "1", "0", "1", "0"},
            {"0", "1", "0", "1", "0", "1", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[369]//MatrixForm=",
  CellTags->"TransitiveClosure"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TranspositionT", "ObjectName",
  CellTags->"TranspositionT"],

Cell["Type: function", "Highlight",
  CellTags->"TranspositionT"],

Cell[TextData[{
  StyleBox["TranspositionT[n,i]", "MR"],
  "  returns the transposition ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, i + 1)\)\)]],
  " as a transformation on ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Usage",
  CellTags->"TranspositionT"],

Cell[TextData[{
  "Position ",
  StyleBox["i", "MR"],
  " has default value 1."
}], "Notes",
  CellTags->"TranspositionT"],

Cell[TextData[{
  "See also ",
  ButtonBox["Merge12T",
    ButtonData:>"Merge12T",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RShiftT",
    ButtonData:>"RShiftT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TranspositionT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TypeGraph", "ObjectName",
  CellTags->"TypeGraph"],

Cell["Type: function", "Highlight",
  CellTags->"TypeGraph"],

Cell[TextData[{
  StyleBox["TypeGraph[G]", "MR"],
  "  returns the type of a graph G"
}], "Usage",
  CellTags->"TypeGraph"],

Cell[TextData[{
  " Graphs can be represented by an edge list (",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  "), a labeled edge list (",
  Cell[BoxData[
      \(TraditionalForm\`t = 2\)]],
  "), an adjacency matrix (",
  Cell[BoxData[
      \(TraditionalForm\`t = 3\)]],
  "), or an adjacency list (",
  Cell[BoxData[
      \(TraditionalForm\`t = 4\)]],
  "). "
}], "Notes",
  CellTags->"TypeGraph"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"TypeGraph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"TypeGraph"],

Cell["A simple 4-point graph, in edge-list representation.", "ExampleText",
  CellTags->"TypeGraph"],

Cell[BoxData[
    \(\(g = Graph[4, 4, 1, {{1, 2}, {2, 3}, {3, 1}, {4, 1}}];\)\)], "Input",
  CellLabel->"In[160]:=",
  CellTags->"TypeGraph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TypeGraph[g]\)], "Input",
  CellLabel->"In[170]:=",
  CellTags->"TypeGraph"],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[170]=",
  CellTags->"TypeGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g\  // \ ToAdjList\)\  // \ TypeGraph\)], "Input",
  CellLabel->"In[171]:=",
  CellTags->"TypeGraph"],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[171]=",
  CellTags->"TypeGraph"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g\  // \ ToAdjMatrix\)\  // \ TypeGraph\)], "Input",
  CellLabel->"In[172]:=",
  CellTags->"TypeGraph"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[172]=",
  CellTags->"TypeGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["UnitElement", "ObjectName",
  CellTags->"UnitElement"],

Cell["Type: function", "Highlight",
  CellTags->"UnitElement"],

Cell[TextData[{
  StyleBox["UnitElement[x]", "MR"],
  "  generates the unit element in the monoid to which ",
  StyleBox["x", "MR"],
  " naturally belongs. "
}], "Usage",
  CellTags->"UnitElement"],

Cell[TextData[{
  "More precisely, ",
  StyleBox["x", "MR"],
  " can be a transformation, a Boolean matrix, a matrix over the tropical \
semiring, or an integer matrix. "
}], "Notes",
  CellTags->"UnitElement"],

Cell[TextData[{
  "Used internally in ",
  StyleBox["GenerateSG", "MR"],
  "."
}], "Notes"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"UnitElement"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"UnitElement"],

Cell["Some unit elements.", "ExampleText",
  CellTags->"UnitElement"],

Cell[CellGroupData[{

Cell["UnitElement[T[2,2,2]]", "Input",
  CellLabel->"In[159]:=",
  CellTags->"UnitElement"],

Cell[BoxData[
    \(T[1, 2, 3]\)], "Output",
  CellLabel->"Out[159]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["UnitElement[{{1,1},{0,0}}]", "Input",
  CellLabel->"In[160]:=",
  CellTags->"UnitElement"],

Cell[BoxData[
    \({{1, 0}, {0, 1}}\)], "Output",
  CellLabel->"Out[160]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VertexSet", "ObjectName",
  CellTags->"VertexSet"],

Cell["Type: function", "Highlight",
  CellTags->"VertexSet"],

Cell[TextData[{
  StyleBox["VertexSet[G]", "MR"],
  "  returns the vertex set of a graph ",
  StyleBox["G", "MR"],
  "."
}], "Usage",
  CellTags->"VertexSet"],

Cell[TextData[{
  "If there is no structured vertex set, ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], n}\)]],
  "  is returned."
}], "Notes",
  CellTags->"VertexSet"],

Cell[TextData[{
  "See also ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Edges",
    ButtonData:>"Edges",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"VertexSet"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"VertexSet"],

Cell["Some graph operations produce structured vertex sets.", "ExampleText",
  CellTags->"VertexSet"],

Cell[BoxData[
    \(\(g = DeBruijnGraph[3, 2, Normalize \[Rule] 1];\)\)], "Input",
  CellLabel->"In[166]:=",
  CellTags->"VertexSet"],

Cell[CellGroupData[{

Cell[BoxData[
    \(VertexSet[g]\)], "Input",
  CellLabel->"In[167]:="],

Cell[BoxData[
    \({"aaa", "aab", "aba", "abb", "baa", "bab", "bba", "bbb"}\)], "Output",
  CellLabel->"Out[167]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vier", "ObjectName",
  CellTags->"Vier"],

Cell["Type: fctassg", "Highlight",
  CellTags->"Vier"],

Cell[TextData[{
  StyleBox["Vier", "MR"],
  "  returns  the fourth part of object ",
  StyleBox["x", "MR"],
  "."
}], "Usage",
  CellTags->"Vier"],

Cell[TextData[{
  "Thsu, ",
  StyleBox["Zwei[x] = x[[2]]", "MR"],
  "."
}], "Notes",
  CellTags->"Vier"],

Cell[TextData[{
  "See also ",
  ButtonBox["Zwei",
    ButtonData:>"Zwei",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["Drei",
    ButtonData:>"Drei",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinusEins",
    ButtonData:>"MinusEins",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinusZwei",
    ButtonData:>"MinusZwei",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Vier"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Warshall", "ObjectName",
  CellTags->"Warshall"],

Cell["Type: function", "Highlight",
  CellTags->"Warshall"],

Cell[TextData[{
  StyleBox["Warshall[B]", "MR"],
  "  computes the transitive closure of Boolean matrix B using Warshall's \
algorithm. "
}], "Usage",
  CellTags->"Warshall"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Reflexive", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"Warshall"],

Cell["\<\
For efficency reasons, the matrix is required to be a 0/1-integer \
matrix. \
\>", "Notes",
  CellTags->"Warshall"],

Cell["\<\
In principle, the algorithm is cubic in the size of the input \
matrix.\
\>", "Notes"],

Cell[TextData[{
  "See also ",
  ButtonBox["TransitiveClosure",
    ButtonData:>"TransitiveClosure",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Closure",
    ButtonData:>"Closure",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Warshall"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Warshall"],

Cell[TextData[{
  "The successor relation on ",
  Cell[BoxData[
      \(TraditionalForm\`\([6]\)\)]],
  ", and its transitive closure."
}], "ExampleText",
  CellTags->"Warshall"],

Cell[CellGroupData[{

Cell["\<\
M = RelationToMatrix[ #1+1==#2&, Range[6] ];
% // MatrixForm\
\>", "Input",
  CellLabel->"In[197]:=",
  CellTags->"Warshall"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1", "0", "0", "0", "0"},
            {"0", "0", "1", "0", "0", "0"},
            {"0", "0", "0", "1", "0", "0"},
            {"0", "0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[198]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Warshall[M]\  // MatrixForm\)], "Input",
  CellLabel->"In[199]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "1", "1", "1", "1", "1"},
            {"0", "0", "1", "1", "1", "1"},
            {"0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[199]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Warshall[M, Reflexive \[Rule] True\ ]\  // MatrixForm\)], "Input",
  CellLabel->"In[200]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1", "1"},
            {"0", "1", "1", "1", "1", "1"},
            {"0", "0", "1", "1", "1", "1"},
            {"0", "0", "0", "1", "1", "1"},
            {"0", "0", "0", "0", "1", "1"},
            {"0", "0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[200]//MatrixForm="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["WeaklyConnectedComponents", "ObjectName",
  CellTags->"WeaklyConnectedComponents"],

Cell["Type: function", "Highlight",
  CellTags->"WeaklyConnectedComponents"],

Cell[TextData[{
  StyleBox["WeaklyConnectedComponents[G,X]", "MR"],
  "  computes the weakly connected component of vertex set ",
  StyleBox["X", "MR"],
  " in graph ",
  StyleBox["G", "MR"],
  ". "
}], "Usage",
  CellTags->"WeaklyConnectedComponents"],

Cell["\<\
X can be a single vertex or a list of vertices; in either case, \
given in positional notation.\
\>", "Notes",
  CellTags->"WeaklyConnectedComponents"],

Cell[TextData[{
  "See also ",
  ButtonBox["StronglyConnectedComponents",
    ButtonData:>"StronglyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Graph",
    ButtonData:>"Graph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"WeaklyConnectedComponents"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WeaklyConnectedComponents"],

Cell["Components in a circulant graph", "ExampleText",
  CellTags->"WeaklyConnectedComponents"],

Cell[CellGroupData[{

Cell["g = CirculantGraph[ 12, {3,-3} ]", "Input",
  CellLabel->"In[178]:=",
  CellTags->"WeaklyConnectedComponents"],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"12", ",", "24", ",", "1", ",", 
          TagBox[\(\[LeftSkeleton]1\[RightSkeleton]\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[178]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(WeaklyConnectedComponents[g, 1]\), "\n", 
    \(WeaklyConnectedComponents[g, 2]\), "\n", 
    \(WeaklyConnectedComponents[g, {1, 2}]\)}], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    \({1, 4, 7, 10}\)], "Output",
  CellLabel->"Out[183]="],

Cell[BoxData[
    \({2, 5, 8, 11}\)], "Output",
  CellLabel->"Out[184]="],

Cell[BoxData[
    \({1, 2, 4, 5, 7, 8, 10, 11}\)], "Output",
  CellLabel->"Out[185]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["WordQ", "ObjectName",
  CellTags->"WordQ"],

Cell["Type: function", "Highlight",
  CellTags->"WordQ"],

Cell[TextData[{
  StyleBox["WordQ[w]", "MR"],
  "  tests whether w is a word: w may be a symbol or a string."
}], "Usage",
  CellTags->"WordQ"],

Cell["Also treats epsilon properly.", "Notes",
  CellTags->"WordQ"],

Cell[TextData[{
  "See also  ",
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordBinomial",
    ButtonData:>"WordBinomial",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordConjugateQ",
    ButtonData:>"WordConjugateQ",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordConjugates",
    ButtonData:>"WordConjugates",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordFactorizations",
    ButtonData:>"WordFactorizations",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordFactors",
    ButtonData:>"WordFactors",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordFusion",
    ButtonData:>"WordFusion",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordLength",
    ButtonData:>"WordLength",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordMap",
    ButtonData:>"WordMap",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordOrder",
    ButtonData:>"WordOrder",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordPower",
    ButtonData:>"WordPower",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordPrefixes",
    ButtonData:>"WordPrefixes",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordReverse",
    ButtonData:>"WordReverse",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordRoot",
    ButtonData:>"WordRoot",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordRotate",
    ButtonData:>"WordRotate",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordShuffle",
    ButtonData:>"WordShuffle",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordSort",
    ButtonData:>"WordSort",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["WordSuffixes",
    ButtonData:>"WordSuffixes",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["Words",
    ButtonData:>"Words",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"WordQ"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordQ"],

Cell["Words as opposed to strings.", "ExampleText",
  CellTags->"WordQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordQ /@ {abc, "\<abc\>", Eps, \[Epsilon], 1234, {a}}\)], "Input",
  CellLabel->"In[170]:=",
  CellTags->"WordQ"],

Cell[BoxData[
    \({True, True, True, True, False, False}\)], "Output",
  CellLabel->"Out[170]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["WordReduce", "ObjectName",
  CellTags->"WordReduce"],

Cell["Type: function", "Highlight",
  CellTags->"WordReduce"],

Cell[TextData[{
  StyleBox["WordReduce[w,eq,opt]", "MR"],
  "  reduces word ",
  StyleBox["w", "MR"],
  " according to equations ",
  StyleBox["eq", "MR"],
  ". "
}], "Usage",
  CellTags->"WordReduce"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"DoTrace", "\[Rule]", "False", "-"},
          {"BoundWR", "\[Rule]", "500", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"WordReduce"],

Cell["noteworthy", "Notes",
  CellTags->"WordReduce"],

Cell[TextData[{
  "Option ",
  StyleBox["DoTrace->True", "MR"],
  " causes a trace to be displayed.  Uses StringReplace internally and may \
therefore perform several substitutions in one step. "
}], "Notes"],

Cell[TextData[{
  "Option ",
  StyleBox["BoundRW->500", "MR"],
  " bounds the number of substitution steps."
}], "Notes"],

Cell["\<\
The equations are only applied in directed form from left to right. \
\
\>", "Notes",
  CellTags->"WordReduce"],

Cell[TextData[{
  "See also ",
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SimplifyRewriteSystem",
    ButtonData:>"SimplifyRewriteSystem",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"WordReduce"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"WordReduce"],

Cell["A small rewrite system.", "ExampleText",
  CellTags->"WordReduce"],

Cell[BoxData[
    \(\(eq = {{aaa, \[Epsilon]}, {bbb, \[Epsilon]}, {ba, ab}};\)\)], "Input",
  CellLabel->"In[212]:=",
  CellTags->"WordReduce"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordReduce[\ RandomWord[10, 2], \ eq\ ]\)], "Input",
  CellLabel->"In[213]:="],

Cell[BoxData[
    \("a"\)], "Output",
  CellLabel->"Out[213]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(WordReduce[\ RandomWord[10, 2], \ eq\ , 
      DoTrace \[Rule] True]\)], "Input",
  CellLabel->"In[214]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "\<\"bbbababbbb\"\>", \({2, 1, 3}\)},
          {"2", "\<\"ababbbb\"\>", \({2, 4, 6}\)},
          {"3", "\<\"abab\"\>", \({3, 2, 3}\)},
          {"4", "\<\"aabb\"\>", 
            InterpretationBox["\<\"\"\>",
              {}]}
          },
        RowSpacings->1,
        ColumnSpacings->5,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableDepth -> 2, TableSpacing -> {1, 5}, 
          TableHeadings -> {Automatic, None}]]]], "Output",
  CellLabel->"Out[214]//TableForm="]
}, Open  ]],

Cell["All words that are irreducible with respect to eq.", "ExampleText",
  CellTags->"WordReduce"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(WordReduce[\ Words[\(-6\)], eq]\  // \ Union\)\  // \ 
      WordSort\)], "Input",
  CellLabel->"In[217]:=",
  CellTags->"WordReduce"],

Cell[BoxData[
    \({"1", "a", "b", "aa", "ab", "bb", "aab", "abb", "aabb"}\)], "Output",
  CellLabel->"Out[217]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Zwei", "ObjectName",
  CellTags->"Zwei"],

Cell["Type: fctassg", "Highlight",
  CellTags->"Zwei"],

Cell[TextData[{
  StyleBox["Zwei[x]", "MR"],
  " "
}], "Usage",
  CellTags->"Zwei"],

Cell[TextData[{
  "Thsu, ",
  StyleBox["Zwei[x] = x[[2]]", "MR"],
  "."
}], "Notes",
  CellTags->"Zwei"],

Cell[TextData[{
  "See also ",
  ButtonBox["Drei",
    ButtonData:>"Drei",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinusEins",
    ButtonData:>"MinusEins",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinusZwei",
    ButtonData:>"MinusZwei",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Zwei"]
}, Open  ]],

Cell[CellGroupData[{

Cell["All", "ObjectName",
  CellTags->"All"],

Cell["Type: option", "Highlight"],

Cell[TextData[{
  StyleBox["All", "MR"],
  "  is an option value for various functions."
}], "Usage",
  CellTags->"All"],

Cell[TextData[{
  StyleBox["See also ", "Text"],
  ButtonBox["PlotFunction",
    ButtonData:>"PlotFunction",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["PlotRelation",
    ButtonData:>"PlotRelation",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"All"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"All"],

Cell[TextData[{
  "The function ",
  StyleBox["PlotRelation", "MR"],
  " by default uses ",
  StyleBox["DoTrace->All", "MR"],
  " which may produce confusing graphics. "
}], "ExampleText",
  CellTags->"All"],

Cell[CellGroupData[{

Cell["PlotRelation[(Mod[#2,#1]===0)&,Range[10],2 ]", "Input",
  CellLabel->"In[93]:=",
  CellTags->"All"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0555556 0.277778 -0.011661 0.0583051 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.22222 .04664 m
.5 .04664 L
s
.22222 .04664 m
.5 .10495 L
s
.22222 .04664 m
.5 .16325 L
s
.22222 .04664 m
.5 .22156 L
s
.22222 .04664 m
.5 .27986 L
s
.22222 .04664 m
.5 .33817 L
s
.22222 .04664 m
.5 .39647 L
s
.22222 .04664 m
.5 .45478 L
s
.22222 .04664 m
.5 .51308 L
s
.22222 .04664 m
.5 .57139 L
s
.22222 .10495 m
.5 .10495 L
s
.22222 .10495 m
.5 .22156 L
s
.22222 .10495 m
.5 .33817 L
s
.22222 .10495 m
.5 .45478 L
s
.22222 .10495 m
.5 .57139 L
s
.22222 .16325 m
.5 .16325 L
s
.22222 .16325 m
.5 .33817 L
s
.22222 .16325 m
.5 .51308 L
s
.22222 .22156 m
.5 .22156 L
s
.22222 .22156 m
.5 .45478 L
s
.22222 .27986 m
.5 .27986 L
s
.22222 .27986 m
.5 .57139 L
s
.22222 .33817 m
.5 .33817 L
s
.22222 .39647 m
.5 .39647 L
s
.22222 .45478 m
.5 .45478 L
s
.22222 .51308 m
.5 .51308 L
s
.22222 .57139 m
.5 .57139 L
s
.5 .04664 m
.77778 .04664 L
s
.5 .04664 m
.77778 .10495 L
s
.5 .04664 m
.77778 .16325 L
s
.5 .04664 m
.77778 .22156 L
s
.5 .04664 m
.77778 .27986 L
s
.5 .04664 m
.77778 .33817 L
s
.5 .04664 m
.77778 .39647 L
s
.5 .04664 m
.77778 .45478 L
s
.5 .04664 m
.77778 .51308 L
s
.5 .04664 m
.77778 .57139 L
s
.5 .10495 m
.77778 .10495 L
s
.5 .10495 m
.77778 .22156 L
s
.5 .10495 m
.77778 .33817 L
s
.5 .10495 m
.77778 .45478 L
s
.5 .10495 m
.77778 .57139 L
s
.5 .16325 m
.77778 .16325 L
s
.5 .16325 m
.77778 .33817 L
s
.5 .16325 m
.77778 .51308 L
s
.5 .22156 m
.77778 .22156 L
s
.5 .22156 m
.77778 .45478 L
s
.5 .27986 m
.77778 .27986 L
s
.5 .27986 m
.77778 .57139 L
s
.5 .33817 m
.77778 .33817 L
s
.5 .39647 m
.77778 .39647 L
s
.5 .45478 m
.77778 .45478 L
s
.5 .51308 m
.77778 .51308 L
s
.5 .57139 m
.77778 .57139 L
s
1 0 0 r
.0144 w
.22222 .04664 Mdot
.22222 .10495 Mdot
.22222 .16325 Mdot
.22222 .22156 Mdot
.22222 .27986 Mdot
.22222 .33817 Mdot
.22222 .39647 Mdot
.22222 .45478 Mdot
.22222 .51308 Mdot
.22222 .57139 Mdot
.5 .04664 Mdot
.5 .10495 Mdot
.5 .16325 Mdot
.5 .22156 Mdot
.5 .27986 Mdot
.5 .33817 Mdot
.5 .39647 Mdot
.5 .45478 Mdot
.5 .51308 Mdot
.5 .57139 Mdot
.77778 .04664 Mdot
.77778 .10495 Mdot
.77778 .16325 Mdot
.77778 .22156 Mdot
.77778 .27986 Mdot
.77778 .33817 Mdot
.77778 .39647 Mdot
.77778 .45478 Mdot
.77778 .51308 Mdot
.77778 .57139 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[93]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[93]="]
}, Open  ]],

Cell["Tracing individual points improves the clarity. ", "ExampleText",
  CellTags->"All"],

Cell[CellGroupData[{

Cell["PlotRelation[(Mod[#2,#1]===0)&,Range[10],2,DoTrace->{2} ]", "Input",
  CellLabel->"In[96]:=",
  CellTags->"All"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0555556 0.277778 -0.011661 0.0583051 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.22222 .10495 m
.5 .10495 L
s
.22222 .10495 m
.5 .22156 L
s
.22222 .10495 m
.5 .33817 L
s
.22222 .10495 m
.5 .45478 L
s
.22222 .10495 m
.5 .57139 L
s
.5 .10495 m
.77778 .10495 L
s
.5 .10495 m
.77778 .22156 L
s
.5 .10495 m
.77778 .33817 L
s
.5 .10495 m
.77778 .45478 L
s
.5 .10495 m
.77778 .57139 L
s
.5 .22156 m
.77778 .22156 L
s
.5 .22156 m
.77778 .45478 L
s
.5 .33817 m
.77778 .33817 L
s
.5 .45478 m
.77778 .45478 L
s
.5 .57139 m
.77778 .57139 L
s
0 0 1 r
.012 w
.22222 .04664 Mdot
.22222 .16325 Mdot
.22222 .22156 Mdot
.22222 .27986 Mdot
.22222 .33817 Mdot
.22222 .39647 Mdot
.22222 .45478 Mdot
.22222 .51308 Mdot
.22222 .57139 Mdot
.5 .04664 Mdot
.5 .16325 Mdot
.5 .27986 Mdot
.5 .39647 Mdot
.5 .51308 Mdot
.77778 .04664 Mdot
.77778 .16325 Mdot
.77778 .27986 Mdot
.77778 .39647 Mdot
.77778 .51308 Mdot
1 0 0 r
.0144 w
.22222 .10495 Mdot
.5 .10495 Mdot
.5 .22156 Mdot
.5 .33817 Mdot
.5 .45478 Mdot
.5 .57139 Mdot
.77778 .10495 Mdot
.77778 .22156 Mdot
.77778 .33817 Mdot
.77778 .45478 Mdot
.77778 .57139 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[96]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[96]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boolean", "ObjectName",
  CellTags->"Boolean"],

Cell["Type: option", "Highlight",
  CellTags->"Boolean"],

Cell[TextData[{
  StyleBox["Boolean", "MR"],
  "  is an option for ",
  StyleBox["TransitionMatrixFA", "MR"],
  ", causes the constructed homomorphism to take values in the semiring of \
Boolean matrices. "
}], "Usage",
  CellTags->"Boolean"],

Cell[TextData[{
  "Associated Functions.\n",
  Cell[BoxData[GridBox[{
          {"TransitionMatrixFA"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"Boolean"],

Cell["\<\
Note that for  efficiency reasons Boolean matrices are implemented \
using 0/1-integer matrices. \
\>", "Notes",
  CellTags->"Boolean"],

Cell[TextData[{
  "See also ",
  ButtonBox["TransitionMatrixFA",
    ButtonData:>"TransitionMatrixFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Boolean"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Boolean"],

Cell["A nondeterministic machine", "ExampleText",
  CellTags->"Boolean"],

Cell[CellGroupData[{

Cell[BoxData[
    \(M = IthSymbolFA[a, \(-4\)]\)], "Input",
  CellLabel->"In[42]:=",
  CellTags->"Boolean"],

Cell[BoxData[
    TagBox[
      RowBox[{"FA", "[", 
        RowBox[{"5", ",", "2", ",", 
          
          TagBox[\({{1, 1, 1}, {1, 1, 2}, {1, 2, 1}, {2, 1, 3}, {2, 2, 
                3}, {3, 1, 4}, {3, 2, 4}, {4, 1, 5}, {4, 2, 5}}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({1}\),
            (Short[ #, 4]&)], ",", 
          TagBox[\({5}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[42]=",
  CellTags->"Boolean"]
}, Open  ]],

Cell[BoxData[
    \(TransitionMatrixFA[M, f, Boolean \[Rule] True]\)], "Input",
  CellLabel->"In[43]:=",
  CellTags->"Boolean"],

Cell[CellGroupData[{

Cell["f[a] // MatrixForm", "Input",
  CellLabel->"In[48]:=",
  CellTags->"Boolean"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[48]//MatrixForm=",
  CellTags->"Boolean"]
}, Open  ]],

Cell[CellGroupData[{

Cell["f[aaaa] // MatrixForm", "Input",
  CellLabel->"In[52]:=",
  CellTags->"Boolean"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "1", "1", "1"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[52]//MatrixForm=",
  CellTags->"Boolean"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundCSM", "ObjectName",
  CellTags->"BoundCSM"],

Cell["Type: option", "Highlight",
  CellTags->"BoundCSM"],

Cell[TextData[{
  StyleBox["BoundCSM", "MR"],
  " BoundCSM is an option for GenerateCSM, limits the size of the generated \
cyclic semimodule. "
}], "Usage",
  CellTags->"BoundCSM"],

Cell["Default is 1000.", "Notes",
  CellTags->"BoundCSM"],

Cell["See GenerateCSM.", "Notes",
  CellTags->"BoundCSM"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundETW", "ObjectName",
  CellTags->"BoundETW"],

Cell["Type: option", "Highlight",
  CellTags->"BoundETW"],

Cell[TextData[{
  StyleBox["BoundETW", "MR"],
  "  is an option for ",
  StyleBox["EquationsToWitnesses", "MR"],
  ". "
}], "Usage",
  CellTags->"BoundETW"],

Cell["Default is 500.", "Notes",
  CellTags->"BoundETW"],

Cell[TextData[{
  "See ",
  ButtonBox["EquationsToWitnesses",
    ButtonData:>"EquationsToWitnesses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"BoundETW"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundGSG", "ObjectName",
  CellTags->"BoundGSG"],

Cell["Type: sysvar", "Highlight",
  CellTags->"BoundGSG"],

Cell[TextData[{
  StyleBox["BoundGSG", "MR"],
  "  is an option that controls the size of a semigroup generated by ",
  StyleBox["GenerateSG", "MR"],
  ". "
}], "Usage",
  CellTags->"BoundGSG"],

Cell["Default is $generateSGBound = 1000.", "Notes",
  CellTags->"BoundGSG"],

Cell[TextData[{
  "See ",
  ButtonBox["generateSGBound",
    ButtonData:>"generateSGBound",
    ButtonStyle->"AddOnsLink"],
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"BoundGSG"]
}, Open  ]],

Cell[CellGroupData[{

Cell["BoundWR", "ObjectName",
  CellTags->"BoundWR"],

Cell["Type: option", "Highlight",
  CellTags->"BoundWR"],

Cell[TextData[{
  StyleBox["BoundWR", "MR"],
  "  is an upper bound for the number of reduction steps in ",
  StyleBox["WordReduce", "MR"],
  ". "
}], "Usage",
  CellTags->"BoundWR"],

Cell["Default is 500.", "Notes",
  CellTags->"BoundWR"],

Cell[TextData[{
  "See ",
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"BoundWR"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ClosureBound", "ObjectName",
  CellTags->"ClosureBound"],

Cell["Type: option", "Highlight",
  CellTags->"ClosureBound"],

Cell[TextData[{
  StyleBox["ClosureBound", "MR"],
  "  is an option for ",
  StyleBox["Closure", "MR"],
  " and ",
  StyleBox["ClosureSearch", "MR"],
  "."
}], "Usage",
  CellTags->"ClosureBound"],

Cell[TextData[{
  "See ",
  ButtonBox["Closure",
    ButtonData:>"Closure",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["ClosureSearch",
    ButtonData:>"ClosureSearch",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ClosureBound"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cols", "ObjectName",
  CellTags->"Cols"],

Cell["Type: option", "Highlight",
  CellTags->"Cols"],

Cell[TextData[{
  StyleBox["Cols", "MR"],
  "  is an option ",
  StyleBox["PrintEquations", "MR"],
  "."
}], "Usage",
  CellTags->"Cols"],

Cell[TextData[{
  "See ",
  ButtonBox["PrintEquations",
    ButtonData:>"PrintEquations",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Cols"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cycle", "ObjectName",
  CellTags->"Cycle"],

Cell["Type: option", "Highlight",
  CellTags->"Cycle"],

Cell[TextData[{
  StyleBox["Cycle", "MR"],
  "  is an option for ",
  StyleBox["AnalyzeOrbit", "MR"],
  " that causes the limiting cycle to be displayed."
}], "Usage",
  CellTags->"Cycle"],

Cell[TextData[{
  "See ",
  ButtonBox["AnalyzeOrbit",
    ButtonData:>"AnalyzeOrbit",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Cycle"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DClasses", "ObjectName",
  CellTags->"DClasses"],

Cell["Type: option", "Highlight",
  CellTags->"DClasses"],

Cell[TextData[{
  StyleBox["DClasses", "MR"],
  "  is an option for ",
  StyleBox["GenerateSG", "MR"],
  "."
}], "Usage",
  CellTags->"DClasses"],

Cell[TextData[{
  "Default value is ",
  StyleBox["False", "MR"],
  "."
}], "Notes",
  CellTags->"DClasses"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DC",
    ButtonData:>"DC",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DClassDecomposition",
    ButtonData:>"DClassDecomposition",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DClasses"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DoTrace", "ObjectName",
  CellTags->"DoTrace"],

Cell["Type: option", "Highlight",
  CellTags->"DoTrace"],

Cell[TextData[{
  StyleBox["DoTrace", "MR"],
  "  is an option for various functions."
}], "Usage",
  CellTags->"DoTrace"],

Cell[TextData[{
  "See  ",
  ButtonBox["PlotFunction",
    ButtonData:>"PlotFunction",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotRelation",
    ButtonData:>"PlotRelation",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SimplifyRewriteSystem",
    ButtonData:>"SimplifyRewriteSystem",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DoTrace"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Eps", "ObjectName",
  CellTags->"Eps"],

Cell["Type: header", "Highlight",
  CellTags->"Eps"],

Cell[TextData[{
  StyleBox["Eps", "MR"],
  "  is used to denote the empty string. "
}], "Usage",
  CellTags->"Eps"],

Cell[TextData[{
  "As a regular expression it denotes the singleton set ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Epsilon]}\)]],
  "."
}], "Notes",
  CellTags->"Eps"],

Cell[TextData[{
  "The system function ",
  StyleBox["ToString", "MR"],
  " is redefined to treat ",
  StyleBox["Eps", "MR"],
  " and \[Epsilon] properly:  ",
  StyleBox["ToString[Eps] \[Rule] \"\".", "MR"]
}], "Notes",
  CellTags->"Eps"],

Cell[TextData[{
  "The empty word can be represented as ",
  StyleBox["Eps", "MR"],
  ", ",
  StyleBox["\"Eps\"", "MR"],
  ", ",
  StyleBox["\"\"", "MR"],
  ", ",
  StyleBox["\[Epsilon]", "MR"],
  ".  For obvious reasong the third form is discouraged."
}], "Notes",
  CellTags->"Eps"],

Cell[TextData[{
  "See ",
  ButtonBox["ToEps",
    ButtonData:>"ToEps",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Eps"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equations", "ObjectName",
  CellTags->"Equations"],

Cell["Type: option", "Highlight",
  CellTags->"Equations"],

Cell[TextData[{
  StyleBox["Equations", "MR"],
  "  is an option for various functions."
}], "Usage",
  CellTags->"Equations"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateCSM",
    ButtonData:>"GenerateCSM",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Equations"]
}, Open  ]],

Cell[CellGroupData[{

Cell["External", "ObjectName",
  CellTags->"External"],

Cell["Type: option", "Highlight",
  CellTags->"External"],

Cell[TextData[{
  StyleBox["External", "MR"],
  "  is an option for various commands with an external implementation. "
}], "Usage",
  CellTags->"External"],

Cell[TextData[{
  "Option  ",
  StyleBox["External->True", "MR"],
  "  causes the external code to be uses, assuming that the appropriate ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  "  has been established. "
}], "Notes",
  CellTags->"External"],

Cell[TextData[{
  "Has default value ",
  StyleBox["$defaultexternal", "MR"],
  "."
}], "Notes",
  CellTags->"External"],

Cell["\<\
The internal and external algorithms produce essentially the same \
output.\
\>", "Notes",
  CellTags->"External"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinimizeFA",
    ButtonData:>"MinimizeFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"defaultexternal"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Filter", "ObjectName",
  CellTags->"Filter"],

Cell["Type: option", "Highlight",
  CellTags->"Filter"],

Cell[TextData[{
  StyleBox["Filter", "MR"],
  " is an option that can be used in GenerateSG to further process the \
objects generated by semigroup multiplications. "
}], "Usage",
  CellTags->"Filter"],

Cell["Useful to enforce modular arithmetic.", "Notes",
  CellTags->"Filter"],

Cell["\<\
Note that this option is only available for the internal algorithm.\
\
\>", "Notes",
  CellTags->"Filter"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Filter"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Filter"],

Cell["Constructing a semigroup of 0/1-matrices with 4 generators.", \
"ExampleText",
  CellTags->"Filter"],

Cell[BoxData[{
    \(\(r\  = \ {{0, 1, 0}, {0, 0, 1}, {1, 0, 0}};\)\), "\n", 
    \(\(t\  = \ {{0, 1, 0}, {1, 0, 0}, {0, 0, 1}};\)\), "\n", 
    \(\(m\  = \ {{1, 0, 0}, {1, 0, 0}, {0, 0, 1}};\)\)}], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \(\(g\  = \ GEN[\ 3, 3, \ {r, t, m}\ ];\)\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(\(S\  = \ 
        GenerateSG[\ g, \ \[IndentingNewLine]\tMatrix \[Rule] True, \ 
          Unit \[Rule] IdentityMatrix, \ Filter \[Rule] Sign\ ];\)\)], "Input",\

  CellLabel->"In[108]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm\  /@ \ S\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    RowBox[{"SG", "[", 
      RowBox[{
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"0", "0", "1"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"0", "0", "1"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"0", "0", "1"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"0", "1", "0"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"0", "1", "0"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"0", "1", "0"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"1", "0", "0"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"1", "0", "0"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "0", "1"},
                {"1", "0", "0"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"0", "0", "1"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"0", "0", "1"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"0", "0", "1"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"0", "1", "0"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"0", "1", "0"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"0", "1", "0"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"1", "0", "0"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"1", "0", "0"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"0", "1", "0"},
                {"1", "0", "0"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "0", "1"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "0", "1"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "0", "1"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "1", "0"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "1", "0"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"0", "1", "0"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"1", "0", "0"},
                {"0", "0", "1"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"1", "0", "0"},
                {"0", "1", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]], ",", 
        TagBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0"},
                {"1", "0", "0"},
                {"1", "0", "0"}
                }], "\[NoBreak]", ")"}],
          Function[ BoxForm`e$, 
            MatrixForm[ BoxForm`e$]]]}], "]"}]], "Output",
  CellLabel->"Out[109]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Full", "ObjectName",
  CellTags->"Full"],

Cell["Type: option", "Highlight",
  CellTags->"Full"],

Cell[TextData[{
  StyleBox["Full", "MR"],
  "  is an option for various functions."
}], "Usage",
  CellTags->"Full"],

Cell[TextData[{
  "See also ",
  ButtonBox["CycleDecompositionT",
    ButtonData:>"CycleDecompositionT",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["CyclicQGraph",
    ButtonData:>"CyclicQGraph",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["DegreeGraph",
    ButtonData:>"DegreeGraph",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["EquationsToWitnesses",
    ButtonData:>"EquationsToWitnesses",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GenerateCSM",
    ButtonData:>"GenerateCSM",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GridLine",
    ButtonData:>"GridLine",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["GridPoints",
    ButtonData:>"GridPoints",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["LongestPath",
    ButtonData:>"LongestPath",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["MakeFullAlphabet",
    ButtonData:>"MakeFullAlphabet",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["PathGraph",
    ButtonData:>"PathGraph",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["PlotFunction",
    ButtonData:>"PlotFunction",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["PlotRelation",
    ButtonData:>"PlotRelation",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ProductGraph",
    ButtonData:>"ProductGraph",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["ShortestPath",
    ButtonData:>"ShortestPath",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  ",  ",
  ButtonBox["StaircasePlot",
    ButtonData:>"StaircasePlot",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"Full"]
}, Open  ]],

Cell[CellGroupData[{

Cell["GridOffset", "ObjectName",
  CellTags->"GridOffset"],

Cell["Type: option", "Highlight",
  CellTags->"GridOffset"],

Cell[TextData[{
  StyleBox["GridOffset", "MR"],
  "  is an option for ",
  StyleBox["GridLine", "MR"],
  "."
}], "Usage",
  CellTags->"GridOffset"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"GridLine"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"GridOffset"],

Cell[TextData[{
  "Determines starting coordinates for the grid. Default value is   ",
  StyleBox["{1,1}", "MR"],
  "."
}], "Notes",
  CellTags->"GridOffset"],

Cell[TextData[{
  "See also ",
  ButtonBox["GridLine",
    ButtonData:>"GridLine",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GridOffset"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Index", "ObjectName",
  CellTags->"Index"],

Cell["Type: option", "Highlight",
  CellTags->"Index"],

Cell[TextData[{
  StyleBox["Index", "MR"],
  "  is a possible value for option ",
  StyleBox["Type", "MR"],
  " in function ",
  StyleBox["ToClasses", "MR"],
  "."
}], "Usage",
  CellTags->"Index"],

Cell[TextData[{
  "See ",
  ButtonBox["ToClasses",
    ButtonData:>"ToClasses",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Type",
    ButtonData:>"Type",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Index"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kary", "ObjectName",
  CellTags->"Kary"],

Cell["Type: option", "Highlight",
  CellTags->"Kary"],

Cell[TextData[{
  StyleBox["Kary", "MR"],
  "  is a Boolean option for ",
  StyleBox["AssignFunction", "MR"],
  ", causes the function to be treated as a ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-ary function."
}], "Usage",
  CellTags->"Kary"],

Cell[TextData[{
  "See ",
  ButtonBox["AssignFunction",
    ButtonData:>"AssignFunction",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Kary"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LabelGrid", "ObjectName",
  CellTags->"LabelGrid"],

Cell["Type: option", "Highlight",
  CellTags->"LabelGrid"],

Cell[TextData[{
  StyleBox["LabelGrid", "MR"],
  "  is an option for ",
  StyleBox["GridPoints", "MR"],
  ", causes the first and last column of grid points to be labeled by \
integers."
}], "Usage",
  CellTags->"LabelGrid"],

Cell[TextData[{
  "See ",
  ButtonBox["GridPoints",
    ButtonData:>"GridPoints",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LabelGrid"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LabelPoints", "ObjectName",
  CellTags->"LabelPoints"],

Cell["Type: option", "Highlight",
  CellTags->"LabelPoints"],

Cell[TextData[{
  StyleBox["LabelPoints", "MR"],
  " LabelPoints is an option for GridPoints, causes all grid points to be \
labeled by integers."
}], "Usage",
  CellTags->"LabelPoints"],

Cell[TextData[{
  " Default is ",
  StyleBox["LabelPoints->None", "MR"],
  ", change to ",
  StyleBox["LabelPoints->labelingfct", "MR"],
  "."
}], "Notes",
  CellTags->"LabelPoints"],

Cell[TextData[{
  "See ",
  ButtonBox["GridPoints",
    ButtonData:>"GridPoints",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LabelPoints"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LineStyle", "ObjectName",
  CellTags->"LineStyle"],

Cell["Type: option", "Highlight",
  CellTags->"LineStyle"],

Cell[TextData[{
  StyleBox["LineStyle", "MR"],
  "  is an option for ",
  StyleBox["PlotTDGraph", "MR"],
  " that controls thickness and color of the lines in the plot."
}], "Usage",
  CellTags->"LineStyle"],

Cell[TextData[{
  "Usage: ",
  StyleBox["LineStyle->{{col1,thick1},{col2,thick2}}", "MR"],
  "."
}], "Notes",
  CellTags->"LineStyle"],

Cell[TextData[{
  "See ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"LineStyle"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrix", "ObjectName",
  CellTags->"Matrix"],

Cell["Type: option", "Highlight",
  CellTags->"Matrix"],

Cell[TextData[{
  StyleBox["Matrix", "MR"],
  "  is a possible value for option ",
  StyleBox["Type", "MR"],
  " in function ",
  StyleBox["ToClasses", "MR"],
  "."
}], "Usage",
  CellTags->"Matrix"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToClasses",
    ButtonData:>"ToClasses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Matrix"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MultiCol", "ObjectName",
  CellTags->"MultiCol"],

Cell["Type: option", "Highlight",
  CellTags->"MultiCol"],

Cell[TextData[{
  StyleBox["MultiCol", "MR"],
  "  is an option for ",
  StyleBox["PlotMatrix", "MR"],
  "."
}], "Usage",
  CellTags->"MultiCol"],

Cell[TextData[{
  "See ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"MultiCol"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NonTrivial", "ObjectName",
  CellTags->"NonTrivial"],

Cell["Type: option", "Highlight",
  CellTags->"NonTrivial"],

Cell[TextData[{
  StyleBox["NonTrivial", "MR"],
  "  is an option for command ",
  StyleBox["StronglyConnectedComponents", "MR"],
  ". "
}], "Usage",
  CellTags->"NonTrivial"],

Cell["\<\
Causes only those stronglyconnected components to be generated that \
contain at least one edge (possibly a self-loop).\
\>", "Notes",
  CellTags->"NonTrivial"],

Cell[TextData[{
  "See ",
  ButtonBox["StronglyConnectedComponents",
    ButtonData:>"StronglyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NonTrivial"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NoRest", "ObjectName",
  CellTags->"NoRest"],

Cell["Type: option", "Highlight",
  CellTags->"NoRest"],

Cell[TextData[{
  StyleBox["NoRest", "MR"],
  "  is an option for ",
  StyleBox["PlotMatrix", "MR"],
  "."
}], "Usage",
  CellTags->"NoRest"],

Cell[TextData[{
  "See ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NoRest"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normalize", "ObjectName",
  CellTags->"Normalize"],

Cell["Type: option", "Highlight",
  CellTags->"Normalize"],

Cell[TextData[{
  StyleBox["Normalize", "MR"],
  " is an option for numerous commands in Automata."
}], "Usage",
  CellTags->"Normalize"],

Cell[TextData[{
  "Default value of ",
  StyleBox["Normalize", "MR"],
  " is ",
  StyleBox["$defaultnormalize", "MR"],
  StyleBox[", can be set with ", "Text"],
  StyleBox["NormalizeControl", "MR"],
  StyleBox[".", "Text"]
}], "Notes",
  CellTags->"Normalize"],

Cell[TextData[{
  " Normalize controls the structure of the state set of a machine or graph. \
For example, for two DFAs ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  ", ",
  StyleBox["UnionFA[M1,M2,Normalize->1]", "MR"],
  " produces a product machine with states of the form ",
  StyleBox["{p,q}", "MR"],
  " where ",
  StyleBox["p", "MR"],
  " and ",
  StyleBox["q", "MR"],
  " are integers.  In ",
  StyleBox["UnionFA[M1,M2,Normalize->2]", "MR"],
  " where ",
  StyleBox["p", "MR"],
  " and ",
  StyleBox["q", "MR"],
  " are elements of the state sets of the input machines. "
}], "Notes",
  CellTags->"Normalize"],

Cell[TextData[{
  " See ",
  ButtonBox["NormalizeFA",
    ButtonData:>"NormalizeFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NormalizeControl",
    ButtonData:>"NormalizeControl",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Normalize"]
}, Open  ]],

Cell[CellGroupData[{

Cell["NRows", "ObjectName",
  CellTags->"NRows"],

Cell["Type: option", "Highlight",
  CellTags->"NRows"],

Cell[TextData[{
  StyleBox["NRows", "MR"],
  "  is an option for ",
  StyleBox["PlotMatrix", "MR"],
  "."
}], "Usage",
  CellTags->"NRows"],

Cell[TextData[{
  "See ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"NRows"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Opts", "ObjectName",
  CellTags->"Opts"],

Cell["Type: option", "Highlight",
  CellTags->"Opts"],

Cell[TextData[{
  StyleBox["Opts", "MR"],
  "  is an option for ",
  StyleBox["AssignFunction", "MR"],
  ". "
}], "Usage",
  CellTags->"Opts"],

Cell["Controls the attributes of the defined function.", "Notes",
  CellTags->"Opts"],

Cell[TextData[{
  "See ",
  ButtonBox["AssignFunction",
    ButtonData:>"AssignFunction",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Opts"]
}, Open  ]],

Cell[CellGroupData[{

Cell["OutPairs", "ObjectName",
  CellTags->"OutPairs"],

Cell["Type: option", "Highlight",
  CellTags->"OutPairs"],

Cell[TextData[{
  StyleBox["OutPairs", "MR"],
  "  is an option for command ",
  StyleBox["RemoveDuplicates", "MR"],
  ". "
}], "Usage",
  CellTags->"OutPairs"],

Cell["Causes the ouput to be returned in pair-list format.", "Notes",
  CellTags->"OutPairs"],

Cell[TextData[{
  "See ",
  ButtonBox["RemoveDuplicates",
    ButtonData:>"RemoveDuplicates",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"OutPairs"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Periodic", "ObjectName",
  CellTags->"Periodic"],

Cell["Type: option", "Highlight",
  CellTags->"Periodic"],

Cell[TextData[{
  StyleBox["Periodic", "MR"],
  "  that speeds up the computation in ",
  StyleBox["AnalyzeOrbit", "MR"],
  " if the orbit is known to be periodic. "
}], "Usage",
  CellTags->"Periodic"],

Cell[TextData[{
  "Default is ",
  StyleBox["Periodic->False", "MR"],
  "."
}], "Notes",
  CellTags->"Periodic"],

Cell[TextData[{
  "See ",
  ButtonBox["AnalyzeOrbit",
    ButtonData:>"AnalyzeOrbit",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Periodic"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RasterStyle", "ObjectName",
  CellTags->"RasterStyle"],

Cell["Type: option", "Highlight",
  CellTags->"RasterStyle"],

Cell[TextData[{
  StyleBox["RasterStyle", "MR"],
  "  is an option for ",
  StyleBox["PlotMatrix", "MR"],
  ", determines the colors used in the raster graphics. "
}], "Usage",
  CellTags->"RasterStyle"],

Cell[TextData[{
  "Default is ",
  StyleBox["$rastercolors", "MR"],
  ", ",
  StyleBox["RasterStyle->Automatic", "MR"],
  " uses ",
  StyleBox["HueRasterColors", "MR"],
  "."
}], "Notes",
  CellTags->"RasterStyle"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["HueRasterColors",
    ButtonData:>"HueRasterColors",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RasterStyle"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reflexive", "ObjectName",
  CellTags->"Reflexive"],

Cell["Type: option", "Highlight",
  CellTags->"Reflexive"],

Cell[TextData[{
  StyleBox["Reflexive", "MR"],
  "  is an option for function ",
  StyleBox["TransitiveClosure", "MR"]
}], "Usage",
  CellTags->"Reflexive"],

Cell[TextData[{
  " Default value is ",
  StyleBox["False", "MR"],
  "."
}], "Notes",
  CellTags->"Reflexive"],

Cell[TextData[{
  "See also ",
  ButtonBox["TransitiveClosure",
    ButtonData:>"TransitiveClosure",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Reflexive"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RegularOnly", "ObjectName",
  CellTags->"RegularOnly"],

Cell["Type: option", "Highlight",
  CellTags->"RegularOnly"],

Cell[TextData[{
  StyleBox["RegularOnly", "MR"],
  "  is an option for command ",
  StyleBox["DClassDecomposition", "MR"],
  ". "
}], "Usage",
  CellTags->"RegularOnly"],

Cell[TextData[{
  "Option ",
  StyleBox["RegularOnly->False", "MR"],
  " causes all D-classes to be generated, rather than just the regular ones. \
"
}], "Notes",
  CellTags->"RegularOnly"],

Cell["\<\
This option causes the internal version of the decomposition \
algorithm to be applied and should only be used for small semigroups.\
\>", \
"Notes",
  CellTags->"RegularOnly"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DClasses",
    ButtonData:>"DClasses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RegularOnly"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Relation", "ObjectName",
  CellTags->"Relation"],

Cell["Type: option", "Highlight",
  CellTags->"Relation"],

Cell[TextData[{
  StyleBox["Relation", "MR"],
  "  is a possible value for option ",
  StyleBox["Type", "MR"],
  " in function ",
  StyleBox["ToClasses", "MR"],
  "."
}], "Usage",
  CellTags->"Relation"],

Cell[TextData[{
  "See ",
  ButtonBox["ToClasses",
    ButtonData:>"ToClasses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Relation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RView", "ObjectName",
  CellTags->"RView"],

Cell["Type: option", "Highlight",
  CellTags->"RView"],

Cell[TextData[{
  StyleBox["RView", "MR"],
  "  is an option for PlotMatrix."
}], "Usage",
  CellTags->"RView"],

Cell[TextData[{
  "See ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RView"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SetClosure", "ObjectName",
  CellTags->"SetClosure"],

Cell["Type: option", "Highlight",
  CellTags->"SetClosure"],

Cell[TextData[{
  StyleBox["SetClosure", "MR"],
  "  is an option in ",
  StyleBox["Closure", "MR"],
  " and ",
  StyleBox["ClosureSearch", "MR"],
  " that determines the signature of the closure function."
}], "Usage",
  CellTags->"SetClosure"],

Cell[TextData[{
  "See ",
  ButtonBox["Closure",
    ButtonData:>"Closure",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ClosureSearch",
    ButtonData:>"ClosureSearch",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SetClosure"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Type", "ObjectName",
  CellTags->"Type"],

Cell["Type: option", "Highlight",
  CellTags->"Type"],

Cell[TextData[{
  StyleBox["Type", "MR"],
  "  is an option for ",
  StyleBox["ToClasses", "MR"],
  ". "
}], "Usage",
  CellTags->"Type"],

Cell[TextData[{
  "Possible values are: ",
  StyleBox["Relation", "MR"],
  " (default), ",
  StyleBox["Function", "MR"],
  ", ",
  StyleBox["Matrix", "MR"],
  ", ",
  StyleBox["Index", "MR"],
  "."
}], "Notes",
  CellTags->"Type"],

Cell[TextData[{
  "See ",
  ButtonBox["ToClasses",
    ButtonData:>"ToClasses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Type"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Where", "ObjectName",
  CellTags->"Where"],

Cell["Type: option", "Highlight",
  CellTags->"Where"],

Cell[TextData[{
  ButtonBox["Where",
    ButtonData:>"Where",
    ButtonStyle->"AddOnsLink"],
  "  is an option for ",
  ButtonBox["SeedConfiguration",
    ButtonData:>"SeedConfiguration",
    ButtonStyle->"AddOnsLink"],
  " that controls positioning of the seed pattern. "
}], "Usage",
  CellTags->"Where"],

Cell[TextData[{
  "Default is ",
  StyleBox["Center", "MR"],
  ", other possible values are ",
  StyleBox["Left", "MR"],
  " or ",
  StyleBox["Right", "MR"],
  "."
}], "Notes",
  CellTags->"Where"],

Cell[TextData[{
  "See also ",
  StyleBox["EvolutionCA", "MR"],
  ", ",
  StyleBox["OrbitCA", "MR"],
  "."
}], "Notes",
  CellTags->"Where"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Where"],

Cell["\<\
Some lists suitable as starting configurations for cellular \
automata.\
\>", "ExampleText",
  CellTags->"Where"],

Cell[CellGroupData[{

Cell["SeedConfiguration[{1,2},10]", "Input",
  CellLabel->"In[96]:=",
  CellTags->"Where"],

Cell[BoxData[
    \({0, 0, 0, 0, 1, 2, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[96]=",
  CellTags->"Where"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SeedConfiguration[{1,2},10,Where->Left]", "Input",
  CellLabel->"In[98]:=",
  CellTags->"Where"],

Cell[BoxData[
    \({1, 2, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[98]=",
  CellTags->"Where"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SeedConfiguration[{1,2},10,Where->Right]", "Input",
  CellLabel->"In[99]:=",
  CellTags->"Where"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 1, 2}\)], "Output",
  CellLabel->"Out[99]=",
  CellTags->"Where"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Witnesses", "ObjectName",
  CellTags->"Witnesses"],

Cell["Type: function", "Highlight",
  CellTags->"Witnesses"],

Cell[TextData[{
  StyleBox["Witnesses[ind]", "MR"],
  "  returns a bit vector for the representatives for each class in an \
equivalence relation given by an index ",
  StyleBox["ind", "MR"],
  "."
}], "Usage",
  CellTags->"Witnesses"],

Cell[TextData[{
  "See ",
  ButtonBox["MakeIndex",
    ButtonData:>"MakeIndex",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToClasses",
    ButtonData:>"ToClasses",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Witnesses"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Witnesses"],

Cell[TextData[{
  "An index obtained on carrier set ",
  Cell[BoxData[
      FormBox[
        RowBox[{\([12]\), Cell[""]}], TraditionalForm]]],
  " from congruence modulo 5. "
}], "ExampleText",
  CellTags->"Witnesses"],

Cell[BoxData[
    \(\(ind\  = \ {1, 2, 3, 4, 5, 1, 2, 3, 4, 5, 1, 2};\)\)], "Input",
  CellLabel->"In[173]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToClasses[\ Range[12], \ ind, \ Type \[Rule] Index\ ]\)], "Input",
  CellLabel->"In[174]:="],

Cell[BoxData[
    \({{1, 6, 11}, {2, 7, 12}, {3, 8}, {4, 9}, {5, 10}}\)], "Output",
  CellLabel->"Out[174]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Witnesses[\ ind\ ]\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \({1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[175]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DC", "ObjectName",
  CellTags->"DC"],

Cell["Type: header", "Highlight",
  CellTags->"DC"],

Cell[TextData[{
  StyleBox["DC[L,R,H]", "MR"],
  "  is an expression denoting a D-class in a transformation semigroup. "
}], "Usage",
  CellTags->"DC"],

Cell[TextData[{
  StyleBox["H", "MR"],
  " is the basic H-class, ",
  StyleBox["L", "MR"],
  " a list of left multipliers and ",
  StyleBox["R", "MR"],
  " a list of right multipliers."
}], "Notes",
  CellTags->"DC"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DClassDimensions",
    ButtonData:>"DClassDimensions",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DClassSize",
    ButtonData:>"DClassSize",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"DC"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"DC"],

Cell["A  D-class, its size and its dimensions.", "ExampleText",
  CellTags->"DClassToBlocks"],

Cell[BoxData[
    \(\(d\  = \ 
        DC[{T[1, 1, 1, 4], T[1, 1, 4, 1], T[1, 1, 4, 4], T[1, 4, 1, 1], 
            T[1, 4, 1, 4], T[1, 4, 4, 1], T[1, 4, 4, 4]}, {T[1, 1, 1, 2], 
            T[1, 1, 1, 3], T[1, 1, 1, 4], T[2, 1, 1, 3], T[2, 1, 1, 4], 
            T[3, 1, 1, 4]}, {T[1, 1, 1, 4], T[4, 4, 4, 1]}];\)\)], "Input",
  CellLabel->"In[150]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DClassDimensions[d]\), "\n", 
    \(DClassSize[d]\)}], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \({7, 6, 2}\)], "Output",
  CellLabel->"Out[151]="],

Cell[BoxData[
    \(84\)], "Output",
  CellLabel->"Out[152]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GEN", "ObjectName",
  CellTags->"GEN"],

Cell["Type: header", "Highlight",
  CellTags->"GEN"],

Cell[TextData[{
  StyleBox["GEN[n,k,{g1,...,gk}]", "MR"],
  "  is a collection of k generators, suitable as input to ",
  StyleBox["GenerateSG", "MR"],
  ". "
}], "Usage",
  CellTags->"GEN"],

Cell[TextData[{
  " The generators ",
  StyleBox["gi", "MR"],
  " can be transformations of size ",
  StyleBox["n", "MR"],
  " or ",
  StyleBox["n", "MR"],
  " by ",
  StyleBox["n", "MR"],
  " matrices over a semiring."
}], "Notes",
  CellTags->"GEN"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SG",
    ButtonData:>"SG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"GEN"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graph", "ObjectName",
  CellTags->"Graph"],

Cell["Type: header", "Highlight",
  CellTags->"Graph"],

Cell[TextData[{
  StyleBox["Graph[n,e,t,A]", "MR"],
  "  represents a directed graph on ",
  StyleBox["n", "MR"],
  " nodes and ",
  StyleBox["e", "MR"],
  " edges with adjacencies given by A. Field ",
  StyleBox["t", "MR"],
  " indicates the type of the graph. "
}], "Usage",
  CellTags->"Graph"],

Cell[TextData[{
  " ",
  StyleBox["A", "MR"],
  " can be an edge list (",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  "), a labeled edge list (",
  Cell[BoxData[
      \(TraditionalForm\`t = 2\)]],
  "), an adjacency matrix (",
  Cell[BoxData[
      \(TraditionalForm\`t = 3\)]],
  "), or an adjacency list (",
  Cell[BoxData[
      \(TraditionalForm\`t = 4\)]],
  "). "
}], "Notes",
  CellTags->"Graph"],

Cell[TextData[{
  "There is a hidden field ",
  StyleBox["V", "MR"],
  " for the underlying vertex set. V can be empty (in which case the vertex \
set is assumed to be ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, \[Ellipsis], n}\)]],
  ") or as an arbitrary list of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". "
}], "Notes"],

Cell[TextData[{
  "See also ",
  ButtonBox["Edges",
    ButtonData:>"Edges",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["VertexSet",
    ButtonData:>"VertexSet",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["WeaklyConnectedComponents",
    ButtonData:>"WeaklyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["StronglyConnectedComponents",
    ButtonData:>"StronglyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NormalizeGraph",
    ButtonData:>"NormalizeGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"Graph"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"Graph"],

Cell["A simple 4-point graph, in edge-list representation.", "ExampleText",
  CellTags->"Graph"],

Cell[BoxData[
    \(\(g = Graph[4, 4, 1, {{1, 2}, {2, 3}, {3, 1}, {4, 1}}];\)\)], "Input",
  CellLabel->"In[160]:=",
  CellTags->"Graph"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Edges[g]\), "\n", 
    \(VertexSet[g]\)}], "Input",
  CellLabel->"In[161]:="],

Cell[BoxData[
    \({{1, 2}, {2, 3}, {3, 1}, {4, 1}}\)], "Output",
  CellLabel->"Out[161]="],

Cell[BoxData[
    \({1, 2, 3, 4}\)], "Output",
  CellLabel->"Out[162]="]
}, Open  ]],

Cell["\<\
The same graph in adjacency matrix and adjacency list \
representation.\
\>", "ExampleText",
  CellTags->"Graph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToAdjMatrix[g]\)], "Input",
  CellLabel->"In[165]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"4", ",", "4", ",", "3", ",", 
          
          TagBox[\({{0, 1, 0, 0}, {0, 0, 1, 0}, {1, 0, 0, 0}, {1, 0, 0, 
                0}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[165]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToAdjList[g]\)], "Input",
  CellLabel->"In[166]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"Graph", "[", 
        RowBox[{"4", ",", "4", ",", "4", ",", 
          TagBox[\({{2}, {3}, {1}, {1}}\),
            (Short[ #, 4]&)]}], "]"}],
      HoldForm]], "Output",
  CellLabel->"Out[166]="]
}, Open  ]],

Cell["Some connected components.", "ExampleText",
  CellTags->"Graph"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WeaklyConnectedComponents[g, 3]\)], "Input",
  CellLabel->"In[169]:="],

Cell[BoxData[
    \({1, 2, 3}\)], "Output",
  CellLabel->"Out[169]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StronglyConnectedComponents[g]\)], "Input",
  CellLabel->"In[168]:="],

Cell[BoxData[
    \({{1, 2, 3}, {4}}\)], "Output",
  CellLabel->"Out[168]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["SG", "ObjectName",
  CellTags->"SG"],

Cell["Type: header", "Highlight",
  CellTags->"SG"],

Cell[TextData[{
  StyleBox["SG", "MR"],
  "  is a header used for transformation semigroups."
}], "Usage",
  CellTags->"SG"],

Cell[TextData[{
  " Elements are transformations, i.e., expressions of the form ",
  StyleBox["T[a1,..,an]", "MR"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`1\  \[LessEqual] \ a\_\(\(\ \)\(i\)\) \[LessEqual] \ 
        n\)]],
  "."
}], "Notes",
  CellTags->"SG"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["SymmetricGroupSG",
    ButtonData:>"SymmetricGroupSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[", ", "Text"],
  ButtonBox["AlternatingGroupSG",
    ButtonData:>"AlternatingGroupSG",
    ButtonStyle->"AddOnsLink"],
  StyleBox[",", "Text"],
  " ",
  ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"SG"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SG"],

Cell["\<\
The symmetric group on 3 points is in particular a semigroup.\
\>", \
"ExampleText",
  CellTags->"SG"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SymmetricGroupSG[3]\)], "Input",
  CellLabel->"In[85]:=",
  CellTags->"SG"],

Cell[BoxData[
    \(SG[T[1, 2, 3], T[1, 3, 2], T[2, 1, 3], T[2, 3, 1], T[3, 1, 2], 
      T[3, 2, 1]]\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["T", "ObjectName",
  CellTags->"T"],

Cell["Type: header", "Highlight",
  CellTags->"T"],

Cell[TextData[{
  StyleBox["T[a1,...,ak]", "MR"],
  "  denotes an element in a transformation semigroup"
}], "Usage",
  CellTags->"T"],

Cell[TextData[{
  "We must have  ",
  Cell[BoxData[
      \(TraditionalForm\`1\  \[LessEqual] \ a\_\(\(\ \)\(i\)\) \[LessEqual] \ 
        n\)]],
  ". "
}], "Notes",
  CellTags->"T"],

Cell[TextData[{
  "Composition is defined on ",
  StyleBox["NonCommutativeMultiply", "MR"],
  " and uses diagrammatic order:  ",
  StyleBox["s**t", "MR"],
  "  means: apply ",
  StyleBox["s", "MR"],
  " first, then apply ",
  StyleBox["t", "MR"],
  "."
}], "Notes"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["OrderT",
    ButtonData:>"OrderT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["RankT",
    ButtonData:>"RankT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ImageT",
    ButtonData:>"ImageT",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["KernelT",
    ButtonData:>"KernelT",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"T"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"T"],

Cell["Some transformations and their products.", "ExampleText",
  CellTags->"T"],

Cell[CellGroupData[{

Cell["\<\
s = T[2,3,1,1]
t = T[2,1,4,3]\
\>", "Input",
  CellLabel->"In[151]:=",
  CellTags->"T"],

Cell[BoxData[
    \(T[2, 3, 1, 1]\)], "Output",
  CellLabel->"Out[151]="],

Cell[BoxData[
    \(T[2, 1, 4, 3]\)], "Output",
  CellLabel->"Out[152]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(s ** t\), "\n", 
    \(t ** s\)}], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(T[1, 4, 2, 2]\)], "Output",
  CellLabel->"Out[153]="],

Cell[BoxData[
    \(T[3, 2, 1, 1]\)], "Output",
  CellLabel->"Out[154]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["$closureBound", "ObjectName",
  CellTags->"closureBound"],

Cell["Type: sysvar", "Highlight",
  CellTags->"closureBound"],

Cell[TextData[{
  StyleBox["$closureBound", "MR"],
  "  is a default bound for the number of steps taken in ",
  StyleBox["Closure.", "MR"]
}], "Usage",
  CellTags->"closureBound"],

Cell[" Default value is 10 to guard against exponential blow-up.", "Notes",
  CellTags->"closureBound"],

Cell[TextData[{
  "See ",
  ButtonBox["Closure",
    ButtonData:>"Closure",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"closureBound"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$closureSearchBound", "ObjectName",
  CellTags->"closureSearchBound"],

Cell["Type: sysvar", "Highlight",
  CellTags->"closureSearchBound"],

Cell[TextData[{
  StyleBox["$closureSearchBound", "MR"],
  "   is a default bound for ",
  StyleBox["ClosureSearch", "MR"],
  ". "
}], "Usage",
  CellTags->"closureSearchBound"],

Cell["\<\
Default value is 500 for the size of closure set to be \
computed.\
\>", "Notes",
  CellTags->"closureSearchBound"],

Cell[TextData[{
  "See ",
  ButtonBox["ClosureSearch",
    ButtonData:>"ClosureSearch",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"closureSearchBound"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$defaultexternal", "ObjectName",
  CellTags->"defaultexternal"],

Cell["Type: sysvar", "Highlight",
  CellTags->"defaultexternal"],

Cell[TextData[{
  StyleBox["$defaultexternal", "MR"],
  "  determines whether an external algorithm is used in a number of \
commands."
}], "Usage",
  CellTags->"defaultexternal"],

Cell[TextData[{
  "Is set to ",
  StyleBox["True", "MR"],
  " automatically if the ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  "  connection to ",
  StyleBox["extaut", "Input"],
  " has been properly established."
}], "Notes",
  CellTags->"defaultexternal"],

Cell[TextData[{
  "Can be overridden locally using option ",
  StyleBox["External->False", "MR"],
  "."
}], "Notes",
  CellTags->"defaultexternal"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MinimizeFA",
    ButtonData:>"MinimizeFA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"defaultexternal"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$deffatline", "ObjectName",
  CellTags->"deffatline"],

Cell["Type: sysvar", "Highlight",
  CellTags->"deffatline"],

Cell[TextData[{
  StyleBox["$deffatline", "MR"],
  "   controls the width of emphasized lines in ",
  StyleBox["PlotTDGraph", "MR"],
  ". "
}], "Usage",
  CellTags->"deffatline"],

Cell[TextData[{
  "The default is 0.005 and can be changed via option ",
  StyleBox["LineStyle", "MR"],
  "."
}], "Notes",
  CellTags->"deffatline"],

Cell[TextData[{
  "See also ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"deffatline"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$deflabeloffset", "ObjectName",
  CellTags->"deflabeloffset"],

Cell["Type: sysvar", "Highlight",
  CellTags->"deflabeloffset"],

Cell[TextData[{
  StyleBox["$deflabeloffset", "MR"],
  "   controls the position of labels in ",
  StyleBox["GridPoints", "MR"],
  ". "
}], "Usage",
  CellTags->"deflabeloffset"],

Cell["Default value is 0.2.", "Notes",
  CellTags->"deflabeloffset"],

Cell[TextData[{
  "See also ",
  ButtonBox["GridPoints",
    ButtonData:>"GridPoints",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"deflabeloffset"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$defpointsize", "ObjectName",
  CellTags->"defpointsize"],

Cell["Type: sysvar", "Highlight",
  CellTags->"defpointsize"],

Cell[TextData[{
  StyleBox["$defpointsize", "MR"],
  "  controls the pointsize in function ",
  StyleBox["GridPoints", "MR"],
  ". "
}], "Usage",
  CellTags->"defpointsize"],

Cell[TextData[{
  "The default is 0.012 and can be changed via option ",
  StyleBox["PlotStyle", "MR"],
  "."
}], "Notes",
  CellTags->"defpointsize"],

Cell[TextData[{
  "See also ",
  ButtonBox["GridPoints",
    ButtonData:>"GridPoints",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"defpointsize"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"defpointsize"],

Cell[TextData[{
  "Controlling point size in ",
  StyleBox["GridPoints", "MR"],
  "."
}], "ExampleText",
  CellTags->"defpointsize"],

Cell[CellGroupData[{

Cell["GridPoints[4,4] // Show;", "Input",
  CellLabel->"In[103]:=",
  CellTags->"defpointsize"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0434783 0.217391 -0.026871 0.134355 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.012 w
.17391 .10748 Mdot
.17391 .24184 Mdot
.17391 .37619 Mdot
.17391 .51055 Mdot
.3913 .10748 Mdot
.3913 .24184 Mdot
.3913 .37619 Mdot
.3913 .51055 Mdot
.6087 .10748 Mdot
.6087 .24184 Mdot
.6087 .37619 Mdot
.6087 .51055 Mdot
.82609 .10748 Mdot
.82609 .24184 Mdot
.82609 .37619 Mdot
.82609 .51055 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[103]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"defpointsize"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Block[{$defpointsize = 0.05}, GridPoints[4, 4]] // Show;\)\)], "Input",\

  CellLabel->"In[105]:=",
  CellTags->"defpointsize"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0434783 0.217391 -0.026871 0.134355 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.05 w
.17391 .10748 Mdot
.17391 .24184 Mdot
.17391 .37619 Mdot
.17391 .51055 Mdot
.3913 .10748 Mdot
.3913 .24184 Mdot
.3913 .37619 Mdot
.3913 .51055 Mdot
.6087 .10748 Mdot
.6087 .24184 Mdot
.6087 .37619 Mdot
.6087 .51055 Mdot
.82609 .10748 Mdot
.82609 .24184 Mdot
.82609 .37619 Mdot
.82609 .51055 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[105]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  CellTags->"defpointsize"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["$defthinline", "ObjectName",
  CellTags->"defthinline"],

Cell["Type: sysvar", "Highlight",
  CellTags->"defthinline"],

Cell[TextData[{
  StyleBox["$defthinline", "MR"],
  " controls the width of plain lines in ",
  StyleBox["PlotTDGraph", "MR"],
  ". "
}], "Usage",
  CellTags->"defthinline"],

Cell[TextData[{
  "The default is 0.005 and can be changed via option ",
  StyleBox["LineStyle", "MR"],
  "."
}], "Notes",
  CellTags->"defthinline"],

Cell[TextData[{
  "See also ",
  ButtonBox["GridLine",
    ButtonData:>"GridLine",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PlotTDGraph",
    ButtonData:>"PlotTDGraph",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"defthinline"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"defthinline"],

Cell[TextData[{
  "Controlling line thickness in ",
  StyleBox["GridLine", "MR"],
  "."
}], "ExampleText",
  CellTags->"defthinline"],

Cell[CellGroupData[{

Cell["GridLine[4,4] // Show;", "Input",
  CellLabel->"In[100]:=",
  CellTags->"defthinline"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0434783 0.217391 -0.026871 0.134355 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 g
.003 w
[ ] 0 setdash
.17391 .10748 m
.17391 .51055 L
s
.3913 .10748 m
.3913 .51055 L
s
.6087 .10748 m
.6087 .51055 L
s
.82609 .10748 m
.82609 .51055 L
s
.17391 .10748 m
.82609 .10748 L
s
.17391 .24184 m
.82609 .24184 L
s
.17391 .37619 m
.82609 .37619 L
s
.17391 .51055 m
.82609 .51055 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[100]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Block[{$defthinline=0.02},
GridLine[4,4]] // Show;\
\>", "Input",
  CellLabel->"In[101]:=",
  CellTags->"defthinline"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0434783 0.217391 -0.026871 0.134355 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.8 g
.02 w
[ ] 0 setdash
.17391 .10748 m
.17391 .51055 L
s
.3913 .10748 m
.3913 .51055 L
s
.6087 .10748 m
.6087 .51055 L
s
.82609 .10748 m
.82609 .51055 L
s
.17391 .10748 m
.82609 .10748 L
s
.17391 .24184 m
.82609 .24184 L
s
.17391 .37619 m
.82609 .37619 L
s
.17391 .51055 m
.82609 .51055 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[101]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]],

Cell["\<\
Block[{$defthinline=0.02},
GridLine[4,4]] // Show;\
\>", "Input",
  CellLabel->"In[101]:=",
  CellTags->"defthinline"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["$dimathReleaseNumber", "ObjectName",
  CellTags->"dimathReleaseNumber"],

Cell["Type: sysvar", "Highlight",
  CellTags->"dimathReleaseNumber"],

Cell[TextData[{
  StyleBox["$dimathReleaseNumber", "MR"],
  "   is the release number of the loaded dimath package."
}], "Usage",
  CellTags->"dimathReleaseNumber"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$generateSGBound", "ObjectName",
  CellTags->"generateSGBound"],

Cell["Type: sysvar", "Highlight",
  CellTags->"generateSGBound"],

Cell[TextData[{
  StyleBox["$generateSGBound", "MR"],
  "  is a default bound for the size of a semigroup generated by ",
  StyleBox["GenerateSG", "MR"],
  ". "
}], "Usage",
  CellTags->"generateSGBound"],

Cell["Default is 1000.", "Notes",
  CellTags->"generateSGBound"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"generateSGBound"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$identitystring", "ObjectName",
  CellTags->"identitystring"],

Cell["Type: sysvar", "Highlight",
  CellTags->"identitystring"],

Cell[TextData[{
  StyleBox["$identitystring", "MR"],
  "   denotes the identity element of a monoid in rewrite rules produced by \
",
  StyleBox["GenerateSG", "MR"],
  "."
}], "Usage",
  CellTags->"identitystring"],

Cell["\<\
 Default is 1 and should be changed if digit alphabets are \
used.\
\>", "Notes",
  CellTags->"identitystring"],

Cell[TextData[{
  "See ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToIdentityString",
    ButtonData:>"ToIdentityString",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"identitystring"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$nullstring", "ObjectName",
  CellTags->"nullstring"],

Cell["Type: sysvar", "Highlight",
  CellTags->"nullstring"],

Cell[TextData[{
  StyleBox["$nullstring", "MR"],
  "   denotes the null element of a semigroup in rewrite rules produced by ",
  StyleBox["GenerateSG", "MR"],
  ". "
}], "Usage",
  CellTags->"nullstring"],

Cell["\<\
Default is 0 and should be changed if digit alphabets are \
used.\
\>", "Notes",
  CellTags->"nullstring"],

Cell[TextData[{
  "See ",
  ButtonBox["SimplifyEquations",
    ButtonData:>"SimplifyEquations",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["WordReduce",
    ButtonData:>"WordReduce",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"nullstring"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$plotrangeoffset", "ObjectName",
  CellTags->"plotrangeoffset"],

Cell["Type: sysvar", "Highlight",
  CellTags->"plotrangeoffset"],

Cell[TextData[{
  StyleBox["$plotrangeoffset", "MR"],
  "   controls the offset for ",
  StyleBox["MakePlotRange", "MR"],
  ". "
}], "Usage",
  CellTags->"plotrangeoffset"],

Cell["Default value is 0.8.", "Notes",
  CellTags->"plotrangeoffset"],

Cell[TextData[{
  "See ",
  ButtonBox["MakePlotRange",
    ButtonData:>"MakePlotRange",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"plotrangeoffset"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$rastercolors", "ObjectName",
  CellTags->"rastercolors"],

Cell["Type: sysvar", "Highlight",
  CellTags->"rastercolors"],

Cell[TextData[{
  StyleBox["$rastercolors", "MR"],
  "   is a list of rules that determines plot colors for raster array plots. \
"
}], "Usage",
  CellTags->"rastercolors"],

Cell["Array elements must be non-negative integers less than 10.", "Notes",
  CellTags->"rastercolors"],

Cell[TextData[{
  "See also  ",
  ButtonBox["PlotMatrix",
    ButtonData:>"PlotMatrix",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["HueRasterColors",
    ButtonData:>"HueRasterColors",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"rastercolors"]
}, Open  ]],

Cell[CellGroupData[{

Cell["$rewriteSimpBound", "ObjectName",
  CellTags->"rewriteSimpBound"],

Cell["Type: sysvar", "Highlight",
  CellTags->"rewriteSimpBound"],

Cell[TextData[{
  StyleBox["$rewriteSimpBound", "MR"],
  "  is a default bound for the number of transformation steps taken in the \
normalization algorithm for rewrite systems. "
}], "Usage",
  CellTags->"rewriteSimpBound"],

Cell["Default value is 100.", "Notes",
  CellTags->"rewriteSimpBound"],

Cell[TextData[{
  "See ",
  ButtonBox["SimplifyRewriteSystem",
    ButtonData:>"SimplifyRewriteSystem",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"rewriteSimpBound"]
}, Open  ]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{824, 996},
WindowMargins->{{Automatic, 68}, {Automatic, 0}},
LanguageCategory->"Mathematica",
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "AccCoaccGraph"->{
    Cell[1776, 53, 64, 1, 42, "ObjectName",
      CellTags->"AccCoaccGraph"],
    Cell[1843, 56, 64, 1, 74, "Highlight",
      CellTags->"AccCoaccGraph"],
    Cell[1910, 59, 283, 10, 64, "Usage",
      CellTags->"AccCoaccGraph"],
    Cell[2196, 71, 123, 4, 33, "Notes",
      CellTags->"AccCoaccGraph"],
    Cell[2322, 77, 181, 6, 33, "Notes",
      CellTags->"AccCoaccGraph"],
    Cell[2506, 85, 476, 20, 33, "Notes",
      CellTags->"AccCoaccGraph"],
    Cell[3007, 109, 71, 1, 59, "ExampleSection",
      CellTags->"AccCoaccGraph"],
    Cell[3081, 112, 148, 4, 70, "ExampleText",
      CellTags->"AccCoaccGraph"],
    Cell[3232, 118, 208, 6, 70, "Input",
      CellTags->"AccCoaccGraph"],
    Cell[3465, 128, 96, 2, 70, "Input",
      CellTags->"AccCoaccGraph"],
    Cell[3564, 132, 330, 10, 70, "Output",
      CellTags->"AccCoaccGraph"],
    Cell[3909, 145, 137, 4, 70, "ExampleText",
      CellTags->"AccCoaccGraph"],
    Cell[4071, 153, 117, 5, 70, "Input",
      CellTags->"AccCoaccGraph"],
    Cell[4191, 160, 262, 8, 70, "Output",
      CellTags->"AccCoaccGraph"],
    Cell[4456, 170, 98, 3, 70, "Output",
      CellTags->"AccCoaccGraph"]},
  "AccessibleGraph"->{
    Cell[4615, 180, 68, 1, 42, "ObjectName",
      CellTags->"AccessibleGraph"],
    Cell[4686, 183, 66, 1, 74, "Highlight",
      CellTags->"AccessibleGraph"],
    Cell[4755, 186, 330, 11, 64, "Usage",
      CellTags->"AccessibleGraph"],
    Cell[5088, 199, 137, 4, 33, "Notes",
      CellTags->"AccessibleGraph"],
    Cell[5228, 205, 450, 19, 33, "Notes",
      CellTags->"AccessibleGraph"],
    Cell[5703, 228, 73, 1, 59, "ExampleSection",
      CellTags->"AccessibleGraph"],
    Cell[5779, 231, 73, 1, 70, "ExampleText",
      CellTags->"AccessibleGraph"],
    Cell[5877, 236, 103, 2, 70, "Input",
      CellTags->"AccessibleGraph"],
    Cell[5983, 240, 459, 11, 70, "Output",
      CellTags->"AccessibleGraph"],
    Cell[6457, 254, 104, 1, 70, "ExampleText",
      CellTags->"AccessibleGraph"],
    Cell[6586, 259, 115, 5, 70, "Input",
      CellTags->"AccessibleGraph"],
    Cell[6704, 266, 357, 10, 70, "Output",
      CellTags->"AccessibleGraph"],
    Cell[7064, 278, 106, 3, 70, "Output",
      CellTags->"AccessibleGraph"],
    Cell[7185, 284, 92, 1, 70, "ExampleText",
      CellTags->"AccessibleGraph"],
    Cell[7302, 289, 111, 2, 70, "Input",
      CellTags->"AccessibleGraph"],
    Cell[7416, 293, 122, 3, 70, "Output",
      CellTags->"AccessibleGraph"]},
  "AlgebraicForm"->{
    Cell[7599, 303, 64, 1, 42, "ObjectName",
      CellTags->"AlgebraicForm"],
    Cell[7666, 306, 64, 1, 74, "Highlight",
      CellTags->"AlgebraicForm"],
    Cell[7733, 309, 199, 6, 43, "Usage",
      CellTags->"AlgebraicForm"],
    Cell[7935, 317, 867, 25, 34, "Notes",
      CellTags->"AlgebraicForm"]},
  "AllStringReplace"->{
    Cell[8839, 347, 70, 1, 42, "ObjectName",
      CellTags->"AllStringReplace"],
    Cell[8912, 350, 69, 1, 74, "Highlight",
      CellTags->"AllStringReplace"],
    Cell[8984, 353, 256, 8, 64, "Usage",
      CellTags->"AllStringReplace"],
    Cell[9243, 363, 247, 7, 54, "Notes",
      CellTags->"AllStringReplace"],
    Cell[9493, 372, 124, 5, 33, "Notes",
      CellTags->"AllStringReplace"],
    Cell[9620, 379, 159, 7, 33, "Notes",
      CellTags->"AllStringReplace"],
    Cell[9804, 390, 74, 1, 59, "ExampleSection",
      CellTags->"AllStringReplace"],
    Cell[9881, 393, 103, 1, 48, "ExampleText",
      CellTags->"AllStringReplace"],
    Cell[10009, 398, 113, 2, 40, "Input",
      CellTags->"AllStringReplace"],
    Cell[10125, 402, 104, 3, 30, "Output",
      CellTags->"AllStringReplace"],
    Cell[10266, 410, 145, 3, 37, "Input",
      CellTags->"AllStringReplace"],
    Cell[10414, 415, 103, 3, 30, "Output",
      CellTags->"AllStringReplace"],
    Cell[10554, 423, 138, 3, 37, "Input",
      CellTags->"AllStringReplace"],
    Cell[10695, 428, 114, 3, 30, "Output",
      CellTags->"AllStringReplace"]},
  "AllTimes"->{
    Cell[10870, 438, 54, 1, 42, "ObjectName",
      CellTags->"AllTimes"],
    Cell[10927, 441, 59, 1, 74, "Highlight",
      CellTags->"AllTimes"],
    Cell[10989, 444, 261, 10, 64, "Usage",
      CellTags->"AllTimes"],
    Cell[11253, 456, 86, 1, 33, "Notes",
      CellTags->"AllTimes"],
    Cell[11342, 459, 319, 15, 33, "Notes",
      CellTags->"AllTimes"],
    Cell[11686, 478, 66, 1, 59, "ExampleSection",
      CellTags->"AllTimes"],
    Cell[11755, 481, 107, 2, 48, "ExampleText",
      CellTags->"AllTimes"],
    Cell[11887, 487, 117, 2, 40, "Input",
      CellTags->"AllTimes"],
    Cell[12007, 491, 131, 3, 30, "Output",
      CellTags->"AllTimes"],
    Cell[12153, 497, 130, 4, 48, "ExampleText",
      CellTags->"AllTimes"],
    Cell[12308, 505, 118, 5, 64, "Input",
      CellTags->"AllTimes"],
    Cell[12429, 512, 186, 4, 53, "Output",
      CellTags->"AllTimes"],
    Cell[12618, 518, 162, 4, 53, "Output",
      CellTags->"AllTimes"]},
  "AlternatingGroupSG"->{
    Cell[12841, 529, 74, 1, 42, "ObjectName",
      CellTags->"AlternatingGroupSG"],
    Cell[12918, 532, 230, 6, 64, "Usage",
      CellTags->"AlternatingGroupSG"],
    Cell[13151, 540, 258, 9, 33, "Notes",
      CellTags->"AlternatingGroupSG"],
    Cell[13412, 551, 437, 19, 33, "Notes",
      CellTags->"AlternatingGroupSG"],
    Cell[13874, 574, 76, 1, 59, "ExampleSection",
      CellTags->"AlternatingGroupSG"],
    Cell[13953, 577, 94, 1, 48, "ExampleText",
      CellTags->"AlternatingGroupSG"],
    Cell[14072, 582, 128, 5, 64, "Input",
      CellTags->"AlternatingGroupSG"],
    Cell[14203, 589, 291, 6, 76, "Output",
      CellTags->"AlternatingGroupSG"],
    Cell[14497, 597, 129, 3, 30, "Output",
      CellTags->"AlternatingGroupSG"]},
  "AnalyzeOrbit"->{
    Cell[14687, 607, 62, 1, 42, "ObjectName",
      CellTags->"AnalyzeOrbit"],
    Cell[14752, 610, 63, 1, 74, "Highlight",
      CellTags->"AnalyzeOrbit"],
    Cell[14818, 613, 472, 15, 85, "Usage",
      CellTags->"AnalyzeOrbit"],
    Cell[15293, 630, 292, 10, 80, "Notes",
      CellTags->"AnalyzeOrbit"],
    Cell[15588, 642, 250, 7, 54, "Notes",
      CellTags->"AnalyzeOrbit"],
    Cell[15841, 651, 179, 5, 33, "Notes",
      CellTags->"AnalyzeOrbit"],
    Cell[16023, 658, 261, 9, 54, "Notes",
      CellTags->"AnalyzeOrbit"],
    Cell[16287, 669, 239, 11, 33, "Notes",
      CellTags->"AnalyzeOrbit"],
    Cell[16551, 684, 70, 1, 59, "ExampleSection",
      CellTags->"AnalyzeOrbit"],
    Cell[16624, 687, 84, 1, 48, "ExampleText",
      CellTags->"AnalyzeOrbit"],
    Cell[16711, 690, 90, 2, 40, "Input",
      CellTags->"AnalyzeOrbit"],
    Cell[16826, 696, 104, 3, 37, "Input",
      CellTags->"AnalyzeOrbit"],
    Cell[16933, 701, 93, 3, 30, "Output",
      CellTags->"AnalyzeOrbit"],
    Cell[17063, 709, 104, 3, 37, "Input",
      CellTags->"AnalyzeOrbit"],
    Cell[17170, 714, 93, 3, 30, "Output",
      CellTags->"AnalyzeOrbit"],
    Cell[17300, 722, 124, 3, 37, "Input",
      CellTags->"AnalyzeOrbit"],
    Cell[17427, 727, 107, 3, 30, "Output",
      CellTags->"AnalyzeOrbit"],
    Cell[17571, 735, 125, 3, 37, "Input",
      CellTags->"AnalyzeOrbit"],
    Cell[17699, 740, 96, 3, 30, "Output",
      CellTags->"AnalyzeOrbit"],
    Cell[17810, 746, 159, 4, 69, "ExampleText",
      CellTags->"AnalyzeOrbit"],
    Cell[17994, 754, 208, 5, 83, "Input",
      CellTags->"AnalyzeOrbit"],
    Cell[18205, 761, 95, 3, 30, "Output",
      CellTags->"AnalyzeOrbit"],
    Cell[18315, 767, 163, 4, 37, "Input",
      CellTags->"AnalyzeOrbit"]},
  "AperiodicQSG"->{
    Cell[18527, 777, 62, 1, 42, "ObjectName",
      CellTags->"AperiodicQSG"],
    Cell[18592, 780, 63, 1, 74, "Highlight",
      CellTags->"AperiodicQSG"],
    Cell[18658, 783, 173, 6, 43, "Usage",
      CellTags->"AperiodicQSG"],
    Cell[18834, 791, 149, 5, 33, "Notes",
      CellTags->"AperiodicQSG"],
    Cell[18986, 798, 520, 23, 33, "Notes",
      CellTags->"AperiodicQSG"],
    Cell[19531, 825, 70, 1, 59, "ExampleSection",
      CellTags->"AperiodicQSG"],
    Cell[19604, 828, 122, 4, 70, "ExampleText",
      CellTags->"AperiodicQSG"],
    Cell[19729, 834, 557, 11, 70, "Input",
      CellTags->"AperiodicQSG"],
    Cell[20311, 849, 102, 3, 70, "Input",
      CellTags->"AperiodicQSG"],
    Cell[20416, 854, 92, 3, 70, "Output",
      CellTags->"AperiodicQSG"],
    Cell[20523, 860, 97, 1, 70, "ExampleText",
      CellTags->"AperiodicQSG"],
    Cell[20645, 865, 108, 2, 70, "Input",
      CellTags->"AperiodicQSG"],
    Cell[20756, 869, 93, 3, 70, "Output",
      CellTags->"AperiodicQSG"]},
  "AperiodicQT"->{
    Cell[20910, 879, 60, 1, 42, "ObjectName",
      CellTags->"AperiodicQT"],
    Cell[20973, 882, 62, 1, 74, "Highlight",
      CellTags->"AperiodicQT"],
    Cell[21038, 885, 175, 6, 43, "Usage",
      CellTags->"AperiodicQT"],
    Cell[21216, 893, 227, 9, 35, "Notes",
      CellTags->"AperiodicQT"],
    Cell[21446, 904, 521, 23, 33, "Notes",
      CellTags->"AperiodicQT"],
    Cell[21992, 931, 69, 1, 59, "ExampleSection",
      CellTags->"AperiodicQT"],
    Cell[22064, 934, 85, 1, 48, "ExampleText",
      CellTags->"AperiodicQT"],
    Cell[22174, 939, 129, 4, 60, "Input",
      CellTags->"AperiodicQT"],
    Cell[22306, 945, 103, 3, 30, "Output",
      CellTags->"AperiodicQT"],
    Cell[22412, 950, 92, 3, 30, "Output",
      CellTags->"AperiodicQT"],
    Cell[22519, 956, 98, 1, 48, "ExampleText",
      CellTags->"AperiodicQT"],
    Cell[22642, 961, 118, 3, 37, "Input",
      CellTags->"AperiodicQT"],
    Cell[22763, 966, 91, 3, 30, "Output",
      CellTags->"AperiodicQT"]},
  "AperiodicSG"->{
    Cell[22915, 976, 60, 1, 42, "ObjectName",
      CellTags->"AperiodicSG"],
    Cell[22978, 979, 62, 1, 74, "Highlight",
      CellTags->"AperiodicSG"],
    Cell[23043, 982, 172, 6, 43, "Usage",
      CellTags->"AperiodicSG"],
    Cell[23218, 990, 231, 9, 35, "Notes",
      CellTags->"AperiodicSG"],
    Cell[23452, 1001, 521, 23, 33, "Notes",
      CellTags->"AperiodicSG"],
    Cell[23998, 1028, 69, 1, 59, "ExampleSection",
      CellTags->"AperiodicSG"],
    Cell[24070, 1031, 140, 4, 48, "ExampleText",
      CellTags->"AperiodicSG"],
    Cell[24213, 1037, 118, 3, 37, "Input",
      CellTags->"AperiodicSG"],
    Cell[24356, 1044, 104, 5, 64, "Input",
      CellTags->"AperiodicSG"],
    Cell[24463, 1051, 295, 6, 99, "Output",
      CellTags->"AperiodicSG"],
    Cell[24761, 1059, 89, 3, 30, "Output",
      CellTags->"AperiodicSG"]},
  "AssignFunction"->{
    Cell[24911, 1069, 66, 1, 42, "ObjectName",
      CellTags->"AssignFunction"],
    Cell[24980, 1072, 65, 1, 74, "Highlight",
      CellTags->"AssignFunction"],
    Cell[25048, 1075, 202, 5, 64, "Usage",
      CellTags->"AssignFunction"],
    Cell[25253, 1082, 267, 7, 54, "Notes",
      CellTags->"AssignFunction"],
    Cell[25523, 1091, 277, 10, 80, "Notes",
      CellTags->"AssignFunction"],
    Cell[25803, 1103, 162, 5, 33, "Notes",
      CellTags->"AssignFunction"],
    Cell[25968, 1110, 173, 5, 33, "Notes",
      CellTags->"AssignFunction"],
    Cell[26144, 1117, 173, 5, 33, "Notes",
      CellTags->"AssignFunction"],
    Cell[26320, 1124, 158, 7, 33, "Notes",
      CellTags->"AssignFunction"],
    Cell[26503, 1135, 72, 1, 59, "ExampleSection",
      CellTags->"AssignFunction"],
    Cell[26578, 1138, 93, 1, 48, "ExampleText",
      CellTags->"AssignFunction"],
    Cell[26696, 1143, 122, 5, 64, "Input",
      CellTags->"AssignFunction"],
    Cell[26821, 1150, 90, 3, 30, "Output",
      CellTags->"AssignFunction"],
    Cell[26948, 1158, 193, 5, 60, "Input",
      CellTags->"AssignFunction"],
    Cell[27144, 1165, 99, 3, 30, "Output",
      CellTags->"AssignFunction"],
    Cell[27258, 1171, 130, 4, 48, "ExampleText",
      CellTags->"AssignFunction"],
    Cell[27413, 1179, 221, 5, 83, "Input",
      CellTags->"AssignFunction"],
    Cell[27637, 1186, 122, 3, 30, "Output",
      CellTags->"AssignFunction"],
    Cell[27762, 1191, 102, 3, 30, "Output",
      CellTags->"AssignFunction"],
    Cell[27901, 1199, 93, 3, 37, "Input",
      CellTags->"AssignFunction"],
    Cell[27997, 1204, 55, 1, 29, "Print",
      CellTags->"AssignFunction"],
    Cell[28055, 1207, 595, 19, 174, "Print",
      CellTags->"AssignFunction"]},
  "BlocksToDClass"->{
    Cell[28711, 1233, 66, 1, 42, "ObjectName",
      CellTags->"BlocksToDClass"],
    Cell[28780, 1236, 65, 1, 74, "Highlight",
      CellTags->"BlocksToDClass"],
    Cell[28848, 1239, 224, 6, 64, "Usage",
      CellTags->"BlocksToDClass"],
    Cell[29075, 1247, 114, 5, 33, "Notes",
      CellTags->"BlocksToDClass"],
    Cell[29192, 1254, 382, 10, 56, "Notes",
      CellTags->"BlocksToDClass"],
    Cell[29577, 1266, 160, 5, 33, "Notes",
      CellTags->"BlocksToDClass"],
    Cell[29740, 1273, 351, 15, 33, "Notes",
      CellTags->"BlocksToDClass"],
    Cell[30116, 1292, 72, 1, 59, "ExampleSection",
      CellTags->"BlocksToDClass"],
    Cell[30191, 1295, 171, 4, 70, "ExampleText",
      CellTags->"BlocksToDClass"],
    Cell[30365, 1301, 295, 5, 70, "Input",
      CellTags->"BlocksToDClass"],
    Cell[30685, 1310, 102, 3, 70, "Input",
      CellTags->"BlocksToDClass"],
    Cell[30790, 1315, 99, 3, 70, "Output",
      CellTags->"BlocksToDClass"],
    Cell[30926, 1323, 106, 3, 70, "Input",
      CellTags->"BlocksToDClass"],
    Cell[31035, 1328, 212, 4, 70, "Output",
      CellTags->"BlocksToDClass"]},
  "BooleanComplement"->{
    Cell[31308, 1339, 72, 1, 42, "ObjectName",
      CellTags->"BooleanComplement"],
    Cell[31383, 1342, 68, 1, 74, "Highlight",
      CellTags->"BooleanComplement"],
    Cell[31454, 1345, 324, 9, 64, "Usage",
      CellTags->"BooleanComplement"],
    Cell[31781, 1356, 155, 4, 33, "Notes",
      CellTags->"BooleanComplement"],
    Cell[31939, 1362, 818, 27, 54, "Notes",
      CellTags->"BooleanComplement"],
    Cell[32782, 1393, 75, 1, 59, "ExampleSection",
      CellTags->"BooleanComplement"],
    Cell[32860, 1396, 99, 1, 70, "ExampleText",
      CellTags->"BooleanComplement"],
    Cell[32962, 1399, 146, 5, 70, "Input",
      CellTags->"BooleanComplement"],
    Cell[33133, 1408, 99, 2, 70, "Input",
      CellTags->"BooleanComplement"],
    Cell[33235, 1412, 125, 3, 70, "Output",
      CellTags->"BooleanComplement"],
    Cell[33397, 1420, 96, 2, 70, "Input",
      CellTags->"BooleanComplement"],
    Cell[33496, 1424, 125, 3, 70, "Output",
      CellTags->"BooleanComplement"]},
  "BooleanComposition"->{
    Cell[33682, 1434, 74, 1, 42, "ObjectName",
      CellTags->"BooleanComposition"],
    Cell[33759, 1437, 69, 1, 74, "Highlight",
      CellTags->"BooleanComposition"],
    Cell[33831, 1440, 281, 8, 64, "Usage",
      CellTags->"BooleanComposition"],
    Cell[34115, 1450, 156, 4, 33, "Notes",
      CellTags->"BooleanComposition"],
    Cell[34274, 1456, 817, 27, 54, "Notes",
      CellTags->"BooleanComposition"],
    Cell[35116, 1487, 76, 1, 59, "ExampleSection",
      CellTags->"BooleanComposition"],
    Cell[35195, 1490, 199, 6, 70, "ExampleText",
      CellTags->"BooleanComposition"],
    Cell[35419, 1500, 111, 2, 70, "Input",
      CellTags->"BooleanComposition"],
    Cell[35533, 1504, 222, 4, 70, "Output",
      CellTags->"BooleanComposition"],
    Cell[35770, 1511, 134, 4, 70, "ExampleText",
      CellTags->"BooleanComposition"],
    Cell[35929, 1519, 165, 4, 70, "Input",
      CellTags->"BooleanComposition"],
    Cell[36097, 1525, 514, 13, 70, "Output",
      CellTags->"BooleanComposition"],
    Cell[36648, 1543, 174, 4, 70, "Input",
      CellTags->"BooleanComposition"],
    Cell[36825, 1549, 514, 13, 70, "Output",
      CellTags->"BooleanComposition"]},
  "BooleanConverse"->{
    Cell[37400, 1569, 68, 1, 42, "ObjectName",
      CellTags->"BooleanConverse"],
    Cell[37471, 1572, 66, 1, 74, "Highlight",
      CellTags->"BooleanConverse"],
    Cell[37540, 1575, 218, 6, 64, "Usage",
      CellTags->"BooleanConverse"],
    Cell[37761, 1583, 175, 7, 33, "Notes",
      CellTags->"BooleanConverse"],
    Cell[37939, 1592, 153, 4, 33, "Notes",
      CellTags->"BooleanConverse"],
    Cell[38095, 1598, 450, 15, 54, "Notes",
      CellTags->"BooleanConverse"],
    Cell[38570, 1617, 73, 1, 59, "ExampleSection",
      CellTags->"BooleanConverse"],
    Cell[38646, 1620, 214, 6, 70, "ExampleText",
      CellTags->"BooleanConverse"],
    Cell[38885, 1630, 133, 5, 70, "Input",
      CellTags->"BooleanConverse"],
    Cell[39021, 1637, 511, 13, 70, "Output",
      CellTags->"BooleanConverse"],
    Cell[39569, 1655, 105, 2, 70, "Input",
      CellTags->"BooleanConverse"],
    Cell[39677, 1659, 511, 13, 70, "Output",
      CellTags->"BooleanConverse"]},
  "BooleanIntersection"->{
    Cell[40249, 1679, 76, 1, 42, "ObjectName",
      CellTags->"BooleanIntersection"],
    Cell[40328, 1682, 70, 1, 74, "Highlight",
      CellTags->"BooleanIntersection"],
    Cell[40401, 1685, 292, 8, 64, "Usage",
      CellTags->"BooleanIntersection"],
    Cell[40696, 1695, 157, 4, 33, "Notes",
      CellTags->"BooleanIntersection"],
    Cell[40856, 1701, 816, 27, 54, "Notes",
      CellTags->"BooleanIntersection"],
    Cell[41697, 1732, 77, 1, 59, "ExampleSection",
      CellTags->"BooleanIntersection"],
    Cell[41777, 1735, 143, 4, 70, "ExampleText",
      CellTags->"BooleanIntersection"],
    Cell[41945, 1743, 144, 5, 70, "Input",
      CellTags->"BooleanIntersection"],
    Cell[42092, 1750, 515, 13, 70, "Output",
      CellTags->"BooleanIntersection"],
    Cell[42644, 1768, 147, 5, 70, "Input",
      CellTags->"BooleanIntersection"],
    Cell[42794, 1775, 515, 13, 70, "Output",
      CellTags->"BooleanIntersection"],
    Cell[43346, 1793, 117, 2, 70, "Input",
      CellTags->"BooleanIntersection"],
    Cell[43466, 1797, 515, 13, 70, "Output",
      CellTags->"BooleanIntersection"]},
  "BooleanPower"->{
    Cell[44042, 1817, 62, 1, 42, "ObjectName",
      CellTags->"BooleanPower"],
    Cell[44107, 1820, 63, 1, 74, "Highlight",
      CellTags->"BooleanPower"],
    Cell[44173, 1823, 246, 8, 64, "Usage",
      CellTags->"BooleanPower"],
    Cell[44422, 1833, 150, 4, 33, "Notes",
      CellTags->"BooleanPower"],
    Cell[44575, 1839, 823, 27, 54, "Notes",
      CellTags->"BooleanPower"],
    Cell[45423, 1870, 70, 1, 59, "ExampleSection",
      CellTags->"BooleanPower"],
    Cell[45496, 1873, 193, 6, 70, "ExampleText",
      CellTags->"BooleanPower"],
    Cell[45714, 1883, 105, 2, 70, "Input",
      CellTags->"BooleanPower"],
    Cell[45822, 1887, 216, 4, 70, "Output",
      CellTags->"BooleanPower"],
    Cell[46053, 1894, 126, 4, 70, "ExampleText",
      CellTags->"BooleanPower"],
    Cell[46204, 1902, 153, 4, 70, "Input",
      CellTags->"BooleanPower"],
    Cell[46360, 1908, 508, 13, 70, "Output",
      CellTags->"BooleanPower"]},
  "BooleanUnion"->{
    Cell[46929, 1928, 62, 1, 42, "ObjectName",
      CellTags->"BooleanUnion"],
    Cell[46994, 1931, 63, 1, 74, "Highlight",
      CellTags->"BooleanUnion"],
    Cell[47060, 1934, 266, 8, 64, "Usage",
      CellTags->"BooleanUnion"],
    Cell[47329, 1944, 150, 4, 33, "Notes",
      CellTags->"BooleanUnion"],
    Cell[47482, 1950, 823, 27, 54, "Notes",
      CellTags->"BooleanUnion"],
    Cell[48330, 1981, 70, 1, 59, "ExampleSection",
      CellTags->"BooleanUnion"],
    Cell[48403, 1984, 135, 4, 70, "ExampleText",
      CellTags->"BooleanUnion"],
    Cell[48563, 1992, 132, 5, 70, "Input",
      CellTags->"BooleanUnion"],
    Cell[48698, 1999, 508, 13, 70, "Output",
      CellTags->"BooleanUnion"],
    Cell[49243, 2017, 135, 5, 70, "Input",
      CellTags->"BooleanUnion"],
    Cell[49381, 2024, 509, 13, 70, "Output",
      CellTags->"BooleanUnion"],
    Cell[49927, 2042, 104, 2, 70, "Input",
      CellTags->"BooleanUnion"],
    Cell[50034, 2046, 509, 13, 70, "Output",
      CellTags->"BooleanUnion"]},
  "CartesianProduct"->{
    Cell[50604, 2066, 70, 1, 42, "ObjectName",
      CellTags->"CartesianProduct"],
    Cell[50677, 2069, 67, 1, 74, "Highlight",
      CellTags->"CartesianProduct"],
    Cell[50747, 2072, 232, 8, 43, "Usage",
      CellTags->"CartesianProduct"],
    Cell[50982, 2082, 116, 4, 33, "Notes",
      CellTags->"CartesianProduct"],
    Cell[51101, 2088, 233, 8, 37, "Notes",
      CellTags->"CartesianProduct"],
    Cell[51337, 2098, 162, 2, 33, "Notes",
      CellTags->"CartesianProduct"],
    Cell[51502, 2102, 196, 7, 33, "Notes",
      CellTags->"CartesianProduct"],
    Cell[51723, 2113, 74, 1, 59, "ExampleSection",
      CellTags->"CartesianProduct"],
    Cell[51800, 2116, 70, 1, 70, "ExampleText",
      CellTags->"CartesianProduct"],
    Cell[51895, 2121, 129, 5, 70, "Input",
      CellTags->"CartesianProduct"],
    Cell[52027, 2128, 140, 3, 70, "Output",
      CellTags->"CartesianProduct"],
    Cell[52204, 2136, 112, 2, 70, "Input",
      CellTags->"CartesianProduct"],
    Cell[52319, 2140, 242, 5, 70, "Output",
      CellTags->"CartesianProduct"],
    Cell[52598, 2150, 109, 2, 70, "Input",
      CellTags->"CartesianProduct"],
    Cell[52710, 2154, 94, 3, 70, "Output",
      CellTags->"CartesianProduct"],
    Cell[52841, 2162, 93, 2, 70, "Input",
      CellTags->"CartesianProduct"],
    Cell[52937, 2166, 96, 3, 70, "Output",
      CellTags->"CartesianProduct"]},
  "CirculantGraph"->{
    Cell[53094, 2176, 66, 1, 42, "ObjectName",
      CellTags->"CirculantGraph"],
    Cell[53163, 2179, 65, 1, 74, "Highlight",
      CellTags->"CirculantGraph"],
    Cell[53231, 2182, 235, 7, 43, "Usage",
      CellTags->"CirculantGraph"],
    Cell[53469, 2191, 309, 10, 54, "Notes",
      CellTags->"CirculantGraph"],
    Cell[53781, 2203, 156, 6, 33, "Notes",
      CellTags->"CirculantGraph"],
    Cell[53940, 2211, 251, 11, 33, "Notes",
      CellTags->"CirculantGraph"],
    Cell[54216, 2226, 72, 1, 59, "ExampleSection",
      CellTags->"CirculantGraph"],
    Cell[54291, 2229, 84, 1, 70, "ExampleText",
      CellTags->"CirculantGraph"],
    Cell[54400, 2234, 101, 2, 70, "Input",
      CellTags->"CirculantGraph"],
    Cell[54504, 2238, 281, 8, 70, "Output",
      CellTags->"CirculantGraph"],
    Cell[54822, 2251, 119, 3, 70, "Input",
      CellTags->"CirculantGraph"],
    Cell[54944, 2256, 125, 3, 70, "Output",
      CellTags->"CirculantGraph"],
    Cell[55084, 2262, 95, 1, 70, "ExampleText",
      CellTags->"CirculantGraph"],
    Cell[55204, 2267, 101, 2, 70, "Input",
      CellTags->"CirculantGraph"],
    Cell[55308, 2271, 281, 8, 70, "Output",
      CellTags->"CirculantGraph"],
    Cell[55626, 2284, 119, 3, 70, "Input",
      CellTags->"CirculantGraph"],
    Cell[55748, 2289, 123, 3, 70, "Output",
      CellTags->"CirculantGraph"]},
  "ClosureSearch"->{
    Cell[55932, 2299, 64, 1, 42, "ObjectName",
      CellTags->"ClosureSearch"],
    Cell[55999, 2302, 64, 1, 74, "Highlight",
      CellTags->"ClosureSearch"],
    Cell[56066, 2305, 272, 10, 64, "Usage",
      CellTags->"ClosureSearch"],
    Cell[56341, 2317, 309, 10, 80, "Notes",
      CellTags->"ClosureSearch"],
    Cell[56653, 2329, 135, 5, 33, "Notes",
      CellTags->"ClosureSearch"],
    Cell[56791, 2336, 328, 10, 54, "Notes",
      CellTags->"ClosureSearch"],
    Cell[57122, 2348, 182, 4, 54, "Notes",
      CellTags->"ClosureSearch"],
    Cell[57307, 2354, 406, 15, 33, "Notes",
      CellTags->"ClosureSearch"],
    Cell[57738, 2373, 71, 1, 59, "ExampleSection",
      CellTags->"ClosureSearch"],
    Cell[57812, 2376, 107, 1, 70, "ExampleText",
      CellTags->"ClosureSearch"],
    Cell[57944, 2381, 180, 4, 70, "Input",
      CellTags->"ClosureSearch"],
    Cell[58127, 2387, 113, 3, 70, "Output",
      CellTags->"ClosureSearch"],
    Cell[58277, 2395, 136, 3, 70, "Input",
      CellTags->"ClosureSearch"],
    Cell[58416, 2400, 92, 3, 70, "Output",
      CellTags->"ClosureSearch"],
    Cell[58523, 2406, 85, 1, 70, "ExampleText",
      CellTags->"ClosureSearch"],
    Cell[58633, 2411, 188, 4, 70, "Input",
      CellTags->"ClosureSearch"],
    Cell[58824, 2417, 93, 3, 70, "Output",
      CellTags->"ClosureSearch"],
    Cell[58954, 2425, 188, 4, 70, "Input",
      CellTags->"ClosureSearch"],
    Cell[59145, 2431, 94, 3, 70, "Output",
      CellTags->"ClosureSearch"]},
  "Closure"->{
    Cell[59300, 2441, 52, 1, 42, "ObjectName",
      CellTags->"Closure"],
    Cell[59355, 2444, 58, 1, 74, "Highlight",
      CellTags->"Closure"],
    Cell[59416, 2447, 147, 4, 43, "Usage",
      CellTags->"Closure"],
    Cell[59566, 2453, 290, 10, 80, "Notes",
      CellTags->"Closure"],
    Cell[59859, 2465, 129, 5, 33, "Notes",
      CellTags->"Closure"],
    Cell[59991, 2472, 322, 10, 54, "Notes",
      CellTags->"Closure"],
    Cell[60316, 2484, 412, 15, 33, "Notes",
      CellTags->"Closure"],
    Cell[60753, 2503, 65, 1, 59, "ExampleSection",
      CellTags->"Closure"],
    Cell[60821, 2506, 83, 1, 70, "ExampleText",
      CellTags->"Closure"],
    Cell[60929, 2511, 101, 2, 70, "Input",
      CellTags->"Closure"],
    Cell[61033, 2515, 139, 3, 70, "Output",
      CellTags->"Closure"],
    Cell[61209, 2523, 100, 2, 70, "Input",
      CellTags->"Closure"],
    Cell[61312, 2527, 111, 3, 70, "Output",
      CellTags->"Closure"],
    Cell[61438, 2533, 101, 1, 70, "ExampleText",
      CellTags->"Closure"],
    Cell[61564, 2538, 174, 4, 70, "Input",
      CellTags->"Closure"],
    Cell[61741, 2544, 107, 3, 70, "Output",
      CellTags->"Closure"],
    Cell[61885, 2552, 110, 2, 70, "Input",
      CellTags->"Closure"],
    Cell[61998, 2556, 464, 8, 70, "Output",
      CellTags->"Closure"],
    Cell[62477, 2567, 196, 5, 70, "ExampleText",
      CellTags->"Closure"],
    Cell[62698, 2576, 155, 4, 70, "Input",
      CellTags->"Closure"],
    Cell[62856, 2582, 118, 3, 70, "Output",
      CellTags->"Closure"]},
  "CollapseT"->{
    Cell[63035, 2592, 56, 1, 42, "ObjectName",
      CellTags->"CollapseT"],
    Cell[63094, 2595, 60, 1, 74, "Highlight",
      CellTags->"CollapseT"],
    Cell[63157, 2598, 190, 6, 43, "Usage",
      CellTags->"CollapseT"],
    Cell[63350, 2606, 172, 7, 33, "Notes",
      CellTags->"CollapseT"],
    Cell[63525, 2615, 152, 5, 33, "Notes",
      CellTags->"CollapseT"],
    Cell[63680, 2622, 576, 23, 33, "Notes",
      CellTags->"CollapseT"],
    Cell[64281, 2649, 67, 1, 59, "ExampleSection",
      CellTags->"CollapseT"],
    Cell[64351, 2652, 82, 1, 70, "ExampleText",
      CellTags->"CollapseT"],
    Cell[64458, 2657, 84, 2, 70, "Input",
      CellTags->"CollapseT"],
    Cell[64545, 2661, 101, 3, 70, "Output",
      CellTags->"CollapseT"],
    Cell[64683, 2669, 122, 4, 70, "Input",
      CellTags->"CollapseT"],
    Cell[64808, 2675, 97, 3, 70, "Output",
      CellTags->"CollapseT"],
    Cell[64908, 2680, 108, 3, 70, "Output",
      CellTags->"CollapseT"],
    Cell[65053, 2688, 96, 3, 70, "Input",
      CellTags->"CollapseT"],
    Cell[65152, 2693, 98, 3, 70, "Output",
      CellTags->"CollapseT"]},
  "ColorQ"->{
    Cell[65311, 2703, 50, 1, 42, "ObjectName",
      CellTags->"ColorQ"],
    Cell[65364, 2706, 57, 1, 74, "Highlight",
      CellTags->"ColorQ"],
    Cell[65424, 2709, 157, 6, 43, "Usage",
      CellTags->"ColorQ"],
    Cell[65584, 2717, 82, 1, 33, "Notes",
      CellTags->"ColorQ"],
    Cell[65669, 2720, 272, 12, 33, "Notes",
      CellTags->"ColorQ"]},
  "CompCycles"->{
    Cell[65978, 2737, 58, 1, 42, "ObjectName",
      CellTags->"CompCycles"],
    Cell[66039, 2740, 61, 1, 74, "Highlight",
      CellTags->"CompCycles"],
    Cell[66103, 2743, 219, 5, 64, "Usage",
      CellTags->"CompCycles"],
    Cell[66325, 2750, 268, 11, 33, "Notes",
      CellTags->"CompCycles"],
    Cell[66618, 2765, 68, 1, 59, "ExampleSection",
      CellTags->"CompCycles"],
    Cell[66689, 2768, 105, 1, 48, "ExampleText",
      CellTags->"CompCycles"],
    Cell[66797, 2771, 151, 4, 60, "Input",
      CellTags->"CompCycles"],
    Cell[66973, 2779, 86, 2, 40, "Input",
      CellTags->"CompCycles"],
    Cell[67062, 2783, 102, 3, 30, "Output",
      CellTags->"CompCycles"],
    Cell[67201, 2791, 166, 4, 60, "Input",
      CellTags->"CompCycles"],
    Cell[67370, 2797, 102, 3, 30, "Output",
      CellTags->"CompCycles"],
    Cell[67475, 2802, 102, 3, 30, "Output",
      CellTags->"CompCycles"],
    Cell[67614, 2810, 108, 2, 40, "Input",
      CellTags->"CompCycles"],
    Cell[67725, 2814, 103, 3, 30, "Output",
      CellTags->"CompCycles"]},
  "Concatenate"->{
    Cell[67889, 2824, 60, 1, 42, "ObjectName",
      CellTags->"Concatenate"],
    Cell[67952, 2827, 62, 1, 74, "Highlight",
      CellTags->"Concatenate"],
    Cell[68017, 2830, 184, 8, 43, "Usage",
      CellTags->"Concatenate"],
    Cell[68204, 2840, 107, 4, 33, "Notes",
      CellTags->"Concatenate"],
    Cell[68314, 2846, 179, 5, 33, "Notes",
      CellTags->"Concatenate"],
    Cell[68496, 2853, 126, 4, 33, "Notes",
      CellTags->"Concatenate"],
    Cell[68625, 2859, 154, 7, 33, "Notes",
      CellTags->"Concatenate"],
    Cell[68804, 2870, 69, 1, 59, "ExampleSection",
      CellTags->"Concatenate"],
    Cell[68876, 2873, 73, 1, 48, "ExampleText",
      CellTags->"Concatenate"],
    Cell[68974, 2878, 135, 4, 60, "Input",
      CellTags->"Concatenate"],
    Cell[69112, 2884, 93, 3, 30, "Output",
      CellTags->"Concatenate"],
    Cell[69208, 2889, 249, 8, 49, "Output",
      CellTags->"Concatenate"],
    Cell[69494, 2902, 113, 3, 37, "Input",
      CellTags->"Concatenate"],
    Cell[69610, 2907, 91, 3, 30, "Output",
      CellTags->"Concatenate"],
    Cell[69738, 2915, 112, 3, 37, "Input",
      CellTags->"Concatenate"],
    Cell[69853, 2920, 108, 3, 30, "Output",
      CellTags->"Concatenate"],
    Cell[69998, 2928, 119, 3, 37, "Input",
      CellTags->"Concatenate"],
    Cell[70120, 2933, 141, 3, 30, "Output",
      CellTags->"Concatenate"]},
  "ConsT"->{
    Cell[70322, 2943, 48, 1, 42, "ObjectName",
      CellTags->"ConsT"],
    Cell[70373, 2946, 56, 1, 74, "Highlight",
      CellTags->"ConsT"],
    Cell[70432, 2949, 211, 8, 43, "Usage",
      CellTags->"ConsT"],
    Cell[70646, 2959, 316, 15, 33, "Notes",
      CellTags->"ConsT"],
    Cell[70987, 2978, 63, 1, 59, "ExampleSection",
      CellTags->"ConsT"],
    Cell[71053, 2981, 70, 1, 70, "ExampleText",
      CellTags->"ConsT"],
    Cell[71148, 2986, 119, 4, 70, "Input",
      CellTags->"ConsT"],
    Cell[71270, 2992, 97, 3, 70, "Output",
      CellTags->"ConsT"],
    Cell[71370, 2997, 82, 3, 70, "Output",
      CellTags->"ConsT"]},
  "Curry"->{
    Cell[71513, 3007, 48, 1, 42, "ObjectName",
      CellTags->"Curry"],
    Cell[71564, 3010, 56, 1, 74, "Highlight",
      CellTags->"Curry"],
    Cell[71623, 3013, 152, 6, 43, "Usage",
      CellTags->"Curry"],
    Cell[71778, 3021, 112, 5, 33, "Notes",
      CellTags->"Curry"],
    Cell[71893, 3028, 142, 4, 33, "Notes",
      CellTags->"Curry"],
    Cell[72060, 3036, 63, 1, 59, "ExampleSection",
      CellTags->"Curry"],
    Cell[72126, 3039, 83, 1, 70, "ExampleText",
      CellTags->"Curry"],
    Cell[72234, 3044, 117, 3, 70, "Input",
      CellTags->"Curry"],
    Cell[72354, 3049, 93, 3, 70, "Output",
      CellTags->"Curry"]},
  "CycleDecompositionT"->{
    Cell[72508, 3059, 76, 1, 42, "ObjectName",
      CellTags->"CycleDecompositionT"],
    Cell[72587, 3062, 70, 1, 74, "Highlight",
      CellTags->"CycleDecompositionT"],
    Cell[72660, 3065, 166, 4, 43, "Usage",
      CellTags->"CycleDecompositionT"],
    Cell[72829, 3071, 235, 9, 58, "Notes",
      CellTags->"CycleDecompositionT"],
    Cell[73067, 3082, 150, 5, 33, "Notes",
      CellTags->"CycleDecompositionT"],
    Cell[73220, 3089, 203, 5, 54, "Notes",
      CellTags->"CycleDecompositionT"],
    Cell[73426, 3096, 334, 15, 33, "Notes",
      CellTags->"CycleDecompositionT"],
    Cell[73785, 3115, 77, 1, 59, "ExampleSection",
      CellTags->"CycleDecompositionT"],
    Cell[73865, 3118, 100, 1, 70, "ExampleText",
      CellTags->"CycleDecompositionT"],
    Cell[73990, 3123, 135, 5, 70, "Input",
      CellTags->"CycleDecompositionT"],
    Cell[74128, 3130, 114, 3, 70, "Output",
      CellTags->"CycleDecompositionT"],
    Cell[74279, 3138, 135, 3, 70, "Input",
      CellTags->"CycleDecompositionT"],
    Cell[74417, 3143, 119, 3, 70, "Output",
      CellTags->"CycleDecompositionT"]},
  "CycleToT"->{
    Cell[74597, 3153, 54, 1, 42, "ObjectName",
      CellTags->"CycleToT"],
    Cell[74654, 3156, 59, 1, 74, "Highlight",
      CellTags->"CycleToT"],
    Cell[74716, 3159, 176, 5, 43, "Usage",
      CellTags->"CycleToT"],
    Cell[74895, 3166, 78, 1, 33, "Notes",
      CellTags->"CycleToT"],
    Cell[74976, 3169, 345, 15, 33, "Notes",
      CellTags->"CycleToT"],
    Cell[75346, 3188, 66, 1, 59, "ExampleSection",
      CellTags->"CycleToT"],
    Cell[75415, 3191, 77, 1, 70, "ExampleText",
      CellTags->"CycleToT"],
    Cell[75517, 3196, 119, 3, 70, "Input",
      CellTags->"CycleToT"],
    Cell[75639, 3201, 100, 3, 70, "Output",
      CellTags->"CycleToT"],
    Cell[75776, 3209, 92, 3, 70, "Input",
      CellTags->"CycleToT"],
    Cell[75871, 3214, 85, 3, 70, "Output",
      CellTags->"CycleToT"],
    Cell[75993, 3222, 144, 4, 70, "Input",
      CellTags->"CycleToT"],
    Cell[76140, 3228, 3031, 230, 70, 2850, 224, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"CycleToT"],
    Cell[79208, 3463, 104, 3, 70, "Input",
      CellTags->"CycleToT"],
    Cell[79315, 3468, 100, 3, 70, "Output",
      CellTags->"CycleToT"]},
  "CyclicQGraph"->{
    Cell[79476, 3478, 62, 1, 42, "ObjectName",
      CellTags->"CyclicQGraph"],
    Cell[79541, 3481, 63, 1, 74, "Highlight",
      CellTags->"CyclicQGraph"],
    Cell[79607, 3484, 160, 6, 43, "Usage",
      CellTags->"CyclicQGraph"],
    Cell[79770, 3492, 60, 1, 33, "Notes",
      CellTags->"CyclicQGraph"],
    Cell[79833, 3495, 155, 7, 33, "Notes",
      CellTags->"CyclicQGraph"],
    Cell[80013, 3506, 70, 1, 59, "ExampleSection",
      CellTags->"CyclicQGraph"],
    Cell[80086, 3509, 66, 1, 48, "ExampleText",
      CellTags->"CyclicQGraph"],
    Cell[80155, 3512, 211, 6, 60, "Input",
      CellTags->"CyclicQGraph"],
    Cell[80391, 3522, 102, 3, 37, "Input",
      CellTags->"CyclicQGraph"],
    Cell[80496, 3527, 92, 3, 30, "Output",
      CellTags->"CyclicQGraph"],
    Cell[80625, 3535, 114, 3, 37, "Input",
      CellTags->"CyclicQGraph"],
    Cell[80742, 3540, 293, 8, 30, "Output",
      CellTags->"CyclicQGraph"],
    Cell[81072, 3553, 103, 3, 37, "Input",
      CellTags->"CyclicQGraph"],
    Cell[81178, 3558, 93, 3, 30, "Output",
      CellTags->"CyclicQGraph"]},
  "DClassDecomposition"->{
    Cell[81332, 3568, 76, 1, 42, "ObjectName",
      CellTags->"DClassDecomposition"],
    Cell[81411, 3571, 70, 1, 74, "Highlight",
      CellTags->"DClassDecomposition"],
    Cell[81484, 3574, 200, 6, 43, "Usage",
      CellTags->"DClassDecomposition"],
    Cell[81687, 3582, 241, 9, 58, "Notes",
      CellTags->"DClassDecomposition"],
    Cell[81931, 3593, 160, 5, 33, "Notes",
      CellTags->"DClassDecomposition"],
    Cell[82094, 3600, 259, 8, 54, "Notes",
      CellTags->"DClassDecomposition"],
    Cell[82356, 3610, 128, 4, 33, "Notes",
      CellTags->"DClassDecomposition"],
    Cell[82487, 3616, 259, 8, 54, "Notes",
      CellTags->"DClassDecomposition"],
    Cell[82749, 3626, 344, 15, 33, "Notes",
      CellTags->"DClassDecomposition"],
    Cell[83118, 3645, 77, 1, 59, "ExampleSection",
      CellTags->"DClassDecomposition"],
    Cell[83198, 3648, 140, 4, 70, "ExampleText",
      CellTags->"DClassDecomposition"],
    Cell[83363, 3656, 122, 5, 70, "Input",
      CellTags->"DClassDecomposition"],
    Cell[83488, 3663, 98, 3, 70, "Output",
      CellTags->"DClassDecomposition"],
    Cell[83601, 3669, 131, 3, 70, "Input",
      CellTags->"DClassDecomposition"],
    Cell[83757, 3676, 149, 4, 70, "Input",
      CellTags->"DClassDecomposition"],
    Cell[83909, 3682, 111, 3, 70, "Output",
      CellTags->"DClassDecomposition"],
    Cell[84023, 3687, 140, 3, 70, "Output",
      CellTags->"DClassDecomposition"],
    Cell[84178, 3693, 113, 1, 70, "ExampleText",
      CellTags->"DClassDecomposition"],
    Cell[84316, 3698, 152, 3, 70, "Input",
      CellTags->"DClassDecomposition"],
    Cell[84471, 3703, 9993, 265, 70, "Output",
      CellTags->"DClassDecomposition"]},
  "DClassDimensions"->{
    Cell[94525, 3975, 70, 1, 42, "ObjectName",
      CellTags->"DClassDimensions"],
    Cell[94598, 3978, 67, 1, 74, "Highlight",
      CellTags->"DClassDimensions"],
    Cell[94668, 3981, 175, 6, 43, "Usage",
      CellTags->"DClassDimensions"],
    Cell[94846, 3989, 116, 5, 33, "Notes",
      CellTags->"DClassDimensions"],
    Cell[94965, 3996, 139, 4, 33, "Notes",
      CellTags->"DClassDimensions"],
    Cell[95107, 4002, 250, 11, 33, "Notes",
      CellTags->"DClassDimensions"],
    Cell[95382, 4017, 74, 1, 59, "ExampleSection",
      CellTags->"DClassDimensions"],
    Cell[95459, 4020, 83, 1, 70, "ExampleText",
      CellTags->"DClassDimensions"],
    Cell[95545, 4023, 385, 7, 70, "Input",
      CellTags->"DClassDimensions"],
    Cell[95955, 4034, 110, 3, 70, "Input",
      CellTags->"DClassDimensions"],
    Cell[96068, 4039, 101, 3, 70, "Output",
      CellTags->"DClassDimensions"]},
  "DClassSize"->{
    Cell[96230, 4049, 58, 1, 42, "ObjectName",
      CellTags->"DClassSize"],
    Cell[96291, 4052, 61, 1, 74, "Highlight",
      CellTags->"DClassSize"],
    Cell[96355, 4055, 156, 6, 43, "Usage",
      CellTags->"DClassSize"],
    Cell[96514, 4063, 110, 5, 33, "Notes",
      CellTags->"DClassSize"],
    Cell[96627, 4070, 139, 4, 33, "Notes",
      CellTags->"DClassSize"],
    Cell[96769, 4076, 273, 11, 33, "Notes",
      CellTags->"DClassSize"],
    Cell[97067, 4091, 68, 1, 59, "ExampleSection",
      CellTags->"DClassSize"],
    Cell[97138, 4094, 77, 1, 70, "ExampleText",
      CellTags->"DClassSize"],
    Cell[97218, 4097, 379, 7, 70, "Input",
      CellTags->"DClassSize"],
    Cell[97622, 4108, 98, 3, 70, "Input",
      CellTags->"DClassSize"],
    Cell[97723, 4113, 88, 3, 70, "Output",
      CellTags->"DClassSize"]},
  "DClassToBlocks"->{
    Cell[97872, 4123, 66, 1, 42, "ObjectName",
      CellTags->"DClassToBlocks"],
    Cell[97941, 4126, 65, 1, 74, "Highlight",
      CellTags->"DClassToBlocks"],
    Cell[98009, 4129, 191, 5, 64, "Usage",
      CellTags->"DClassToBlocks"],
    Cell[98203, 4136, 114, 5, 33, "Notes",
      CellTags->"DClassToBlocks"],
    Cell[98320, 4143, 323, 9, 35, "Notes",
      CellTags->"DClassToBlocks"],
    Cell[98646, 4154, 160, 5, 33, "Notes",
      CellTags->"DClassToBlocks"],
    Cell[98809, 4161, 349, 15, 33, "Notes",
      CellTags->"DClassToBlocks"],
    Cell[99183, 4180, 72, 1, 59, "ExampleSection",
      CellTags->"DClassToBlocks"],
    Cell[99258, 4183, 96, 1, 70, "ExampleText",
      CellTags->"DClassToBlocks"],
    Cell[99379, 4188, 292, 6, 70, "Input",
      CellTags->"DClassToBlocks"],
    Cell[99674, 4196, 649, 19, 70, "Output",
      CellTags->"DClassToBlocks"],
    Cell[100360, 4220, 124, 3, 70, "Input",
      CellTags->"DClassToBlocks"],
    Cell[100487, 4225, 1740, 45, 70, "Output",
      CellTags->"DClassToBlocks"],
    Cell[508289, 22609, 93, 1, 70, "ExampleText",
      CellTags->"DClassToBlocks"]},
  "DClassT"->{
    Cell[102288, 4277, 52, 1, 42, "ObjectName",
      CellTags->"DClassT"],
    Cell[102343, 4280, 58, 1, 74, "Highlight",
      CellTags->"DClassT"],
    Cell[102404, 4283, 212, 8, 43, "Usage",
      CellTags->"DClassT"],
    Cell[102619, 4293, 92, 1, 33, "Notes",
      CellTags->"DClassT"],
    Cell[102714, 4296, 241, 11, 33, "Notes",
      CellTags->"DClassT"],
    Cell[102980, 4311, 65, 1, 59, "ExampleSection",
      CellTags->"DClassT"],
    Cell[103048, 4314, 93, 1, 70, "ExampleText",
      CellTags->"DClassT"],
    Cell[103166, 4319, 110, 5, 70, "Input",
      CellTags->"DClassT"],
    Cell[103279, 4326, 85, 3, 70, "Output",
      CellTags->"DClassT"],
    Cell[103401, 4334, 170, 4, 70, "Input",
      CellTags->"DClassT"],
    Cell[103574, 4340, 160, 4, 70, "Output",
      CellTags->"DClassT"],
    Cell[103737, 4346, 699, 19, 70, "Output",
      CellTags->"DClassT"],
    Cell[104473, 4370, 170, 4, 70, "Input",
      CellTags->"DClassT"],
    Cell[104646, 4376, 196, 4, 70, "Output",
      CellTags->"DClassT"],
    Cell[104845, 4382, 2219, 63, 70, "Output",
      CellTags->"DClassT"],
    Cell[107101, 4450, 170, 4, 70, "Input",
      CellTags->"DClassT"],
    Cell[107274, 4456, 196, 4, 70, "Output",
      CellTags->"DClassT"],
    Cell[107473, 4462, 683, 21, 70, "Output",
      CellTags->"DClassT"]},
  "DegreeGraph"->{
    Cell[108217, 4490, 60, 1, 42, "ObjectName",
      CellTags->"DegreeGraph"],
    Cell[108280, 4493, 62, 1, 74, "Highlight",
      CellTags->"DegreeGraph"],
    Cell[108345, 4496, 199, 8, 43, "Usage",
      CellTags->"DegreeGraph"],
    Cell[108547, 4506, 227, 9, 58, "Notes",
      CellTags->"DegreeGraph"],
    Cell[108777, 4517, 182, 7, 33, "Notes",
      CellTags->"DegreeGraph"],
    Cell[108962, 4526, 154, 7, 33, "Notes",
      CellTags->"DegreeGraph"],
    Cell[109141, 4537, 69, 1, 59, "ExampleSection",
      CellTags->"DegreeGraph"],
    Cell[109213, 4540, 135, 4, 70, "ExampleText",
      CellTags->"DegreeGraph"],
    Cell[109373, 4548, 97, 2, 70, "Input",
      CellTags->"DegreeGraph"],
    Cell[109473, 4552, 436, 11, 70, "Output",
      CellTags->"DegreeGraph"],
    Cell[109946, 4568, 103, 3, 70, "Input",
      CellTags->"DegreeGraph"],
    Cell[110052, 4573, 88, 3, 70, "Output",
      CellTags->"DegreeGraph"],
    Cell[110177, 4581, 124, 3, 70, "Input",
      CellTags->"DegreeGraph"],
    Cell[110304, 4586, 93, 3, 70, "Output",
      CellTags->"DegreeGraph"],
    Cell[110434, 4594, 161, 4, 70, "Input",
      CellTags->"DegreeGraph"],
    Cell[110598, 4600, 95, 3, 70, "Output",
      CellTags->"DegreeGraph"]},
  "Dependency"->{
    Cell[110754, 4610, 58, 1, 42, "ObjectName",
      CellTags->"Dependency"],
    Cell[110815, 4613, 61, 1, 74, "Highlight",
      CellTags->"Dependency"],
    Cell[110879, 4616, 261, 8, 64, "Usage",
      CellTags->"Dependency"],
    Cell[111143, 4626, 367, 14, 35, "Notes",
      CellTags->"Dependency"],
    Cell[111513, 4642, 129, 5, 33, "Notes",
      CellTags->"Dependency"],
    Cell[111645, 4649, 167, 7, 33, "Notes",
      CellTags->"Dependency"],
    Cell[111837, 4660, 68, 1, 59, "ExampleSection",
      CellTags->"Dependency"],
    Cell[111908, 4663, 101, 1, 70, "ExampleText",
      CellTags->"Dependency"],
    Cell[112012, 4666, 111, 5, 70, "Input",
      CellTags->"Dependency"],
    Cell[112148, 4675, 132, 3, 70, "Input",
      CellTags->"Dependency"],
    Cell[112283, 4680, 109, 3, 70, "Output",
      CellTags->"Dependency"],
    Cell[112429, 4688, 97, 3, 70, "Input",
      CellTags->"Dependency"],
    Cell[112529, 4693, 91, 3, 70, "Output",
      CellTags->"Dependency"]},
  "DisjointQ"->{
    Cell[112681, 4703, 56, 1, 42, "ObjectName",
      CellTags->"DisjointQ"],
    Cell[112740, 4706, 60, 1, 74, "Highlight",
      CellTags->"DisjointQ"],
    Cell[112803, 4709, 197, 8, 43, "Usage",
      CellTags->"DisjointQ"],
    Cell[113003, 4719, 156, 7, 33, "Notes",
      CellTags->"DisjointQ"],
    Cell[113184, 4730, 67, 1, 59, "ExampleSection",
      CellTags->"DisjointQ"],
    Cell[113254, 4733, 86, 1, 70, "ExampleText",
      CellTags->"DisjointQ"],
    Cell[113365, 4738, 96, 2, 70, "Input",
      CellTags->"DisjointQ"],
    Cell[113464, 4742, 88, 3, 70, "Output",
      CellTags->"DisjointQ"],
    Cell[113589, 4750, 94, 2, 70, "Input",
      CellTags->"DisjointQ"],
    Cell[113686, 4754, 89, 3, 70, "Output",
      CellTags->"DisjointQ"]},
  "DoShow"->{
    Cell[113836, 4764, 50, 1, 42, "ObjectName",
      CellTags->"DoShow"],
    Cell[113889, 4767, 57, 1, 74, "Highlight",
      CellTags->"DoShow"],
    Cell[113949, 4770, 253, 10, 64, "Usage",
      CellTags->"DoShow"],
    Cell[114205, 4782, 134, 5, 33, "Notes",
      CellTags->"DoShow"],
    Cell[114342, 4789, 157, 7, 33, "Notes",
      CellTags->"DoShow"],
    Cell[114524, 4800, 64, 1, 59, "ExampleSection",
      CellTags->"DoShow"],
    Cell[114591, 4803, 80, 1, 70, "ExampleText",
      CellTags->"DoShow"],
    Cell[114674, 4806, 176, 5, 70, "Input",
      CellTags->"DoShow"],
    Cell[114875, 4815, 95, 3, 70, "Input",
      CellTags->"DoShow"],
    Cell[114973, 4820, 2661, 187, 70, 2487, 181, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"DoShow"]},
  "Drei"->{
    Cell[117695, 5014, 46, 1, 42, "ObjectName",
      CellTags->"Drei"],
    Cell[117744, 5017, 54, 1, 74, "Highlight",
      CellTags->"Drei"],
    Cell[117801, 5020, 147, 6, 43, "Usage",
      CellTags->"Drei"],
    Cell[117951, 5028, 104, 5, 33, "Notes",
      CellTags->"Drei"],
    Cell[118058, 5035, 333, 15, 33, "Notes",
      CellTags->"Drei"]},
  "EdgeQ"->{
    Cell[118428, 5055, 48, 1, 42, "ObjectName",
      CellTags->"EdgeQ"],
    Cell[118479, 5058, 56, 1, 74, "Highlight",
      CellTags->"EdgeQ"],
    Cell[118538, 5061, 223, 9, 43, "Usage",
      CellTags->"EdgeQ"],
    Cell[118764, 5072, 154, 7, 33, "Notes",
      CellTags->"EdgeQ"],
    Cell[118921, 5081, 148, 7, 33, "Notes",
      CellTags->"EdgeQ"]},
  "Edges"->{
    Cell[119106, 5093, 48, 1, 42, "ObjectName",
      CellTags->"Edges"],
    Cell[119157, 5096, 56, 1, 74, "Highlight",
      CellTags->"Edges"],
    Cell[119216, 5099, 116, 4, 43, "Usage",
      CellTags->"Edges"],
    Cell[119335, 5105, 166, 4, 54, "Notes",
      CellTags->"Edges"],
    Cell[119504, 5111, 255, 11, 33, "Notes",
      CellTags->"Edges"]},
  "EnumForm"->{
    Cell[119796, 5127, 54, 1, 42, "ObjectName",
      CellTags->"EnumForm"],
    Cell[119853, 5130, 59, 1, 74, "Highlight",
      CellTags->"EnumForm"],
    Cell[119915, 5133, 210, 8, 43, "Usage",
      CellTags->"EnumForm"],
    Cell[120128, 5143, 221, 9, 58, "Notes",
      CellTags->"EnumForm"],
    Cell[120352, 5154, 162, 7, 33, "Notes",
      CellTags->"EnumForm"],
    Cell[120517, 5163, 130, 5, 33, "Notes",
      CellTags->"EnumForm"],
    Cell[120650, 5170, 179, 8, 33, "Notes",
      CellTags->"EnumForm"],
    Cell[120854, 5182, 66, 1, 59, "ExampleSection",
      CellTags->"EnumForm"],
    Cell[120923, 5185, 95, 1, 70, "ExampleText",
      CellTags->"EnumForm"],
    Cell[121043, 5190, 161, 4, 70, "Input",
      CellTags->"EnumForm"],
    Cell[121207, 5196, 284, 5, 70, "Output",
      CellTags->"EnumForm"],
    Cell[121528, 5206, 94, 3, 70, "Input",
      CellTags->"EnumForm"],
    Cell[121625, 5211, 989, 23, 70, "Output",
      CellTags->"EnumForm"],
    Cell[122629, 5237, 106, 2, 70, "ExampleText",
      CellTags->"EnumForm"],
    Cell[122760, 5243, 95, 3, 70, "Input",
      CellTags->"EnumForm"],
    Cell[122858, 5248, 989, 23, 70, "Output",
      CellTags->"EnumForm"]},
  "EquationsToWitnesses"->{
    Cell[123908, 5278, 78, 1, 42, "ObjectName",
      CellTags->"EquationsToWitnesses"],
    Cell[123989, 5281, 71, 1, 74, "Highlight",
      CellTags->"EquationsToWitnesses"],
    Cell[124063, 5284, 285, 8, 64, "Usage",
      CellTags->"EquationsToWitnesses"],
    Cell[124351, 5294, 283, 10, 80, "Notes",
      CellTags->"EquationsToWitnesses"],
    Cell[124637, 5306, 217, 7, 33, "Notes",
      CellTags->"EquationsToWitnesses"],
    Cell[124857, 5315, 185, 4, 54, "Notes",
      CellTags->"EquationsToWitnesses"],
    Cell[125045, 5321, 173, 7, 33, "Notes",
      CellTags->"EquationsToWitnesses"],
    Cell[125243, 5332, 78, 1, 59, "ExampleSection",
      CellTags->"EquationsToWitnesses"],
    Cell[125324, 5335, 194, 6, 70, "ExampleText",
      CellTags->"EquationsToWitnesses"],
    Cell[125543, 5345, 160, 4, 70, "Input",
      CellTags->"EquationsToWitnesses"],
    Cell[125706, 5351, 122, 3, 70, "Output",
      CellTags->"EquationsToWitnesses"],
    Cell[125865, 5359, 179, 4, 70, "Input",
      CellTags->"EquationsToWitnesses"],
    Cell[126047, 5365, 134, 3, 70, "Output",
      CellTags->"EquationsToWitnesses"],
    Cell[126196, 5371, 391, 12, 70, "ExampleText",
      CellTags->"EquationsToWitnesses"],
    Cell[126612, 5387, 193, 4, 70, "Input",
      CellTags->"EquationsToWitnesses"],
    Cell[126808, 5393, 204, 4, 70, "Output",
      CellTags->"EquationsToWitnesses"],
    Cell[127027, 5400, 137, 4, 70, "ExampleText",
      CellTags->"EquationsToWitnesses"],
    Cell[127189, 5408, 202, 4, 70, "Input",
      CellTags->"EquationsToWitnesses"],
    Cell[127394, 5414, 199, 4, 70, "Output",
      CellTags->"EquationsToWitnesses"],
    Cell[127630, 5423, 108, 3, 70, "Input",
      CellTags->"EquationsToWitnesses"],
    Cell[127741, 5428, 100, 3, 70, "Output",
      CellTags->"EquationsToWitnesses"]},
  "FastPowerSet"->{
    Cell[127902, 5438, 62, 1, 42, "ObjectName",
      CellTags->"FastPowerSet"],
    Cell[127967, 5441, 63, 1, 74, "Highlight",
      CellTags->"FastPowerSet"],
    Cell[128033, 5444, 147, 4, 43, "Usage",
      CellTags->"FastPowerSet"],
    Cell[128183, 5450, 152, 5, 33, "Notes",
      CellTags->"FastPowerSet"],
    Cell[128338, 5457, 156, 7, 33, "Notes",
      CellTags->"FastPowerSet"],
    Cell[128519, 5468, 70, 1, 59, "ExampleSection",
      CellTags->"FastPowerSet"],
    Cell[128592, 5471, 122, 4, 70, "ExampleText",
      CellTags->"FastPowerSet"],
    Cell[128739, 5479, 128, 3, 70, "Input",
      CellTags->"FastPowerSet"],
    Cell[128870, 5484, 124, 3, 70, "Output",
      CellTags->"FastPowerSet"],
    Cell[129031, 5492, 124, 3, 70, "Input",
      CellTags->"FastPowerSet"],
    Cell[129158, 5497, 124, 3, 70, "Output",
      CellTags->"FastPowerSet"],
    Cell[129319, 5505, 138, 4, 70, "Input",
      CellTags->"FastPowerSet"],
    Cell[129460, 5511, 93, 3, 70, "Output",
      CellTags->"FastPowerSet"],
    Cell[129556, 5516, 92, 3, 70, "Output",
      CellTags->"FastPowerSet"]},
  "FlattenOne"->{
    Cell[129709, 5526, 58, 1, 42, "ObjectName",
      CellTags->"FlattenOne"],
    Cell[129770, 5529, 61, 1, 74, "Highlight",
      CellTags->"FlattenOne"],
    Cell[129834, 5532, 154, 6, 43, "Usage",
      CellTags->"FlattenOne"],
    Cell[129991, 5540, 70, 1, 33, "Notes",
      CellTags->"FlattenOne"],
    Cell[130064, 5543, 153, 7, 33, "Notes",
      CellTags->"FlattenOne"],
    Cell[130242, 5554, 68, 1, 59, "ExampleSection",
      CellTags->"FlattenOne"],
    Cell[130313, 5557, 91, 1, 70, "ExampleText",
      CellTags->"FlattenOne"],
    Cell[130429, 5562, 96, 2, 70, "Input",
      CellTags->"FlattenOne"],
    Cell[130528, 5566, 111, 3, 70, "Output",
      CellTags->"FlattenOne"],
    Cell[130676, 5574, 137, 3, 70, "Input",
      CellTags->"FlattenOne"],
    Cell[130816, 5579, 503, 15, 70, "Output",
      CellTags->"FlattenOne"]},
  "Frequencies"->{
    Cell[131380, 5601, 60, 1, 42, "ObjectName",
      CellTags->"Frequencies"],
    Cell[131443, 5604, 62, 1, 74, "Highlight",
      CellTags->"Frequencies"],
    Cell[131508, 5607, 197, 6, 43, "Usage",
      CellTags->"Frequencies"],
    Cell[131708, 5615, 165, 6, 33, "Notes",
      CellTags->"Frequencies"],
    Cell[131898, 5625, 69, 1, 59, "ExampleSection",
      CellTags->"Frequencies"],
    Cell[131970, 5628, 94, 1, 70, "ExampleText",
      CellTags->"Frequencies"],
    Cell[132089, 5633, 199, 5, 70, "Input",
      CellTags->"Frequencies"],
    Cell[132291, 5640, 134, 3, 70, "Output",
      CellTags->"Frequencies"],
    Cell[132428, 5645, 420, 15, 70, "Output",
      CellTags->"Frequencies"]},
  "FromBitVector"->{
    Cell[132909, 5667, 64, 1, 42, "ObjectName",
      CellTags->"FromBitVector"],
    Cell[132976, 5670, 64, 1, 74, "Highlight",
      CellTags->"FromBitVector"],
    Cell[133043, 5673, 212, 8, 43, "Usage",
      CellTags->"FromBitVector"],
    Cell[133258, 5683, 97, 1, 33, "Notes",
      CellTags->"FromBitVector"],
    Cell[133358, 5686, 168, 7, 33, "Notes",
      CellTags->"FromBitVector"],
    Cell[133551, 5697, 71, 1, 59, "ExampleSection",
      CellTags->"FromBitVector"],
    Cell[133625, 5700, 100, 1, 70, "ExampleText",
      CellTags->"FromBitVector"],
    Cell[133750, 5705, 92, 2, 70, "Input",
      CellTags->"FromBitVector"],
    Cell[133845, 5709, 185, 4, 70, "Output",
      CellTags->"FromBitVector"],
    Cell[134067, 5718, 131, 3, 70, "Input",
      CellTags->"FromBitVector"],
    Cell[134201, 5723, 142, 3, 70, "Output",
      CellTags->"FromBitVector"]},
  "FromEps"->{
    Cell[134404, 5733, 52, 1, 42, "ObjectName",
      CellTags->"FromEps"],
    Cell[134459, 5736, 58, 1, 74, "Highlight",
      CellTags->"FromEps"],
    Cell[134520, 5739, 279, 11, 43, "Usage",
      CellTags->"FromEps"],
    Cell[134802, 5752, 96, 1, 33, "Notes",
      CellTags->"FromEps"],
    Cell[134901, 5755, 150, 7, 33, "Notes",
      CellTags->"FromEps"],
    Cell[135076, 5766, 65, 1, 59, "ExampleSection",
      CellTags->"FromEps"],
    Cell[135144, 5769, 86, 1, 70, "ExampleText",
      CellTags->"FromEps"],
    Cell[135255, 5774, 132, 3, 70, "Input",
      CellTags->"FromEps"],
    Cell[135390, 5779, 138, 3, 70, "Output",
      CellTags->"FromEps"],
    Cell[428064, 18839, 127, 4, 70, "ExampleText",
      CellTags->"FromEps"],
    Cell[428216, 18847, 100, 3, 70, "Input",
      CellTags->"FromEps"]},
  "FromIdentityString"->{
    Cell[135589, 5789, 74, 1, 42, "ObjectName",
      CellTags->"FromIdentityString"],
    Cell[135666, 5792, 69, 1, 74, "Highlight",
      CellTags->"FromIdentityString"],
    Cell[135738, 5795, 236, 8, 43, "Usage",
      CellTags->"FromIdentityString"],
    Cell[135977, 5805, 125, 4, 33, "Notes",
      CellTags->"FromIdentityString"],
    Cell[136105, 5811, 147, 2, 33, "Notes",
      CellTags->"FromIdentityString"],
    Cell[136255, 5815, 1040, 39, 75, "Notes",
      CellTags->"FromIdentityString"],
    Cell[137320, 5858, 76, 1, 59, "ExampleSection",
      CellTags->"FromIdentityString"],
    Cell[137399, 5861, 106, 1, 70, "ExampleText",
      CellTags->"FromIdentityString"],
    Cell[137508, 5864, 116, 2, 70, "Input",
      CellTags->"FromIdentityString"],
    Cell[137649, 5870, 96, 2, 70, "Input",
      CellTags->"FromIdentityString"],
    Cell[137748, 5874, 500, 13, 70, "Output",
      CellTags->"FromIdentityString"],
    Cell[138285, 5892, 116, 2, 70, "Input",
      CellTags->"FromIdentityString"],
    Cell[138404, 5896, 516, 13, 70, "Output",
      CellTags->"FromIdentityString"]},
  "GenerateCSM"->{
    Cell[138981, 5916, 60, 1, 42, "ObjectName",
      CellTags->"GenerateCSM"],
    Cell[139044, 5919, 62, 1, 74, "Highlight",
      CellTags->"GenerateCSM"],
    Cell[139109, 5922, 232, 8, 64, "Usage",
      CellTags->"GenerateCSM"],
    Cell[139344, 5932, 280, 10, 80, "Notes",
      CellTags->"GenerateCSM"],
    Cell[139627, 5944, 212, 6, 54, "Notes",
      CellTags->"GenerateCSM"],
    Cell[139842, 5952, 143, 5, 33, "Notes",
      CellTags->"GenerateCSM"],
    Cell[139988, 5959, 285, 9, 54, "Notes",
      CellTags->"GenerateCSM"],
    Cell[140276, 5970, 125, 4, 33, "Notes",
      CellTags->"GenerateCSM"],
    Cell[140404, 5976, 164, 7, 33, "Notes",
      CellTags->"GenerateCSM"],
    Cell[140593, 5987, 69, 1, 59, "ExampleSection",
      CellTags->"GenerateCSM"],
    Cell[140665, 5990, 134, 4, 70, "ExampleText",
      CellTags->"GenerateCSM"],
    Cell[140802, 5996, 190, 5, 70, "Input",
      CellTags->"GenerateCSM"],
    Cell[141017, 6005, 285, 8, 70, "Input",
      CellTags->"GenerateCSM"],
    Cell[141305, 6015, 108, 3, 70, "Output",
      CellTags->"GenerateCSM"],
    Cell[141416, 6020, 661, 19, 70, "Output",
      CellTags->"GenerateCSM"],
    Cell[142080, 6041, 420, 12, 70, "Output",
      CellTags->"GenerateCSM"],
    Cell[142515, 6056, 71, 1, 70, "ExampleText",
      CellTags->"GenerateCSM"],
    Cell[142611, 6061, 285, 6, 70, "Input",
      CellTags->"GenerateCSM"],
    Cell[142899, 6069, 273, 5, 70, "Output",
      CellTags->"GenerateCSM"]},
  "GenerateSG"->{
    Cell[143233, 6081, 58, 1, 42, "ObjectName",
      CellTags->"GenerateSG"],
    Cell[143294, 6084, 61, 1, 74, "Highlight",
      CellTags->"GenerateSG"],
    Cell[143358, 6087, 183, 6, 43, "Usage",
      CellTags->"GenerateSG"],
    Cell[143544, 6095, 442, 13, 152, "Notes",
      CellTags->"GenerateSG"],
    Cell[143989, 6110, 154, 5, 33, "Notes",
      CellTags->"GenerateSG"],
    Cell[144146, 6117, 389, 15, 54, "Notes",
      CellTags->"GenerateSG"],
    Cell[144538, 6134, 172, 5, 33, "Notes",
      CellTags->"GenerateSG"],
    Cell[144713, 6141, 120, 4, 33, "Notes",
      CellTags->"GenerateSG"],
    Cell[144836, 6147, 261, 6, 54, "Notes",
      CellTags->"GenerateSG"],
    Cell[145100, 6155, 161, 4, 33, "Notes",
      CellTags->"GenerateSG"],
    Cell[145264, 6161, 407, 19, 33, "Notes",
      CellTags->"GenerateSG"],
    Cell[145696, 6184, 68, 1, 59, "ExampleSection",
      CellTags->"GenerateSG"],
    Cell[145767, 6187, 131, 4, 70, "ExampleText",
      CellTags->"GenerateSG"],
    Cell[145923, 6195, 136, 6, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[146474, 6224, 140, 4, 70, "ExampleText",
      CellTags->"GenerateSG"],
    Cell[146617, 6230, 145, 4, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[146787, 6238, 104, 3, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[146894, 6243, 678, 18, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[147587, 6264, 149, 4, 70, "ExampleText",
      CellTags->"GenerateSG"],
    Cell[147761, 6272, 108, 3, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[147872, 6277, 95, 3, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[147982, 6283, 170, 4, 70, "ExampleText",
      CellTags->"GenerateSG"],
    Cell[148177, 6291, 102, 3, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[148282, 6296, 1094, 25, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[149413, 6326, 115, 3, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[149531, 6331, 89, 3, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[149657, 6339, 138, 3, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[149798, 6344, 788, 21, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[150601, 6368, 166, 4, 70, "ExampleText",
      CellTags->"GenerateSG"],
    Cell[150770, 6374, 139, 3, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[150912, 6379, 157, 4, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[151094, 6387, 140, 4, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[151237, 6393, 88, 3, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[151328, 6398, 119, 3, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[151462, 6404, 249, 8, 70, "ExampleText",
      Evaluatable->False,
      CellTags->"GenerateSG"],
    Cell[151736, 6416, 331, 8, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[152070, 6426, 1736, 45, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[153809, 6473, 1549, 37, 70, "Output",
      CellTags->"GenerateSG"],
    Cell[155373, 6513, 227, 8, 70, "ExampleText",
      Evaluatable->False,
      CellTags->"GenerateSG"],
    Cell[155625, 6525, 100, 3, 70, "Input",
      CellTags->"GenerateSG"],
    Cell[155728, 6530, 90, 3, 70, "Output",
      CellTags->"GenerateSG"]},
  "GreenHQT"->{
    Cell[155879, 6540, 54, 1, 42, "ObjectName",
      CellTags->"GreenHQT"],
    Cell[155936, 6543, 59, 1, 74, "Highlight",
      CellTags->"GreenHQT"],
    Cell[155998, 6546, 250, 10, 43, "Usage",
      CellTags->"GreenHQT"],
    Cell[156251, 6558, 500, 19, 33, "Notes",
      CellTags->"GreenHQT"]},
  "GreenJQT"->{
    Cell[156788, 6582, 54, 1, 42, "ObjectName",
      CellTags->"GreenJQT"],
    Cell[156845, 6585, 59, 1, 74, "Highlight",
      CellTags->"GreenJQT"],
    Cell[156907, 6588, 250, 10, 43, "Usage",
      CellTags->"GreenJQT"],
    Cell[157160, 6600, 500, 19, 33, "Notes",
      CellTags->"GreenJQT"]},
  "GreenLQT"->{
    Cell[157697, 6624, 54, 1, 42, "ObjectName",
      CellTags->"GreenLQT"],
    Cell[157754, 6627, 59, 1, 74, "Highlight",
      CellTags->"GreenLQT"],
    Cell[157816, 6630, 250, 10, 43, "Usage",
      CellTags->"GreenLQT"],
    Cell[158069, 6642, 500, 19, 33, "Notes",
      CellTags->"GreenLQT"]},
  "GreenRQT"->{
    Cell[158606, 6666, 54, 1, 42, "ObjectName",
      CellTags->"GreenRQT"],
    Cell[158663, 6669, 59, 1, 74, "Highlight",
      CellTags->"GreenRQT"],
    Cell[158725, 6672, 250, 10, 43, "Usage",
      CellTags->"GreenRQT"],
    Cell[158978, 6684, 500, 19, 33, "Notes",
      CellTags->"GreenRQT"]},
  "GridLine"->{
    Cell[159515, 6708, 54, 1, 42, "ObjectName",
      CellTags->"GridLine"],
    Cell[159572, 6711, 59, 1, 74, "Highlight",
      CellTags->"GridLine"],
    Cell[159634, 6714, 218, 8, 43, "Usage",
      CellTags->"GridLine"],
    Cell[159855, 6724, 353, 11, 104, "Notes",
      CellTags->"GridLine"],
    Cell[160211, 6737, 90, 1, 33, "Notes",
      CellTags->"GridLine"],
    Cell[160304, 6740, 259, 11, 33, "Notes",
      CellTags->"GridLine"],
    Cell[160588, 6755, 66, 1, 59, "ExampleSection",
      CellTags->"GridLine"],
    Cell[160657, 6758, 62, 1, 70, "ExampleText",
      CellTags->"GridLine"],
    Cell[160744, 6763, 114, 3, 70, "Input",
      CellTags->"GridLine"],
    Cell[160861, 6768, 1135, 75, 70, 958, 69, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"GridLine"],
    Cell[162011, 6846, 80, 1, 70, "ExampleText",
      CellTags->"GridLine"],
    Cell[162094, 6849, 325, 8, 70, "Input",
      CellTags->"GridLine"],
    Cell[162444, 6861, 81, 2, 70, "Input",
      CellTags->"GridLine"],
    Cell[162528, 6865, 1241, 83, 70, 1063, 77, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"GridLine"]},
  "GridPoints"->{
    Cell[163830, 6955, 58, 1, 42, "ObjectName",
      CellTags->"GridPoints"],
    Cell[163891, 6958, 61, 1, 74, "Highlight",
      CellTags->"GridPoints"],
    Cell[163955, 6961, 221, 8, 43, "Usage",
      CellTags->"GridPoints"],
    Cell[164179, 6971, 458, 14, 128, "Notes",
      CellTags->"GridPoints"],
    Cell[164640, 6987, 91, 1, 33, "Notes",
      CellTags->"GridPoints"],
    Cell[164734, 6990, 257, 11, 33, "Notes",
      CellTags->"GridPoints"],
    Cell[165016, 7005, 68, 1, 59, "ExampleSection",
      CellTags->"GridPoints"],
    Cell[165087, 7008, 65, 1, 70, "ExampleText",
      CellTags->"GridPoints"],
    Cell[165177, 7013, 144, 4, 70, "Input",
      CellTags->"GridPoints"],
    Cell[165324, 7019, 1249, 69, 70, 1070, 63, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"GridPoints"],
    Cell[166588, 7091, 72, 1, 70, "ExampleText",
      CellTags->"GridPoints"],
    Cell[166685, 7096, 355, 7, 70, "Input",
      CellTags->"GridPoints"],
    Cell[167043, 7105, 8471, 468, 70, 8292, 462, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"GridPoints"]},
  "HClassSize"->{
    Cell[175575, 7580, 58, 1, 42, "ObjectName",
      CellTags->"HClassSize"],
    Cell[175636, 7583, 61, 1, 74, "Highlight",
      CellTags->"HClassSize"],
    Cell[175700, 7586, 173, 6, 43, "Usage",
      CellTags->"HClassSize"],
    Cell[175876, 7594, 110, 5, 33, "Notes",
      CellTags->"HClassSize"],
    Cell[175989, 7601, 271, 11, 33, "Notes",
      CellTags->"HClassSize"]},
  "HClassT"->{
    Cell[176297, 7617, 52, 1, 42, "ObjectName",
      CellTags->"HClassT"],
    Cell[176352, 7620, 58, 1, 74, "Highlight",
      CellTags->"HClassT"],
    Cell[176413, 7623, 206, 8, 43, "Usage",
      CellTags->"HClassT"],
    Cell[176622, 7633, 79, 1, 33, "Notes",
      CellTags->"HClassT"],
    Cell[176704, 7636, 149, 7, 33, "Notes",
      CellTags->"HClassT"]},
  "HTrivialQSG"->{
    Cell[176890, 7648, 60, 1, 42, "ObjectName",
      CellTags->"HTrivialQSG"],
    Cell[176953, 7651, 62, 1, 74, "Highlight",
      CellTags->"HTrivialQSG"],
    Cell[177018, 7654, 165, 6, 43, "Usage",
      CellTags->"HTrivialQSG"],
    Cell[177186, 7662, 692, 27, 54, "Notes",
      CellTags->"HTrivialQSG"]},
  "HueRasterColors"->{
    Cell[177915, 7694, 68, 1, 42, "ObjectName",
      CellTags->"HueRasterColors"],
    Cell[177986, 7697, 66, 1, 74, "Highlight",
      CellTags->"HueRasterColors"],
    Cell[178055, 7700, 179, 6, 43, "Usage",
      CellTags->"HueRasterColors"],
    Cell[178237, 7708, 132, 5, 33, "Notes",
      CellTags->"HueRasterColors"],
    Cell[178372, 7715, 400, 15, 33, "Notes",
      CellTags->"HueRasterColors"],
    Cell[178797, 7734, 73, 1, 59, "ExampleSection",
      CellTags->"HueRasterColors"],
    Cell[178873, 7737, 76, 1, 70, "ExampleText",
      CellTags->"HueRasterColors"],
    Cell[178952, 7740, 142, 3, 70, "Input",
      CellTags->"HueRasterColors"],
    Cell[179119, 7747, 151, 4, 70, "Input",
      CellTags->"HueRasterColors"],
    Cell[179273, 7753, 7350, 171, 70, 7170, 165, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"HueRasterColors"]},
  "IdealT"->{
    Cell[186684, 7931, 50, 1, 42, "ObjectName",
      CellTags->"IdealT"],
    Cell[186737, 7934, 57, 1, 74, "Highlight",
      CellTags->"IdealT"],
    Cell[186797, 7937, 220, 8, 43, "Usage",
      CellTags->"IdealT"],
    Cell[187020, 7947, 73, 1, 33, "Notes",
      CellTags->"IdealT"],
    Cell[187096, 7950, 257, 11, 33, "Notes",
      CellTags->"IdealT"],
    Cell[187378, 7965, 64, 1, 59, "ExampleSection",
      CellTags->"IdealT"],
    Cell[187445, 7968, 125, 4, 70, "ExampleText",
      CellTags->"IdealT"],
    Cell[187573, 7974, 108, 3, 70, "Input",
      CellTags->"IdealT"],
    Cell[187706, 7981, 107, 3, 70, "Input",
      CellTags->"IdealT"],
    Cell[187816, 7986, 117, 3, 70, "Output",
      CellTags->"IdealT"],
    Cell[187970, 7994, 107, 3, 70, "Input",
      CellTags->"IdealT"],
    Cell[188080, 7999, 354, 6, 70, "Output",
      CellTags->"IdealT"]},
  "IdemQT"->{
    Cell[188495, 8012, 50, 1, 42, "ObjectName",
      CellTags->"IdemQT"],
    Cell[188548, 8015, 57, 1, 74, "Highlight",
      CellTags->"IdemQT"],
    Cell[188608, 8018, 161, 6, 43, "Usage",
      CellTags->"IdemQT"],
    Cell[188772, 8026, 341, 15, 33, "Notes",
      CellTags->"IdemQT"],
    Cell[189138, 8045, 64, 1, 59, "ExampleSection",
      CellTags->"IdemQT"],
    Cell[189205, 8048, 91, 1, 70, "ExampleText",
      CellTags->"IdemQT"],
    Cell[189299, 8051, 115, 3, 70, "Input",
      CellTags->"IdemQT"],
    Cell[189439, 8058, 99, 3, 70, "Input",
      CellTags->"IdemQT"],
    Cell[189541, 8063, 210, 5, 70, "Output",
      CellTags->"IdemQT"]},
  "IdemSG"->{
    Cell[189812, 8075, 50, 1, 42, "ObjectName",
      CellTags->"IdemSG"],
    Cell[189865, 8078, 57, 1, 74, "Highlight",
      CellTags->"IdemSG"],
    Cell[189925, 8081, 163, 6, 43, "Usage",
      CellTags->"IdemSG"],
    Cell[190091, 8089, 73, 1, 33, "Notes",
      CellTags->"IdemSG"],
    Cell[190167, 8092, 341, 15, 33, "Notes",
      CellTags->"IdemSG"],
    Cell[190533, 8111, 64, 1, 59, "ExampleSection",
      CellTags->"IdemSG"],
    Cell[190600, 8114, 91, 1, 70, "ExampleText",
      CellTags->"IdemSG"],
    Cell[190694, 8117, 108, 3, 70, "Input",
      CellTags->"IdemSG"],
    Cell[190827, 8124, 89, 3, 70, "Input",
      CellTags->"IdemSG"],
    Cell[190919, 8129, 210, 5, 70, "Output",
      CellTags->"IdemSG"]},
  "ImageT"->{
    Cell[191190, 8141, 50, 1, 42, "ObjectName",
      CellTags->"ImageT"],
    Cell[191243, 8144, 57, 1, 74, "Highlight",
      CellTags->"ImageT"],
    Cell[191303, 8147, 171, 6, 43, "Usage",
      CellTags->"ImageT"],
    Cell[191477, 8155, 106, 5, 33, "Notes",
      CellTags->"ImageT"],
    Cell[191586, 8162, 457, 19, 33, "Notes",
      CellTags->"ImageT"],
    Cell[192068, 8185, 64, 1, 59, "ExampleSection",
      CellTags->"ImageT"],
    Cell[192135, 8188, 91, 1, 70, "ExampleText",
      CellTags->"ImageT"],
    Cell[192251, 8193, 197, 5, 70, "Input",
      CellTags->"ImageT"],
    Cell[192451, 8200, 1404, 37, 70, "Output",
      CellTags->"ImageT"]},
  "IndToWitnesses"->{
    Cell[193916, 8244, 66, 1, 42, "ObjectName",
      CellTags->"IndToWitnesses"],
    Cell[193985, 8247, 65, 1, 74, "Highlight",
      CellTags->"IndToWitnesses"],
    Cell[194053, 8250, 253, 7, 70, "Usage",
      CellTags->"IndToWitnesses"],
    Cell[194309, 8259, 225, 6, 33, "Notes",
      CellTags->"IndToWitnesses"],
    Cell[194537, 8267, 262, 11, 33, "Notes",
      CellTags->"IndToWitnesses"],
    Cell[194824, 8282, 72, 1, 59, "ExampleSection",
      CellTags->"IndToWitnesses"],
    Cell[194899, 8285, 76, 1, 70, "ExampleText",
      CellTags->"IndToWitnesses"],
    Cell[195000, 8290, 130, 3, 70, "Input",
      CellTags->"IndToWitnesses"]},
  "InGroupQT"->{
    Cell[195277, 8304, 56, 1, 42, "ObjectName",
      CellTags->"InGroupQT"],
    Cell[195336, 8307, 60, 1, 74, "Highlight",
      CellTags->"InGroupQT"],
    Cell[195399, 8310, 169, 6, 43, "Usage",
      CellTags->"InGroupQT"],
    Cell[195571, 8318, 344, 15, 33, "Notes",
      CellTags->"InGroupQT"],
    Cell[195940, 8337, 67, 1, 59, "ExampleSection",
      CellTags->"InGroupQT"],
    Cell[196010, 8340, 94, 1, 70, "ExampleText",
      CellTags->"InGroupQT"],
    Cell[196107, 8343, 118, 3, 70, "Input",
      CellTags->"InGroupQT"],
    Cell[196250, 8350, 109, 3, 70, "Input",
      CellTags->"InGroupQT"],
    Cell[196362, 8355, 357, 6, 70, "Output",
      CellTags->"InGroupQT"]},
  "InGroupSG"->{
    Cell[196780, 8368, 56, 1, 42, "ObjectName",
      CellTags->"InGroupSG"],
    Cell[196839, 8371, 60, 1, 74, "Highlight",
      CellTags->"InGroupSG"],
    Cell[196902, 8374, 218, 8, 43, "Usage",
      CellTags->"InGroupSG"],
    Cell[197123, 8384, 76, 1, 33, "Notes",
      CellTags->"InGroupSG"],
    Cell[197202, 8387, 344, 15, 33, "Notes",
      CellTags->"InGroupSG"],
    Cell[197571, 8406, 67, 1, 59, "ExampleSection",
      CellTags->"InGroupSG"],
    Cell[197641, 8409, 94, 1, 70, "ExampleText",
      CellTags->"InGroupSG"],
    Cell[197738, 8412, 111, 3, 70, "Input",
      CellTags->"InGroupSG"],
    Cell[197874, 8419, 123, 4, 70, "Input",
      CellTags->"InGroupSG"],
    Cell[198000, 8425, 213, 5, 70, "Output",
      CellTags->"InGroupSG"],
    Cell[198216, 8432, 357, 6, 70, "Output",
      CellTags->"InGroupSG"],
    Cell[198610, 8443, 118, 3, 70, "Input",
      CellTags->"InGroupSG"],
    Cell[198731, 8448, 163, 4, 70, "Output",
      CellTags->"InGroupSG"]},
  "InverseT"->{
    Cell[198955, 8459, 54, 1, 42, "ObjectName",
      CellTags->"InverseT"],
    Cell[199012, 8462, 59, 1, 74, "Highlight",
      CellTags->"InverseT"],
    Cell[199074, 8465, 163, 6, 43, "Usage",
      CellTags->"InverseT"],
    Cell[199240, 8473, 142, 5, 33, "Notes",
      CellTags->"InverseT"],
    Cell[199385, 8480, 247, 11, 33, "Notes",
      CellTags->"InverseT"],
    Cell[199657, 8495, 66, 1, 59, "ExampleSection",
      CellTags->"InverseT"],
    Cell[199726, 8498, 95, 1, 70, "ExampleText",
      CellTags->"InverseT"],
    Cell[199846, 8503, 141, 5, 70, "Input",
      CellTags->"InverseT"],
    Cell[199990, 8510, 563, 16, 70, "Output",
      CellTags->"InverseT"]},
  "IrreducibleQ"->{
    Cell[200614, 8533, 62, 1, 42, "ObjectName",
      CellTags->"IrreducibleQ"],
    Cell[200679, 8536, 63, 1, 74, "Highlight",
      CellTags->"IrreducibleQ"],
    Cell[200745, 8539, 228, 8, 43, "Usage",
      CellTags->"IrreducibleQ"],
    Cell[200976, 8549, 139, 5, 33, "Notes",
      CellTags->"IrreducibleQ"],
    Cell[201118, 8556, 275, 11, 33, "Notes",
      CellTags->"IrreducibleQ"],
    Cell[201418, 8571, 70, 1, 59, "ExampleSection",
      CellTags->"IrreducibleQ"],
    Cell[201491, 8574, 74, 1, 70, "ExampleText",
      CellTags->"IrreducibleQ"],
    Cell[201568, 8577, 126, 3, 70, "Input",
      CellTags->"IrreducibleQ"],
    Cell[201719, 8584, 166, 4, 70, "Input",
      CellTags->"IrreducibleQ"],
    Cell[201888, 8590, 92, 3, 70, "Output",
      CellTags->"IrreducibleQ"],
    Cell[201983, 8595, 91, 3, 70, "Output",
      CellTags->"IrreducibleQ"]},
  "JTrivialQSG"->{
    Cell[202135, 8605, 60, 1, 42, "ObjectName",
      CellTags->"JTrivialQSG"],
    Cell[202198, 8608, 62, 1, 74, "Highlight",
      CellTags->"JTrivialQSG"],
    Cell[202263, 8611, 164, 6, 43, "Usage",
      CellTags->"JTrivialQSG"],
    Cell[202430, 8619, 92, 1, 33, "Notes",
      CellTags->"JTrivialQSG"],
    Cell[202525, 8622, 142, 5, 33, "Notes",
      CellTags->"JTrivialQSG"],
    Cell[202670, 8629, 692, 27, 54, "Notes",
      CellTags->"JTrivialQSG"]},
  "JTrivialSG"->{
    Cell[203399, 8661, 58, 1, 42, "ObjectName",
      CellTags->"JTrivialSG"],
    Cell[203460, 8664, 61, 1, 74, "Highlight",
      CellTags->"JTrivialSG"],
    Cell[203524, 8667, 186, 5, 64, "Usage",
      CellTags->"JTrivialSG"],
    Cell[203713, 8674, 185, 6, 33, "Notes",
      CellTags->"JTrivialSG"],
    Cell[203901, 8682, 484, 19, 33, "Notes",
      CellTags->"JTrivialSG"],
    Cell[204410, 8705, 68, 1, 59, "ExampleSection",
      CellTags->"JTrivialSG"],
    Cell[204481, 8708, 75, 1, 70, "ExampleText",
      CellTags->"JTrivialSG"],
    Cell[204581, 8713, 97, 3, 70, "Input",
      CellTags->"JTrivialSG"],
    Cell[204681, 8718, 318, 6, 70, "Output",
      CellTags->"JTrivialSG"],
    Cell[205036, 8729, 100, 3, 70, "Input",
      CellTags->"JTrivialSG"],
    Cell[205139, 8734, 236, 5, 70, "Output",
      CellTags->"JTrivialSG"],
    Cell[205412, 8744, 82, 2, 70, "Input",
      CellTags->"JTrivialSG"],
    Cell[205497, 8748, 89, 3, 70, "Output",
      CellTags->"JTrivialSG"]},
  "KernelImageToT"->{
    Cell[205647, 8758, 66, 1, 42, "ObjectName",
      CellTags->"KernelImageToT"],
    Cell[205716, 8761, 65, 1, 74, "Highlight",
      CellTags->"KernelImageToT"],
    Cell[205784, 8764, 167, 4, 43, "Usage",
      CellTags->"KernelImageToT"],
    Cell[205954, 8770, 145, 4, 33, "Notes",
      CellTags->"KernelImageToT"],
    Cell[206102, 8776, 467, 19, 33, "Notes",
      CellTags->"KernelImageToT"],
    Cell[206594, 8799, 72, 1, 59, "ExampleSection",
      CellTags->"KernelImageToT"],
    Cell[206669, 8802, 128, 4, 70, "ExampleText",
      CellTags->"KernelImageToT"],
    Cell[206822, 8810, 88, 2, 70, "Input",
      CellTags->"KernelImageToT"],
    Cell[206913, 8814, 122, 3, 70, "Output",
      CellTags->"KernelImageToT"],
    Cell[207072, 8822, 145, 4, 70, "Input",
      CellTags->"KernelImageToT"],
    Cell[207220, 8828, 112, 3, 70, "Output",
      CellTags->"KernelImageToT"],
    Cell[207335, 8833, 135, 3, 70, "Output",
      CellTags->"KernelImageToT"],
    Cell[207507, 8841, 111, 3, 70, "Input",
      CellTags->"KernelImageToT"],
    Cell[207621, 8846, 122, 3, 70, "Output",
      CellTags->"KernelImageToT"]},
  "KernelT"->{
    Cell[207804, 8856, 52, 1, 42, "ObjectName",
      CellTags->"KernelT"],
    Cell[207859, 8859, 58, 1, 74, "Highlight",
      CellTags->"KernelT"],
    Cell[207920, 8862, 155, 6, 43, "Usage",
      CellTags->"KernelT"],
    Cell[208078, 8870, 107, 5, 33, "Notes",
      CellTags->"KernelT"],
    Cell[208188, 8877, 233, 6, 54, "Notes",
      CellTags->"KernelT"],
    Cell[208424, 8885, 456, 19, 33, "Notes",
      CellTags->"KernelT"],
    Cell[208905, 8908, 65, 1, 59, "ExampleSection",
      CellTags->"KernelT"],
    Cell[208973, 8911, 93, 1, 70, "ExampleText",
      CellTags->"KernelT"],
    Cell[209091, 8916, 197, 5, 70, "Input",
      CellTags->"KernelT"],
    Cell[209291, 8923, 1589, 37, 70, "Output",
      CellTags->"KernelT"]},
  "KPermutationsR"->{
    Cell[210941, 8967, 66, 1, 42, "ObjectName",
      CellTags->"KPermutationsR"],
    Cell[211010, 8970, 65, 1, 74, "Highlight",
      CellTags->"KPermutationsR"],
    Cell[211078, 8973, 249, 8, 64, "Usage",
      CellTags->"KPermutationsR"],
    Cell[211330, 8983, 193, 8, 33, "Notes",
      CellTags->"KPermutationsR"],
    Cell[211526, 8993, 277, 11, 33, "Notes",
      CellTags->"KPermutationsR"],
    Cell[211806, 9006, 171, 7, 33, "Notes",
      CellTags->"KPermutationsR"],
    Cell[212002, 9017, 72, 1, 59, "ExampleSection",
      CellTags->"KPermutationsR"],
    Cell[212077, 9020, 83, 1, 70, "ExampleText",
      CellTags->"KPermutationsR"],
    Cell[212185, 9025, 97, 2, 70, "Input",
      CellTags->"KPermutationsR"],
    Cell[212285, 9029, 422, 7, 70, "Output",
      CellTags->"KPermutationsR"],
    Cell[212744, 9041, 96, 2, 70, "Input",
      CellTags->"KPermutationsR"],
    Cell[212843, 9045, 237, 5, 70, "Output",
      CellTags->"KPermutationsR"]},
  "LabelEdgeList"->{
    Cell[213141, 9057, 64, 1, 42, "ObjectName",
      CellTags->"LabelEdgeList"],
    Cell[213208, 9060, 64, 1, 74, "Highlight",
      CellTags->"LabelEdgeList"],
    Cell[213275, 9063, 181, 6, 43, "Usage",
      CellTags->"LabelEdgeList"],
    Cell[213459, 9071, 96, 1, 33, "Notes",
      CellTags->"LabelEdgeList"],
    Cell[213558, 9074, 245, 11, 33, "Notes",
      CellTags->"LabelEdgeList"],
    Cell[213828, 9089, 71, 1, 59, "ExampleSection",
      CellTags->"LabelEdgeList"],
    Cell[213902, 9092, 89, 1, 70, "ExampleText",
      CellTags->"LabelEdgeList"],
    Cell[214016, 9097, 88, 2, 70, "Input",
      CellTags->"LabelEdgeList"],
    Cell[214107, 9101, 270, 8, 70, "Output",
      CellTags->"LabelEdgeList"],
    Cell[214414, 9114, 117, 3, 70, "Input",
      CellTags->"LabelEdgeList"],
    Cell[214534, 9119, 279, 8, 70, "Output",
      CellTags->"LabelEdgeList"]},
  "LeftIdealT"->{
    Cell[214874, 9134, 58, 1, 42, "ObjectName",
      CellTags->"LeftIdealT"],
    Cell[214935, 9137, 61, 1, 74, "Highlight",
      CellTags->"LeftIdealT"],
    Cell[214999, 9140, 167, 4, 43, "Usage",
      CellTags->"LeftIdealT"],
    Cell[215169, 9146, 77, 1, 33, "Notes",
      CellTags->"LeftIdealT"],
    Cell[215249, 9149, 253, 11, 33, "Notes",
      CellTags->"LeftIdealT"],
    Cell[215527, 9164, 68, 1, 59, "ExampleSection",
      CellTags->"LeftIdealT"],
    Cell[215598, 9167, 134, 4, 70, "ExampleText",
      CellTags->"LeftIdealT"],
    Cell[215735, 9173, 112, 3, 70, "Input",
      CellTags->"LeftIdealT"],
    Cell[215872, 9180, 115, 3, 70, "Input",
      CellTags->"LeftIdealT"],
    Cell[215990, 9185, 97, 3, 70, "Output",
      CellTags->"LeftIdealT"],
    Cell[216124, 9193, 115, 3, 70, "Input",
      CellTags->"LeftIdealT"],
    Cell[216242, 9198, 188, 4, 70, "Output",
      CellTags->"LeftIdealT"]},
  "LeftNullQT"->{
    Cell[216491, 9209, 58, 1, 42, "ObjectName",
      CellTags->"LeftNullQT"],
    Cell[216552, 9212, 61, 1, 74, "Highlight",
      CellTags->"LeftNullQT"],
    Cell[216616, 9215, 205, 8, 43, "Usage",
      CellTags->"LeftNullQT"],
    Cell[216824, 9225, 53, 1, 33, "Notes",
      CellTags->"LeftNullQT"],
    Cell[216880, 9228, 163, 7, 33, "Notes",
      CellTags->"LeftNullQT"]},
  "LeftNullSG"->{
    Cell[217080, 9240, 58, 1, 42, "ObjectName",
      CellTags->"LeftNullSG"],
    Cell[217141, 9243, 61, 1, 74, "Highlight",
      CellTags->"LeftNullSG"],
    Cell[217205, 9246, 162, 6, 43, "Usage",
      CellTags->"LeftNullSG"],
    Cell[217370, 9254, 77, 1, 33, "Notes",
      CellTags->"LeftNullSG"],
    Cell[217450, 9257, 340, 15, 33, "Notes",
      CellTags->"LeftNullSG"],
    Cell[217815, 9276, 68, 1, 59, "ExampleSection",
      CellTags->"LeftNullSG"],
    Cell[217886, 9279, 123, 4, 70, "ExampleText",
      CellTags->"LeftNullSG"],
    Cell[218012, 9285, 92, 2, 70, "Input",
      CellTags->"LeftNullSG"],
    Cell[218129, 9291, 98, 3, 70, "Input",
      CellTags->"LeftNullSG"],
    Cell[218230, 9296, 88, 3, 70, "Output",
      CellTags->"LeftNullSG"]},
  "LeftOneQT"->{
    Cell[218379, 9306, 56, 1, 42, "ObjectName",
      CellTags->"LeftOneQT"],
    Cell[218438, 9309, 60, 1, 74, "Highlight",
      CellTags->"LeftOneQT"],
    Cell[218501, 9312, 207, 8, 43, "Usage",
      CellTags->"LeftOneQT"],
    Cell[218711, 9322, 160, 7, 33, "Notes",
      CellTags->"LeftOneQT"]},
  "LeftOneSG"->{
    Cell[218908, 9334, 56, 1, 42, "ObjectName",
      CellTags->"LeftOneSG"],
    Cell[218967, 9337, 60, 1, 74, "Highlight",
      CellTags->"LeftOneSG"],
    Cell[219030, 9340, 165, 6, 43, "Usage",
      CellTags->"LeftOneSG"],
    Cell[219198, 9348, 76, 1, 33, "Notes",
      CellTags->"LeftOneSG"],
    Cell[219277, 9351, 430, 19, 33, "Notes",
      CellTags->"LeftOneSG"],
    Cell[219732, 9374, 67, 1, 59, "ExampleSection",
      CellTags->"LeftOneSG"],
    Cell[219802, 9377, 138, 4, 70, "ExampleText",
      CellTags->"LeftOneSG"],
    Cell[219943, 9383, 91, 2, 70, "Input",
      CellTags->"LeftOneSG"],
    Cell[220059, 9389, 95, 3, 70, "Input",
      CellTags->"LeftOneSG"],
    Cell[220157, 9394, 96, 3, 70, "Output",
      CellTags->"LeftOneSG"]},
  "LocallyCommQSG"->{
    Cell[220314, 9404, 66, 1, 42, "ObjectName",
      CellTags->"LocallyCommQSG"],
    Cell[220383, 9407, 65, 1, 74, "Highlight",
      CellTags->"LocallyCommQSG"],
    Cell[220451, 9410, 175, 6, 43, "Usage",
      CellTags->"LocallyCommQSG"],
    Cell[220629, 9418, 232, 9, 33, "Notes",
      CellTags->"LocallyCommQSG"],
    Cell[220864, 9429, 695, 27, 54, "Notes",
      CellTags->"LocallyCommQSG"]},
  "LocallyIdemQSG"->{
    Cell[221596, 9461, 66, 1, 42, "ObjectName",
      CellTags->"LocallyIdemQSG"],
    Cell[221665, 9464, 65, 1, 74, "Highlight",
      CellTags->"LocallyIdemQSG"],
    Cell[221733, 9467, 147, 4, 43, "Usage",
      CellTags->"LocallyIdemQSG"],
    Cell[221883, 9473, 231, 9, 33, "Notes",
      CellTags->"LocallyIdemQSG"],
    Cell[222117, 9484, 689, 27, 54, "Notes",
      CellTags->"LocallyIdemQSG"]},
  "LongestPath"->{
    Cell[222843, 9516, 60, 1, 42, "ObjectName",
      CellTags->"LongestPath"],
    Cell[222906, 9519, 62, 1, 74, "Highlight",
      CellTags->"LongestPath"],
    Cell[222971, 9522, 189, 6, 43, "Usage",
      CellTags->"LongestPath"],
    Cell[223163, 9530, 227, 9, 58, "Notes",
      CellTags->"LongestPath"],
    Cell[223393, 9541, 166, 5, 33, "Notes",
      CellTags->"LongestPath"],
    Cell[223562, 9548, 151, 4, 33, "Notes",
      CellTags->"LongestPath"],
    Cell[223716, 9554, 204, 5, 54, "Notes",
      CellTags->"LongestPath"],
    Cell[223923, 9561, 286, 11, 33, "Notes",
      CellTags->"LongestPath"],
    Cell[224234, 9576, 69, 1, 59, "ExampleSection",
      CellTags->"LongestPath"],
    Cell[224306, 9579, 72, 1, 70, "ExampleText",
      CellTags->"LongestPath"],
    Cell[224381, 9582, 184, 6, 70, "Input",
      CellTags->"LongestPath"],
    Cell[224590, 9592, 103, 3, 70, "Input",
      CellTags->"LongestPath"],
    Cell[224696, 9597, 87, 3, 70, "Output",
      CellTags->"LongestPath"],
    Cell[224798, 9603, 86, 1, 70, "ExampleText",
      CellTags->"LongestPath"],
    Cell[224909, 9608, 120, 3, 70, "Input",
      CellTags->"LongestPath"],
    Cell[225032, 9613, 104, 3, 70, "Output",
      CellTags->"LongestPath"]},
  "LShiftT"->{
    Cell[225197, 9623, 52, 1, 42, "ObjectName",
      CellTags->"LShiftT"],
    Cell[225252, 9626, 58, 1, 74, "Highlight",
      CellTags->"LShiftT"],
    Cell[225313, 9629, 170, 6, 43, "Usage",
      CellTags->"LShiftT"],
    Cell[225486, 9637, 486, 19, 33, "Notes",
      CellTags->"LShiftT"]},
  "MakeAlphabet"->{
    Cell[226009, 9661, 62, 1, 42, "ObjectName",
      CellTags->"MakeAlphabet"],
    Cell[226074, 9664, 63, 1, 74, "Highlight",
      CellTags->"MakeAlphabet"],
    Cell[226140, 9667, 234, 10, 43, "Usage",
      CellTags->"MakeAlphabet"],
    Cell[226377, 9679, 166, 5, 33, "Notes",
      CellTags->"MakeAlphabet"],
    Cell[226546, 9686, 469, 19, 33, "Notes",
      CellTags->"MakeAlphabet"],
    Cell[227040, 9709, 70, 1, 59, "ExampleSection",
      CellTags->"MakeAlphabet"],
    Cell[227113, 9712, 93, 1, 70, "ExampleText",
      CellTags->"MakeAlphabet"],
    Cell[227231, 9717, 112, 5, 70, "Input",
      CellTags->"MakeAlphabet"],
    Cell[227346, 9724, 98, 3, 70, "Output",
      CellTags->"MakeAlphabet"],
    Cell[227447, 9729, 262, 8, 70, "Output",
      CellTags->"MakeAlphabet"]},
  "MakeFullAlphabet"->{
    Cell[227770, 9744, 70, 1, 42, "ObjectName",
      CellTags->"MakeFullAlphabet"],
    Cell[227843, 9747, 67, 1, 74, "Highlight",
      CellTags->"MakeFullAlphabet"],
    Cell[227913, 9750, 319, 12, 64, "Usage",
      CellTags->"MakeFullAlphabet"],
    Cell[228235, 9764, 170, 5, 33, "Notes",
      CellTags->"MakeFullAlphabet"],
    Cell[228408, 9771, 465, 19, 33, "Notes",
      CellTags->"MakeFullAlphabet"],
    Cell[228898, 9794, 74, 1, 59, "ExampleSection",
      CellTags->"MakeFullAlphabet"],
    Cell[228975, 9797, 97, 1, 70, "ExampleText",
      CellTags->"MakeFullAlphabet"],
    Cell[229097, 9802, 120, 5, 70, "Input",
      CellTags->"MakeFullAlphabet"],
    Cell[229220, 9809, 107, 3, 70, "Output",
      CellTags->"MakeFullAlphabet"],
    Cell[229330, 9814, 275, 8, 70, "Output",
      CellTags->"MakeFullAlphabet"]},
  "MakeIndex"->{
    Cell[229666, 9829, 56, 1, 42, "ObjectName",
      CellTags->"MakeIndex"],
    Cell[229725, 9832, 60, 1, 74, "Highlight",
      CellTags->"MakeIndex"],
    Cell[229788, 9835, 220, 8, 43, "Usage",
      CellTags->"MakeIndex"],
    Cell[230011, 9845, 129, 6, 33, "Notes",
      CellTags->"MakeIndex"],
    Cell[230143, 9853, 116, 2, 33, "Notes",
      CellTags->"MakeIndex"],
    Cell[230262, 9857, 205, 6, 33, "Notes",
      CellTags->"MakeIndex"],
    Cell[230470, 9865, 160, 7, 33, "Notes",
      CellTags->"MakeIndex"],
    Cell[230655, 9876, 67, 1, 59, "ExampleSection",
      CellTags->"MakeIndex"],
    Cell[230725, 9879, 71, 1, 70, "ExampleText",
      CellTags->"MakeIndex"],
    Cell[230821, 9884, 135, 3, 70, "Input",
      CellTags->"MakeIndex"],
    Cell[230959, 9889, 126, 3, 70, "Output",
      CellTags->"MakeIndex"]},
  "MakeMonoidSG"->{
    Cell[231146, 9899, 62, 1, 42, "ObjectName",
      CellTags->"MakeMonoidSG"],
    Cell[231211, 9902, 63, 1, 74, "Highlight",
      CellTags->"MakeMonoidSG"],
    Cell[231277, 9905, 194, 6, 43, "Usage",
      CellTags->"MakeMonoidSG"],
    Cell[231474, 9913, 163, 7, 33, "Notes",
      CellTags->"MakeMonoidSG"],
    Cell[231662, 9924, 70, 1, 59, "ExampleSection",
      CellTags->"MakeMonoidSG"],
    Cell[231735, 9927, 78, 1, 70, "ExampleText",
      CellTags->"MakeMonoidSG"],
    Cell[231816, 9930, 134, 3, 70, "Input",
      CellTags->"MakeMonoidSG"],
    Cell[231975, 9937, 102, 3, 70, "Input",
      CellTags->"MakeMonoidSG"],
    Cell[232080, 9942, 138, 3, 70, "Output",
      CellTags->"MakeMonoidSG"]},
  "MakePlotRange"->{
    Cell[232279, 9952, 64, 1, 31, "ObjectName",
      CellTags->"MakePlotRange"],
    Cell[232346, 9955, 64, 1, 74, "Highlight",
      CellTags->"MakePlotRange"],
    Cell[232413, 9958, 190, 6, 43, "Usage",
      CellTags->"MakePlotRange"],
    Cell[232606, 9966, 91, 1, 33, "Notes",
      CellTags->"MakePlotRange"]},
  "Merge12T"->{
    Cell[232734, 9972, 54, 1, 42, "ObjectName",
      CellTags->"Merge12T"],
    Cell[232791, 9975, 59, 1, 74, "Highlight",
      CellTags->"Merge12T"],
    Cell[232853, 9978, 161, 6, 43, "Usage",
      CellTags->"Merge12T"],
    Cell[233017, 9986, 101, 1, 33, "Notes",
      CellTags->"Merge12T"],
    Cell[233121, 9989, 350, 15, 33, "Notes",
      CellTags->"Merge12T"]},
  "MinusEins"->{
    Cell[233508, 10009, 56, 1, 42, "ObjectName",
      CellTags->"MinusEins"],
    Cell[233567, 10012, 59, 1, 74, "Highlight",
      CellTags->"MinusEins"],
    Cell[233629, 10015, 159, 7, 43, "Usage",
      CellTags->"MinusEins"],
    Cell[233791, 10024, 114, 5, 33, "Notes",
      CellTags->"MinusEins"],
    Cell[233908, 10031, 346, 15, 33, "Notes",
      CellTags->"MinusEins"]},
  "MinusZwei"->{
    Cell[234291, 10051, 56, 1, 42, "ObjectName",
      CellTags->"MinusZwei"],
    Cell[234350, 10054, 59, 1, 74, "Highlight",
      CellTags->"MinusZwei"],
    Cell[234412, 10057, 170, 6, 43, "Usage",
      CellTags->"MinusZwei"],
    Cell[234585, 10065, 114, 5, 33, "Notes",
      CellTags->"MinusZwei"],
    Cell[234702, 10072, 346, 15, 33, "Notes",
      CellTags->"MinusZwei"]},
  "MonoidQSG"->{
    Cell[235085, 10092, 56, 1, 42, "ObjectName",
      CellTags->"MonoidQSG"],
    Cell[235144, 10095, 60, 1, 74, "Highlight",
      CellTags->"MonoidQSG"],
    Cell[235207, 10098, 160, 6, 43, "Usage",
      CellTags->"MonoidQSG"],
    Cell[235370, 10106, 694, 27, 54, "Notes",
      CellTags->"MonoidQSG"]},
  "NilpotentQSG"->{
    Cell[236101, 10138, 62, 1, 42, "ObjectName",
      CellTags->"NilpotentQSG"],
    Cell[236166, 10141, 63, 1, 74, "Highlight",
      CellTags->"NilpotentQSG"],
    Cell[236232, 10144, 218, 6, 64, "Usage",
      CellTags->"NilpotentQSG"],
    Cell[236453, 10152, 691, 27, 54, "Notes",
      CellTags->"NilpotentQSG"]},
  "NonDecreasing"->{
    Cell[237181, 10184, 64, 1, 42, "ObjectName",
      CellTags->"NonDecreasing"],
    Cell[237248, 10187, 64, 1, 74, "Highlight",
      CellTags->"NonDecreasing"],
    Cell[237315, 10190, 289, 11, 43, "Usage",
      CellTags->"NonDecreasing"],
    Cell[237607, 10203, 282, 11, 33, "Notes",
      CellTags->"NonDecreasing"],
    Cell[237914, 10218, 71, 1, 59, "ExampleSection",
      CellTags->"NonDecreasing"],
    Cell[237988, 10221, 176, 6, 70, "ExampleText",
      CellTags->"NonDecreasing"],
    Cell[238189, 10231, 90, 2, 70, "Input",
      CellTags->"NonDecreasing"],
    Cell[238282, 10235, 491, 8, 70, "Output",
      CellTags->"NonDecreasing"]},
  "NonTransientGraph"->{
    Cell[238834, 10250, 72, 1, 42, "ObjectName",
      CellTags->"NonTransientGraph"],
    Cell[238909, 10253, 68, 1, 74, "Highlight",
      CellTags->"NonTransientGraph"],
    Cell[238980, 10256, 178, 6, 43, "Usage",
      CellTags->"NonTransientGraph"],
    Cell[239161, 10264, 261, 6, 54, "Notes",
      CellTags->"NonTransientGraph"],
    Cell[239425, 10272, 155, 5, 33, "Notes",
      CellTags->"NonTransientGraph"],
    Cell[239583, 10279, 416, 15, 33, "Notes",
      CellTags->"NonTransientGraph"],
    Cell[240024, 10298, 75, 1, 59, "ExampleSection",
      CellTags->"NonTransientGraph"],
    Cell[240102, 10301, 94, 1, 70, "ExampleText",
      CellTags->"NonTransientGraph"],
    Cell[240199, 10304, 237, 6, 70, "Input",
      CellTags->"NonTransientGraph"],
    Cell[240461, 10314, 143, 4, 70, "Input",
      CellTags->"NonTransientGraph"],
    Cell[240607, 10320, 266, 8, 70, "Output",
      CellTags->"NonTransientGraph"],
    Cell[240876, 10330, 117, 3, 70, "Output",
      CellTags->"NonTransientGraph"],
    Cell[424160, 18682, 107, 1, 70, "ExampleText",
      CellTags->"NonTransientGraph"],
    Cell[424270, 18685, 237, 6, 70, "Input",
      CellTags->"NonTransientGraph"]},
  "NormalizeGraph"->{
    Cell[241054, 10340, 66, 1, 42, "ObjectName",
      CellTags->"NormalizeGraph"],
    Cell[241123, 10343, 65, 1, 74, "Highlight",
      CellTags->"NormalizeGraph"],
    Cell[241191, 10346, 174, 6, 43, "Usage",
      CellTags->"NormalizeGraph"],
    Cell[241368, 10354, 201, 5, 54, "Notes",
      CellTags->"NormalizeGraph"],
    Cell[241572, 10361, 130, 4, 33, "Notes",
      CellTags->"NormalizeGraph"],
    Cell[241705, 10367, 355, 15, 33, "Notes",
      CellTags->"NormalizeGraph"],
    Cell[242085, 10386, 72, 1, 59, "ExampleSection",
      CellTags->"NormalizeGraph"],
    Cell[242160, 10389, 179, 5, 70, "ExampleText",
      CellTags->"NormalizeGraph"],
    Cell[242364, 10398, 193, 5, 70, "Input",
      CellTags->"NormalizeGraph"],
    Cell[242560, 10405, 263, 8, 70, "Output",
      CellTags->"NormalizeGraph"],
    Cell[242826, 10415, 114, 3, 70, "Output",
      CellTags->"NormalizeGraph"],
    Cell[242977, 10423, 147, 4, 70, "Input",
      CellTags->"NormalizeGraph"],
    Cell[243127, 10429, 263, 8, 70, "Output",
      CellTags->"NormalizeGraph"],
    Cell[243393, 10439, 99, 3, 70, "Output",
      CellTags->"NormalizeGraph"]},
  "NullQT"->{
    Cell[243553, 10449, 50, 1, 42, "ObjectName",
      CellTags->"NullQT"],
    Cell[243606, 10452, 57, 1, 74, "Highlight",
      CellTags->"NullQT"],
    Cell[243666, 10455, 202, 8, 43, "Usage",
      CellTags->"NullQT"],
    Cell[243871, 10465, 148, 7, 33, "Notes",
      CellTags->"NullQT"]},
  "NullSG"->{
    Cell[244056, 10477, 50, 1, 42, "ObjectName",
      CellTags->"NullSG"],
    Cell[244109, 10480, 57, 1, 74, "Highlight",
      CellTags->"NullSG"],
    Cell[244169, 10483, 170, 6, 43, "Usage",
      CellTags->"NullSG"],
    Cell[244342, 10491, 441, 19, 33, "Notes",
      CellTags->"NullSG"],
    Cell[244808, 10514, 64, 1, 59, "ExampleSection",
      CellTags->"NullSG"],
    Cell[244875, 10517, 69, 1, 70, "ExampleText",
      CellTags->"NullSG"],
    Cell[244947, 10520, 545, 10, 70, "Input",
      CellTags->"NullSG"],
    Cell[245517, 10534, 118, 4, 70, "Input",
      CellTags->"NullSG"],
    Cell[245638, 10540, 103, 3, 70, "Output",
      CellTags->"NullSG"],
    Cell[245744, 10545, 264, 5, 70, "Output",
      CellTags->"NullSG"]},
  "NumEdges"->{
    Cell[246069, 10557, 54, 1, 31, "ObjectName",
      CellTags->"NumEdges"],
    Cell[246126, 10560, 59, 1, 74, "Highlight",
      CellTags->"NumEdges"],
    Cell[246188, 10563, 161, 6, 43, "Usage",
      CellTags->"NumEdges"],
    Cell[246352, 10571, 338, 15, 33, "Notes",
      CellTags->"NumEdges"]},
  "NumVertices"->{
    Cell[246727, 10591, 60, 1, 42, "ObjectName",
      CellTags->"NumVertices"],
    Cell[246790, 10594, 62, 1, 74, "Highlight",
      CellTags->"NumVertices"],
    Cell[246855, 10597, 170, 6, 43, "Usage",
      CellTags->"NumVertices"],
    Cell[247028, 10605, 335, 15, 33, "Notes",
      CellTags->"NumVertices"]},
  "OneQT"->{
    Cell[247400, 10625, 48, 1, 42, "ObjectName",
      CellTags->"OneQT"],
    Cell[247451, 10628, 56, 1, 74, "Highlight",
      CellTags->"OneQT"],
    Cell[247510, 10631, 206, 8, 43, "Usage",
      CellTags->"OneQT"],
    Cell[247719, 10641, 233, 11, 33, "Notes",
      CellTags->"OneQT"],
    Cell[247977, 10656, 63, 1, 59, "ExampleSection",
      CellTags->"OneQT"],
    Cell[248043, 10659, 96, 1, 70, "ExampleText",
      CellTags->"OneQT"],
    Cell[248142, 10662, 205, 5, 70, "Input",
      CellTags->"OneQT"],
    Cell[248372, 10671, 121, 3, 70, "Input",
      CellTags->"OneQT"],
    Cell[248496, 10676, 122, 3, 70, "Output",
      CellTags->"OneQT"]},
  "OneSG"->{
    Cell[248679, 10686, 48, 1, 42, "ObjectName",
      CellTags->"OneSG"],
    Cell[248730, 10689, 56, 1, 74, "Highlight",
      CellTags->"OneSG"],
    Cell[248789, 10692, 164, 6, 43, "Usage",
      CellTags->"OneSG"],
    Cell[248956, 10700, 233, 11, 33, "Notes",
      CellTags->"OneSG"],
    Cell[249214, 10715, 63, 1, 59, "ExampleSection",
      CellTags->"OneSG"],
    Cell[249280, 10718, 94, 1, 70, "ExampleText",
      CellTags->"OneSG"],
    Cell[249399, 10723, 89, 2, 70, "Input",
      CellTags->"OneSG"],
    Cell[249491, 10727, 279, 6, 70, "Output",
      CellTags->"OneSG"],
    Cell[249807, 10738, 88, 3, 70, "Input",
      CellTags->"OneSG"],
    Cell[249898, 10743, 96, 3, 70, "Output",
      CellTags->"OneSG"],
    Cell[250009, 10749, 104, 2, 70, "ExampleText",
      CellTags->"OneSG"],
    Cell[250138, 10755, 122, 3, 70, "Input",
      CellTags->"OneSG"],
    Cell[250263, 10760, 119, 3, 70, "Output",
      CellTags->"OneSG"],
    Cell[250419, 10768, 88, 3, 70, "Input",
      CellTags->"OneSG"],
    Cell[250510, 10773, 83, 3, 70, "Output",
      CellTags->"OneSG"],
    Cell[250630, 10781, 94, 3, 70, "Input",
      CellTags->"OneSG"],
    Cell[250727, 10786, 117, 3, 70, "Output",
      CellTags->"OneSG"]},
  "OneT"->{
    Cell[250905, 10796, 46, 1, 42, "ObjectName",
      CellTags->"OneT"],
    Cell[250954, 10799, 55, 1, 74, "Highlight",
      CellTags->"OneT"],
    Cell[251012, 10802, 226, 8, 43, "Usage",
      CellTags->"OneT"],
    Cell[251241, 10812, 199, 6, 33, "Notes",
      CellTags->"OneT"],
    Cell[251443, 10820, 234, 11, 33, "Notes",
      CellTags->"OneT"],
    Cell[251702, 10835, 62, 1, 59, "ExampleSection",
      CellTags->"OneT"],
    Cell[251767, 10838, 83, 1, 70, "ExampleText",
      CellTags->"OneT"],
    Cell[251875, 10843, 71, 2, 70, "Input",
      CellTags->"OneT"],
    Cell[251949, 10847, 96, 3, 70, "Output",
      CellTags->"OneT"],
    Cell[252082, 10855, 112, 3, 70, "Input",
      CellTags->"OneT"],
    Cell[252197, 10860, 84, 3, 70, "Output",
      CellTags->"OneT"]},
  "OrderT"->{
    Cell[252342, 10870, 50, 1, 42, "ObjectName",
      CellTags->"OrderT"],
    Cell[252395, 10873, 57, 1, 74, "Highlight",
      CellTags->"OrderT"],
    Cell[252455, 10876, 125, 4, 43, "Usage",
      CellTags->"OrderT"],
    Cell[252583, 10882, 247, 11, 33, "Notes",
      CellTags->"OrderT"],
    Cell[252855, 10897, 64, 1, 59, "ExampleSection",
      CellTags->"OrderT"],
    Cell[252922, 10900, 121, 4, 70, "ExampleText",
      CellTags->"OrderT"],
    Cell[253046, 10906, 91, 2, 70, "Input",
      CellTags->"OrderT"],
    Cell[253162, 10912, 154, 4, 70, "Input",
      CellTags->"OrderT"],
    Cell[253319, 10918, 276, 5, 70, "Output",
      CellTags->"OrderT"],
    Cell[253598, 10925, 389, 14, 70, "Output",
      CellTags->"OrderT"]},
  "PairsToRules"->{
    Cell[254048, 10946, 62, 1, 31, "ObjectName",
      CellTags->"PairsToRules"],
    Cell[254113, 10949, 63, 1, 74, "Highlight",
      CellTags->"PairsToRules"],
    Cell[254179, 10952, 130, 4, 43, "Usage",
      CellTags->"PairsToRules"],
    Cell[254312, 10958, 565, 19, 33, "Notes",
      CellTags->"PairsToRules"],
    Cell[254902, 10981, 70, 1, 59, "ExampleSection",
      CellTags->"PairsToRules"],
    Cell[254975, 10984, 103, 1, 48, "ExampleText",
      CellTags->"PairsToRules"],
    Cell[255081, 10987, 212, 4, 60, "Input",
      CellTags->"PairsToRules"],
    Cell[255318, 10995, 119, 3, 37, "Input",
      CellTags->"PairsToRules"],
    Cell[255440, 11000, 526, 15, 144, "Output",
      CellTags->"PairsToRules"]},
  "Pairs"->{
    Cell[256027, 11022, 48, 1, 31, "ObjectName",
      CellTags->"Pairs"],
    Cell[256078, 11025, 56, 1, 74, "Highlight",
      CellTags->"Pairs"],
    Cell[256137, 11028, 227, 8, 43, "Usage",
      CellTags->"Pairs"],
    Cell[256367, 11038, 94, 4, 33, "Notes",
      CellTags->"Pairs"],
    Cell[256464, 11044, 151, 5, 33, "Notes",
      CellTags->"Pairs"],
    Cell[256618, 11051, 93, 1, 33, "Notes",
      CellTags->"Pairs"],
    Cell[256714, 11054, 207, 7, 33, "Notes",
      CellTags->"Pairs"],
    Cell[256946, 11065, 63, 1, 59, "ExampleSection",
      CellTags->"Pairs"],
    Cell[257012, 11068, 62, 1, 70, "ExampleText",
      CellTags->"Pairs"],
    Cell[257099, 11073, 86, 2, 70, "Input",
      CellTags->"Pairs"],
    Cell[257188, 11077, 105, 3, 70, "Output",
      CellTags->"Pairs"],
    Cell[257330, 11085, 94, 2, 70, "Input",
      CellTags->"Pairs"],
    Cell[257427, 11089, 114, 3, 70, "Output",
      CellTags->"Pairs"],
    Cell[257578, 11097, 76, 2, 70, "Input",
      CellTags->"Pairs"],
    Cell[257657, 11101, 83, 3, 70, "Output",
      CellTags->"Pairs"],
    Cell[257777, 11109, 77, 2, 70, "Input",
      CellTags->"Pairs"],
    Cell[257857, 11113, 210, 5, 70, "Message",
      CellTags->"Pairs"],
    Cell[258070, 11120, 90, 3, 70, "Output",
      CellTags->"Pairs"]},
  "PartitionCumRest"->{
    Cell[258221, 11130, 70, 1, 42, "ObjectName",
      CellTags->"PartitionCumRest"],
    Cell[258294, 11133, 67, 1, 74, "Highlight",
      CellTags->"PartitionCumRest"],
    Cell[258364, 11136, 279, 10, 64, "Usage",
      CellTags->"PartitionCumRest"],
    Cell[258646, 11148, 149, 5, 33, "Notes",
      CellTags->"PartitionCumRest"]},
  "Partitions"->{
    Cell[258832, 11158, 58, 1, 42, "ObjectName",
      CellTags->"Partitions"],
    Cell[258893, 11161, 61, 1, 74, "Highlight",
      CellTags->"Partitions"],
    Cell[258957, 11164, 153, 6, 43, "Usage",
      CellTags->"Partitions"],
    Cell[259113, 11172, 218, 8, 33, "Notes",
      CellTags->"Partitions"],
    Cell[259334, 11182, 261, 11, 33, "Notes",
      CellTags->"Partitions"],
    Cell[259620, 11197, 68, 1, 59, "ExampleSection",
      CellTags->"Partitions"],
    Cell[259691, 11200, 144, 6, 70, "ExampleText",
      CellTags->"Partitions"],
    Cell[259860, 11210, 82, 2, 70, "Input",
      CellTags->"Partitions"],
    Cell[259945, 11214, 169, 4, 70, "Output",
      CellTags->"Partitions"]},
  "PathGraph"->{
    Cell[260175, 11225, 56, 1, 42, "ObjectName",
      CellTags->"PathGraph"],
    Cell[260234, 11228, 60, 1, 74, "Highlight",
      CellTags->"PathGraph"],
    Cell[260297, 11231, 170, 6, 43, "Usage",
      CellTags->"PathGraph"],
    Cell[260470, 11239, 225, 9, 58, "Notes",
      CellTags->"PathGraph"],
    Cell[260698, 11250, 141, 5, 33, "Notes",
      CellTags->"PathGraph"],
    Cell[260842, 11257, 256, 11, 33, "Notes",
      CellTags->"PathGraph"],
    Cell[261123, 11272, 67, 1, 59, "ExampleSection",
      CellTags->"PathGraph"],
    Cell[261193, 11275, 74, 1, 70, "ExampleText",
      CellTags->"PathGraph"],
    Cell[261292, 11280, 101, 3, 70, "Input",
      CellTags->"PathGraph"],
    Cell[261396, 11285, 344, 10, 70, "Output",
      CellTags->"PathGraph"],
    Cell[261777, 11300, 115, 3, 70, "Input",
      CellTags->"PathGraph"],
    Cell[261895, 11305, 110, 3, 70, "Output",
      CellTags->"PathGraph"],
    Cell[262020, 11311, 84, 1, 70, "ExampleText",
      CellTags->"PathGraph"],
    Cell[262129, 11316, 120, 3, 70, "Input",
      CellTags->"PathGraph"],
    Cell[262252, 11321, 355, 10, 70, "Output",
      CellTags->"PathGraph"],
    Cell[262644, 11336, 139, 3, 70, "Input",
      CellTags->"PathGraph"],
    Cell[262786, 11341, 91, 3, 70, "Output",
      CellTags->"PathGraph"]},
  "PermuteGraph"->{
    Cell[262938, 11351, 62, 1, 31, "ObjectName",
      CellTags->"PermuteGraph"],
    Cell[263003, 11354, 63, 1, 74, "Highlight",
      CellTags->"PermuteGraph"],
    Cell[263069, 11357, 186, 8, 43, "Usage",
      CellTags->"PermuteGraph"],
    Cell[263258, 11367, 125, 5, 33, "Notes",
      CellTags->"PermuteGraph"],
    Cell[263386, 11374, 155, 7, 33, "Notes",
      CellTags->"PermuteGraph"],
    Cell[263566, 11385, 70, 1, 59, "ExampleSection",
      CellTags->"PermuteGraph"],
    Cell[263639, 11388, 126, 4, 70, "ExampleText",
      CellTags->"PermuteGraph"],
    Cell[263790, 11396, 87, 2, 70, "Input",
      CellTags->"PermuteGraph"],
    Cell[263880, 11400, 285, 8, 70, "Output",
      CellTags->"PermuteGraph"],
    Cell[264202, 11413, 131, 3, 70, "Input",
      CellTags->"PermuteGraph"],
    Cell[264336, 11418, 285, 8, 70, "Output",
      CellTags->"PermuteGraph"]},
  "PlotFunction"->{
    Cell[264682, 11433, 62, 1, 31, "ObjectName",
      CellTags->"PlotFunction"],
    Cell[264747, 11436, 63, 1, 74, "Highlight",
      CellTags->"PlotFunction"],
    Cell[264813, 11439, 256, 10, 43, "Usage",
      CellTags->"PlotFunction"],
    Cell[265072, 11451, 442, 14, 128, "Notes",
      CellTags->"PlotFunction"],
    Cell[265517, 11467, 168, 7, 33, "Notes",
      CellTags->"PlotFunction"],
    Cell[265710, 11478, 70, 1, 59, "ExampleSection",
      CellTags->"PlotFunction"],
    Cell[265783, 11481, 90, 1, 70, "ExampleText",
      CellTags->"PlotFunction"],
    Cell[265898, 11486, 174, 4, 70, "Input",
      CellTags->"PlotFunction"],
    Cell[266075, 11492, 2953, 193, 70, 2772, 187, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PlotFunction"]},
  "PlotMatrix"->{
    Cell[269089, 11692, 58, 1, 42, "ObjectName",
      CellTags->"PlotMatrix"],
    Cell[269150, 11695, 61, 1, 74, "Highlight",
      CellTags->"PlotMatrix"],
    Cell[269214, 11698, 163, 6, 43, "Usage",
      CellTags->"PlotMatrix"],
    Cell[269380, 11706, 528, 15, 200, "Notes",
      CellTags->"PlotMatrix"],
    Cell[269911, 11723, 156, 5, 33, "Notes",
      CellTags->"PlotMatrix"],
    Cell[270070, 11730, 139, 5, 33, "Notes",
      CellTags->"PlotMatrix"],
    Cell[270212, 11737, 142, 5, 33, "Notes",
      CellTags->"PlotMatrix"],
    Cell[270357, 11744, 140, 5, 33, "Notes",
      CellTags->"PlotMatrix"],
    Cell[270500, 11751, 179, 5, 33, "Notes",
      CellTags->"PlotMatrix"],
    Cell[270682, 11758, 199, 6, 54, "Notes",
      CellTags->"PlotMatrix"],
    Cell[270884, 11766, 171, 5, 33, "Notes",
      CellTags->"PlotMatrix"],
    Cell[271058, 11773, 185, 7, 33, "Notes",
      CellTags->"PlotMatrix"],
    Cell[271246, 11782, 373, 15, 33, "Notes",
      CellTags->"PlotMatrix"],
    Cell[271644, 11801, 68, 1, 59, "ExampleSection",
      CellTags->"PlotMatrix"],
    Cell[271715, 11804, 96, 1, 70, "ExampleText",
      CellTags->"PlotMatrix"],
    Cell[271814, 11807, 110, 2, 70, "Input",
      CellTags->"PlotMatrix"],
    Cell[271949, 11813, 103, 3, 70, "Input",
      CellTags->"PlotMatrix"],
    Cell[272055, 11818, 1491, 83, 70, 1316, 77, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PlotMatrix"]},
  "PlotRelation"->{
    Cell[273607, 11908, 62, 1, 42, "ObjectName",
      CellTags->"PlotRelation"],
    Cell[273672, 11911, 63, 1, 74, "Highlight",
      CellTags->"PlotRelation"],
    Cell[273738, 11914, 263, 10, 43, "Usage",
      CellTags->"PlotRelation"],
    Cell[274004, 11926, 531, 16, 130, "Notes",
      CellTags->"PlotRelation"],
    Cell[274538, 11944, 254, 11, 33, "Notes",
      CellTags->"PlotRelation"],
    Cell[274817, 11959, 70, 1, 59, "ExampleSection",
      CellTags->"PlotRelation"],
    Cell[274890, 11962, 90, 1, 70, "ExampleText",
      CellTags->"PlotRelation"],
    Cell[274983, 11965, 142, 3, 70, "Input",
      CellTags->"PlotRelation"],
    Cell[275150, 11972, 132, 3, 70, "Input",
      CellTags->"PlotRelation"],
    Cell[275285, 11977, 3102, 203, 70, 2921, 197, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PlotRelation"]},
  "PlotTDGraph"->{
    Cell[278448, 12187, 60, 1, 31, "ObjectName",
      CellTags->"PlotTDGraph"],
    Cell[278511, 12190, 62, 1, 74, "Highlight",
      CellTags->"PlotTDGraph"],
    Cell[278576, 12193, 252, 9, 43, "Usage",
      CellTags->"PlotTDGraph"],
    Cell[278831, 12204, 530, 16, 130, "Notes",
      CellTags->"PlotTDGraph"],
    Cell[279364, 12222, 155, 5, 33, "Notes",
      CellTags->"PlotTDGraph"],
    Cell[279522, 12229, 221, 7, 33, "Notes",
      CellTags->"PlotTDGraph"],
    Cell[279746, 12238, 284, 11, 33, "Notes",
      CellTags->"PlotTDGraph"],
    Cell[280055, 12253, 69, 1, 59, "ExampleSection",
      CellTags->"PlotTDGraph"],
    Cell[280127, 12256, 189, 6, 70, "ExampleText",
      CellTags->"PlotTDGraph"],
    Cell[280341, 12266, 447, 10, 70, "Input",
      CellTags->"PlotTDGraph"],
    Cell[280791, 12278, 484, 12, 70, "Output",
      CellTags->"PlotTDGraph"],
    Cell[281312, 12295, 108, 3, 70, "Input",
      CellTags->"PlotTDGraph"],
    Cell[281423, 12300, 1985, 145, 70, 1805, 139, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PlotTDGraph"],
    Cell[283445, 12450, 163, 4, 70, "Input",
      CellTags->"PlotTDGraph"],
    Cell[283611, 12456, 2567, 204, 70, 2387, 198, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"PlotTDGraph"]},
  "PlotT"->{
    Cell[286239, 12667, 48, 1, 42, "ObjectName",
      CellTags->"PlotT"],
    Cell[286290, 12670, 56, 1, 74, "Highlight",
      CellTags->"PlotT"],
    Cell[286349, 12673, 190, 8, 43, "Usage",
      CellTags->"PlotT"],
    Cell[286542, 12683, 223, 9, 58, "Notes",
      CellTags->"PlotT"],
    Cell[286768, 12694, 121, 5, 33, "Notes",
      CellTags->"PlotT"],
    Cell[286892, 12701, 101, 5, 33, "Notes",
      CellTags->"PlotT"],
    Cell[286996, 12708, 348, 15, 33, "Notes",
      CellTags->"PlotT"],
    Cell[287369, 12727, 63, 1, 59, "ExampleSection",
      CellTags->"PlotT"],
    Cell[287435, 12730, 98, 1, 70, "ExampleText",
      CellTags->"PlotT"],
    Cell[287558, 12735, 79, 2, 70, "Input",
      CellTags->"PlotT"]},
  "PositionList"->{
    Cell[292094, 13057, 62, 1, 42, "ObjectName",
      CellTags->"PositionList"],
    Cell[292159, 13060, 63, 1, 74, "Highlight",
      CellTags->"PositionList"],
    Cell[292225, 13063, 240, 8, 43, "Usage",
      CellTags->"PositionList"],
    Cell[292468, 13073, 169, 7, 33, "Notes",
      CellTags->"PositionList"],
    Cell[292662, 13084, 70, 1, 59, "ExampleSection",
      CellTags->"PositionList"],
    Cell[292735, 13087, 132, 4, 70, "ExampleText",
      CellTags->"PositionList"],
    Cell[292892, 13095, 108, 2, 70, "Input",
      CellTags->"PositionList"],
    Cell[293003, 13099, 155, 4, 70, "Output",
      CellTags->"PositionList"],
    Cell[293195, 13108, 143, 4, 70, "Input",
      CellTags->"PositionList"],
    Cell[293341, 13114, 166, 4, 70, "Output",
      CellTags->"PositionList"]},
  "PositionOne"->{
    Cell[293568, 13125, 60, 1, 42, "ObjectName",
      CellTags->"PositionOne"],
    Cell[293631, 13128, 62, 1, 74, "Highlight",
      CellTags->"PositionOne"],
    Cell[293696, 13131, 162, 6, 43, "Usage",
      CellTags->"PositionOne"],
    Cell[293861, 13139, 59, 1, 33, "Notes",
      CellTags->"PositionOne"]},
  "PowerSet"->{
    Cell[293957, 13145, 54, 1, 42, "ObjectName",
      CellTags->"PowerSet"],
    Cell[294014, 13148, 59, 1, 74, "Highlight",
      CellTags->"PowerSet"],
    Cell[294076, 13151, 186, 8, 43, "Usage",
      CellTags->"PowerSet"],
    Cell[294265, 13161, 136, 5, 33, "Notes",
      CellTags->"PowerSet"],
    Cell[294404, 13168, 136, 6, 33, "Notes",
      CellTags->"PowerSet"],
    Cell[294543, 13176, 201, 7, 33, "Notes",
      CellTags->"PowerSet"],
    Cell[294769, 13187, 66, 1, 59, "ExampleSection",
      CellTags->"PowerSet"],
    Cell[294838, 13190, 146, 6, 70, "ExampleText",
      CellTags->"PowerSet"],
    Cell[295009, 13200, 86, 2, 70, "Input",
      CellTags->"PowerSet"],
    Cell[295098, 13204, 232, 5, 70, "Output",
      CellTags->"PowerSet"],
    Cell[295367, 13214, 88, 2, 70, "Input",
      CellTags->"PowerSet"],
    Cell[295458, 13218, 132, 3, 70, "Output",
      CellTags->"PowerSet"]},
  "PrintDClass"->{
    Cell[295651, 13228, 60, 1, 31, "ObjectName",
      CellTags->"PrintDClass"],
    Cell[295714, 13231, 62, 1, 74, "Highlight",
      CellTags->"PrintDClass"],
    Cell[295779, 13234, 154, 6, 43, "Usage",
      CellTags->"PrintDClass"],
    Cell[295936, 13242, 111, 5, 33, "Notes",
      CellTags->"PrintDClass"],
    Cell[296050, 13249, 134, 4, 33, "Notes",
      CellTags->"PrintDClass"],
    Cell[296187, 13255, 358, 15, 33, "Notes",
      CellTags->"PrintDClass"],
    Cell[296570, 13274, 69, 1, 59, "ExampleSection",
      CellTags->"PrintDClass"],
    Cell[296642, 13277, 78, 1, 70, "ExampleText",
      CellTags->"PrintDClass"],
    Cell[296723, 13280, 380, 7, 70, "Input",
      CellTags->"PrintDClass"],
    Cell[297128, 13291, 100, 3, 70, "Input",
      CellTags->"PrintDClass"],
    Cell[297231, 13296, 152, 4, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[297386, 13302, 313, 6, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[297702, 13310, 276, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[297981, 13320, 152, 4, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[298136, 13326, 95, 3, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[298234, 13331, 205, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[298442, 13338, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[298678, 13345, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[298985, 13355, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[299221, 13362, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[299528, 13372, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[299764, 13379, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[300071, 13389, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[300307, 13396, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[300614, 13406, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[300850, 13413, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[301157, 13423, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[301393, 13430, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[301700, 13440, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[301936, 13447, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[302243, 13457, 103, 3, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[302349, 13462, 205, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[302557, 13469, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[302793, 13476, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[303100, 13486, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[303336, 13493, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[303643, 13503, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[303879, 13510, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[304186, 13520, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[304422, 13527, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[304729, 13537, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[304965, 13544, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[305272, 13554, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[305508, 13561, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[305815, 13571, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[306051, 13578, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[306358, 13588, 103, 3, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[306464, 13593, 205, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[306672, 13600, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[306908, 13607, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[307215, 13617, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[307451, 13624, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[307758, 13634, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[307994, 13641, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[308301, 13651, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[308537, 13658, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[308844, 13668, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[309080, 13675, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[309387, 13685, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[309623, 13692, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[309930, 13702, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[310166, 13709, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[310473, 13719, 103, 3, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[310579, 13724, 205, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[310787, 13731, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[311023, 13738, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[311330, 13748, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[311566, 13755, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[311873, 13765, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[312109, 13772, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[312416, 13782, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[312652, 13789, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[312959, 13799, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[313195, 13806, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[313502, 13816, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[313738, 13823, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[314045, 13833, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[314281, 13840, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[314588, 13850, 103, 3, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[314694, 13855, 205, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[314902, 13862, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[315138, 13869, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[315445, 13879, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[315681, 13886, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[315988, 13896, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[316224, 13903, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[316531, 13913, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[316767, 13920, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[317074, 13930, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[317310, 13937, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[317617, 13947, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[317853, 13954, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[318160, 13964, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[318396, 13971, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[318703, 13981, 103, 3, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[318809, 13986, 205, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[319017, 13993, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[319253, 14000, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[319560, 14010, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[319796, 14017, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[320103, 14027, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[320339, 14034, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[320646, 14044, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[320882, 14051, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[321189, 14061, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[321425, 14068, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[321732, 14078, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[321968, 14085, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[322275, 14095, 233, 5, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[322511, 14102, 304, 8, 70, "Print",
      CellTags->"PrintDClass"],
    Cell[322818, 14112, 103, 3, 70, "Print",
      CellTags->"PrintDClass"]},
  "PrintEquations"->{
    Cell[322982, 14122, 66, 1, 31, "ObjectName",
      CellTags->"PrintEquations"],
    Cell[323051, 14125, 65, 1, 74, "Highlight",
      CellTags->"PrintEquations"],
    Cell[323119, 14128, 153, 4, 43, "Usage",
      CellTags->"PrintEquations"],
    Cell[323275, 14134, 279, 10, 80, "Notes",
      CellTags->"PrintEquations"],
    Cell[323557, 14146, 149, 5, 33, "Notes",
      CellTags->"PrintEquations"],
    Cell[323709, 14153, 458, 19, 33, "Notes",
      CellTags->"PrintEquations"],
    Cell[324192, 14176, 72, 1, 59, "ExampleSection",
      CellTags->"PrintEquations"],
    Cell[324267, 14179, 142, 4, 70, "ExampleText",
      CellTags->"PrintEquations"],
    Cell[324412, 14185, 159, 4, 70, "Input",
      CellTags->"PrintEquations"],
    Cell[324596, 14193, 99, 3, 70, "Input",
      CellTags->"PrintEquations"],
    Cell[324698, 14198, 92, 3, 70, "Output",
      CellTags->"PrintEquations"],
    Cell[324805, 14204, 102, 1, 70, "ExampleText",
      CellTags->"PrintEquations"],
    Cell[324932, 14209, 169, 4, 70, "Input",
      CellTags->"PrintEquations"],
    Cell[325104, 14215, 1780, 38, 70, "Output",
      CellTags->"PrintEquations"]},
  "PrintWitnesses"->{
    Cell[326945, 14260, 66, 1, 42, "ObjectName",
      CellTags->"PrintWitnesses"],
    Cell[327014, 14263, 65, 1, 74, "Highlight",
      CellTags->"PrintWitnesses"],
    Cell[327082, 14266, 204, 6, 43, "Usage",
      CellTags->"PrintWitnesses"],
    Cell[327289, 14274, 458, 19, 33, "Notes",
      CellTags->"PrintWitnesses"],
    Cell[327772, 14297, 72, 1, 59, "ExampleSection",
      CellTags->"PrintWitnesses"],
    Cell[327847, 14300, 142, 4, 70, "ExampleText",
      CellTags->"PrintWitnesses"],
    Cell[327992, 14306, 159, 4, 70, "Input",
      CellTags->"PrintWitnesses"],
    Cell[328176, 14314, 109, 3, 70, "Input",
      CellTags->"PrintWitnesses"],
    Cell[328288, 14319, 1720, 39, 70, "Output",
      CellTags->"PrintWitnesses"]},
  "ProductGraph"->{
    Cell[330069, 14365, 62, 1, 42, "ObjectName",
      CellTags->"ProductGraph"],
    Cell[330134, 14368, 63, 1, 74, "Highlight",
      CellTags->"ProductGraph"],
    Cell[330200, 14371, 234, 8, 43, "Usage",
      CellTags->"ProductGraph"],
    Cell[330437, 14381, 227, 9, 58, "Notes",
      CellTags->"ProductGraph"],
    Cell[330667, 14392, 604, 22, 54, "Notes",
      CellTags->"ProductGraph"],
    Cell[331274, 14416, 320, 11, 33, "Notes",
      CellTags->"ProductGraph"],
    Cell[331597, 14429, 305, 11, 33, "Notes",
      CellTags->"ProductGraph"],
    Cell[331927, 14444, 70, 1, 59, "ExampleSection",
      CellTags->"ProductGraph"],
    Cell[332000, 14447, 98, 1, 70, "ExampleText",
      CellTags->"ProductGraph"],
    Cell[332101, 14450, 160, 4, 70, "Input",
      CellTags->"ProductGraph"],
    Cell[332286, 14458, 111, 3, 70, "Input",
      CellTags->"ProductGraph"],
    Cell[332400, 14463, 430, 11, 70, "Output",
      CellTags->"ProductGraph"],
    Cell[332867, 14479, 99, 3, 70, "Input",
      CellTags->"ProductGraph"],
    Cell[332969, 14484, 193, 4, 70, "Output",
      CellTags->"ProductGraph"],
    Cell[333199, 14493, 118, 3, 70, "Input",
      CellTags->"ProductGraph"],
    Cell[333320, 14498, 127, 3, 70, "Output",
      CellTags->"ProductGraph"],
    Cell[333484, 14506, 118, 3, 70, "Input",
      CellTags->"ProductGraph"],
    Cell[333605, 14511, 109, 3, 70, "Output",
      CellTags->"ProductGraph"],
    Cell[333751, 14519, 117, 3, 70, "Input",
      CellTags->"ProductGraph"],
    Cell[333871, 14524, 135, 3, 70, "Output",
      CellTags->"ProductGraph"]},
  "ProductLabeledGraph"->{
    Cell[334067, 14534, 76, 1, 42, "ObjectName",
      CellTags->"ProductLabeledGraph"],
    Cell[334146, 14537, 70, 1, 74, "Highlight",
      CellTags->"ProductLabeledGraph"],
    Cell[334219, 14540, 227, 8, 43, "Usage",
      CellTags->"ProductLabeledGraph"],
    Cell[334449, 14550, 495, 16, 54, "Notes",
      CellTags->"ProductLabeledGraph"],
    Cell[334947, 14568, 298, 11, 33, "Notes",
      CellTags->"ProductLabeledGraph"],
    Cell[335270, 14583, 77, 1, 59, "ExampleSection",
      CellTags->"ProductLabeledGraph"],
    Cell[335350, 14586, 210, 5, 70, "ExampleText",
      CellTags->"ProductLabeledGraph"],
    Cell[335585, 14595, 235, 6, 70, "Input",
      CellTags->"ProductLabeledGraph"],
    Cell[335823, 14603, 368, 10, 70, "Output",
      CellTags->"ProductLabeledGraph"],
    Cell[336228, 14618, 128, 3, 70, "Input",
      CellTags->"ProductLabeledGraph"],
    Cell[336359, 14623, 493, 12, 70, "Output",
      CellTags->"ProductLabeledGraph"],
    Cell[336889, 14640, 125, 3, 70, "Input",
      CellTags->"ProductLabeledGraph"],
    Cell[337017, 14645, 156, 4, 70, "Output",
      CellTags->"ProductLabeledGraph"],
    Cell[337210, 14654, 103, 3, 70, "Input",
      CellTags->"ProductLabeledGraph"],
    Cell[337316, 14659, 254, 8, 70, "Output",
      CellTags->"ProductLabeledGraph"]},
  "RandomPermutation"->{
    Cell[337631, 14674, 72, 1, 31, "ObjectName",
      CellTags->"RandomPermutation"],
    Cell[337706, 14677, 68, 1, 74, "Highlight",
      CellTags->"RandomPermutation"],
    Cell[337777, 14680, 197, 6, 43, "Usage",
      CellTags->"RandomPermutation"],
    Cell[337977, 14688, 178, 7, 33, "Notes",
      CellTags->"RandomPermutation"],
    Cell[338180, 14699, 75, 1, 59, "ExampleSection",
      CellTags->"RandomPermutation"],
    Cell[338258, 14702, 159, 6, 70, "ExampleText",
      CellTags->"RandomPermutation"],
    Cell[338442, 14712, 96, 2, 70, "Input",
      CellTags->"RandomPermutation"],
    Cell[338541, 14716, 123, 3, 70, "Output",
      CellTags->"RandomPermutation"]},
  "RandomT"->{
    Cell[338725, 14726, 52, 1, 31, "ObjectName",
      CellTags->"RandomT"],
    Cell[338780, 14729, 58, 1, 74, "Highlight",
      CellTags->"RandomT"],
    Cell[338841, 14732, 132, 4, 43, "Usage",
      CellTags->"RandomT"],
    Cell[338976, 14738, 73, 1, 33, "Notes",
      CellTags->"RandomT"],
    Cell[339052, 14741, 142, 7, 33, "Notes",
      CellTags->"RandomT"],
    Cell[339219, 14752, 65, 1, 59, "ExampleSection",
      CellTags->"RandomT"],
    Cell[339287, 14755, 74, 1, 70, "ExampleText",
      CellTags->"RandomT"],
    Cell[339386, 14760, 89, 2, 70, "Input",
      CellTags->"RandomT"],
    Cell[339478, 14764, 231, 5, 70, "Output",
      CellTags->"RandomT"]},
  "RankT"->{
    Cell[339770, 14776, 48, 1, 42, "ObjectName",
      CellTags->"RankT"],
    Cell[339821, 14779, 56, 1, 74, "Highlight",
      CellTags->"RankT"],
    Cell[339880, 14782, 105, 5, 33, "Notes",
      CellTags->"RankT"],
    Cell[339988, 14789, 196, 6, 43, "Usage",
      CellTags->"RankT"],
    Cell[340187, 14797, 105, 5, 33, "Notes",
      CellTags->"RankT"],
    Cell[340295, 14804, 458, 19, 33, "Notes",
      CellTags->"RankT"],
    Cell[340778, 14827, 63, 1, 59, "ExampleSection",
      CellTags->"RankT"],
    Cell[340844, 14830, 90, 1, 70, "ExampleText",
      CellTags->"RankT"],
    Cell[340959, 14835, 149, 4, 70, "Input",
      CellTags->"RankT"],
    Cell[341111, 14841, 1186, 37, 70, "Output",
      CellTags->"RankT"]},
  "RegularQT"->{
    Cell[342358, 14885, 56, 1, 42, "ObjectName",
      CellTags->"RegularQT"],
    Cell[342417, 14888, 60, 1, 74, "Highlight",
      CellTags->"RegularQT"],
    Cell[342480, 14891, 204, 8, 43, "Usage",
      CellTags->"RegularQT"],
    Cell[342687, 14901, 155, 7, 33, "Notes",
      CellTags->"RegularQT"]},
  "RegularSG"->{
    Cell[342879, 14913, 56, 1, 42, "ObjectName",
      CellTags->"RegularSG"],
    Cell[342938, 14916, 60, 1, 74, "Highlight",
      CellTags->"RegularSG"],
    Cell[343001, 14919, 166, 6, 43, "Usage",
      CellTags->"RegularSG"],
    Cell[343170, 14927, 81, 1, 33, "Notes",
      CellTags->"RegularSG"],
    Cell[343254, 14930, 256, 11, 33, "Notes",
      CellTags->"RegularSG"],
    Cell[343535, 14945, 67, 1, 59, "ExampleSection",
      CellTags->"RegularSG"],
    Cell[343605, 14948, 104, 1, 70, "ExampleText",
      CellTags->"RegularSG"],
    Cell[343712, 14951, 145, 4, 70, "Input",
      CellTags->"RegularSG"],
    Cell[343882, 14959, 95, 3, 70, "Input",
      CellTags->"RegularSG"],
    Cell[343980, 14964, 99, 3, 70, "Output",
      CellTags->"RegularSG"],
    Cell[344116, 14972, 92, 3, 70, "Input",
      CellTags->"RegularSG"],
    Cell[344211, 14977, 99, 3, 70, "Output",
      CellTags->"RegularSG"]},
  "RelationToMatrix"->{
    Cell[344371, 14987, 70, 1, 42, "ObjectName",
      CellTags->"RelationToMatrix"],
    Cell[344444, 14990, 67, 1, 74, "Highlight",
      CellTags->"RelationToMatrix"],
    Cell[344514, 14993, 245, 8, 64, "Usage",
      CellTags->"RelationToMatrix"],
    Cell[344762, 15003, 98, 1, 33, "Notes",
      CellTags->"RelationToMatrix"],
    Cell[344863, 15006, 108, 1, 33, "Notes",
      CellTags->"RelationToMatrix"],
    Cell[344974, 15009, 830, 31, 54, "Notes",
      CellTags->"RelationToMatrix"],
    Cell[345829, 15044, 74, 1, 59, "ExampleSection",
      CellTags->"RelationToMatrix"],
    Cell[345906, 15047, 86, 1, 70, "ExampleText",
      CellTags->"RelationToMatrix"],
    Cell[346017, 15052, 108, 2, 70, "Input",
      CellTags->"RelationToMatrix"],
    Cell[346128, 15056, 326, 6, 70, "Output",
      CellTags->"RelationToMatrix"]},
  "RemoveDuplicates"->{
    Cell[346515, 15069, 70, 1, 31, "ObjectName",
      CellTags->"RemoveDuplicates"],
    Cell[346588, 15072, 67, 1, 74, "Highlight",
      CellTags->"RemoveDuplicates"],
    Cell[346658, 15075, 168, 6, 43, "Usage",
      CellTags->"RemoveDuplicates"],
    Cell[346829, 15083, 236, 9, 58, "Notes",
      CellTags->"RemoveDuplicates"],
    Cell[347068, 15094, 186, 5, 33, "Notes",
      CellTags->"RemoveDuplicates"],
    Cell[347257, 15101, 278, 8, 54, "Notes",
      CellTags->"RemoveDuplicates"],
    Cell[347560, 15113, 74, 1, 59, "ExampleSection",
      CellTags->"RemoveDuplicates"],
    Cell[347637, 15116, 79, 1, 70, "ExampleText",
      CellTags->"RemoveDuplicates"],
    Cell[347741, 15121, 97, 2, 70, "Input",
      CellTags->"RemoveDuplicates"],
    Cell[347841, 15125, 121, 3, 70, "Output",
      CellTags->"RemoveDuplicates"],
    Cell[347999, 15133, 109, 3, 70, "Input",
      CellTags->"RemoveDuplicates"],
    Cell[348111, 15138, 103, 3, 70, "Output",
      CellTags->"RemoveDuplicates"],
    Cell[348251, 15146, 120, 3, 70, "Input",
      CellTags->"RemoveDuplicates"],
    Cell[348374, 15151, 119, 3, 70, "Output",
      CellTags->"RemoveDuplicates"],
    Cell[348530, 15159, 145, 3, 70, "Input",
      CellTags->"RemoveDuplicates"],
    Cell[348678, 15164, 123, 3, 70, "Output",
      CellTags->"RemoveDuplicates"]},
  "RemoveVertex"->{
    Cell[348862, 15174, 62, 1, 31, "ObjectName",
      CellTags->"RemoveVertex"],
    Cell[348927, 15177, 63, 1, 74, "Highlight",
      CellTags->"RemoveVertex"],
    Cell[348993, 15180, 189, 8, 43, "Usage",
      CellTags->"RemoveVertex"],
    Cell[349185, 15190, 135, 5, 33, "Notes",
      CellTags->"RemoveVertex"],
    Cell[349323, 15197, 155, 7, 33, "Notes",
      CellTags->"RemoveVertex"],
    Cell[349503, 15208, 70, 1, 59, "ExampleSection",
      CellTags->"RemoveVertex"],
    Cell[349576, 15211, 113, 2, 70, "ExampleText",
      CellTags->"RemoveVertex"],
    Cell[349714, 15217, 86, 2, 70, "Input",
      CellTags->"RemoveVertex"],
    Cell[349803, 15221, 328, 10, 70, "Output",
      CellTags->"RemoveVertex"],
    Cell[350168, 15236, 113, 3, 70, "Input",
      CellTags->"RemoveVertex"],
    Cell[350284, 15241, 284, 8, 70, "Output",
      CellTags->"RemoveVertex"],
    Cell[350605, 15254, 168, 4, 70, "Input",
      CellTags->"RemoveVertex"],
    Cell[350776, 15260, 111, 3, 70, "Output",
      CellTags->"RemoveVertex"],
    Cell[350890, 15265, 99, 3, 70, "Output",
      CellTags->"RemoveVertex"]},
  "RenumberRules"->{
    Cell[351050, 15275, 64, 1, 42, "ObjectName",
      CellTags->"RenumberRules"],
    Cell[351117, 15278, 64, 1, 74, "Highlight",
      CellTags->"RenumberRules"],
    Cell[351184, 15281, 241, 8, 64, "Usage",
      CellTags->"RenumberRules"],
    Cell[351428, 15291, 273, 10, 80, "Notes",
      CellTags->"RenumberRules"],
    Cell[351704, 15303, 157, 7, 33, "Notes",
      CellTags->"RenumberRules"],
    Cell[351864, 15312, 172, 5, 33, "Notes",
      CellTags->"RenumberRules"],
    Cell[352039, 15319, 162, 7, 33, "Notes",
      CellTags->"RenumberRules"],
    Cell[352226, 15330, 71, 1, 59, "ExampleSection",
      CellTags->"RenumberRules"],
    Cell[352300, 15333, 82, 1, 70, "ExampleText",
      CellTags->"RenumberRules"],
    Cell[352407, 15338, 98, 2, 70, "Input",
      CellTags->"RenumberRules"],
    Cell[352508, 15342, 470, 8, 70, "Output",
      CellTags->"RenumberRules"],
    Cell[352993, 15353, 121, 3, 70, "Input",
      CellTags->"RenumberRules"],
    Cell[353139, 15360, 102, 3, 70, "Input",
      CellTags->"RenumberRules"],
    Cell[353244, 15365, 183, 4, 70, "Output",
      CellTags->"RenumberRules"],
    Cell[353464, 15374, 137, 3, 70, "Input",
      CellTags->"RenumberRules"],
    Cell[353604, 15379, 132, 3, 70, "Output",
      CellTags->"RenumberRules"]},
  "ReplaceParts"->{
    Cell[353797, 15389, 62, 1, 42, "ObjectName",
      CellTags->"ReplaceParts"],
    Cell[353862, 15392, 63, 1, 74, "Highlight",
      CellTags->"ReplaceParts"],
    Cell[353928, 15395, 150, 4, 43, "Usage",
      CellTags->"ReplaceParts"],
    Cell[354081, 15401, 67, 1, 33, "Notes",
      CellTags->"ReplaceParts"]},
  "ReverseGraph"->{
    Cell[354185, 15407, 62, 1, 42, "ObjectName",
      CellTags->"ReverseGraph"],
    Cell[354250, 15410, 63, 1, 74, "Highlight",
      CellTags->"ReverseGraph"],
    Cell[354316, 15413, 160, 6, 43, "Usage",
      CellTags->"ReverseGraph"],
    Cell[354479, 15421, 126, 4, 33, "Notes",
      CellTags->"ReverseGraph"],
    Cell[354608, 15427, 255, 11, 33, "Notes",
      CellTags->"ReverseGraph"],
    Cell[354888, 15442, 70, 1, 59, "ExampleSection",
      CellTags->"ReverseGraph"],
    Cell[354961, 15445, 81, 1, 70, "ExampleText",
      CellTags->"ReverseGraph"],
    Cell[355067, 15450, 87, 2, 70, "Input",
      CellTags->"ReverseGraph"],
    Cell[355157, 15454, 285, 8, 70, "Output",
      CellTags->"ReverseGraph"],
    Cell[355479, 15467, 102, 3, 70, "Input",
      CellTags->"ReverseGraph"],
    Cell[355584, 15472, 285, 8, 70, "Output",
      CellTags->"ReverseGraph"],
    Cell[355906, 15485, 131, 3, 70, "Input",
      CellTags->"ReverseGraph"],
    Cell[356040, 15490, 410, 11, 70, "Output",
      CellTags->"ReverseGraph"]},
  "RightIdealT"->{
    Cell[356511, 15508, 60, 1, 42, "ObjectName",
      CellTags->"RightIdealT"],
    Cell[356574, 15511, 62, 1, 74, "Highlight",
      CellTags->"RightIdealT"],
    Cell[356639, 15514, 170, 4, 43, "Usage",
      CellTags->"RightIdealT"],
    Cell[356812, 15520, 78, 1, 33, "Notes",
      CellTags->"RightIdealT"],
    Cell[356893, 15523, 252, 11, 33, "Notes",
      CellTags->"RightIdealT"],
    Cell[357170, 15538, 69, 1, 59, "ExampleSection",
      CellTags->"RightIdealT"],
    Cell[357242, 15541, 136, 4, 70, "ExampleText",
      CellTags->"RightIdealT"],
    Cell[357381, 15547, 113, 3, 70, "Input",
      CellTags->"RightIdealT"],
    Cell[357519, 15554, 117, 3, 70, "Input",
      CellTags->"RightIdealT"],
    Cell[357639, 15559, 122, 3, 70, "Output",
      CellTags->"RightIdealT"],
    Cell[357798, 15567, 117, 3, 70, "Input",
      CellTags->"RightIdealT"],
    Cell[357918, 15572, 201, 4, 70, "Output",
      CellTags->"RightIdealT"]},
  "RightNullQT"->{
    Cell[358180, 15583, 60, 1, 31, "ObjectName",
      CellTags->"RightNullQT"],
    Cell[358243, 15586, 62, 1, 74, "Highlight",
      CellTags->"RightNullQT"],
    Cell[358308, 15589, 218, 8, 43, "Usage",
      CellTags->"RightNullQT"],
    Cell[358529, 15599, 432, 19, 33, "Notes",
      CellTags->"RightNullQT"]},
  "RightNullSG"->{
    Cell[358998, 15623, 60, 1, 42, "ObjectName",
      CellTags->"RightNullSG"],
    Cell[359061, 15626, 62, 1, 74, "Highlight",
      CellTags->"RightNullSG"],
    Cell[359126, 15629, 164, 6, 43, "Usage",
      CellTags->"RightNullSG"],
    Cell[359293, 15637, 78, 1, 33, "Notes",
      CellTags->"RightNullSG"],
    Cell[359374, 15640, 473, 19, 33, "Notes",
      CellTags->"RightNullSG"],
    Cell[359872, 15663, 69, 1, 59, "ExampleSection",
      CellTags->"RightNullSG"],
    Cell[359944, 15666, 154, 4, 70, "ExampleText",
      CellTags->"RightNullSG"],
    Cell[360101, 15672, 94, 2, 70, "Input",
      CellTags->"RightNullSG"],
    Cell[360220, 15678, 100, 3, 70, "Input",
      CellTags->"RightNullSG"],
    Cell[360323, 15683, 123, 3, 70, "Output",
      CellTags->"RightNullSG"]},
  "RightOneQT"->{
    Cell[360507, 15693, 58, 1, 42, "ObjectName",
      CellTags->"RightOneQT"],
    Cell[360568, 15696, 61, 1, 74, "Highlight",
      CellTags->"RightOneQT"],
    Cell[360632, 15699, 220, 8, 43, "Usage",
      CellTags->"RightOneQT"],
    Cell[360855, 15709, 431, 19, 33, "Notes",
      CellTags->"RightOneQT"]},
  "RightOneSG"->{
    Cell[361323, 15733, 58, 1, 42, "ObjectName",
      CellTags->"RightOneSG"],
    Cell[361384, 15736, 61, 1, 74, "Highlight",
      CellTags->"RightOneSG"],
    Cell[361448, 15739, 168, 6, 43, "Usage",
      CellTags->"RightOneSG"],
    Cell[361619, 15747, 77, 1, 33, "Notes",
      CellTags->"RightOneSG"],
    Cell[361699, 15750, 431, 19, 33, "Notes",
      CellTags->"RightOneSG"],
    Cell[362155, 15773, 68, 1, 59, "ExampleSection",
      CellTags->"RightOneSG"],
    Cell[362226, 15776, 140, 4, 70, "ExampleText",
      CellTags->"RightOneSG"],
    Cell[362369, 15782, 92, 2, 70, "Input",
      CellTags->"RightOneSG"],
    Cell[362486, 15788, 97, 3, 70, "Input",
      CellTags->"RightOneSG"],
    Cell[362586, 15793, 97, 3, 70, "Output",
      CellTags->"RightOneSG"]},
  "RootList"->{
    Cell[362744, 15803, 54, 1, 42, "ObjectName",
      CellTags->"RootList"],
    Cell[362801, 15806, 59, 1, 74, "Highlight",
      CellTags->"RootList"],
    Cell[362863, 15809, 360, 13, 45, "Usage",
      CellTags->"RootList"],
    Cell[363226, 15824, 131, 5, 33, "Notes",
      CellTags->"RootList"],
    Cell[363360, 15831, 265, 11, 33, "Notes",
      CellTags->"RootList"],
    Cell[363650, 15846, 66, 1, 59, "ExampleSection",
      CellTags->"RootList"],
    Cell[363719, 15849, 79, 1, 70, "ExampleText",
      CellTags->"RootList"],
    Cell[363823, 15854, 116, 3, 70, "Input",
      CellTags->"RootList"],
    Cell[363942, 15859, 128, 3, 70, "Output",
      CellTags->"RootList"],
    Cell[364107, 15867, 93, 3, 70, "Input",
      CellTags->"RootList"],
    Cell[364203, 15872, 92, 3, 70, "Output",
      CellTags->"RootList"]},
  "RShiftT"->{
    Cell[364356, 15882, 52, 1, 42, "ObjectName",
      CellTags->"RShiftT"],
    Cell[364411, 15885, 58, 1, 74, "Highlight",
      CellTags->"RShiftT"],
    Cell[364472, 15888, 173, 6, 43, "Usage",
      CellTags->"RShiftT"],
    Cell[364648, 15896, 486, 19, 33, "Notes",
      CellTags->"RShiftT"]},
  "RulesToPairs"->{
    Cell[365171, 15920, 62, 1, 42, "ObjectName",
      CellTags->"RulesToPairs"],
    Cell[365236, 15923, 63, 1, 74, "Highlight",
      CellTags->"RulesToPairs"],
    Cell[365302, 15926, 138, 4, 43, "Usage",
      CellTags->"RulesToPairs"],
    Cell[365443, 15932, 565, 19, 33, "Notes",
      CellTags->"RulesToPairs"],
    Cell[366033, 15955, 70, 1, 59, "ExampleSection",
      CellTags->"RulesToPairs"],
    Cell[366106, 15958, 100, 1, 70, "ExampleText",
      CellTags->"RulesToPairs"],
    Cell[366209, 15961, 241, 5, 70, "Input",
      CellTags->"RulesToPairs"],
    Cell[366475, 15970, 102, 3, 70, "Input",
      CellTags->"RulesToPairs"],
    Cell[366580, 15975, 173, 4, 70, "Output",
      CellTags->"RulesToPairs"]},
  "SeedConfiguration"->{
    Cell[366814, 15986, 72, 1, 31, "ObjectName",
      CellTags->"SeedConfiguration"],
    Cell[366889, 15989, 68, 1, 74, "Highlight",
      CellTags->"SeedConfiguration"],
    Cell[366960, 15992, 180, 4, 43, "Usage",
      CellTags->"SeedConfiguration"],
    Cell[367143, 15998, 247, 9, 58, "Notes",
      CellTags->"SeedConfiguration"],
    Cell[367393, 16009, 132, 4, 33, "Notes",
      CellTags->"SeedConfiguration"],
    Cell[367528, 16015, 109, 1, 33, "Notes",
      CellTags->"SeedConfiguration"],
    Cell[367640, 16018, 262, 11, 33, "Notes",
      CellTags->"SeedConfiguration"],
    Cell[367927, 16033, 75, 1, 59, "ExampleSection",
      CellTags->"SeedConfiguration"],
    Cell[368005, 16036, 81, 1, 70, "ExampleText",
      CellTags->"SeedConfiguration"],
    Cell[368111, 16041, 102, 2, 70, "Input",
      CellTags->"SeedConfiguration"],
    Cell[368216, 16045, 122, 3, 70, "Output",
      CellTags->"SeedConfiguration"],
    Cell[368375, 16053, 114, 2, 70, "Input",
      CellTags->"SeedConfiguration"],
    Cell[368492, 16057, 122, 3, 70, "Output",
      CellTags->"SeedConfiguration"]},
  "SelectOptions"->{
    Cell[368675, 16067, 64, 1, 42, "ObjectName",
      CellTags->"SelectOptions"],
    Cell[368742, 16070, 64, 1, 74, "Highlight",
      CellTags->"SelectOptions"],
    Cell[368809, 16073, 222, 8, 43, "Usage",
      CellTags->"SelectOptions"],
    Cell[369034, 16083, 192, 6, 33, "Notes",
      CellTags->"SelectOptions"]},
  "SelectorQ"->{
    Cell[369263, 16094, 56, 1, 42, "ObjectName",
      CellTags->"SelectorQ"],
    Cell[369322, 16097, 60, 1, 74, "Highlight",
      CellTags->"SelectorQ"],
    Cell[369385, 16100, 229, 8, 43, "Usage",
      CellTags->"SelectorQ"],
    Cell[369617, 16110, 231, 9, 33, "Notes",
      CellTags->"SelectorQ"],
    Cell[369851, 16121, 162, 7, 33, "Notes",
      CellTags->"SelectorQ"],
    Cell[370038, 16132, 67, 1, 59, "ExampleSection",
      CellTags->"SelectorQ"],
    Cell[370108, 16135, 174, 6, 70, "ExampleText",
      CellTags->"SelectorQ"],
    Cell[370285, 16143, 137, 3, 70, "Input",
      CellTags->"SelectorQ"],
    Cell[370447, 16150, 115, 3, 70, "Input",
      CellTags->"SelectorQ"],
    Cell[370565, 16155, 88, 3, 70, "Output",
      CellTags->"SelectorQ"],
    Cell[370690, 16163, 114, 3, 70, "Input",
      CellTags->"SelectorQ"],
    Cell[370807, 16168, 89, 3, 70, "Output",
      CellTags->"SelectorQ"]},
  "ShortestPath"->{
    Cell[370957, 16178, 62, 1, 42, "ObjectName",
      CellTags->"ShortestPath"],
    Cell[371022, 16181, 63, 1, 74, "Highlight",
      CellTags->"ShortestPath"],
    Cell[371088, 16184, 278, 10, 64, "Usage",
      CellTags->"ShortestPath"],
    Cell[371369, 16196, 228, 9, 58, "Notes",
      CellTags->"ShortestPath"],
    Cell[371600, 16207, 137, 5, 33, "Notes",
      CellTags->"ShortestPath"],
    Cell[371740, 16214, 250, 11, 33, "Notes",
      CellTags->"ShortestPath"],
    Cell[371993, 16227, 379, 15, 33, "Notes",
      CellTags->"ShortestPath"],
    Cell[372397, 16246, 70, 1, 59, "ExampleSection",
      CellTags->"ShortestPath"],
    Cell[372470, 16249, 127, 4, 70, "ExampleText",
      CellTags->"ShortestPath"],
    Cell[372622, 16257, 121, 3, 70, "Input",
      CellTags->"ShortestPath"],
    Cell[372746, 16262, 438, 11, 70, "Output",
      CellTags->"ShortestPath"],
    Cell[373221, 16278, 104, 3, 70, "Input",
      CellTags->"ShortestPath"],
    Cell[373328, 16283, 177, 4, 70, "Output",
      CellTags->"ShortestPath"],
    Cell[373542, 16292, 123, 3, 70, "Input",
      CellTags->"ShortestPath"],
    Cell[373668, 16297, 211, 4, 70, "Output",
      CellTags->"ShortestPath"]},
  "ShowArray"->{
    Cell[373940, 16308, 56, 1, 42, "ObjectName",
      CellTags->"ShowArray"],
    Cell[373999, 16311, 60, 1, 74, "Highlight",
      CellTags->"ShowArray"],
    Cell[374062, 16314, 231, 8, 43, "Usage",
      CellTags->"ShowArray"],
    Cell[374296, 16324, 191, 7, 33, "Notes",
      CellTags->"ShowArray"],
    Cell[374490, 16333, 162, 7, 33, "Notes",
      CellTags->"ShowArray"],
    Cell[374677, 16344, 67, 1, 59, "ExampleSection",
      CellTags->"ShowArray"],
    Cell[374747, 16347, 75, 1, 70, "ExampleText",
      CellTags->"ShowArray"],
    Cell[374825, 16350, 238, 5, 70, "Input",
      CellTags->"ShowArray"]},
  "Shuffle"->{
    Cell[383752, 17011, 52, 1, 31, "ObjectName",
      CellTags->"Shuffle"],
    Cell[383807, 17014, 58, 1, 74, "Highlight",
      CellTags->"Shuffle"],
    Cell[383868, 17017, 200, 9, 43, "Usage",
      CellTags->"Shuffle"],
    Cell[384071, 17028, 240, 11, 33, "Notes",
      CellTags->"Shuffle"],
    Cell[384314, 17041, 270, 11, 33, "Notes",
      CellTags->"Shuffle"],
    Cell[384609, 17056, 65, 1, 59, "ExampleSection",
      CellTags->"Shuffle"],
    Cell[384677, 17059, 105, 2, 70, "ExampleText",
      CellTags->"Shuffle"],
    Cell[384807, 17065, 90, 2, 70, "Input",
      CellTags->"Shuffle"]},
  "SimplifyEquations"->{
    Cell[385208, 17080, 72, 1, 31, "ObjectName",
      CellTags->"SimplifyEquations"],
    Cell[385283, 17083, 68, 1, 74, "Highlight",
      CellTags->"SimplifyEquations"],
    Cell[385354, 17086, 226, 6, 64, "Usage",
      CellTags->"SimplifyEquations"],
    Cell[385583, 17094, 232, 9, 58, "Notes",
      CellTags->"SimplifyEquations"],
    Cell[385818, 17105, 275, 9, 54, "Notes",
      CellTags->"SimplifyEquations"],
    Cell[386096, 17116, 288, 11, 33, "Notes",
      CellTags->"SimplifyEquations"],
    Cell[386409, 17131, 75, 1, 59, "ExampleSection",
      CellTags->"SimplifyEquations"],
    Cell[386487, 17134, 141, 4, 70, "ExampleText",
      CellTags->"SimplifyEquations"],
    Cell[386631, 17140, 161, 4, 70, "Input",
      CellTags->"SimplifyEquations"]},
  "SimplifyRewriteSystem"->{
    Cell[388912, 17207, 80, 1, 42, "ObjectName",
      CellTags->"SimplifyRewriteSystem"],
    Cell[388995, 17210, 72, 1, 74, "Highlight",
      CellTags->"SimplifyRewriteSystem"],
    Cell[389070, 17213, 211, 6, 43, "Usage",
      CellTags->"SimplifyRewriteSystem"],
    Cell[389284, 17221, 240, 9, 58, "Notes",
      CellTags->"SimplifyRewriteSystem"],
    Cell[389527, 17232, 254, 6, 54, "Notes",
      CellTags->"SimplifyRewriteSystem"],
    Cell[389784, 17240, 218, 6, 54, "Notes",
      CellTags->"SimplifyRewriteSystem"],
    Cell[390181, 17258, 79, 1, 59, "ExampleSection",
      CellTags->"SimplifyRewriteSystem"],
    Cell[390263, 17261, 199, 5, 70, "ExampleText",
      CellTags->"SimplifyRewriteSystem"],
    Cell[390465, 17268, 165, 4, 70, "Input",
      CellTags->"SimplifyRewriteSystem"]},
  "SolveSG"->{
    Cell[393128, 17345, 52, 1, 42, "ObjectName",
      CellTags->"SolveSG"],
    Cell[393183, 17348, 58, 1, 74, "Highlight",
      CellTags->"SolveSG"],
    Cell[393244, 17351, 237, 8, 64, "Usage",
      CellTags->"SolveSG"],
    Cell[393484, 17361, 308, 10, 82, "Notes",
      CellTags->"SolveSG"],
    Cell[393795, 17373, 193, 7, 33, "Notes",
      CellTags->"SolveSG"],
    Cell[393991, 17382, 158, 7, 33, "Notes",
      CellTags->"SolveSG"],
    Cell[394152, 17391, 240, 11, 33, "Notes",
      CellTags->"SolveSG"],
    Cell[394417, 17406, 65, 1, 59, "ExampleSection",
      CellTags->"SolveSG"],
    Cell[394485, 17409, 93, 1, 70, "ExampleText",
      CellTags->"SolveSG"],
    Cell[394603, 17414, 89, 2, 70, "Input",
      CellTags->"SolveSG"],
    Cell[395212, 17441, 108, 2, 70, "ExampleText",
      CellTags->"SolveSG"],
    Cell[395323, 17445, 90, 2, 70, "Input",
      CellTags->"SolveSG"]},
  "StaircasePlot"->{
    Cell[395839, 17470, 64, 1, 31, "ObjectName",
      CellTags->"StaircasePlot"],
    Cell[395906, 17473, 64, 1, 74, "Highlight",
      CellTags->"StaircasePlot"],
    Cell[395973, 17476, 171, 4, 43, "Usage",
      CellTags->"StaircasePlot"],
    Cell[396147, 17482, 278, 10, 80, "Notes",
      CellTags->"StaircasePlot"],
    Cell[396428, 17494, 128, 5, 33, "Notes",
      CellTags->"StaircasePlot"],
    Cell[396559, 17501, 440, 19, 33, "Notes",
      CellTags->"StaircasePlot"],
    Cell[397024, 17524, 71, 1, 59, "ExampleSection",
      CellTags->"StaircasePlot"],
    Cell[397098, 17527, 92, 1, 70, "ExampleText",
      CellTags->"StaircasePlot"],
    Cell[397215, 17532, 180, 4, 70, "Input",
      CellTags->"StaircasePlot"]},
  "Status"->{
    Cell[399042, 17648, 50, 1, 31, "ObjectName",
      CellTags->"Status"],
    Cell[399095, 17651, 57, 1, 74, "Highlight",
      CellTags->"Status"],
    Cell[399155, 17654, 139, 4, 43, "Usage",
      CellTags->"Status"],
    Cell[399319, 17662, 64, 1, 59, "ExampleSection",
      CellTags->"Status"],
    Cell[399386, 17665, 62, 1, 70, "ExampleText",
      CellTags->"Status"],
    Cell[399473, 17670, 73, 2, 70, "Input",
      CellTags->"Status"]},
  "StronglyConnectedComponents"->{
    Cell[400892, 17702, 92, 1, 42, "ObjectName",
      CellTags->"StronglyConnectedComponents"],
    Cell[400987, 17705, 78, 1, 74, "Highlight",
      CellTags->"StronglyConnectedComponents"],
    Cell[401068, 17708, 299, 6, 85, "Usage",
      CellTags->"StronglyConnectedComponents"],
    Cell[401370, 17716, 316, 10, 80, "Notes",
      CellTags->"StronglyConnectedComponents"],
    Cell[401689, 17728, 210, 6, 54, "Notes",
      CellTags->"StronglyConnectedComponents"],
    Cell[401902, 17736, 96, 1, 33, "Notes",
      CellTags->"StronglyConnectedComponents"],
    Cell[402001, 17739, 504, 19, 33, "Notes",
      CellTags->"StronglyConnectedComponents"],
    Cell[402530, 17762, 85, 1, 59, "ExampleSection",
      CellTags->"StronglyConnectedComponents"],
    Cell[402618, 17765, 117, 1, 48, "ExampleText",
      CellTags->"StronglyConnectedComponents"],
    Cell[402738, 17768, 246, 6, 60, "Input",
      CellTags->"StronglyConnectedComponents"],
    Cell[403009, 17778, 131, 3, 37, "Input",
      CellTags->"StronglyConnectedComponents"],
    Cell[403143, 17783, 141, 3, 30, "Output",
      CellTags->"StronglyConnectedComponents"],
    Cell[403321, 17791, 156, 3, 37, "Input",
      CellTags->"StronglyConnectedComponents"],
    Cell[403480, 17796, 121, 3, 30, "Output",
      CellTags->"StronglyConnectedComponents"]},
  "SubGraph"->{
    Cell[403662, 17806, 54, 1, 42, "ObjectName",
      CellTags->"SubGraph"],
    Cell[403719, 17809, 59, 1, 74, "Highlight",
      CellTags->"SubGraph"],
    Cell[403781, 17812, 204, 8, 43, "Usage",
      CellTags->"SubGraph"],
    Cell[403988, 17822, 225, 9, 58, "Notes",
      CellTags->"SubGraph"],
    Cell[404216, 17833, 118, 4, 33, "Notes",
      CellTags->"SubGraph"],
    Cell[404337, 17839, 251, 11, 33, "Notes",
      CellTags->"SubGraph"],
    Cell[404613, 17854, 66, 1, 59, "ExampleSection",
      CellTags->"SubGraph"],
    Cell[404682, 17857, 122, 4, 70, "ExampleText",
      CellTags->"SubGraph"],
    Cell[404829, 17865, 83, 2, 70, "Input",
      CellTags->"SubGraph"]},
  "SubsetQ"->{
    Cell[406178, 17928, 52, 1, 31, "ObjectName",
      CellTags->"SubsetQ"],
    Cell[406233, 17931, 58, 1, 74, "Highlight",
      CellTags->"SubsetQ"],
    Cell[406294, 17934, 203, 8, 43, "Usage",
      CellTags->"SubsetQ"],
    Cell[406500, 17944, 126, 5, 33, "Notes",
      CellTags->"SubsetQ"],
    Cell[406629, 17951, 156, 7, 33, "Notes",
      CellTags->"SubsetQ"],
    Cell[406810, 17962, 65, 1, 59, "ExampleSection",
      CellTags->"SubsetQ"],
    Cell[406878, 17965, 78, 1, 70, "ExampleText",
      CellTags->"SubsetQ"],
    Cell[406981, 17970, 91, 2, 70, "Input",
      CellTags->"SubsetQ"],
    Cell[407175, 17981, 91, 2, 70, "Input",
      CellTags->"SubsetQ"]},
  "SymbolList"->{
    Cell[407394, 17994, 58, 1, 42, "ObjectName",
      CellTags->"SymbolList"],
    Cell[407455, 17997, 61, 1, 74, "Highlight",
      CellTags->"SymbolList"],
    Cell[407519, 18000, 272, 10, 43, "Usage",
      CellTags->"SymbolList"],
    Cell[407794, 18012, 114, 4, 33, "Notes",
      CellTags->"SymbolList"],
    Cell[407933, 18020, 68, 1, 59, "ExampleSection",
      CellTags->"SymbolList"],
    Cell[408004, 18023, 67, 1, 70, "ExampleText",
      CellTags->"SymbolList"],
    Cell[408096, 18028, 115, 5, 70, "Input",
      CellTags->"SymbolList"]},
  "SymmetricGroupSG"->{
    Cell[408622, 18053, 70, 1, 42, "ObjectName",
      CellTags->"SymmetricGroupSG"],
    Cell[408695, 18056, 67, 1, 74, "Highlight",
      CellTags->"SymmetricGroupSG"],
    Cell[408765, 18059, 148, 4, 43, "Usage",
      CellTags->"SymmetricGroupSG"],
    Cell[408916, 18065, 254, 9, 33, "Notes",
      CellTags->"SymmetricGroupSG"],
    Cell[409173, 18076, 389, 15, 33, "Notes",
      CellTags->"SymmetricGroupSG"],
    Cell[409587, 18095, 74, 1, 59, "ExampleSection",
      CellTags->"SymmetricGroupSG"],
    Cell[409664, 18098, 87, 1, 70, "ExampleText",
      CellTags->"SymmetricGroupSG"],
    Cell[409776, 18103, 93, 2, 70, "Input",
      CellTags->"SymmetricGroupSG"]},
  "TableSG"->{
    Cell[410391, 18122, 52, 1, 42, "ObjectName",
      CellTags->"TableSG"],
    Cell[410446, 18125, 58, 1, 74, "Highlight",
      CellTags->"TableSG"],
    Cell[410507, 18128, 157, 4, 43, "Usage",
      CellTags->"TableSG"],
    Cell[410667, 18134, 195, 7, 33, "Notes",
      CellTags->"TableSG"],
    Cell[410865, 18143, 155, 7, 33, "Notes",
      CellTags->"TableSG"],
    Cell[411045, 18154, 65, 1, 59, "ExampleSection",
      CellTags->"TableSG"],
    Cell[411113, 18157, 117, 4, 70, "ExampleText",
      CellTags->"TableSG"],
    Cell[411233, 18163, 152, 4, 70, "Input",
      CellTags->"TableSG"]},
  "ToAdjList"->{
    Cell[412708, 18207, 56, 1, 42, "ObjectName",
      CellTags->"ToAdjList"],
    Cell[412767, 18210, 60, 1, 74, "Highlight",
      CellTags->"ToAdjList"],
    Cell[412830, 18213, 166, 6, 43, "Usage",
      CellTags->"ToAdjList"],
    Cell[412999, 18221, 123, 4, 33, "Notes",
      CellTags->"ToAdjList"],
    Cell[413125, 18227, 151, 4, 33, "Notes",
      CellTags->"ToAdjList"],
    Cell[413279, 18233, 346, 15, 33, "Notes",
      CellTags->"ToAdjList"],
    Cell[413650, 18252, 67, 1, 59, "ExampleSection",
      CellTags->"ToAdjList"],
    Cell[413720, 18255, 93, 1, 70, "ExampleText",
      CellTags->"ToAdjList"],
    Cell[413838, 18260, 90, 2, 70, "Input",
      CellTags->"ToAdjList"],
    Cell[413931, 18264, 434, 11, 70, "Output",
      CellTags->"ToAdjList"],
    Cell[414402, 18280, 131, 3, 70, "Input",
      CellTags->"ToAdjList"],
    Cell[414536, 18285, 434, 15, 70, "Output",
      CellTags->"ToAdjList"]},
  "ToAdjMatrix"->{
    Cell[415031, 18307, 60, 1, 31, "ObjectName",
      CellTags->"ToAdjMatrix"],
    Cell[415094, 18310, 62, 1, 74, "Highlight",
      CellTags->"ToAdjMatrix"],
    Cell[415159, 18313, 172, 6, 43, "Usage",
      CellTags->"ToAdjMatrix"],
    Cell[415334, 18321, 141, 4, 33, "Notes",
      CellTags->"ToAdjMatrix"],
    Cell[415478, 18327, 344, 15, 33, "Notes",
      CellTags->"ToAdjMatrix"],
    Cell[415847, 18346, 69, 1, 59, "ExampleSection",
      CellTags->"ToAdjMatrix"],
    Cell[415919, 18349, 96, 1, 70, "ExampleText",
      CellTags->"ToAdjMatrix"],
    Cell[416040, 18354, 92, 2, 70, "Input",
      CellTags->"ToAdjMatrix"]},
  "ToBitVector"->{
    Cell[417402, 18398, 60, 1, 31, "ObjectName",
      CellTags->"ToBitVector"],
    Cell[417465, 18401, 62, 1, 74, "Highlight",
      CellTags->"ToBitVector"],
    Cell[417530, 18404, 206, 8, 43, "Usage",
      CellTags->"ToBitVector"],
    Cell[417739, 18414, 95, 1, 33, "Notes",
      CellTags->"ToBitVector"],
    Cell[417837, 18417, 170, 7, 33, "Notes",
      CellTags->"ToBitVector"],
    Cell[418032, 18428, 69, 1, 59, "ExampleSection",
      CellTags->"ToBitVector"],
    Cell[418104, 18431, 99, 1, 70, "ExampleText",
      CellTags->"ToBitVector"],
    Cell[418228, 18436, 92, 2, 70, "Input",
      CellTags->"ToBitVector"],
    Cell[418323, 18440, 140, 3, 70, "Output",
      CellTags->"ToBitVector"],
    Cell[418500, 18448, 127, 3, 70, "Input",
      CellTags->"ToBitVector"],
    Cell[418630, 18453, 183, 4, 70, "Output",
      CellTags->"ToBitVector"]},
  "ToClasses"->{
    Cell[418874, 18464, 56, 1, 42, "ObjectName",
      CellTags->"ToClasses"],
    Cell[418933, 18467, 60, 1, 74, "Highlight",
      CellTags->"ToClasses"],
    Cell[418996, 18470, 236, 8, 43, "Usage",
      CellTags->"ToClasses"],
    Cell[419235, 18480, 252, 9, 58, "Notes",
      CellTags->"ToClasses"],
    Cell[419490, 18491, 337, 11, 54, "Notes",
      CellTags->"ToClasses"],
    Cell[419989, 18512, 263, 11, 33, "Notes",
      CellTags->"ToClasses"],
    Cell[420277, 18527, 67, 1, 59, "ExampleSection",
      CellTags->"ToClasses"],
    Cell[420347, 18530, 124, 4, 70, "ExampleText",
      CellTags->"ToClasses"],
    Cell[420474, 18536, 139, 3, 70, "Input",
      CellTags->"ToClasses"],
    Cell[420858, 18552, 90, 1, 70, "ExampleText",
      CellTags->"ToClasses"],
    Cell[421923, 18583, 76, 1, 70, "ExampleText",
      CellTags->"ToClasses"],
    Cell[422353, 18601, 66, 1, 70, "ExampleText",
      CellTags->"ToClasses"]},
  "ToDAG"->{
    Cell[422975, 18630, 48, 1, 42, "ObjectName",
      CellTags->"ToDAG"],
    Cell[423026, 18633, 56, 1, 74, "Highlight",
      CellTags->"ToDAG"],
    Cell[423085, 18636, 270, 7, 64, "Usage",
      CellTags->"ToDAG"],
    Cell[423358, 18645, 222, 9, 58, "Notes",
      CellTags->"ToDAG"],
    Cell[423583, 18656, 486, 19, 33, "Notes",
      CellTags->"ToDAG"],
    Cell[424094, 18679, 63, 1, 59, "ExampleSection",
      CellTags->"ToDAG"]},
  "ToEdgeList"->{
    Cell[425053, 18718, 58, 1, 42, "ObjectName",
      CellTags->"ToEdgeList"],
    Cell[425114, 18721, 61, 1, 74, "Highlight",
      CellTags->"ToEdgeList"],
    Cell[425178, 18724, 163, 6, 43, "Usage",
      CellTags->"ToEdgeList"],
    Cell[425344, 18732, 345, 15, 33, "Notes",
      CellTags->"ToEdgeList"],
    Cell[425714, 18751, 68, 1, 59, "ExampleSection",
      CellTags->"ToEdgeList"],
    Cell[425785, 18754, 105, 1, 70, "ExampleText",
      CellTags->"ToEdgeList"]},
  "ToEps"->{
    Cell[427405, 18806, 48, 1, 31, "ObjectName",
      CellTags->"ToEps"],
    Cell[427456, 18809, 56, 1, 74, "Highlight",
      CellTags->"ToEps"],
    Cell[427515, 18812, 202, 8, 43, "Usage",
      CellTags->"ToEps"],
    Cell[427720, 18822, 98, 1, 33, "Notes",
      CellTags->"ToEps"],
    Cell[427821, 18825, 152, 7, 33, "Notes",
      CellTags->"ToEps"],
    Cell[427998, 18836, 63, 1, 59, "ExampleSection",
      CellTags->"ToEps"]},
  "ToIdentityString"->{
    Cell[428449, 18861, 70, 1, 31, "ObjectName",
      CellTags->"ToIdentityString"],
    Cell[428522, 18864, 67, 1, 74, "Highlight",
      CellTags->"ToIdentityString"],
    Cell[428592, 18867, 233, 8, 43, "Usage",
      CellTags->"ToIdentityString"],
    Cell[428828, 18877, 289, 11, 33, "Notes",
      CellTags->"ToIdentityString"],
    Cell[429142, 18892, 74, 1, 59, "ExampleSection",
      CellTags->"ToIdentityString"],
    Cell[429219, 18895, 83, 1, 70, "ExampleText",
      CellTags->"ToIdentityString"],
    Cell[429327, 18900, 109, 2, 70, "Input",
      CellTags->"ToIdentityString"]},
  "ToList"->{
    Cell[429578, 18913, 50, 1, 42, "ObjectName",
      CellTags->"ToList"],
    Cell[429631, 18916, 57, 1, 74, "Highlight",
      CellTags->"ToList"],
    Cell[429691, 18919, 182, 8, 43, "Usage",
      CellTags->"ToList"]},
  "ToTDGraph"->{
    Cell[429910, 18932, 56, 1, 42, "ObjectName",
      CellTags->"ToTDGraph"],
    Cell[429969, 18935, 60, 1, 74, "Highlight",
      CellTags->"ToTDGraph"],
    Cell[430032, 18938, 266, 9, 64, "Usage",
      CellTags->"ToTDGraph"],
    Cell[430301, 18949, 226, 9, 58, "Notes",
      CellTags->"ToTDGraph"],
    Cell[430530, 18960, 77, 1, 33, "Notes",
      CellTags->"ToTDGraph"],
    Cell[430610, 18963, 177, 7, 33, "Notes",
      CellTags->"ToTDGraph"],
    Cell[430812, 18974, 67, 1, 59, "ExampleSection",
      CellTags->"ToTDGraph"],
    Cell[430882, 18977, 187, 6, 70, "ExampleText",
      CellTags->"ToTDGraph"]},
  "TransformationSG"->{
    Cell[434355, 19181, 70, 1, 42, "ObjectName",
      CellTags->"TransformationSG"],
    Cell[434428, 19184, 67, 1, 74, "Highlight",
      CellTags->"TransformationSG"],
    Cell[434498, 19187, 186, 6, 43, "Usage",
      CellTags->"TransformationSG"],
    Cell[434687, 19195, 254, 8, 33, "Notes",
      CellTags->"TransformationSG"],
    Cell[434944, 19205, 384, 15, 33, "Notes",
      CellTags->"TransformationSG"],
    Cell[435353, 19224, 74, 1, 59, "ExampleSection",
      CellTags->"TransformationSG"],
    Cell[435430, 19227, 101, 1, 70, "ExampleText",
      CellTags->"TransformationSG"],
    Cell[435556, 19232, 98, 2, 70, "Input",
      CellTags->"TransformationSG"]},
  "TransientPeriodicT"->{
    Cell[436308, 19260, 74, 1, 42, "ObjectName",
      CellTags->"TransientPeriodicT"],
    Cell[436385, 19263, 69, 1, 74, "Highlight",
      CellTags->"TransientPeriodicT"],
    Cell[436457, 19266, 244, 7, 64, "Usage",
      CellTags->"TransientPeriodicT"],
    Cell[436704, 19275, 163, 4, 33, "Notes",
      CellTags->"TransientPeriodicT"],
    Cell[436870, 19281, 163, 7, 33, "Notes",
      CellTags->"TransientPeriodicT"],
    Cell[437058, 19292, 76, 1, 59, "ExampleSection",
      CellTags->"TransientPeriodicT"],
    Cell[437137, 19295, 160, 4, 70, "ExampleText",
      CellTags->"TransientPeriodicT"],
    Cell[437300, 19301, 121, 3, 70, "Input",
      CellTags->"TransientPeriodicT"]},
  "TransitiveClosure"->{
    Cell[438546, 19349, 72, 1, 31, "ObjectName",
      CellTags->"TransitiveClosure"],
    Cell[438621, 19352, 68, 1, 74, "Highlight",
      CellTags->"TransitiveClosure"],
    Cell[438692, 19355, 193, 6, 43, "Usage",
      CellTags->"TransitiveClosure"],
    Cell[438888, 19363, 238, 9, 58, "Notes",
      CellTags->"TransitiveClosure"],
    Cell[439129, 19374, 172, 5, 33, "Notes",
      CellTags->"TransitiveClosure"],
    Cell[439304, 19381, 144, 5, 33, "Notes",
      CellTags->"TransitiveClosure"],
    Cell[439451, 19388, 402, 15, 33, "Notes",
      CellTags->"TransitiveClosure"],
    Cell[439878, 19407, 75, 1, 59, "ExampleSection",
      CellTags->"TransitiveClosure"],
    Cell[439956, 19410, 91, 1, 70, "ExampleText",
      CellTags->"TransitiveClosure"],
    Cell[440050, 19413, 348, 6, 70, "Input",
      CellTags->"TransitiveClosure"],
    Cell[440423, 19423, 111, 3, 70, "Input",
      CellTags->"TransitiveClosure"],
    Cell[440537, 19428, 682, 15, 70, "Output",
      CellTags->"TransitiveClosure"],
    Cell[441256, 19448, 128, 3, 70, "Input",
      CellTags->"TransitiveClosure"],
    Cell[441387, 19453, 682, 15, 70, "Output",
      CellTags->"TransitiveClosure"]},
  "TranspositionT"->{
    Cell[442130, 19475, 66, 1, 42, "ObjectName",
      CellTags->"TranspositionT"],
    Cell[442199, 19478, 65, 1, 74, "Highlight",
      CellTags->"TranspositionT"],
    Cell[442267, 19481, 278, 10, 43, "Usage",
      CellTags->"TranspositionT"],
    Cell[442548, 19493, 122, 5, 33, "Notes",
      CellTags->"TranspositionT"],
    Cell[442673, 19500, 253, 11, 33, "Notes",
      CellTags->"TranspositionT"]},
  "TypeGraph"->{
    Cell[442963, 19516, 56, 1, 42, "ObjectName",
      CellTags->"TypeGraph"],
    Cell[443022, 19519, 60, 1, 74, "Highlight",
      CellTags->"TypeGraph"],
    Cell[443085, 19522, 123, 4, 43, "Usage",
      CellTags->"TypeGraph"],
    Cell[443211, 19528, 410, 15, 54, "Notes",
      CellTags->"TypeGraph"],
    Cell[443624, 19545, 152, 7, 33, "Notes",
      CellTags->"TypeGraph"],
    Cell[443801, 19556, 67, 1, 59, "ExampleSection",
      CellTags->"TypeGraph"],
    Cell[443871, 19559, 100, 1, 70, "ExampleText",
      CellTags->"TypeGraph"],
    Cell[443974, 19562, 141, 3, 70, "Input",
      CellTags->"TypeGraph"],
    Cell[444140, 19569, 96, 3, 70, "Input",
      CellTags->"TypeGraph"],
    Cell[444239, 19574, 86, 3, 70, "Output",
      CellTags->"TypeGraph"],
    Cell[444362, 19582, 123, 3, 70, "Input",
      CellTags->"TypeGraph"],
    Cell[444488, 19587, 86, 3, 70, "Output",
      CellTags->"TypeGraph"],
    Cell[444611, 19595, 125, 3, 70, "Input",
      CellTags->"TypeGraph"],
    Cell[444739, 19600, 86, 3, 70, "Output",
      CellTags->"TypeGraph"]},
  "UnitElement"->{
    Cell[444886, 19610, 60, 1, 42, "ObjectName",
      CellTags->"UnitElement"],
    Cell[444949, 19613, 62, 1, 74, "Highlight",
      CellTags->"UnitElement"],
    Cell[445014, 19616, 197, 6, 43, "Usage",
      CellTags->"UnitElement"],
    Cell[445214, 19624, 210, 6, 54, "Notes",
      CellTags->"UnitElement"],
    Cell[445521, 19638, 159, 7, 33, "Notes",
      CellTags->"UnitElement"],
    Cell[445705, 19649, 69, 1, 59, "ExampleSection",
      CellTags->"UnitElement"],
    Cell[445777, 19652, 69, 1, 48, "ExampleText",
      CellTags->"UnitElement"],
    Cell[445871, 19657, 91, 2, 40, "Input",
      CellTags->"UnitElement"],
    Cell[446072, 19668, 96, 2, 40, "Input",
      CellTags->"UnitElement"]},
  "VertexSet"->{
    Cell[446308, 19681, 56, 1, 31, "ObjectName",
      CellTags->"VertexSet"],
    Cell[446367, 19684, 60, 1, 74, "Highlight",
      CellTags->"VertexSet"],
    Cell[446430, 19687, 158, 6, 43, "Usage",
      CellTags->"VertexSet"],
    Cell[446591, 19695, 185, 6, 33, "Notes",
      CellTags->"VertexSet"],
    Cell[446779, 19703, 238, 11, 33, "Notes",
      CellTags->"VertexSet"],
    Cell[447042, 19718, 67, 1, 59, "ExampleSection",
      CellTags->"VertexSet"],
    Cell[447112, 19721, 101, 1, 70, "ExampleText",
      CellTags->"VertexSet"],
    Cell[447216, 19724, 133, 3, 70, "Input",
      CellTags->"VertexSet"]},
  "Vier"->{
    Cell[447625, 19744, 46, 1, 42, "ObjectName",
      CellTags->"Vier"],
    Cell[447674, 19747, 54, 1, 74, "Highlight",
      CellTags->"Vier"],
    Cell[447731, 19750, 146, 6, 43, "Usage",
      CellTags->"Vier"],
    Cell[447880, 19758, 104, 5, 33, "Notes",
      CellTags->"Vier"],
    Cell[447987, 19765, 435, 19, 33, "Notes",
      CellTags->"Vier"]},
  "Warshall"->{
    Cell[448459, 19789, 54, 1, 42, "ObjectName",
      CellTags->"Warshall"],
    Cell[448516, 19792, 59, 1, 74, "Highlight",
      CellTags->"Warshall"],
    Cell[448578, 19795, 174, 5, 43, "Usage",
      CellTags->"Warshall"],
    Cell[448755, 19802, 229, 9, 58, "Notes",
      CellTags->"Warshall"],
    Cell[448987, 19813, 125, 4, 33, "Notes",
      CellTags->"Warshall"],
    Cell[449214, 19824, 265, 11, 33, "Notes",
      CellTags->"Warshall"],
    Cell[449504, 19839, 66, 1, 59, "ExampleSection",
      CellTags->"Warshall"],
    Cell[449573, 19842, 178, 6, 70, "ExampleText",
      CellTags->"Warshall"],
    Cell[449776, 19852, 135, 5, 70, "Input",
      CellTags->"Warshall"]},
  "WeaklyConnectedComponents"->{
    Cell[451696, 19920, 88, 1, 42, "ObjectName",
      CellTags->"WeaklyConnectedComponents"],
    Cell[451787, 19923, 76, 1, 74, "Highlight",
      CellTags->"WeaklyConnectedComponents"],
    Cell[451866, 19926, 252, 8, 64, "Usage",
      CellTags->"WeaklyConnectedComponents"],
    Cell[452121, 19936, 161, 4, 33, "Notes",
      CellTags->"WeaklyConnectedComponents"],
    Cell[452285, 19942, 298, 11, 33, "Notes",
      CellTags->"WeaklyConnectedComponents"],
    Cell[452608, 19957, 83, 1, 59, "ExampleSection",
      CellTags->"WeaklyConnectedComponents"],
    Cell[452694, 19960, 95, 1, 70, "ExampleText",
      CellTags->"WeaklyConnectedComponents"],
    Cell[452814, 19965, 116, 2, 70, "Input",
      CellTags->"WeaklyConnectedComponents"]},
  "WordQ"->{
    Cell[453716, 20004, 48, 1, 42, "ObjectName",
      CellTags->"WordQ"],
    Cell[453767, 20007, 56, 1, 74, "Highlight",
      CellTags->"WordQ"],
    Cell[453826, 20010, 143, 4, 43, "Usage",
      CellTags->"WordQ"],
    Cell[453972, 20016, 67, 1, 33, "Notes",
      CellTags->"WordQ"],
    Cell[454042, 20019, 1945, 79, 96, "Notes",
      CellTags->"WordQ"],
    Cell[456012, 20102, 63, 1, 59, "ExampleSection",
      CellTags->"WordQ"],
    Cell[456078, 20105, 72, 1, 70, "ExampleText",
      CellTags->"WordQ"],
    Cell[456175, 20110, 133, 3, 70, "Input",
      CellTags->"WordQ"]},
  "WordReduce"->{
    Cell[456470, 20124, 58, 1, 31, "ObjectName",
      CellTags->"WordReduce"],
    Cell[456531, 20127, 61, 1, 74, "Highlight",
      CellTags->"WordReduce"],
    Cell[456595, 20130, 201, 8, 43, "Usage",
      CellTags->"WordReduce"],
    Cell[456799, 20140, 275, 10, 80, "Notes",
      CellTags->"WordReduce"],
    Cell[457077, 20152, 53, 1, 33, "Notes",
      CellTags->"WordReduce"],
    Cell[457468, 20168, 121, 4, 33, "Notes",
      CellTags->"WordReduce"],
    Cell[457592, 20174, 295, 11, 33, "Notes",
      CellTags->"WordReduce"],
    Cell[457912, 20189, 68, 1, 59, "ExampleSection",
      CellTags->"WordReduce"],
    Cell[457983, 20192, 72, 1, 70, "ExampleText",
      CellTags->"WordReduce"],
    Cell[458058, 20195, 143, 3, 70, "Input",
      CellTags->"WordReduce"],
    Cell[459193, 20238, 99, 1, 70, "ExampleText",
      CellTags->"WordReduce"],
    Cell[459317, 20243, 156, 4, 70, "Input",
      CellTags->"WordReduce"]},
  "Zwei"->{
    Cell[459652, 20258, 46, 1, 42, "ObjectName",
      CellTags->"Zwei"],
    Cell[459701, 20261, 54, 1, 74, "Highlight",
      CellTags->"Zwei"],
    Cell[459758, 20264, 83, 4, 43, "Usage",
      CellTags->"Zwei"],
    Cell[459844, 20270, 104, 5, 33, "Notes",
      CellTags->"Zwei"],
    Cell[459951, 20277, 333, 15, 33, "Notes",
      CellTags->"Zwei"]},
  "All"->{
    Cell[460321, 20297, 44, 1, 42, "ObjectName",
      CellTags->"All"],
    Cell[460404, 20302, 120, 4, 43, "Usage",
      CellTags->"All"],
    Cell[460527, 20308, 430, 15, 33, "Notes",
      CellTags->"All"],
    Cell[460982, 20327, 61, 1, 59, "ExampleSection",
      CellTags->"All"],
    Cell[461046, 20330, 207, 7, 70, "ExampleText",
      CellTags->"All"],
    Cell[461278, 20341, 105, 2, 70, "Input",
      CellTags->"All"],
    Cell[464506, 20592, 90, 1, 70, "ExampleText",
      CellTags->"All"],
    Cell[464621, 20597, 118, 2, 70, "Input",
      CellTags->"All"]},
  "Boolean"->{
    Cell[466753, 20737, 52, 1, 42, "ObjectName",
      CellTags->"Boolean"],
    Cell[466808, 20740, 56, 1, 74, "Highlight",
      CellTags->"Boolean"],
    Cell[466867, 20743, 242, 7, 64, "Usage",
      CellTags->"Boolean"],
    Cell[467112, 20752, 220, 8, 58, "Notes",
      CellTags->"Boolean"],
    Cell[467335, 20762, 145, 4, 33, "Notes",
      CellTags->"Boolean"],
    Cell[467483, 20768, 176, 7, 33, "Notes",
      CellTags->"Boolean"],
    Cell[467684, 20779, 65, 1, 59, "ExampleSection",
      CellTags->"Boolean"],
    Cell[467752, 20782, 72, 1, 70, "ExampleText",
      CellTags->"Boolean"],
    Cell[467849, 20787, 107, 3, 70, "Input",
      CellTags->"Boolean"],
    Cell[467959, 20792, 477, 14, 70, "Output",
      CellTags->"Boolean"],
    Cell[468451, 20809, 127, 3, 70, "Input",
      CellTags->"Boolean"],
    Cell[468603, 20816, 83, 2, 70, "Input",
      CellTags->"Boolean"],
    Cell[468689, 20820, 434, 12, 70, "Output",
      CellTags->"Boolean"],
    Cell[469160, 20837, 86, 2, 70, "Input",
      CellTags->"Boolean"],
    Cell[469249, 20841, 434, 12, 70, "Output",
      CellTags->"Boolean"]},
  "BoundCSM"->{
    Cell[469744, 20860, 54, 1, 31, "ObjectName",
      CellTags->"BoundCSM"],
    Cell[469801, 20863, 57, 1, 74, "Highlight",
      CellTags->"BoundCSM"],
    Cell[469861, 20866, 181, 5, 64, "Usage",
      CellTags->"BoundCSM"],
    Cell[470045, 20873, 57, 1, 33, "Notes",
      CellTags->"BoundCSM"],
    Cell[470105, 20876, 57, 1, 33, "Notes",
      CellTags->"BoundCSM"]},
  "BoundETW"->{
    Cell[470199, 20882, 54, 1, 42, "ObjectName",
      CellTags->"BoundETW"],
    Cell[470256, 20885, 57, 1, 74, "Highlight",
      CellTags->"BoundETW"],
    Cell[470316, 20888, 156, 6, 43, "Usage",
      CellTags->"BoundETW"],
    Cell[470475, 20896, 56, 1, 33, "Notes",
      CellTags->"BoundETW"],
    Cell[470534, 20899, 176, 7, 33, "Notes",
      CellTags->"BoundETW"]},
  "BoundGSG"->{
    Cell[470747, 20911, 54, 1, 42, "ObjectName",
      CellTags->"BoundGSG"],
    Cell[470804, 20914, 57, 1, 74, "Highlight",
      CellTags->"BoundGSG"],
    Cell[470864, 20917, 193, 6, 43, "Usage",
      CellTags->"BoundGSG"],
    Cell[471060, 20925, 76, 1, 33, "Notes",
      CellTags->"BoundGSG"],
    Cell[471139, 20928, 254, 10, 33, "Notes",
      CellTags->"BoundGSG"]},
  "BoundWR"->{
    Cell[471430, 20943, 52, 1, 42, "ObjectName",
      CellTags->"BoundWR"],
    Cell[471485, 20946, 56, 1, 74, "Highlight",
      CellTags->"BoundWR"],
    Cell[471544, 20949, 182, 6, 43, "Usage",
      CellTags->"BoundWR"],
    Cell[471729, 20957, 55, 1, 33, "Notes",
      CellTags->"BoundWR"],
    Cell[471787, 20960, 155, 7, 33, "Notes",
      CellTags->"BoundWR"]},
  "ClosureBound"->{
    Cell[471979, 20972, 62, 1, 42, "ObjectName",
      CellTags->"ClosureBound"],
    Cell[472044, 20975, 61, 1, 74, "Highlight",
      CellTags->"ClosureBound"],
    Cell[472108, 20978, 196, 8, 43, "Usage",
      CellTags->"ClosureBound"],
    Cell[472307, 20988, 259, 11, 33, "Notes",
      CellTags->"ClosureBound"]},
  "Cols"->{
    Cell[472603, 21004, 46, 1, 42, "ObjectName",
      CellTags->"Cols"],
    Cell[472652, 21007, 53, 1, 74, "Highlight",
      CellTags->"Cols"],
    Cell[472708, 21010, 137, 6, 43, "Usage",
      CellTags->"Cols"],
    Cell[472848, 21018, 160, 7, 33, "Notes",
      CellTags->"Cols"]},
  "Cycle"->{
    Cell[473045, 21030, 48, 1, 42, "ObjectName",
      CellTags->"Cycle"],
    Cell[473096, 21033, 54, 1, 74, "Highlight",
      CellTags->"Cycle"],
    Cell[473153, 21036, 188, 6, 43, "Usage",
      CellTags->"Cycle"],
    Cell[473344, 21044, 157, 7, 33, "Notes",
      CellTags->"Cycle"]},
  "DClasses"->{
    Cell[473538, 21056, 54, 1, 42, "ObjectName",
      CellTags->"DClasses"],
    Cell[473595, 21059, 57, 1, 74, "Highlight",
      CellTags->"DClasses"],
    Cell[473655, 21062, 145, 6, 43, "Usage",
      CellTags->"DClasses"],
    Cell[473803, 21070, 108, 5, 33, "Notes",
      CellTags->"DClasses"],
    Cell[473914, 21077, 355, 15, 33, "Notes",
      CellTags->"DClasses"]},
  "DoTrace"->{
    Cell[474306, 21097, 52, 1, 42, "ObjectName",
      CellTags->"DoTrace"],
    Cell[474361, 21100, 56, 1, 74, "Highlight",
      CellTags->"DoTrace"],
    Cell[474420, 21103, 122, 4, 43, "Usage",
      CellTags->"DoTrace"],
    Cell[474545, 21109, 572, 23, 54, "Notes",
      CellTags->"DoTrace"]},
  "Eps"->{
    Cell[475154, 21137, 44, 1, 42, "ObjectName",
      CellTags->"Eps"],
    Cell[475201, 21140, 52, 1, 74, "Highlight",
      CellTags->"Eps"],
    Cell[475256, 21143, 115, 4, 43, "Usage",
      CellTags->"Eps"],
    Cell[475374, 21149, 171, 6, 33, "Notes",
      CellTags->"Eps"],
    Cell[475548, 21157, 238, 8, 33, "Notes",
      CellTags->"Eps"],
    Cell[475789, 21167, 284, 11, 54, "Notes",
      CellTags->"Eps"],
    Cell[476076, 21180, 141, 7, 33, "Notes",
      CellTags->"Eps"]},
  "Equations"->{
    Cell[476254, 21192, 56, 1, 42, "ObjectName",
      CellTags->"Equations"],
    Cell[476313, 21195, 58, 1, 74, "Highlight",
      CellTags->"Equations"],
    Cell[476374, 21198, 126, 4, 43, "Usage",
      CellTags->"Equations"],
    Cell[476503, 21204, 255, 11, 33, "Notes",
      CellTags->"Equations"]},
  "External"->{
    Cell[476795, 21220, 54, 1, 42, "ObjectName",
      CellTags->"External"],
    Cell[476852, 21223, 57, 1, 74, "Highlight",
      CellTags->"External"],
    Cell[476912, 21226, 156, 4, 43, "Usage",
      CellTags->"External"],
    Cell[477071, 21232, 255, 8, 54, "Notes",
      CellTags->"External"],
    Cell[477329, 21242, 120, 5, 33, "Notes",
      CellTags->"External"],
    Cell[477452, 21249, 124, 4, 33, "Notes",
      CellTags->"External"]},
  "defaultexternal"->{
    Cell[477579, 21255, 448, 19, 33, "Notes",
      CellTags->"defaultexternal"],
    Cell[518580, 23097, 69, 1, 42, "ObjectName",
      CellTags->"defaultexternal"],
    Cell[518652, 23100, 64, 1, 74, "Highlight",
      CellTags->"defaultexternal"],
    Cell[518719, 23103, 179, 5, 43, "Usage",
      CellTags->"defaultexternal"],
    Cell[518901, 23110, 267, 10, 36, "Notes",
      CellTags->"defaultexternal"],
    Cell[519171, 23122, 147, 5, 33, "Notes",
      CellTags->"defaultexternal"],
    Cell[519321, 23129, 448, 19, 33, "Notes",
      CellTags->"defaultexternal"]},
  "Filter"->{
    Cell[478064, 21279, 50, 1, 42, "ObjectName",
      CellTags->"Filter"],
    Cell[478117, 21282, 55, 1, 74, "Highlight",
      CellTags->"Filter"],
    Cell[478175, 21285, 201, 5, 64, "Usage",
      CellTags->"Filter"],
    Cell[478379, 21292, 76, 1, 33, "Notes",
      CellTags->"Filter"],
    Cell[478458, 21295, 116, 4, 33, "Notes",
      CellTags->"Filter"],
    Cell[478577, 21301, 159, 7, 33, "Notes",
      CellTags->"Filter"],
    Cell[478761, 21312, 64, 1, 59, "ExampleSection",
      CellTags->"Filter"],
    Cell[478828, 21315, 106, 2, 70, "ExampleText",
      CellTags->"Filter"]},
  "Full"->{
    Cell[487302, 21568, 46, 1, 42, "ObjectName",
      CellTags->"Full"],
    Cell[487351, 21571, 53, 1, 74, "Highlight",
      CellTags->"Full"],
    Cell[487407, 21574, 116, 4, 43, "Usage",
      CellTags->"Full"],
    Cell[487526, 21580, 1988, 79, 96, "Notes",
      CellTags->"Full"]},
  "GridOffset"->{
    Cell[489551, 21664, 58, 1, 42, "ObjectName",
      CellTags->"GridOffset"],
    Cell[489612, 21667, 59, 1, 74, "Highlight",
      CellTags->"GridOffset"],
    Cell[489674, 21670, 147, 6, 43, "Usage",
      CellTags->"GridOffset"],
    Cell[489824, 21678, 205, 9, 58, "Notes",
      CellTags->"GridOffset"],
    Cell[490032, 21689, 158, 5, 33, "Notes",
      CellTags->"GridOffset"],
    Cell[490193, 21696, 159, 7, 33, "Notes",
      CellTags->"GridOffset"]},
  "Index"->{
    Cell[490389, 21708, 48, 1, 42, "ObjectName",
      CellTags->"Index"],
    Cell[490440, 21711, 54, 1, 74, "Highlight",
      CellTags->"Index"],
    Cell[490497, 21714, 197, 8, 43, "Usage",
      CellTags->"Index"],
    Cell[490697, 21724, 235, 11, 33, "Notes",
      CellTags->"Index"]},
  "Kary"->{
    Cell[490969, 21740, 46, 1, 42, "ObjectName",
      CellTags->"Kary"],
    Cell[491018, 21743, 53, 1, 74, "Highlight",
      CellTags->"Kary"],
    Cell[491074, 21746, 256, 9, 43, "Usage",
      CellTags->"Kary"],
    Cell[491333, 21757, 160, 7, 33, "Notes",
      CellTags->"Kary"]},
  "LabelGrid"->{
    Cell[491530, 21769, 56, 1, 42, "ObjectName",
      CellTags->"LabelGrid"],
    Cell[491589, 21772, 58, 1, 74, "Highlight",
      CellTags->"LabelGrid"],
    Cell[491650, 21775, 224, 7, 64, "Usage",
      CellTags->"LabelGrid"],
    Cell[491877, 21784, 157, 7, 33, "Notes",
      CellTags->"LabelGrid"]},
  "LabelPoints"->{
    Cell[492071, 21796, 60, 1, 42, "ObjectName",
      CellTags->"LabelPoints"],
    Cell[492134, 21799, 60, 1, 74, "Highlight",
      CellTags->"LabelPoints"],
    Cell[492197, 21802, 186, 5, 43, "Usage",
      CellTags->"LabelPoints"],
    Cell[492386, 21809, 182, 7, 33, "Notes",
      CellTags->"LabelPoints"],
    Cell[492571, 21818, 159, 7, 33, "Notes",
      CellTags->"LabelPoints"]},
  "LineStyle"->{
    Cell[492767, 21830, 56, 1, 42, "ObjectName",
      CellTags->"LineStyle"],
    Cell[492826, 21833, 58, 1, 74, "Highlight",
      CellTags->"LineStyle"],
    Cell[492887, 21836, 207, 6, 43, "Usage",
      CellTags->"LineStyle"],
    Cell[493097, 21844, 134, 5, 33, "Notes",
      CellTags->"LineStyle"],
    Cell[493234, 21851, 159, 7, 33, "Notes",
      CellTags->"LineStyle"]},
  "Matrix"->{
    Cell[493430, 21863, 50, 1, 42, "ObjectName",
      CellTags->"Matrix"],
    Cell[493483, 21866, 55, 1, 74, "Highlight",
      CellTags->"Matrix"],
    Cell[493541, 21869, 199, 8, 43, "Usage",
      CellTags->"Matrix"],
    Cell[493743, 21879, 157, 7, 33, "Notes",
      CellTags->"Matrix"]},
  "MultiCol"->{
    Cell[493937, 21891, 54, 1, 42, "ObjectName",
      CellTags->"MultiCol"],
    Cell[493994, 21894, 57, 1, 74, "Highlight",
      CellTags->"MultiCol"],
    Cell[494054, 21897, 145, 6, 43, "Usage",
      CellTags->"MultiCol"],
    Cell[494202, 21905, 156, 7, 33, "Notes",
      CellTags->"MultiCol"]},
  "NonTrivial"->{
    Cell[494395, 21917, 58, 1, 42, "ObjectName",
      CellTags->"NonTrivial"],
    Cell[494456, 21920, 59, 1, 74, "Highlight",
      CellTags->"NonTrivial"],
    Cell[494518, 21923, 175, 6, 43, "Usage",
      CellTags->"NonTrivial"],
    Cell[494696, 21931, 170, 4, 54, "Notes",
      CellTags->"NonTrivial"],
    Cell[494869, 21937, 192, 7, 33, "Notes",
      CellTags->"NonTrivial"]},
  "NoRest"->{
    Cell[495098, 21949, 50, 1, 42, "ObjectName",
      CellTags->"NoRest"],
    Cell[495151, 21952, 55, 1, 74, "Highlight",
      CellTags->"NoRest"],
    Cell[495209, 21955, 141, 6, 43, "Usage",
      CellTags->"NoRest"],
    Cell[495353, 21963, 154, 7, 33, "Notes",
      CellTags->"NoRest"]},
  "Normalize"->{
    Cell[495544, 21975, 56, 1, 42, "ObjectName",
      CellTags->"Normalize"],
    Cell[495603, 21978, 58, 1, 74, "Highlight",
      CellTags->"Normalize"],
    Cell[495664, 21981, 137, 4, 43, "Usage",
      CellTags->"Normalize"],
    Cell[495804, 21987, 260, 9, 33, "Notes",
      CellTags->"Normalize"],
    Cell[496067, 21998, 636, 22, 96, "Notes",
      CellTags->"Normalize"],
    Cell[496706, 22022, 268, 11, 33, "Notes",
      CellTags->"Normalize"]},
  "NRows"->{
    Cell[497011, 22038, 48, 1, 42, "ObjectName",
      CellTags->"NRows"],
    Cell[497062, 22041, 54, 1, 74, "Highlight",
      CellTags->"NRows"],
    Cell[497119, 22044, 139, 6, 43, "Usage",
      CellTags->"NRows"],
    Cell[497261, 22052, 153, 7, 33, "Notes",
      CellTags->"NRows"]},
  "Opts"->{
    Cell[497451, 22064, 46, 1, 42, "ObjectName",
      CellTags->"Opts"],
    Cell[497500, 22067, 53, 1, 74, "Highlight",
      CellTags->"Opts"],
    Cell[497556, 22070, 142, 6, 43, "Usage",
      CellTags->"Opts"],
    Cell[497701, 22078, 85, 1, 33, "Notes",
      CellTags->"Opts"],
    Cell[497789, 22081, 160, 7, 33, "Notes",
      CellTags->"Opts"]},
  "OutPairs"->{
    Cell[497986, 22093, 54, 1, 42, "ObjectName",
      CellTags->"OutPairs"],
    Cell[498043, 22096, 57, 1, 74, "Highlight",
      CellTags->"OutPairs"],
    Cell[498103, 22099, 160, 6, 43, "Usage",
      CellTags->"OutPairs"],
    Cell[498266, 22107, 93, 1, 33, "Notes",
      CellTags->"OutPairs"],
    Cell[498362, 22110, 168, 7, 33, "Notes",
      CellTags->"OutPairs"]},
  "Periodic"->{
    Cell[498567, 22122, 54, 1, 42, "ObjectName",
      CellTags->"Periodic"],
    Cell[498624, 22125, 57, 1, 74, "Highlight",
      CellTags->"Periodic"],
    Cell[498684, 22128, 202, 6, 43, "Usage",
      CellTags->"Periodic"],
    Cell[498889, 22136, 112, 5, 33, "Notes",
      CellTags->"Periodic"],
    Cell[499004, 22143, 160, 7, 33, "Notes",
      CellTags->"Periodic"]},
  "RasterStyle"->{
    Cell[499201, 22155, 60, 1, 42, "ObjectName",
      CellTags->"RasterStyle"],
    Cell[499264, 22158, 60, 1, 74, "Highlight",
      CellTags->"RasterStyle"],
    Cell[499327, 22161, 203, 6, 43, "Usage",
      CellTags->"RasterStyle"],
    Cell[499533, 22169, 214, 9, 33, "Notes",
      CellTags->"RasterStyle"],
    Cell[499750, 22180, 270, 11, 33, "Notes",
      CellTags->"RasterStyle"]},
  "Reflexive"->{
    Cell[500057, 22196, 56, 1, 42, "ObjectName",
      CellTags->"Reflexive"],
    Cell[500116, 22199, 58, 1, 74, "Highlight",
      CellTags->"Reflexive"],
    Cell[500177, 22202, 156, 5, 43, "Usage",
      CellTags->"Reflexive"],
    Cell[500336, 22209, 110, 5, 33, "Notes",
      CellTags->"Reflexive"],
    Cell[500449, 22216, 176, 7, 33, "Notes",
      CellTags->"Reflexive"]},
  "RegularOnly"->{
    Cell[500662, 22228, 60, 1, 42, "ObjectName",
      CellTags->"RegularOnly"],
    Cell[500725, 22231, 60, 1, 74, "Highlight",
      CellTags->"RegularOnly"],
    Cell[500788, 22234, 169, 6, 43, "Usage",
      CellTags->"RegularOnly"],
    Cell[500960, 22242, 189, 6, 33, "Notes",
      CellTags->"RegularOnly"],
    Cell[501152, 22250, 186, 5, 54, "Notes",
      CellTags->"RegularOnly"],
    Cell[501341, 22257, 256, 11, 33, "Notes",
      CellTags->"RegularOnly"]},
  "Relation"->{
    Cell[501634, 22273, 54, 1, 42, "ObjectName",
      CellTags->"Relation"],
    Cell[501691, 22276, 57, 1, 74, "Highlight",
      CellTags->"Relation"],
    Cell[501751, 22279, 203, 8, 43, "Usage",
      CellTags->"Relation"],
    Cell[501957, 22289, 154, 7, 33, "Notes",
      CellTags->"Relation"]},
  "RView"->{
    Cell[502148, 22301, 48, 1, 42, "ObjectName",
      CellTags->"RView"],
    Cell[502199, 22304, 54, 1, 74, "Highlight",
      CellTags->"RView"],
    Cell[502256, 22307, 111, 4, 43, "Usage",
      CellTags->"RView"],
    Cell[502370, 22313, 153, 7, 33, "Notes",
      CellTags->"RView"]},
  "SetClosure"->{
    Cell[502560, 22325, 58, 1, 42, "ObjectName",
      CellTags->"SetClosure"],
    Cell[502621, 22328, 59, 1, 74, "Highlight",
      CellTags->"SetClosure"],
    Cell[502683, 22331, 245, 8, 64, "Usage",
      CellTags->"SetClosure"],
    Cell[502931, 22341, 254, 11, 33, "Notes",
      CellTags->"SetClosure"]},
  "Type"->{
    Cell[503222, 22357, 46, 1, 42, "ObjectName",
      CellTags->"Type"],
    Cell[503271, 22360, 53, 1, 74, "Highlight",
      CellTags->"Type"],
    Cell[503327, 22363, 137, 6, 43, "Usage",
      CellTags->"Type"],
    Cell[503467, 22371, 230, 11, 33, "Notes",
      CellTags->"Type"],
    Cell[503700, 22384, 150, 7, 33, "Notes",
      CellTags->"Type"]},
  "Where"->{
    Cell[503887, 22396, 48, 1, 42, "ObjectName",
      CellTags->"Where"],
    Cell[503938, 22399, 54, 1, 74, "Highlight",
      CellTags->"Where"],
    Cell[503995, 22402, 307, 10, 43, "Usage",
      CellTags->"Where"],
    Cell[504305, 22414, 197, 9, 33, "Notes",
      CellTags->"Where"],
    Cell[504505, 22425, 140, 7, 33, "Notes",
      CellTags->"Where"],
    Cell[504670, 22436, 63, 1, 59, "ExampleSection",
      CellTags->"Where"],
    Cell[504736, 22439, 123, 4, 70, "ExampleText",
      CellTags->"Where"],
    Cell[504884, 22447, 90, 2, 70, "Input",
      CellTags->"Where"],
    Cell[504977, 22451, 110, 3, 70, "Output",
      CellTags->"Where"],
    Cell[505124, 22459, 102, 2, 70, "Input",
      CellTags->"Where"],
    Cell[505229, 22463, 110, 3, 70, "Output",
      CellTags->"Where"],
    Cell[505376, 22471, 103, 2, 70, "Input",
      CellTags->"Where"],
    Cell[505482, 22475, 110, 3, 70, "Output",
      CellTags->"Where"]},
  "Witnesses"->{
    Cell[505653, 22485, 56, 1, 42, "ObjectName",
      CellTags->"Witnesses"],
    Cell[505712, 22488, 60, 1, 74, "Highlight",
      CellTags->"Witnesses"],
    Cell[505775, 22491, 235, 7, 64, "Usage",
      CellTags->"Witnesses"],
    Cell[506013, 22500, 249, 11, 33, "Notes",
      CellTags->"Witnesses"],
    Cell[506287, 22515, 67, 1, 59, "ExampleSection",
      CellTags->"Witnesses"],
    Cell[506357, 22518, 219, 7, 70, "ExampleText",
      CellTags->"Witnesses"]},
  "DC"->{
    Cell[507212, 22557, 42, 1, 42, "ObjectName",
      CellTags->"DC"],
    Cell[507257, 22560, 51, 1, 74, "Highlight",
      CellTags->"DC"],
    Cell[507311, 22563, 151, 4, 43, "Usage",
      CellTags->"DC"],
    Cell[507465, 22569, 216, 8, 33, "Notes",
      CellTags->"DC"],
    Cell[507684, 22579, 517, 23, 33, "Notes",
      CellTags->"DC"],
    Cell[508226, 22606, 60, 1, 59, "ExampleSection",
      CellTags->"DC"]},
  "GEN"->{
    Cell[509071, 22640, 44, 1, 42, "ObjectName",
      CellTags->"GEN"],
    Cell[509118, 22643, 52, 1, 74, "Highlight",
      CellTags->"GEN"],
    Cell[509173, 22646, 190, 6, 43, "Usage",
      CellTags->"GEN"],
    Cell[509366, 22654, 251, 11, 33, "Notes",
      CellTags->"GEN"],
    Cell[509620, 22667, 309, 15, 33, "Notes",
      CellTags->"GEN"]},
  "Graph"->{
    Cell[509966, 22687, 48, 1, 42, "ObjectName",
      CellTags->"Graph"],
    Cell[510017, 22690, 54, 1, 74, "Highlight",
      CellTags->"Graph"],
    Cell[510074, 22693, 297, 10, 64, "Usage",
      CellTags->"Graph"],
    Cell[510374, 22705, 414, 17, 54, "Notes",
      CellTags->"Graph"],
    Cell[511143, 22737, 602, 23, 54, "Notes",
      CellTags->"Graph"],
    Cell[511770, 22764, 63, 1, 59, "ExampleSection",
      CellTags->"Graph"],
    Cell[511836, 22767, 96, 1, 70, "ExampleText",
      CellTags->"Graph"],
    Cell[511935, 22770, 137, 3, 70, "Input",
      CellTags->"Graph"],
    Cell[512380, 22791, 123, 4, 70, "ExampleText",
      CellTags->"Graph"],
    Cell[513268, 22831, 70, 1, 70, "ExampleText",
      CellTags->"Graph"]},
  "SG"->{
    Cell[513791, 22860, 42, 1, 42, "ObjectName",
      CellTags->"SG"],
    Cell[513836, 22863, 51, 1, 74, "Highlight",
      CellTags->"SG"],
    Cell[513890, 22866, 124, 4, 43, "Usage",
      CellTags->"SG"],
    Cell[514017, 22872, 275, 9, 33, "Notes",
      CellTags->"SG"],
    Cell[514295, 22883, 513, 20, 33, "Notes",
      CellTags->"SG"],
    Cell[514833, 22907, 60, 1, 59, "ExampleSection",
      CellTags->"SG"],
    Cell[514896, 22910, 112, 4, 70, "ExampleText",
      CellTags->"SG"],
    Cell[515033, 22918, 95, 3, 70, "Input",
      CellTags->"SG"]},
  "T"->{
    Cell[515332, 22933, 40, 1, 42, "ObjectName",
      CellTags->"T"],
    Cell[515375, 22936, 50, 1, 74, "Highlight",
      CellTags->"T"],
    Cell[515428, 22939, 134, 4, 43, "Usage",
      CellTags->"T"],
    Cell[515565, 22945, 182, 7, 33, "Notes",
      CellTags->"T"],
    Cell[516018, 22966, 506, 23, 33, "Notes",
      CellTags->"T"],
    Cell[516549, 22993, 59, 1, 59, "ExampleSection",
      CellTags->"T"],
    Cell[516611, 22996, 80, 1, 70, "ExampleText",
      CellTags->"T"],
    Cell[516716, 23001, 97, 5, 70, "Input",
      CellTags->"T"]},
  "closureBound"->{
    Cell[517305, 23037, 63, 1, 42, "ObjectName",
      CellTags->"closureBound"],
    Cell[517371, 23040, 61, 1, 74, "Highlight",
      CellTags->"closureBound"],
    Cell[517435, 23043, 180, 5, 43, "Usage",
      CellTags->"closureBound"],
    Cell[517618, 23050, 103, 1, 33, "Notes",
      CellTags->"closureBound"],
    Cell[517724, 23053, 154, 7, 33, "Notes",
      CellTags->"closureBound"]},
  "closureSearchBound"->{
    Cell[517915, 23065, 75, 1, 42, "ObjectName",
      CellTags->"closureSearchBound"],
    Cell[517993, 23068, 67, 1, 74, "Highlight",
      CellTags->"closureSearchBound"],
    Cell[518063, 23071, 177, 6, 43, "Usage",
      CellTags->"closureSearchBound"],
    Cell[518243, 23079, 125, 4, 33, "Notes",
      CellTags->"closureSearchBound"],
    Cell[518371, 23085, 172, 7, 33, "Notes",
      CellTags->"closureSearchBound"]},
  "deffatline"->{
    Cell[519806, 23153, 59, 1, 42, "ObjectName",
      CellTags->"deffatline"],
    Cell[519868, 23156, 59, 1, 74, "Highlight",
      CellTags->"deffatline"],
    Cell[519930, 23159, 178, 6, 43, "Usage",
      CellTags->"deffatline"],
    Cell[520111, 23167, 148, 5, 33, "Notes",
      CellTags->"deffatline"],
    Cell[520262, 23174, 165, 7, 33, "Notes",
      CellTags->"deffatline"]},
  "deflabeloffset"->{
    Cell[520464, 23186, 67, 1, 42, "ObjectName",
      CellTags->"deflabeloffset"],
    Cell[520534, 23189, 63, 1, 74, "Highlight",
      CellTags->"deflabeloffset"],
    Cell[520600, 23192, 178, 6, 43, "Usage",
      CellTags->"deflabeloffset"],
    Cell[520781, 23200, 68, 1, 33, "Notes",
      CellTags->"deflabeloffset"],
    Cell[520852, 23203, 265, 11, 33, "Notes",
      CellTags->"deflabeloffset"]},
  "defpointsize"->{
    Cell[521154, 23219, 63, 1, 42, "ObjectName",
      CellTags->"defpointsize"],
    Cell[521220, 23222, 61, 1, 74, "Highlight",
      CellTags->"defpointsize"],
    Cell[521284, 23225, 173, 6, 43, "Usage",
      CellTags->"defpointsize"],
    Cell[521460, 23233, 150, 5, 33, "Notes",
      CellTags->"defpointsize"],
    Cell[521613, 23240, 263, 11, 33, "Notes",
      CellTags->"defpointsize"],
    Cell[521901, 23255, 70, 1, 59, "ExampleSection",
      CellTags->"defpointsize"],
    Cell[521974, 23258, 132, 5, 70, "ExampleText",
      CellTags->"defpointsize"],
    Cell[522131, 23267, 95, 2, 70, "Input",
      CellTags->"defpointsize"],
    Cell[522229, 23271, 1091, 60, 70, 910, 54, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"defpointsize"],
    Cell[523357, 23336, 149, 4, 70, "Input",
      CellTags->"defpointsize"],
    Cell[523509, 23342, 1090, 60, 70, 909, 54, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"defpointsize"]},
  "defthinline"->{
    Cell[524660, 23409, 61, 1, 42, "ObjectName",
      CellTags->"defthinline"],
    Cell[524724, 23412, 60, 1, 74, "Highlight",
      CellTags->"defthinline"],
    Cell[524787, 23415, 173, 6, 43, "Usage",
      CellTags->"defthinline"],
    Cell[524963, 23423, 149, 5, 33, "Notes",
      CellTags->"defthinline"],
    Cell[525115, 23430, 258, 11, 33, "Notes",
      CellTags->"defthinline"],
    Cell[525398, 23445, 69, 1, 59, "ExampleSection",
      CellTags->"defthinline"],
    Cell[525470, 23448, 133, 5, 70, "ExampleText",
      CellTags->"defthinline"],
    Cell[525628, 23457, 92, 2, 70, "Input",
      CellTags->"defthinline"],
    Cell[526806, 23534, 128, 5, 70, "Input",
      CellTags->"defthinline"],
    Cell[527997, 23612, 128, 5, 70, "Input",
      CellTags->"defthinline"]},
  "dimathReleaseNumber"->{
    Cell[528174, 23623, 77, 1, 42, "ObjectName",
      CellTags->"dimathReleaseNumber"],
    Cell[528254, 23626, 68, 1, 74, "Highlight",
      CellTags->"dimathReleaseNumber"],
    Cell[528325, 23629, 164, 4, 43, "Usage",
      CellTags->"dimathReleaseNumber"]},
  "generateSGBound"->{
    Cell[528526, 23638, 69, 1, 42, "ObjectName",
      CellTags->"generateSGBound"],
    Cell[528598, 23641, 64, 1, 74, "Highlight",
      CellTags->"generateSGBound"],
    Cell[528665, 23644, 204, 6, 43, "Usage",
      CellTags->"generateSGBound"],
    Cell[528872, 23652, 64, 1, 33, "Notes",
      CellTags->"generateSGBound"],
    Cell[528939, 23655, 163, 7, 33, "Notes",
      CellTags->"generateSGBound"]},
  "identitystring"->{
    Cell[529139, 23667, 67, 1, 42, "ObjectName",
      CellTags->"identitystring"],
    Cell[529209, 23670, 63, 1, 74, "Highlight",
      CellTags->"identitystring"],
    Cell[529275, 23673, 214, 7, 64, "Usage",
      CellTags->"identitystring"],
    Cell[529492, 23682, 121, 4, 33, "Notes",
      CellTags->"identitystring"],
    Cell[529616, 23688, 270, 11, 33, "Notes",
      CellTags->"identitystring"]},
  "nullstring"->{
    Cell[529923, 23704, 59, 1, 42, "ObjectName",
      CellTags->"nullstring"],
    Cell[529985, 23707, 59, 1, 74, "Highlight",
      CellTags->"nullstring"],
    Cell[530047, 23710, 204, 6, 43, "Usage",
      CellTags->"nullstring"],
    Cell[530254, 23718, 116, 4, 33, "Notes",
      CellTags->"nullstring"],
    Cell[530373, 23724, 268, 11, 33, "Notes",
      CellTags->"nullstring"]},
  "plotrangeoffset"->{
    Cell[530678, 23740, 69, 1, 42, "ObjectName",
      CellTags->"plotrangeoffset"],
    Cell[530750, 23743, 64, 1, 74, "Highlight",
      CellTags->"plotrangeoffset"],
    Cell[530817, 23746, 172, 6, 43, "Usage",
      CellTags->"plotrangeoffset"],
    Cell[530992, 23754, 69, 1, 33, "Notes",
      CellTags->"plotrangeoffset"],
    Cell[531064, 23757, 169, 7, 33, "Notes",
      CellTags->"plotrangeoffset"]},
  "rastercolors"->{
    Cell[531270, 23769, 63, 1, 42, "ObjectName",
      CellTags->"rastercolors"],
    Cell[531336, 23772, 61, 1, 74, "Highlight",
      CellTags->"rastercolors"],
    Cell[531400, 23775, 172, 5, 43, "Usage",
      CellTags->"rastercolors"],
    Cell[531575, 23782, 103, 1, 33, "Notes",
      CellTags->"rastercolors"],
    Cell[531681, 23785, 370, 15, 33, "Notes",
      CellTags->"rastercolors"]},
  "rewriteSimpBound"->{
    Cell[532088, 23805, 71, 1, 42, "ObjectName",
      CellTags->"rewriteSimpBound"],
    Cell[532162, 23808, 65, 1, 74, "Highlight",
      CellTags->"rewriteSimpBound"],
    Cell[532230, 23811, 224, 5, 64, "Usage",
      CellTags->"rewriteSimpBound"],
    Cell[532457, 23818, 70, 1, 33, "Notes",
      CellTags->"rewriteSimpBound"],
    Cell[532530, 23821, 186, 7, 33, "Notes",
      CellTags->"rewriteSimpBound"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"AccCoaccGraph", 533406, 23849},
  {"AccessibleGraph", 534580, 23880},
  {"AlgebraicForm", 535873, 23913},
  {"AllStringReplace", 536206, 23922},
  {"AllTimes", 537345, 23951},
  {"AlternatingGroupSG", 538326, 23978},
  {"AnalyzeOrbit", 539096, 23997},
  {"AperiodicQSG", 540871, 24044},
  {"AperiodicQT", 541894, 24071},
  {"AperiodicSG", 542903, 24098},
  {"AssignFunction", 543770, 24121},
  {"BlocksToDClass", 545538, 24166},
  {"BooleanComplement", 546680, 24195},
  {"BooleanComposition", 547700, 24220},
  {"BooleanConverse", 548905, 24249},
  {"BooleanIntersection", 549907, 24274},
  {"BooleanPower", 551035, 24301},
  {"BooleanUnion", 551999, 24326},
  {"CartesianProduct", 553040, 24353},
  {"CirculantGraph", 554444, 24388},
  {"ClosureSearch", 555823, 24423},
  {"Closure", 557333, 24462},
  {"CollapseT", 558882, 24505},
  {"ColorQ", 560013, 24536},
  {"CompCycles", 560389, 24547},
  {"Concatenate", 561470, 24576},
  {"ConsT", 562857, 24613},
  {"Curry", 563513, 24632},
  {"CycleDecompositionT", 564182, 24651},
  {"CycleToT", 565302, 24678},
  {"CyclicQGraph", 566506, 24711},
  {"DClassDecomposition", 567618, 24740},
  {"DClassDimensions", 569337, 24781},
  {"DClassSize", 570258, 24804},
  {"DClassToBlocks", 571115, 24827},
  {"DClassT", 572258, 24856},
  {"DegreeGraph", 573604, 24893},
  {"Dependency", 574861, 24926},
  {"DisjointQ", 575876, 24953},
  {"DoShow", 576649, 24974},
  {"Drei", 577474, 24997},
  {"EdgeQ", 577841, 25008},
  {"Edges", 578212, 25019},
  {"EnumForm", 578587, 25030},
  {"EquationsToWitnesses", 579813, 25063},
  {"FastPowerSet", 581659, 25106},
  {"FlattenOne", 582779, 25135},
  {"Frequencies", 583645, 25158},
  {"FromBitVector", 584374, 25177},
  {"FromEps", 585269, 25200},
  {"FromIdentityString", 586117, 25223},
  {"GenerateCSM", 587242, 25250},
  {"GenerateSG", 588738, 25289},
  {"GreenHQT", 591957, 25374},
  {"GreenJQT", 592275, 25383},
  {"GreenLQT", 592593, 25392},
  {"GreenRQT", 592911, 25401},
  {"GridLine", 593229, 25410},
  {"GridPoints", 594455, 25443},
  {"HClassSize", 595638, 25474},
  {"HClassT", 596037, 25485},
  {"HTrivialQSG", 596423, 25496},
  {"HueRasterColors", 596759, 25505},
  {"IdealT", 597677, 25528},
  {"IdemQT", 598567, 25553},
  {"IdemSG", 599242, 25572},
  {"ImageT", 599987, 25593},
  {"IndToWitnesses", 600673, 25612},
  {"InGroupQT", 601344, 25629},
  {"InGroupSG", 602050, 25648},
  {"InverseT", 603052, 25675},
  {"IrreducibleQ", 603753, 25694},
  {"JTrivialQSG", 604641, 25717},
  {"JTrivialSG", 605123, 25730},
  {"KernelImageToT", 606142, 25757},
  {"KernelT", 607289, 25786},
  {"KPermutationsR", 608056, 25807},
  {"LabelEdgeList", 609047, 25832},
  {"LeftIdealT", 609945, 25855},
  {"LeftNullQT", 610886, 25880},
  {"LeftNullSG", 611286, 25891},
  {"LeftOneQT", 612073, 25912},
  {"LeftOneSG", 612394, 25921},
  {"LocallyCommQSG", 613176, 25942},
  {"LocallyIdemQSG", 613602, 25953},
  {"LongestPath", 614025, 25964},
  {"LShiftT", 615284, 25997},
  {"MakeAlphabet", 615601, 26006},
  {"MakeFullAlphabet", 616419, 26027},
  {"MakeIndex", 617271, 26048},
  {"MakeMonoidSG", 618127, 26071},
  {"MakePlotRange", 618863, 26090},
  {"Merge12T", 619198, 26099},
  {"MinusEins", 619589, 26110},
  {"MinusZwei", 619990, 26121},
  {"MonoidQSG", 620391, 26132},
  {"NilpotentQSG", 620720, 26141},
  {"NonDecreasing", 621062, 26150},
  {"NonTransientGraph", 621743, 26167},
  {"NormalizeGraph", 622957, 26196},
  {"NullQT", 624117, 26225},
  {"NullSG", 624427, 26234},
  {"NumEdges", 625188, 26255},
  {"NumVertices", 625512, 26264},
  {"OneQT", 625842, 26273},
  {"OneSG", 626517, 26292},
  {"OneT", 627763, 26327},
  {"OrderT", 628568, 26350},
  {"PairsToRules", 629333, 26371},
  {"Pairs", 630074, 26390},
  {"PartitionCumRest", 631395, 26427},
  {"Partitions", 631750, 26436},
  {"PathGraph", 632474, 26455},
  {"PermuteGraph", 633801, 26490},
  {"PlotFunction", 634702, 26513},
  {"PlotMatrix", 635528, 26534},
  {"PlotRelation", 637020, 26573},
  {"PlotTDGraph", 637926, 26596},
  {"PlotT", 639286, 26631},
  {"PositionList", 640037, 26652},
  {"PositionOne", 640860, 26673},
  {"PowerSet", 641191, 26682},
  {"PrintDClass", 642120, 26707},
  {"PrintEquations", 650710, 26930},
  {"PrintWitnesses", 651884, 26959},
  {"ProductGraph", 652650, 26978},
  {"ProductLabeledGraph", 654266, 27019},
  {"RandomPermutation", 655596, 27050},
  {"RandomT", 656297, 27067},
  {"RankT", 656987, 27086},
  {"RegularQT", 657739, 27107},
  {"RegularSG", 658064, 27116},
  {"RelationToMatrix", 659008, 27141},
  {"RemoveDuplicates", 659874, 27162},
  {"RemoveVertex", 661230, 27195},
  {"RenumberRules", 662368, 27224},
  {"ReplaceParts", 663676, 27257},
  {"ReverseGraph", 664015, 27266},
  {"RightIdealT", 665073, 27293},
  {"RightNullQT", 666040, 27318},
  {"RightNullSG", 666376, 27327},
  {"RightOneQT", 667186, 27348},
  {"RightOneSG", 667517, 27357},
  {"RootList", 668313, 27378},
  {"RShiftT", 669165, 27401},
  {"RulesToPairs", 669486, 27410},
  {"SeedConfiguration", 670237, 27429},
  {"SelectOptions", 671361, 27456},
  {"SelectorQ", 671702, 27465},
  {"ShortestPath", 672644, 27490},
  {"ShowArray", 673860, 27521},
  {"Shuffle", 674496, 27538},
  {"SimplifyEquations", 675128, 27555},
  {"SimplifyRewriteSystem", 675927, 27574},
  {"SolveSG", 676747, 27593},
  {"StaircasePlot", 677671, 27618},
  {"Status", 678419, 27637},
  {"StronglyConnectedComponents", 678906, 27650},
  {"SubGraph", 680249, 27679},
  {"SubsetQ", 680952, 27698},
  {"SymbolList", 681646, 27717},
  {"SymmetricGroupSG", 682224, 27732},
  {"TableSG", 682916, 27749},
  {"ToAdjList", 683539, 27766},
  {"ToAdjMatrix", 684483, 27791},
  {"ToBitVector", 685139, 27808},
  {"ToClasses", 686024, 27831},
  {"ToDAG", 686976, 27856},
  {"ToEdgeList", 687437, 27869},
  {"ToEps", 687929, 27882},
  {"ToIdentityString", 688394, 27895},
  {"ToList", 689004, 27910},
  {"ToTDGraph", 689245, 27917},
  {"TransformationSG", 689890, 27934},
  {"TransientPeriodicT", 690594, 27951},
  {"TransitiveClosure", 691313, 27968},
  {"TranspositionT", 692523, 27997},
  {"TypeGraph", 692950, 28008},
  {"UnitElement", 694041, 28037},
  {"VertexSet", 694770, 28056},
  {"Vier", 695405, 28073},
  {"Warshall", 695780, 28084},
  {"WeaklyConnectedComponents", 696502, 28103},
  {"WordQ", 697265, 28120},
  {"WordReduce", 697873, 28137},
  {"Zwei", 698824, 28162},
  {"All", 699193, 28173},
  {"Boolean", 699785, 28190},
  {"BoundCSM", 700921, 28221},
  {"BoundETW", 701313, 28232},
  {"BoundGSG", 701706, 28243},
  {"BoundWR", 702099, 28254},
  {"ClosureBound", 702491, 28265},
  {"Cols", 702824, 28274},
  {"Cycle", 703125, 28283},
  {"DClasses", 703433, 28292},
  {"DoTrace", 703827, 28303},
  {"Eps", 704139, 28312},
  {"Equations", 704648, 28327},
  {"External", 704973, 28336},
  {"defaultexternal", 705448, 28349},
  {"Filter", 706040, 28364},
  {"Full", 706649, 28381},
  {"GridOffset", 706957, 28390},
  {"Index", 707434, 28403},
  {"Kary", 707739, 28412},
  {"LabelGrid", 708044, 28421},
  {"LabelPoints", 708371, 28430},
  {"LineStyle", 708781, 28441},
  {"Matrix", 709178, 28452},
  {"MultiCol", 709490, 28461},
  {"NonTrivial", 709812, 28470},
  {"NoRest", 710214, 28481},
  {"Normalize", 710527, 28490},
  {"NRows", 711000, 28503},
  {"Opts", 711304, 28512},
  {"OutPairs", 711677, 28523},
  {"Periodic", 712070, 28534},
  {"RasterStyle", 712467, 28545},
  {"Reflexive", 712878, 28556},
  {"RegularOnly", 713280, 28567},
  {"Relation", 713767, 28580},
  {"RView", 714084, 28589},
  {"SetClosure", 714394, 28598},
  {"Type", 714719, 28607},
  {"Where", 715091, 28618},
  {"Witnesses", 716056, 28645},
  {"DC", 716539, 28658},
  {"GEN", 716975, 28671},
  {"Graph", 717343, 28682},
  {"SG", 718098, 28703},
  {"T", 718673, 28720},
  {"closureBound", 719250, 28737},
  {"closureSearchBound", 719674, 28748},
  {"deffatline", 720120, 28759},
  {"deflabeloffset", 720530, 28770},
  {"defpointsize", 720958, 28781},
  {"defthinline", 722015, 28808},
  {"dimathReleaseNumber", 722834, 28829},
  {"generateSGBound", 723120, 28836},
  {"identitystring", 723554, 28847},
  {"nullstring", 723981, 28858},
  {"plotrangeoffset", 724393, 28869},
  {"rastercolors", 724825, 28880},
  {"rewriteSimpBound", 725248, 28891}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 42, "ObjectName",
  CellTags->"AccCoaccGraph"],
Cell[1843, 56, 64, 1, 74, "Highlight",
  CellTags->"AccCoaccGraph"],
Cell[1910, 59, 283, 10, 64, "Usage",
  CellTags->"AccCoaccGraph"],
Cell[2196, 71, 123, 4, 33, "Notes",
  CellTags->"AccCoaccGraph"],
Cell[2322, 77, 181, 6, 33, "Notes",
  CellTags->"AccCoaccGraph"],
Cell[2506, 85, 476, 20, 33, "Notes",
  CellTags->"AccCoaccGraph"],

Cell[CellGroupData[{
Cell[3007, 109, 71, 1, 59, "ExampleSection",
  CellTags->"AccCoaccGraph"],
Cell[3081, 112, 148, 4, 70, "ExampleText",
  CellTags->"AccCoaccGraph"],
Cell[3232, 118, 208, 6, 70, "Input",
  CellTags->"AccCoaccGraph"],

Cell[CellGroupData[{
Cell[3465, 128, 96, 2, 70, "Input",
  CellTags->"AccCoaccGraph"],
Cell[3564, 132, 330, 10, 70, "Output",
  CellTags->"AccCoaccGraph"]
}, Open  ]],
Cell[3909, 145, 137, 4, 70, "ExampleText",
  CellTags->"AccCoaccGraph"],

Cell[CellGroupData[{
Cell[4071, 153, 117, 5, 70, "Input",
  CellTags->"AccCoaccGraph"],
Cell[4191, 160, 262, 8, 70, "Output",
  CellTags->"AccCoaccGraph"],
Cell[4456, 170, 98, 3, 70, "Output",
  CellTags->"AccCoaccGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4615, 180, 68, 1, 42, "ObjectName",
  CellTags->"AccessibleGraph"],
Cell[4686, 183, 66, 1, 74, "Highlight",
  CellTags->"AccessibleGraph"],
Cell[4755, 186, 330, 11, 64, "Usage",
  CellTags->"AccessibleGraph"],
Cell[5088, 199, 137, 4, 33, "Notes",
  CellTags->"AccessibleGraph"],
Cell[5228, 205, 450, 19, 33, "Notes",
  CellTags->"AccessibleGraph"],

Cell[CellGroupData[{
Cell[5703, 228, 73, 1, 59, "ExampleSection",
  CellTags->"AccessibleGraph"],
Cell[5779, 231, 73, 1, 70, "ExampleText",
  CellTags->"AccessibleGraph"],

Cell[CellGroupData[{
Cell[5877, 236, 103, 2, 70, "Input",
  CellTags->"AccessibleGraph"],
Cell[5983, 240, 459, 11, 70, "Output",
  CellTags->"AccessibleGraph"]
}, Open  ]],
Cell[6457, 254, 104, 1, 70, "ExampleText",
  CellTags->"AccessibleGraph"],

Cell[CellGroupData[{
Cell[6586, 259, 115, 5, 70, "Input",
  CellTags->"AccessibleGraph"],
Cell[6704, 266, 357, 10, 70, "Output",
  CellTags->"AccessibleGraph"],
Cell[7064, 278, 106, 3, 70, "Output",
  CellTags->"AccessibleGraph"]
}, Open  ]],
Cell[7185, 284, 92, 1, 70, "ExampleText",
  CellTags->"AccessibleGraph"],

Cell[CellGroupData[{
Cell[7302, 289, 111, 2, 70, "Input",
  CellTags->"AccessibleGraph"],
Cell[7416, 293, 122, 3, 70, "Output",
  CellTags->"AccessibleGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7599, 303, 64, 1, 42, "ObjectName",
  CellTags->"AlgebraicForm"],
Cell[7666, 306, 64, 1, 74, "Highlight",
  CellTags->"AlgebraicForm"],
Cell[7733, 309, 199, 6, 43, "Usage",
  CellTags->"AlgebraicForm"],
Cell[7935, 317, 867, 25, 34, "Notes",
  CellTags->"AlgebraicForm"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8839, 347, 70, 1, 42, "ObjectName",
  CellTags->"AllStringReplace"],
Cell[8912, 350, 69, 1, 74, "Highlight",
  CellTags->"AllStringReplace"],
Cell[8984, 353, 256, 8, 64, "Usage",
  CellTags->"AllStringReplace"],
Cell[9243, 363, 247, 7, 54, "Notes",
  CellTags->"AllStringReplace"],
Cell[9493, 372, 124, 5, 33, "Notes",
  CellTags->"AllStringReplace"],
Cell[9620, 379, 159, 7, 33, "Notes",
  CellTags->"AllStringReplace"],

Cell[CellGroupData[{
Cell[9804, 390, 74, 1, 59, "ExampleSection",
  CellTags->"AllStringReplace"],
Cell[9881, 393, 103, 1, 48, "ExampleText",
  CellTags->"AllStringReplace"],

Cell[CellGroupData[{
Cell[10009, 398, 113, 2, 40, "Input",
  CellTags->"AllStringReplace"],
Cell[10125, 402, 104, 3, 30, "Output",
  CellTags->"AllStringReplace"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10266, 410, 145, 3, 37, "Input",
  CellTags->"AllStringReplace"],
Cell[10414, 415, 103, 3, 30, "Output",
  CellTags->"AllStringReplace"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10554, 423, 138, 3, 37, "Input",
  CellTags->"AllStringReplace"],
Cell[10695, 428, 114, 3, 30, "Output",
  CellTags->"AllStringReplace"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10870, 438, 54, 1, 42, "ObjectName",
  CellTags->"AllTimes"],
Cell[10927, 441, 59, 1, 74, "Highlight",
  CellTags->"AllTimes"],
Cell[10989, 444, 261, 10, 64, "Usage",
  CellTags->"AllTimes"],
Cell[11253, 456, 86, 1, 33, "Notes",
  CellTags->"AllTimes"],
Cell[11342, 459, 319, 15, 33, "Notes",
  CellTags->"AllTimes"],

Cell[CellGroupData[{
Cell[11686, 478, 66, 1, 59, "ExampleSection",
  CellTags->"AllTimes"],
Cell[11755, 481, 107, 2, 48, "ExampleText",
  CellTags->"AllTimes"],

Cell[CellGroupData[{
Cell[11887, 487, 117, 2, 40, "Input",
  CellTags->"AllTimes"],
Cell[12007, 491, 131, 3, 30, "Output",
  CellTags->"AllTimes"]
}, Open  ]],
Cell[12153, 497, 130, 4, 48, "ExampleText",
  CellTags->"AllTimes"],

Cell[CellGroupData[{
Cell[12308, 505, 118, 5, 64, "Input",
  CellTags->"AllTimes"],
Cell[12429, 512, 186, 4, 53, "Output",
  CellTags->"AllTimes"],
Cell[12618, 518, 162, 4, 53, "Output",
  CellTags->"AllTimes"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12841, 529, 74, 1, 42, "ObjectName",
  CellTags->"AlternatingGroupSG"],
Cell[12918, 532, 230, 6, 64, "Usage",
  CellTags->"AlternatingGroupSG"],
Cell[13151, 540, 258, 9, 33, "Notes",
  CellTags->"AlternatingGroupSG"],
Cell[13412, 551, 437, 19, 33, "Notes",
  CellTags->"AlternatingGroupSG"],

Cell[CellGroupData[{
Cell[13874, 574, 76, 1, 59, "ExampleSection",
  CellTags->"AlternatingGroupSG"],
Cell[13953, 577, 94, 1, 48, "ExampleText",
  CellTags->"AlternatingGroupSG"],

Cell[CellGroupData[{
Cell[14072, 582, 128, 5, 64, "Input",
  CellTags->"AlternatingGroupSG"],
Cell[14203, 589, 291, 6, 76, "Output",
  CellTags->"AlternatingGroupSG"],
Cell[14497, 597, 129, 3, 30, "Output",
  CellTags->"AlternatingGroupSG"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14687, 607, 62, 1, 42, "ObjectName",
  CellTags->"AnalyzeOrbit"],
Cell[14752, 610, 63, 1, 74, "Highlight",
  CellTags->"AnalyzeOrbit"],
Cell[14818, 613, 472, 15, 85, "Usage",
  CellTags->"AnalyzeOrbit"],
Cell[15293, 630, 292, 10, 80, "Notes",
  CellTags->"AnalyzeOrbit"],
Cell[15588, 642, 250, 7, 54, "Notes",
  CellTags->"AnalyzeOrbit"],
Cell[15841, 651, 179, 5, 33, "Notes",
  CellTags->"AnalyzeOrbit"],
Cell[16023, 658, 261, 9, 54, "Notes",
  CellTags->"AnalyzeOrbit"],
Cell[16287, 669, 239, 11, 33, "Notes",
  CellTags->"AnalyzeOrbit"],

Cell[CellGroupData[{
Cell[16551, 684, 70, 1, 59, "ExampleSection",
  CellTags->"AnalyzeOrbit"],
Cell[16624, 687, 84, 1, 48, "ExampleText",
  CellTags->"AnalyzeOrbit"],
Cell[16711, 690, 90, 2, 40, "Input",
  CellTags->"AnalyzeOrbit"],

Cell[CellGroupData[{
Cell[16826, 696, 104, 3, 37, "Input",
  CellTags->"AnalyzeOrbit"],
Cell[16933, 701, 93, 3, 30, "Output",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17063, 709, 104, 3, 37, "Input",
  CellTags->"AnalyzeOrbit"],
Cell[17170, 714, 93, 3, 30, "Output",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17300, 722, 124, 3, 37, "Input",
  CellTags->"AnalyzeOrbit"],
Cell[17427, 727, 107, 3, 30, "Output",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17571, 735, 125, 3, 37, "Input",
  CellTags->"AnalyzeOrbit"],
Cell[17699, 740, 96, 3, 30, "Output",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],
Cell[17810, 746, 159, 4, 69, "ExampleText",
  CellTags->"AnalyzeOrbit"],

Cell[CellGroupData[{
Cell[17994, 754, 208, 5, 83, "Input",
  CellTags->"AnalyzeOrbit"],
Cell[18205, 761, 95, 3, 30, "Output",
  CellTags->"AnalyzeOrbit"]
}, Open  ]],
Cell[18315, 767, 163, 4, 37, "Input",
  CellTags->"AnalyzeOrbit"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18527, 777, 62, 1, 42, "ObjectName",
  CellTags->"AperiodicQSG"],
Cell[18592, 780, 63, 1, 74, "Highlight",
  CellTags->"AperiodicQSG"],
Cell[18658, 783, 173, 6, 43, "Usage",
  CellTags->"AperiodicQSG"],
Cell[18834, 791, 149, 5, 33, "Notes",
  CellTags->"AperiodicQSG"],
Cell[18986, 798, 520, 23, 33, "Notes",
  CellTags->"AperiodicQSG"],

Cell[CellGroupData[{
Cell[19531, 825, 70, 1, 59, "ExampleSection",
  CellTags->"AperiodicQSG"],
Cell[19604, 828, 122, 4, 70, "ExampleText",
  CellTags->"AperiodicQSG"],
Cell[19729, 834, 557, 11, 70, "Input",
  CellTags->"AperiodicQSG"],

Cell[CellGroupData[{
Cell[20311, 849, 102, 3, 70, "Input",
  CellTags->"AperiodicQSG"],
Cell[20416, 854, 92, 3, 70, "Output",
  CellTags->"AperiodicQSG"]
}, Open  ]],
Cell[20523, 860, 97, 1, 70, "ExampleText",
  CellTags->"AperiodicQSG"],

Cell[CellGroupData[{
Cell[20645, 865, 108, 2, 70, "Input",
  CellTags->"AperiodicQSG"],
Cell[20756, 869, 93, 3, 70, "Output",
  CellTags->"AperiodicQSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20910, 879, 60, 1, 42, "ObjectName",
  CellTags->"AperiodicQT"],
Cell[20973, 882, 62, 1, 74, "Highlight",
  CellTags->"AperiodicQT"],
Cell[21038, 885, 175, 6, 43, "Usage",
  CellTags->"AperiodicQT"],
Cell[21216, 893, 227, 9, 35, "Notes",
  CellTags->"AperiodicQT"],
Cell[21446, 904, 521, 23, 33, "Notes",
  CellTags->"AperiodicQT"],

Cell[CellGroupData[{
Cell[21992, 931, 69, 1, 59, "ExampleSection",
  CellTags->"AperiodicQT"],
Cell[22064, 934, 85, 1, 48, "ExampleText",
  CellTags->"AperiodicQT"],

Cell[CellGroupData[{
Cell[22174, 939, 129, 4, 60, "Input",
  CellTags->"AperiodicQT"],
Cell[22306, 945, 103, 3, 30, "Output",
  CellTags->"AperiodicQT"],
Cell[22412, 950, 92, 3, 30, "Output",
  CellTags->"AperiodicQT"]
}, Open  ]],
Cell[22519, 956, 98, 1, 48, "ExampleText",
  CellTags->"AperiodicQT"],

Cell[CellGroupData[{
Cell[22642, 961, 118, 3, 37, "Input",
  CellTags->"AperiodicQT"],
Cell[22763, 966, 91, 3, 30, "Output",
  CellTags->"AperiodicQT"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22915, 976, 60, 1, 42, "ObjectName",
  CellTags->"AperiodicSG"],
Cell[22978, 979, 62, 1, 74, "Highlight",
  CellTags->"AperiodicSG"],
Cell[23043, 982, 172, 6, 43, "Usage",
  CellTags->"AperiodicSG"],
Cell[23218, 990, 231, 9, 35, "Notes",
  CellTags->"AperiodicSG"],
Cell[23452, 1001, 521, 23, 33, "Notes",
  CellTags->"AperiodicSG"],

Cell[CellGroupData[{
Cell[23998, 1028, 69, 1, 59, "ExampleSection",
  CellTags->"AperiodicSG"],
Cell[24070, 1031, 140, 4, 48, "ExampleText",
  CellTags->"AperiodicSG"],
Cell[24213, 1037, 118, 3, 37, "Input",
  CellTags->"AperiodicSG"],

Cell[CellGroupData[{
Cell[24356, 1044, 104, 5, 64, "Input",
  CellTags->"AperiodicSG"],
Cell[24463, 1051, 295, 6, 99, "Output",
  CellTags->"AperiodicSG"],
Cell[24761, 1059, 89, 3, 30, "Output",
  CellTags->"AperiodicSG"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24911, 1069, 66, 1, 42, "ObjectName",
  CellTags->"AssignFunction"],
Cell[24980, 1072, 65, 1, 74, "Highlight",
  CellTags->"AssignFunction"],
Cell[25048, 1075, 202, 5, 64, "Usage",
  CellTags->"AssignFunction"],
Cell[25253, 1082, 267, 7, 54, "Notes",
  CellTags->"AssignFunction"],
Cell[25523, 1091, 277, 10, 80, "Notes",
  CellTags->"AssignFunction"],
Cell[25803, 1103, 162, 5, 33, "Notes",
  CellTags->"AssignFunction"],
Cell[25968, 1110, 173, 5, 33, "Notes",
  CellTags->"AssignFunction"],
Cell[26144, 1117, 173, 5, 33, "Notes",
  CellTags->"AssignFunction"],
Cell[26320, 1124, 158, 7, 33, "Notes",
  CellTags->"AssignFunction"],

Cell[CellGroupData[{
Cell[26503, 1135, 72, 1, 59, "ExampleSection",
  CellTags->"AssignFunction"],
Cell[26578, 1138, 93, 1, 48, "ExampleText",
  CellTags->"AssignFunction"],

Cell[CellGroupData[{
Cell[26696, 1143, 122, 5, 64, "Input",
  CellTags->"AssignFunction"],
Cell[26821, 1150, 90, 3, 30, "Output",
  CellTags->"AssignFunction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26948, 1158, 193, 5, 60, "Input",
  CellTags->"AssignFunction"],
Cell[27144, 1165, 99, 3, 30, "Output",
  CellTags->"AssignFunction"]
}, Open  ]],
Cell[27258, 1171, 130, 4, 48, "ExampleText",
  CellTags->"AssignFunction"],

Cell[CellGroupData[{
Cell[27413, 1179, 221, 5, 83, "Input",
  CellTags->"AssignFunction"],
Cell[27637, 1186, 122, 3, 30, "Output",
  CellTags->"AssignFunction"],
Cell[27762, 1191, 102, 3, 30, "Output",
  CellTags->"AssignFunction"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27901, 1199, 93, 3, 37, "Input",
  CellTags->"AssignFunction"],
Cell[27997, 1204, 55, 1, 29, "Print",
  CellTags->"AssignFunction"],
Cell[28055, 1207, 595, 19, 174, "Print",
  CellTags->"AssignFunction"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28711, 1233, 66, 1, 42, "ObjectName",
  CellTags->"BlocksToDClass"],
Cell[28780, 1236, 65, 1, 74, "Highlight",
  CellTags->"BlocksToDClass"],
Cell[28848, 1239, 224, 6, 64, "Usage",
  CellTags->"BlocksToDClass"],
Cell[29075, 1247, 114, 5, 33, "Notes",
  CellTags->"BlocksToDClass"],
Cell[29192, 1254, 382, 10, 56, "Notes",
  CellTags->"BlocksToDClass"],
Cell[29577, 1266, 160, 5, 33, "Notes",
  CellTags->"BlocksToDClass"],
Cell[29740, 1273, 351, 15, 33, "Notes",
  CellTags->"BlocksToDClass"],

Cell[CellGroupData[{
Cell[30116, 1292, 72, 1, 59, "ExampleSection",
  CellTags->"BlocksToDClass"],
Cell[30191, 1295, 171, 4, 70, "ExampleText",
  CellTags->"BlocksToDClass"],
Cell[30365, 1301, 295, 5, 70, "Input",
  CellTags->"BlocksToDClass"],

Cell[CellGroupData[{
Cell[30685, 1310, 102, 3, 70, "Input",
  CellTags->"BlocksToDClass"],
Cell[30790, 1315, 99, 3, 70, "Output",
  CellTags->"BlocksToDClass"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30926, 1323, 106, 3, 70, "Input",
  CellTags->"BlocksToDClass"],
Cell[31035, 1328, 212, 4, 70, "Output",
  CellTags->"BlocksToDClass"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31308, 1339, 72, 1, 42, "ObjectName",
  CellTags->"BooleanComplement"],
Cell[31383, 1342, 68, 1, 74, "Highlight",
  CellTags->"BooleanComplement"],
Cell[31454, 1345, 324, 9, 64, "Usage",
  CellTags->"BooleanComplement"],
Cell[31781, 1356, 155, 4, 33, "Notes",
  CellTags->"BooleanComplement"],
Cell[31939, 1362, 818, 27, 54, "Notes",
  CellTags->"BooleanComplement"],

Cell[CellGroupData[{
Cell[32782, 1393, 75, 1, 59, "ExampleSection",
  CellTags->"BooleanComplement"],
Cell[32860, 1396, 99, 1, 70, "ExampleText",
  CellTags->"BooleanComplement"],
Cell[32962, 1399, 146, 5, 70, "Input",
  CellTags->"BooleanComplement"],

Cell[CellGroupData[{
Cell[33133, 1408, 99, 2, 70, "Input",
  CellTags->"BooleanComplement"],
Cell[33235, 1412, 125, 3, 70, "Output",
  CellTags->"BooleanComplement"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33397, 1420, 96, 2, 70, "Input",
  CellTags->"BooleanComplement"],
Cell[33496, 1424, 125, 3, 70, "Output",
  CellTags->"BooleanComplement"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33682, 1434, 74, 1, 42, "ObjectName",
  CellTags->"BooleanComposition"],
Cell[33759, 1437, 69, 1, 74, "Highlight",
  CellTags->"BooleanComposition"],
Cell[33831, 1440, 281, 8, 64, "Usage",
  CellTags->"BooleanComposition"],
Cell[34115, 1450, 156, 4, 33, "Notes",
  CellTags->"BooleanComposition"],
Cell[34274, 1456, 817, 27, 54, "Notes",
  CellTags->"BooleanComposition"],

Cell[CellGroupData[{
Cell[35116, 1487, 76, 1, 59, "ExampleSection",
  CellTags->"BooleanComposition"],
Cell[35195, 1490, 199, 6, 70, "ExampleText",
  CellTags->"BooleanComposition"],

Cell[CellGroupData[{
Cell[35419, 1500, 111, 2, 70, "Input",
  CellTags->"BooleanComposition"],
Cell[35533, 1504, 222, 4, 70, "Output",
  CellTags->"BooleanComposition"]
}, Open  ]],
Cell[35770, 1511, 134, 4, 70, "ExampleText",
  CellTags->"BooleanComposition"],

Cell[CellGroupData[{
Cell[35929, 1519, 165, 4, 70, "Input",
  CellTags->"BooleanComposition"],
Cell[36097, 1525, 514, 13, 70, "Output",
  CellTags->"BooleanComposition"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36648, 1543, 174, 4, 70, "Input",
  CellTags->"BooleanComposition"],
Cell[36825, 1549, 514, 13, 70, "Output",
  CellTags->"BooleanComposition"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37400, 1569, 68, 1, 42, "ObjectName",
  CellTags->"BooleanConverse"],
Cell[37471, 1572, 66, 1, 74, "Highlight",
  CellTags->"BooleanConverse"],
Cell[37540, 1575, 218, 6, 64, "Usage",
  CellTags->"BooleanConverse"],
Cell[37761, 1583, 175, 7, 33, "Notes",
  CellTags->"BooleanConverse"],
Cell[37939, 1592, 153, 4, 33, "Notes",
  CellTags->"BooleanConverse"],
Cell[38095, 1598, 450, 15, 54, "Notes",
  CellTags->"BooleanConverse"],

Cell[CellGroupData[{
Cell[38570, 1617, 73, 1, 59, "ExampleSection",
  CellTags->"BooleanConverse"],
Cell[38646, 1620, 214, 6, 70, "ExampleText",
  CellTags->"BooleanConverse"],

Cell[CellGroupData[{
Cell[38885, 1630, 133, 5, 70, "Input",
  CellTags->"BooleanConverse"],
Cell[39021, 1637, 511, 13, 70, "Output",
  CellTags->"BooleanConverse"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39569, 1655, 105, 2, 70, "Input",
  CellTags->"BooleanConverse"],
Cell[39677, 1659, 511, 13, 70, "Output",
  CellTags->"BooleanConverse"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40249, 1679, 76, 1, 42, "ObjectName",
  CellTags->"BooleanIntersection"],
Cell[40328, 1682, 70, 1, 74, "Highlight",
  CellTags->"BooleanIntersection"],
Cell[40401, 1685, 292, 8, 64, "Usage",
  CellTags->"BooleanIntersection"],
Cell[40696, 1695, 157, 4, 33, "Notes",
  CellTags->"BooleanIntersection"],
Cell[40856, 1701, 816, 27, 54, "Notes",
  CellTags->"BooleanIntersection"],

Cell[CellGroupData[{
Cell[41697, 1732, 77, 1, 59, "ExampleSection",
  CellTags->"BooleanIntersection"],
Cell[41777, 1735, 143, 4, 70, "ExampleText",
  CellTags->"BooleanIntersection"],

Cell[CellGroupData[{
Cell[41945, 1743, 144, 5, 70, "Input",
  CellTags->"BooleanIntersection"],
Cell[42092, 1750, 515, 13, 70, "Output",
  CellTags->"BooleanIntersection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42644, 1768, 147, 5, 70, "Input",
  CellTags->"BooleanIntersection"],
Cell[42794, 1775, 515, 13, 70, "Output",
  CellTags->"BooleanIntersection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43346, 1793, 117, 2, 70, "Input",
  CellTags->"BooleanIntersection"],
Cell[43466, 1797, 515, 13, 70, "Output",
  CellTags->"BooleanIntersection"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44042, 1817, 62, 1, 42, "ObjectName",
  CellTags->"BooleanPower"],
Cell[44107, 1820, 63, 1, 74, "Highlight",
  CellTags->"BooleanPower"],
Cell[44173, 1823, 246, 8, 64, "Usage",
  CellTags->"BooleanPower"],
Cell[44422, 1833, 150, 4, 33, "Notes",
  CellTags->"BooleanPower"],
Cell[44575, 1839, 823, 27, 54, "Notes",
  CellTags->"BooleanPower"],

Cell[CellGroupData[{
Cell[45423, 1870, 70, 1, 59, "ExampleSection",
  CellTags->"BooleanPower"],
Cell[45496, 1873, 193, 6, 70, "ExampleText",
  CellTags->"BooleanPower"],

Cell[CellGroupData[{
Cell[45714, 1883, 105, 2, 70, "Input",
  CellTags->"BooleanPower"],
Cell[45822, 1887, 216, 4, 70, "Output",
  CellTags->"BooleanPower"]
}, Open  ]],
Cell[46053, 1894, 126, 4, 70, "ExampleText",
  CellTags->"BooleanPower"],

Cell[CellGroupData[{
Cell[46204, 1902, 153, 4, 70, "Input",
  CellTags->"BooleanPower"],
Cell[46360, 1908, 508, 13, 70, "Output",
  CellTags->"BooleanPower"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46929, 1928, 62, 1, 42, "ObjectName",
  CellTags->"BooleanUnion"],
Cell[46994, 1931, 63, 1, 74, "Highlight",
  CellTags->"BooleanUnion"],
Cell[47060, 1934, 266, 8, 64, "Usage",
  CellTags->"BooleanUnion"],
Cell[47329, 1944, 150, 4, 33, "Notes",
  CellTags->"BooleanUnion"],
Cell[47482, 1950, 823, 27, 54, "Notes",
  CellTags->"BooleanUnion"],

Cell[CellGroupData[{
Cell[48330, 1981, 70, 1, 59, "ExampleSection",
  CellTags->"BooleanUnion"],
Cell[48403, 1984, 135, 4, 70, "ExampleText",
  CellTags->"BooleanUnion"],

Cell[CellGroupData[{
Cell[48563, 1992, 132, 5, 70, "Input",
  CellTags->"BooleanUnion"],
Cell[48698, 1999, 508, 13, 70, "Output",
  CellTags->"BooleanUnion"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49243, 2017, 135, 5, 70, "Input",
  CellTags->"BooleanUnion"],
Cell[49381, 2024, 509, 13, 70, "Output",
  CellTags->"BooleanUnion"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49927, 2042, 104, 2, 70, "Input",
  CellTags->"BooleanUnion"],
Cell[50034, 2046, 509, 13, 70, "Output",
  CellTags->"BooleanUnion"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[50604, 2066, 70, 1, 42, "ObjectName",
  CellTags->"CartesianProduct"],
Cell[50677, 2069, 67, 1, 74, "Highlight",
  CellTags->"CartesianProduct"],
Cell[50747, 2072, 232, 8, 43, "Usage",
  CellTags->"CartesianProduct"],
Cell[50982, 2082, 116, 4, 33, "Notes",
  CellTags->"CartesianProduct"],
Cell[51101, 2088, 233, 8, 37, "Notes",
  CellTags->"CartesianProduct"],
Cell[51337, 2098, 162, 2, 33, "Notes",
  CellTags->"CartesianProduct"],
Cell[51502, 2102, 196, 7, 33, "Notes",
  CellTags->"CartesianProduct"],

Cell[CellGroupData[{
Cell[51723, 2113, 74, 1, 59, "ExampleSection",
  CellTags->"CartesianProduct"],
Cell[51800, 2116, 70, 1, 70, "ExampleText",
  CellTags->"CartesianProduct"],

Cell[CellGroupData[{
Cell[51895, 2121, 129, 5, 70, "Input",
  CellTags->"CartesianProduct"],
Cell[52027, 2128, 140, 3, 70, "Output",
  CellTags->"CartesianProduct"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52204, 2136, 112, 2, 70, "Input",
  CellTags->"CartesianProduct"],
Cell[52319, 2140, 242, 5, 70, "Output",
  CellTags->"CartesianProduct"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52598, 2150, 109, 2, 70, "Input",
  CellTags->"CartesianProduct"],
Cell[52710, 2154, 94, 3, 70, "Output",
  CellTags->"CartesianProduct"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52841, 2162, 93, 2, 70, "Input",
  CellTags->"CartesianProduct"],
Cell[52937, 2166, 96, 3, 70, "Output",
  CellTags->"CartesianProduct"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53094, 2176, 66, 1, 42, "ObjectName",
  CellTags->"CirculantGraph"],
Cell[53163, 2179, 65, 1, 74, "Highlight",
  CellTags->"CirculantGraph"],
Cell[53231, 2182, 235, 7, 43, "Usage",
  CellTags->"CirculantGraph"],
Cell[53469, 2191, 309, 10, 54, "Notes",
  CellTags->"CirculantGraph"],
Cell[53781, 2203, 156, 6, 33, "Notes",
  CellTags->"CirculantGraph"],
Cell[53940, 2211, 251, 11, 33, "Notes",
  CellTags->"CirculantGraph"],

Cell[CellGroupData[{
Cell[54216, 2226, 72, 1, 59, "ExampleSection",
  CellTags->"CirculantGraph"],
Cell[54291, 2229, 84, 1, 70, "ExampleText",
  CellTags->"CirculantGraph"],

Cell[CellGroupData[{
Cell[54400, 2234, 101, 2, 70, "Input",
  CellTags->"CirculantGraph"],
Cell[54504, 2238, 281, 8, 70, "Output",
  CellTags->"CirculantGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54822, 2251, 119, 3, 70, "Input",
  CellTags->"CirculantGraph"],
Cell[54944, 2256, 125, 3, 70, "Output",
  CellTags->"CirculantGraph"]
}, Open  ]],
Cell[55084, 2262, 95, 1, 70, "ExampleText",
  CellTags->"CirculantGraph"],

Cell[CellGroupData[{
Cell[55204, 2267, 101, 2, 70, "Input",
  CellTags->"CirculantGraph"],
Cell[55308, 2271, 281, 8, 70, "Output",
  CellTags->"CirculantGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55626, 2284, 119, 3, 70, "Input",
  CellTags->"CirculantGraph"],
Cell[55748, 2289, 123, 3, 70, "Output",
  CellTags->"CirculantGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[55932, 2299, 64, 1, 42, "ObjectName",
  CellTags->"ClosureSearch"],
Cell[55999, 2302, 64, 1, 74, "Highlight",
  CellTags->"ClosureSearch"],
Cell[56066, 2305, 272, 10, 64, "Usage",
  CellTags->"ClosureSearch"],
Cell[56341, 2317, 309, 10, 80, "Notes",
  CellTags->"ClosureSearch"],
Cell[56653, 2329, 135, 5, 33, "Notes",
  CellTags->"ClosureSearch"],
Cell[56791, 2336, 328, 10, 54, "Notes",
  CellTags->"ClosureSearch"],
Cell[57122, 2348, 182, 4, 54, "Notes",
  CellTags->"ClosureSearch"],
Cell[57307, 2354, 406, 15, 33, "Notes",
  CellTags->"ClosureSearch"],

Cell[CellGroupData[{
Cell[57738, 2373, 71, 1, 59, "ExampleSection",
  CellTags->"ClosureSearch"],
Cell[57812, 2376, 107, 1, 70, "ExampleText",
  CellTags->"ClosureSearch"],

Cell[CellGroupData[{
Cell[57944, 2381, 180, 4, 70, "Input",
  CellTags->"ClosureSearch"],
Cell[58127, 2387, 113, 3, 70, "Output",
  CellTags->"ClosureSearch"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58277, 2395, 136, 3, 70, "Input",
  CellTags->"ClosureSearch"],
Cell[58416, 2400, 92, 3, 70, "Output",
  CellTags->"ClosureSearch"]
}, Open  ]],
Cell[58523, 2406, 85, 1, 70, "ExampleText",
  CellTags->"ClosureSearch"],

Cell[CellGroupData[{
Cell[58633, 2411, 188, 4, 70, "Input",
  CellTags->"ClosureSearch"],
Cell[58824, 2417, 93, 3, 70, "Output",
  CellTags->"ClosureSearch"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58954, 2425, 188, 4, 70, "Input",
  CellTags->"ClosureSearch"],
Cell[59145, 2431, 94, 3, 70, "Output",
  CellTags->"ClosureSearch"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[59300, 2441, 52, 1, 42, "ObjectName",
  CellTags->"Closure"],
Cell[59355, 2444, 58, 1, 74, "Highlight",
  CellTags->"Closure"],
Cell[59416, 2447, 147, 4, 43, "Usage",
  CellTags->"Closure"],
Cell[59566, 2453, 290, 10, 80, "Notes",
  CellTags->"Closure"],
Cell[59859, 2465, 129, 5, 33, "Notes",
  CellTags->"Closure"],
Cell[59991, 2472, 322, 10, 54, "Notes",
  CellTags->"Closure"],
Cell[60316, 2484, 412, 15, 33, "Notes",
  CellTags->"Closure"],

Cell[CellGroupData[{
Cell[60753, 2503, 65, 1, 59, "ExampleSection",
  CellTags->"Closure"],
Cell[60821, 2506, 83, 1, 70, "ExampleText",
  CellTags->"Closure"],

Cell[CellGroupData[{
Cell[60929, 2511, 101, 2, 70, "Input",
  CellTags->"Closure"],
Cell[61033, 2515, 139, 3, 70, "Output",
  CellTags->"Closure"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61209, 2523, 100, 2, 70, "Input",
  CellTags->"Closure"],
Cell[61312, 2527, 111, 3, 70, "Output",
  CellTags->"Closure"]
}, Open  ]],
Cell[61438, 2533, 101, 1, 70, "ExampleText",
  CellTags->"Closure"],

Cell[CellGroupData[{
Cell[61564, 2538, 174, 4, 70, "Input",
  CellTags->"Closure"],
Cell[61741, 2544, 107, 3, 70, "Output",
  CellTags->"Closure"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61885, 2552, 110, 2, 70, "Input",
  CellTags->"Closure"],
Cell[61998, 2556, 464, 8, 70, "Output",
  CellTags->"Closure"]
}, Open  ]],
Cell[62477, 2567, 196, 5, 70, "ExampleText",
  CellTags->"Closure"],

Cell[CellGroupData[{
Cell[62698, 2576, 155, 4, 70, "Input",
  CellTags->"Closure"],
Cell[62856, 2582, 118, 3, 70, "Output",
  CellTags->"Closure"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63035, 2592, 56, 1, 42, "ObjectName",
  CellTags->"CollapseT"],
Cell[63094, 2595, 60, 1, 74, "Highlight",
  CellTags->"CollapseT"],
Cell[63157, 2598, 190, 6, 43, "Usage",
  CellTags->"CollapseT"],
Cell[63350, 2606, 172, 7, 33, "Notes",
  CellTags->"CollapseT"],
Cell[63525, 2615, 152, 5, 33, "Notes",
  CellTags->"CollapseT"],
Cell[63680, 2622, 576, 23, 33, "Notes",
  CellTags->"CollapseT"],

Cell[CellGroupData[{
Cell[64281, 2649, 67, 1, 59, "ExampleSection",
  CellTags->"CollapseT"],
Cell[64351, 2652, 82, 1, 70, "ExampleText",
  CellTags->"CollapseT"],

Cell[CellGroupData[{
Cell[64458, 2657, 84, 2, 70, "Input",
  CellTags->"CollapseT"],
Cell[64545, 2661, 101, 3, 70, "Output",
  CellTags->"CollapseT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64683, 2669, 122, 4, 70, "Input",
  CellTags->"CollapseT"],
Cell[64808, 2675, 97, 3, 70, "Output",
  CellTags->"CollapseT"],
Cell[64908, 2680, 108, 3, 70, "Output",
  CellTags->"CollapseT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65053, 2688, 96, 3, 70, "Input",
  CellTags->"CollapseT"],
Cell[65152, 2693, 98, 3, 70, "Output",
  CellTags->"CollapseT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[65311, 2703, 50, 1, 42, "ObjectName",
  CellTags->"ColorQ"],
Cell[65364, 2706, 57, 1, 74, "Highlight",
  CellTags->"ColorQ"],
Cell[65424, 2709, 157, 6, 43, "Usage",
  CellTags->"ColorQ"],
Cell[65584, 2717, 82, 1, 33, "Notes",
  CellTags->"ColorQ"],
Cell[65669, 2720, 272, 12, 33, "Notes",
  CellTags->"ColorQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65978, 2737, 58, 1, 42, "ObjectName",
  CellTags->"CompCycles"],
Cell[66039, 2740, 61, 1, 74, "Highlight",
  CellTags->"CompCycles"],
Cell[66103, 2743, 219, 5, 64, "Usage",
  CellTags->"CompCycles"],
Cell[66325, 2750, 268, 11, 33, "Notes",
  CellTags->"CompCycles"],

Cell[CellGroupData[{
Cell[66618, 2765, 68, 1, 59, "ExampleSection",
  CellTags->"CompCycles"],
Cell[66689, 2768, 105, 1, 48, "ExampleText",
  CellTags->"CompCycles"],
Cell[66797, 2771, 151, 4, 60, "Input",
  CellTags->"CompCycles"],

Cell[CellGroupData[{
Cell[66973, 2779, 86, 2, 40, "Input",
  CellTags->"CompCycles"],
Cell[67062, 2783, 102, 3, 30, "Output",
  CellTags->"CompCycles"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67201, 2791, 166, 4, 60, "Input",
  CellTags->"CompCycles"],
Cell[67370, 2797, 102, 3, 30, "Output",
  CellTags->"CompCycles"],
Cell[67475, 2802, 102, 3, 30, "Output",
  CellTags->"CompCycles"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67614, 2810, 108, 2, 40, "Input",
  CellTags->"CompCycles"],
Cell[67725, 2814, 103, 3, 30, "Output",
  CellTags->"CompCycles"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[67889, 2824, 60, 1, 42, "ObjectName",
  CellTags->"Concatenate"],
Cell[67952, 2827, 62, 1, 74, "Highlight",
  CellTags->"Concatenate"],
Cell[68017, 2830, 184, 8, 43, "Usage",
  CellTags->"Concatenate"],
Cell[68204, 2840, 107, 4, 33, "Notes",
  CellTags->"Concatenate"],
Cell[68314, 2846, 179, 5, 33, "Notes",
  CellTags->"Concatenate"],
Cell[68496, 2853, 126, 4, 33, "Notes",
  CellTags->"Concatenate"],
Cell[68625, 2859, 154, 7, 33, "Notes",
  CellTags->"Concatenate"],

Cell[CellGroupData[{
Cell[68804, 2870, 69, 1, 59, "ExampleSection",
  CellTags->"Concatenate"],
Cell[68876, 2873, 73, 1, 48, "ExampleText",
  CellTags->"Concatenate"],

Cell[CellGroupData[{
Cell[68974, 2878, 135, 4, 60, "Input",
  CellTags->"Concatenate"],
Cell[69112, 2884, 93, 3, 30, "Output",
  CellTags->"Concatenate"],
Cell[69208, 2889, 249, 8, 49, "Output",
  CellTags->"Concatenate"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69494, 2902, 113, 3, 37, "Input",
  CellTags->"Concatenate"],
Cell[69610, 2907, 91, 3, 30, "Output",
  CellTags->"Concatenate"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69738, 2915, 112, 3, 37, "Input",
  CellTags->"Concatenate"],
Cell[69853, 2920, 108, 3, 30, "Output",
  CellTags->"Concatenate"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69998, 2928, 119, 3, 37, "Input",
  CellTags->"Concatenate"],
Cell[70120, 2933, 141, 3, 30, "Output",
  CellTags->"Concatenate"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[70322, 2943, 48, 1, 42, "ObjectName",
  CellTags->"ConsT"],
Cell[70373, 2946, 56, 1, 74, "Highlight",
  CellTags->"ConsT"],
Cell[70432, 2949, 211, 8, 43, "Usage",
  CellTags->"ConsT"],
Cell[70646, 2959, 316, 15, 33, "Notes",
  CellTags->"ConsT"],

Cell[CellGroupData[{
Cell[70987, 2978, 63, 1, 59, "ExampleSection",
  CellTags->"ConsT"],
Cell[71053, 2981, 70, 1, 70, "ExampleText",
  CellTags->"ConsT"],

Cell[CellGroupData[{
Cell[71148, 2986, 119, 4, 70, "Input",
  CellTags->"ConsT"],
Cell[71270, 2992, 97, 3, 70, "Output",
  CellTags->"ConsT"],
Cell[71370, 2997, 82, 3, 70, "Output",
  CellTags->"ConsT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[71513, 3007, 48, 1, 42, "ObjectName",
  CellTags->"Curry"],
Cell[71564, 3010, 56, 1, 74, "Highlight",
  CellTags->"Curry"],
Cell[71623, 3013, 152, 6, 43, "Usage",
  CellTags->"Curry"],
Cell[71778, 3021, 112, 5, 33, "Notes",
  CellTags->"Curry"],
Cell[71893, 3028, 142, 4, 33, "Notes",
  CellTags->"Curry"],

Cell[CellGroupData[{
Cell[72060, 3036, 63, 1, 59, "ExampleSection",
  CellTags->"Curry"],
Cell[72126, 3039, 83, 1, 70, "ExampleText",
  CellTags->"Curry"],

Cell[CellGroupData[{
Cell[72234, 3044, 117, 3, 70, "Input",
  CellTags->"Curry"],
Cell[72354, 3049, 93, 3, 70, "Output",
  CellTags->"Curry"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[72508, 3059, 76, 1, 42, "ObjectName",
  CellTags->"CycleDecompositionT"],
Cell[72587, 3062, 70, 1, 74, "Highlight",
  CellTags->"CycleDecompositionT"],
Cell[72660, 3065, 166, 4, 43, "Usage",
  CellTags->"CycleDecompositionT"],
Cell[72829, 3071, 235, 9, 58, "Notes",
  CellTags->"CycleDecompositionT"],
Cell[73067, 3082, 150, 5, 33, "Notes",
  CellTags->"CycleDecompositionT"],
Cell[73220, 3089, 203, 5, 54, "Notes",
  CellTags->"CycleDecompositionT"],
Cell[73426, 3096, 334, 15, 33, "Notes",
  CellTags->"CycleDecompositionT"],

Cell[CellGroupData[{
Cell[73785, 3115, 77, 1, 59, "ExampleSection",
  CellTags->"CycleDecompositionT"],
Cell[73865, 3118, 100, 1, 70, "ExampleText",
  CellTags->"CycleDecompositionT"],

Cell[CellGroupData[{
Cell[73990, 3123, 135, 5, 70, "Input",
  CellTags->"CycleDecompositionT"],
Cell[74128, 3130, 114, 3, 70, "Output",
  CellTags->"CycleDecompositionT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74279, 3138, 135, 3, 70, "Input",
  CellTags->"CycleDecompositionT"],
Cell[74417, 3143, 119, 3, 70, "Output",
  CellTags->"CycleDecompositionT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[74597, 3153, 54, 1, 42, "ObjectName",
  CellTags->"CycleToT"],
Cell[74654, 3156, 59, 1, 74, "Highlight",
  CellTags->"CycleToT"],
Cell[74716, 3159, 176, 5, 43, "Usage",
  CellTags->"CycleToT"],
Cell[74895, 3166, 78, 1, 33, "Notes",
  CellTags->"CycleToT"],
Cell[74976, 3169, 345, 15, 33, "Notes",
  CellTags->"CycleToT"],

Cell[CellGroupData[{
Cell[75346, 3188, 66, 1, 59, "ExampleSection",
  CellTags->"CycleToT"],
Cell[75415, 3191, 77, 1, 70, "ExampleText",
  CellTags->"CycleToT"],

Cell[CellGroupData[{
Cell[75517, 3196, 119, 3, 70, "Input",
  CellTags->"CycleToT"],
Cell[75639, 3201, 100, 3, 70, "Output",
  CellTags->"CycleToT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75776, 3209, 92, 3, 70, "Input",
  CellTags->"CycleToT"],
Cell[75871, 3214, 85, 3, 70, "Output",
  CellTags->"CycleToT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75993, 3222, 144, 4, 70, "Input",
  CellTags->"CycleToT"],
Cell[76140, 3228, 3031, 230, 70, 2850, 224, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"CycleToT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79208, 3463, 104, 3, 70, "Input",
  CellTags->"CycleToT"],
Cell[79315, 3468, 100, 3, 70, "Output",
  CellTags->"CycleToT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[79476, 3478, 62, 1, 42, "ObjectName",
  CellTags->"CyclicQGraph"],
Cell[79541, 3481, 63, 1, 74, "Highlight",
  CellTags->"CyclicQGraph"],
Cell[79607, 3484, 160, 6, 43, "Usage",
  CellTags->"CyclicQGraph"],
Cell[79770, 3492, 60, 1, 33, "Notes",
  CellTags->"CyclicQGraph"],
Cell[79833, 3495, 155, 7, 33, "Notes",
  CellTags->"CyclicQGraph"],

Cell[CellGroupData[{
Cell[80013, 3506, 70, 1, 59, "ExampleSection",
  CellTags->"CyclicQGraph"],
Cell[80086, 3509, 66, 1, 48, "ExampleText",
  CellTags->"CyclicQGraph"],
Cell[80155, 3512, 211, 6, 60, "Input",
  CellTags->"CyclicQGraph"],

Cell[CellGroupData[{
Cell[80391, 3522, 102, 3, 37, "Input",
  CellTags->"CyclicQGraph"],
Cell[80496, 3527, 92, 3, 30, "Output",
  CellTags->"CyclicQGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[80625, 3535, 114, 3, 37, "Input",
  CellTags->"CyclicQGraph"],
Cell[80742, 3540, 293, 8, 30, "Output",
  CellTags->"CyclicQGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81072, 3553, 103, 3, 37, "Input",
  CellTags->"CyclicQGraph"],
Cell[81178, 3558, 93, 3, 30, "Output",
  CellTags->"CyclicQGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[81332, 3568, 76, 1, 42, "ObjectName",
  CellTags->"DClassDecomposition"],
Cell[81411, 3571, 70, 1, 74, "Highlight",
  CellTags->"DClassDecomposition"],
Cell[81484, 3574, 200, 6, 43, "Usage",
  CellTags->"DClassDecomposition"],
Cell[81687, 3582, 241, 9, 58, "Notes",
  CellTags->"DClassDecomposition"],
Cell[81931, 3593, 160, 5, 33, "Notes",
  CellTags->"DClassDecomposition"],
Cell[82094, 3600, 259, 8, 54, "Notes",
  CellTags->"DClassDecomposition"],
Cell[82356, 3610, 128, 4, 33, "Notes",
  CellTags->"DClassDecomposition"],
Cell[82487, 3616, 259, 8, 54, "Notes",
  CellTags->"DClassDecomposition"],
Cell[82749, 3626, 344, 15, 33, "Notes",
  CellTags->"DClassDecomposition"],

Cell[CellGroupData[{
Cell[83118, 3645, 77, 1, 59, "ExampleSection",
  CellTags->"DClassDecomposition"],
Cell[83198, 3648, 140, 4, 70, "ExampleText",
  CellTags->"DClassDecomposition"],

Cell[CellGroupData[{
Cell[83363, 3656, 122, 5, 70, "Input",
  CellTags->"DClassDecomposition"],
Cell[83488, 3663, 98, 3, 70, "Output",
  CellTags->"DClassDecomposition"]
}, Open  ]],
Cell[83601, 3669, 131, 3, 70, "Input",
  CellTags->"DClassDecomposition"],

Cell[CellGroupData[{
Cell[83757, 3676, 149, 4, 70, "Input",
  CellTags->"DClassDecomposition"],
Cell[83909, 3682, 111, 3, 70, "Output",
  CellTags->"DClassDecomposition"],
Cell[84023, 3687, 140, 3, 70, "Output",
  CellTags->"DClassDecomposition"]
}, Open  ]],
Cell[84178, 3693, 113, 1, 70, "ExampleText",
  CellTags->"DClassDecomposition"],

Cell[CellGroupData[{
Cell[84316, 3698, 152, 3, 70, "Input",
  CellTags->"DClassDecomposition"],
Cell[84471, 3703, 9993, 265, 70, "Output",
  CellTags->"DClassDecomposition"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[94525, 3975, 70, 1, 42, "ObjectName",
  CellTags->"DClassDimensions"],
Cell[94598, 3978, 67, 1, 74, "Highlight",
  CellTags->"DClassDimensions"],
Cell[94668, 3981, 175, 6, 43, "Usage",
  CellTags->"DClassDimensions"],
Cell[94846, 3989, 116, 5, 33, "Notes",
  CellTags->"DClassDimensions"],
Cell[94965, 3996, 139, 4, 33, "Notes",
  CellTags->"DClassDimensions"],
Cell[95107, 4002, 250, 11, 33, "Notes",
  CellTags->"DClassDimensions"],

Cell[CellGroupData[{
Cell[95382, 4017, 74, 1, 59, "ExampleSection",
  CellTags->"DClassDimensions"],
Cell[95459, 4020, 83, 1, 70, "ExampleText",
  CellTags->"DClassDimensions"],
Cell[95545, 4023, 385, 7, 70, "Input",
  CellTags->"DClassDimensions"],

Cell[CellGroupData[{
Cell[95955, 4034, 110, 3, 70, "Input",
  CellTags->"DClassDimensions"],
Cell[96068, 4039, 101, 3, 70, "Output",
  CellTags->"DClassDimensions"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[96230, 4049, 58, 1, 42, "ObjectName",
  CellTags->"DClassSize"],
Cell[96291, 4052, 61, 1, 74, "Highlight",
  CellTags->"DClassSize"],
Cell[96355, 4055, 156, 6, 43, "Usage",
  CellTags->"DClassSize"],
Cell[96514, 4063, 110, 5, 33, "Notes",
  CellTags->"DClassSize"],
Cell[96627, 4070, 139, 4, 33, "Notes",
  CellTags->"DClassSize"],
Cell[96769, 4076, 273, 11, 33, "Notes",
  CellTags->"DClassSize"],

Cell[CellGroupData[{
Cell[97067, 4091, 68, 1, 59, "ExampleSection",
  CellTags->"DClassSize"],
Cell[97138, 4094, 77, 1, 70, "ExampleText",
  CellTags->"DClassSize"],
Cell[97218, 4097, 379, 7, 70, "Input",
  CellTags->"DClassSize"],

Cell[CellGroupData[{
Cell[97622, 4108, 98, 3, 70, "Input",
  CellTags->"DClassSize"],
Cell[97723, 4113, 88, 3, 70, "Output",
  CellTags->"DClassSize"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[97872, 4123, 66, 1, 42, "ObjectName",
  CellTags->"DClassToBlocks"],
Cell[97941, 4126, 65, 1, 74, "Highlight",
  CellTags->"DClassToBlocks"],
Cell[98009, 4129, 191, 5, 64, "Usage",
  CellTags->"DClassToBlocks"],
Cell[98203, 4136, 114, 5, 33, "Notes",
  CellTags->"DClassToBlocks"],
Cell[98320, 4143, 323, 9, 35, "Notes",
  CellTags->"DClassToBlocks"],
Cell[98646, 4154, 160, 5, 33, "Notes",
  CellTags->"DClassToBlocks"],
Cell[98809, 4161, 349, 15, 33, "Notes",
  CellTags->"DClassToBlocks"],

Cell[CellGroupData[{
Cell[99183, 4180, 72, 1, 59, "ExampleSection",
  CellTags->"DClassToBlocks"],
Cell[99258, 4183, 96, 1, 70, "ExampleText",
  CellTags->"DClassToBlocks"],

Cell[CellGroupData[{
Cell[99379, 4188, 292, 6, 70, "Input",
  CellTags->"DClassToBlocks"],
Cell[99674, 4196, 649, 19, 70, "Output",
  CellTags->"DClassToBlocks"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100360, 4220, 124, 3, 70, "Input",
  CellTags->"DClassToBlocks"],
Cell[100487, 4225, 1740, 45, 70, "Output",
  CellTags->"DClassToBlocks"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[102288, 4277, 52, 1, 42, "ObjectName",
  CellTags->"DClassT"],
Cell[102343, 4280, 58, 1, 74, "Highlight",
  CellTags->"DClassT"],
Cell[102404, 4283, 212, 8, 43, "Usage",
  CellTags->"DClassT"],
Cell[102619, 4293, 92, 1, 33, "Notes",
  CellTags->"DClassT"],
Cell[102714, 4296, 241, 11, 33, "Notes",
  CellTags->"DClassT"],

Cell[CellGroupData[{
Cell[102980, 4311, 65, 1, 59, "ExampleSection",
  CellTags->"DClassT"],
Cell[103048, 4314, 93, 1, 70, "ExampleText",
  CellTags->"DClassT"],

Cell[CellGroupData[{
Cell[103166, 4319, 110, 5, 70, "Input",
  CellTags->"DClassT"],
Cell[103279, 4326, 85, 3, 70, "Output",
  CellTags->"DClassT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103401, 4334, 170, 4, 70, "Input",
  CellTags->"DClassT"],
Cell[103574, 4340, 160, 4, 70, "Output",
  CellTags->"DClassT"],
Cell[103737, 4346, 699, 19, 70, "Output",
  CellTags->"DClassT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104473, 4370, 170, 4, 70, "Input",
  CellTags->"DClassT"],
Cell[104646, 4376, 196, 4, 70, "Output",
  CellTags->"DClassT"],
Cell[104845, 4382, 2219, 63, 70, "Output",
  CellTags->"DClassT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107101, 4450, 170, 4, 70, "Input",
  CellTags->"DClassT"],
Cell[107274, 4456, 196, 4, 70, "Output",
  CellTags->"DClassT"],
Cell[107473, 4462, 683, 21, 70, "Output",
  CellTags->"DClassT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[108217, 4490, 60, 1, 42, "ObjectName",
  CellTags->"DegreeGraph"],
Cell[108280, 4493, 62, 1, 74, "Highlight",
  CellTags->"DegreeGraph"],
Cell[108345, 4496, 199, 8, 43, "Usage",
  CellTags->"DegreeGraph"],
Cell[108547, 4506, 227, 9, 58, "Notes",
  CellTags->"DegreeGraph"],
Cell[108777, 4517, 182, 7, 33, "Notes",
  CellTags->"DegreeGraph"],
Cell[108962, 4526, 154, 7, 33, "Notes",
  CellTags->"DegreeGraph"],

Cell[CellGroupData[{
Cell[109141, 4537, 69, 1, 59, "ExampleSection",
  CellTags->"DegreeGraph"],
Cell[109213, 4540, 135, 4, 70, "ExampleText",
  CellTags->"DegreeGraph"],

Cell[CellGroupData[{
Cell[109373, 4548, 97, 2, 70, "Input",
  CellTags->"DegreeGraph"],
Cell[109473, 4552, 436, 11, 70, "Output",
  CellTags->"DegreeGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109946, 4568, 103, 3, 70, "Input",
  CellTags->"DegreeGraph"],
Cell[110052, 4573, 88, 3, 70, "Output",
  CellTags->"DegreeGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110177, 4581, 124, 3, 70, "Input",
  CellTags->"DegreeGraph"],
Cell[110304, 4586, 93, 3, 70, "Output",
  CellTags->"DegreeGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110434, 4594, 161, 4, 70, "Input",
  CellTags->"DegreeGraph"],
Cell[110598, 4600, 95, 3, 70, "Output",
  CellTags->"DegreeGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[110754, 4610, 58, 1, 42, "ObjectName",
  CellTags->"Dependency"],
Cell[110815, 4613, 61, 1, 74, "Highlight",
  CellTags->"Dependency"],
Cell[110879, 4616, 261, 8, 64, "Usage",
  CellTags->"Dependency"],
Cell[111143, 4626, 367, 14, 35, "Notes",
  CellTags->"Dependency"],
Cell[111513, 4642, 129, 5, 33, "Notes",
  CellTags->"Dependency"],
Cell[111645, 4649, 167, 7, 33, "Notes",
  CellTags->"Dependency"],

Cell[CellGroupData[{
Cell[111837, 4660, 68, 1, 59, "ExampleSection",
  CellTags->"Dependency"],
Cell[111908, 4663, 101, 1, 70, "ExampleText",
  CellTags->"Dependency"],
Cell[112012, 4666, 111, 5, 70, "Input",
  CellTags->"Dependency"],

Cell[CellGroupData[{
Cell[112148, 4675, 132, 3, 70, "Input",
  CellTags->"Dependency"],
Cell[112283, 4680, 109, 3, 70, "Output",
  CellTags->"Dependency"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112429, 4688, 97, 3, 70, "Input",
  CellTags->"Dependency"],
Cell[112529, 4693, 91, 3, 70, "Output",
  CellTags->"Dependency"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[112681, 4703, 56, 1, 42, "ObjectName",
  CellTags->"DisjointQ"],
Cell[112740, 4706, 60, 1, 74, "Highlight",
  CellTags->"DisjointQ"],
Cell[112803, 4709, 197, 8, 43, "Usage",
  CellTags->"DisjointQ"],
Cell[113003, 4719, 156, 7, 33, "Notes",
  CellTags->"DisjointQ"],

Cell[CellGroupData[{
Cell[113184, 4730, 67, 1, 59, "ExampleSection",
  CellTags->"DisjointQ"],
Cell[113254, 4733, 86, 1, 70, "ExampleText",
  CellTags->"DisjointQ"],

Cell[CellGroupData[{
Cell[113365, 4738, 96, 2, 70, "Input",
  CellTags->"DisjointQ"],
Cell[113464, 4742, 88, 3, 70, "Output",
  CellTags->"DisjointQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113589, 4750, 94, 2, 70, "Input",
  CellTags->"DisjointQ"],
Cell[113686, 4754, 89, 3, 70, "Output",
  CellTags->"DisjointQ"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[113836, 4764, 50, 1, 42, "ObjectName",
  CellTags->"DoShow"],
Cell[113889, 4767, 57, 1, 74, "Highlight",
  CellTags->"DoShow"],
Cell[113949, 4770, 253, 10, 64, "Usage",
  CellTags->"DoShow"],
Cell[114205, 4782, 134, 5, 33, "Notes",
  CellTags->"DoShow"],
Cell[114342, 4789, 157, 7, 33, "Notes",
  CellTags->"DoShow"],

Cell[CellGroupData[{
Cell[114524, 4800, 64, 1, 59, "ExampleSection",
  CellTags->"DoShow"],
Cell[114591, 4803, 80, 1, 70, "ExampleText",
  CellTags->"DoShow"],
Cell[114674, 4806, 176, 5, 70, "Input",
  CellTags->"DoShow"],

Cell[CellGroupData[{
Cell[114875, 4815, 95, 3, 70, "Input",
  CellTags->"DoShow"],
Cell[114973, 4820, 2661, 187, 70, 2487, 181, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"DoShow"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[117695, 5014, 46, 1, 42, "ObjectName",
  CellTags->"Drei"],
Cell[117744, 5017, 54, 1, 74, "Highlight",
  CellTags->"Drei"],
Cell[117801, 5020, 147, 6, 43, "Usage",
  CellTags->"Drei"],
Cell[117951, 5028, 104, 5, 33, "Notes",
  CellTags->"Drei"],
Cell[118058, 5035, 333, 15, 33, "Notes",
  CellTags->"Drei"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118428, 5055, 48, 1, 42, "ObjectName",
  CellTags->"EdgeQ"],
Cell[118479, 5058, 56, 1, 74, "Highlight",
  CellTags->"EdgeQ"],
Cell[118538, 5061, 223, 9, 43, "Usage",
  CellTags->"EdgeQ"],
Cell[118764, 5072, 154, 7, 33, "Notes",
  CellTags->"EdgeQ"],
Cell[118921, 5081, 148, 7, 33, "Notes",
  CellTags->"EdgeQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119106, 5093, 48, 1, 42, "ObjectName",
  CellTags->"Edges"],
Cell[119157, 5096, 56, 1, 74, "Highlight",
  CellTags->"Edges"],
Cell[119216, 5099, 116, 4, 43, "Usage",
  CellTags->"Edges"],
Cell[119335, 5105, 166, 4, 54, "Notes",
  CellTags->"Edges"],
Cell[119504, 5111, 255, 11, 33, "Notes",
  CellTags->"Edges"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119796, 5127, 54, 1, 42, "ObjectName",
  CellTags->"EnumForm"],
Cell[119853, 5130, 59, 1, 74, "Highlight",
  CellTags->"EnumForm"],
Cell[119915, 5133, 210, 8, 43, "Usage",
  CellTags->"EnumForm"],
Cell[120128, 5143, 221, 9, 58, "Notes",
  CellTags->"EnumForm"],
Cell[120352, 5154, 162, 7, 33, "Notes",
  CellTags->"EnumForm"],
Cell[120517, 5163, 130, 5, 33, "Notes",
  CellTags->"EnumForm"],
Cell[120650, 5170, 179, 8, 33, "Notes",
  CellTags->"EnumForm"],

Cell[CellGroupData[{
Cell[120854, 5182, 66, 1, 59, "ExampleSection",
  CellTags->"EnumForm"],
Cell[120923, 5185, 95, 1, 70, "ExampleText",
  CellTags->"EnumForm"],

Cell[CellGroupData[{
Cell[121043, 5190, 161, 4, 70, "Input",
  CellTags->"EnumForm"],
Cell[121207, 5196, 284, 5, 70, "Output",
  CellTags->"EnumForm"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121528, 5206, 94, 3, 70, "Input",
  CellTags->"EnumForm"],
Cell[121625, 5211, 989, 23, 70, "Output",
  CellTags->"EnumForm"]
}, Open  ]],
Cell[122629, 5237, 106, 2, 70, "ExampleText",
  CellTags->"EnumForm"],

Cell[CellGroupData[{
Cell[122760, 5243, 95, 3, 70, "Input",
  CellTags->"EnumForm"],
Cell[122858, 5248, 989, 23, 70, "Output",
  CellTags->"EnumForm"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[123908, 5278, 78, 1, 42, "ObjectName",
  CellTags->"EquationsToWitnesses"],
Cell[123989, 5281, 71, 1, 74, "Highlight",
  CellTags->"EquationsToWitnesses"],
Cell[124063, 5284, 285, 8, 64, "Usage",
  CellTags->"EquationsToWitnesses"],
Cell[124351, 5294, 283, 10, 80, "Notes",
  CellTags->"EquationsToWitnesses"],
Cell[124637, 5306, 217, 7, 33, "Notes",
  CellTags->"EquationsToWitnesses"],
Cell[124857, 5315, 185, 4, 54, "Notes",
  CellTags->"EquationsToWitnesses"],
Cell[125045, 5321, 173, 7, 33, "Notes",
  CellTags->"EquationsToWitnesses"],

Cell[CellGroupData[{
Cell[125243, 5332, 78, 1, 59, "ExampleSection",
  CellTags->"EquationsToWitnesses"],
Cell[125324, 5335, 194, 6, 70, "ExampleText",
  CellTags->"EquationsToWitnesses"],

Cell[CellGroupData[{
Cell[125543, 5345, 160, 4, 70, "Input",
  CellTags->"EquationsToWitnesses"],
Cell[125706, 5351, 122, 3, 70, "Output",
  CellTags->"EquationsToWitnesses"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125865, 5359, 179, 4, 70, "Input",
  CellTags->"EquationsToWitnesses"],
Cell[126047, 5365, 134, 3, 70, "Output",
  CellTags->"EquationsToWitnesses"]
}, Open  ]],
Cell[126196, 5371, 391, 12, 70, "ExampleText",
  CellTags->"EquationsToWitnesses"],

Cell[CellGroupData[{
Cell[126612, 5387, 193, 4, 70, "Input",
  CellTags->"EquationsToWitnesses"],
Cell[126808, 5393, 204, 4, 70, "Output",
  CellTags->"EquationsToWitnesses"]
}, Open  ]],
Cell[127027, 5400, 137, 4, 70, "ExampleText",
  CellTags->"EquationsToWitnesses"],

Cell[CellGroupData[{
Cell[127189, 5408, 202, 4, 70, "Input",
  CellTags->"EquationsToWitnesses"],
Cell[127394, 5414, 199, 4, 70, "Output",
  CellTags->"EquationsToWitnesses"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127630, 5423, 108, 3, 70, "Input",
  CellTags->"EquationsToWitnesses"],
Cell[127741, 5428, 100, 3, 70, "Output",
  CellTags->"EquationsToWitnesses"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[127902, 5438, 62, 1, 42, "ObjectName",
  CellTags->"FastPowerSet"],
Cell[127967, 5441, 63, 1, 74, "Highlight",
  CellTags->"FastPowerSet"],
Cell[128033, 5444, 147, 4, 43, "Usage",
  CellTags->"FastPowerSet"],
Cell[128183, 5450, 152, 5, 33, "Notes",
  CellTags->"FastPowerSet"],
Cell[128338, 5457, 156, 7, 33, "Notes",
  CellTags->"FastPowerSet"],

Cell[CellGroupData[{
Cell[128519, 5468, 70, 1, 59, "ExampleSection",
  CellTags->"FastPowerSet"],
Cell[128592, 5471, 122, 4, 70, "ExampleText",
  CellTags->"FastPowerSet"],

Cell[CellGroupData[{
Cell[128739, 5479, 128, 3, 70, "Input",
  CellTags->"FastPowerSet"],
Cell[128870, 5484, 124, 3, 70, "Output",
  CellTags->"FastPowerSet"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129031, 5492, 124, 3, 70, "Input",
  CellTags->"FastPowerSet"],
Cell[129158, 5497, 124, 3, 70, "Output",
  CellTags->"FastPowerSet"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129319, 5505, 138, 4, 70, "Input",
  CellTags->"FastPowerSet"],
Cell[129460, 5511, 93, 3, 70, "Output",
  CellTags->"FastPowerSet"],
Cell[129556, 5516, 92, 3, 70, "Output",
  CellTags->"FastPowerSet"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[129709, 5526, 58, 1, 42, "ObjectName",
  CellTags->"FlattenOne"],
Cell[129770, 5529, 61, 1, 74, "Highlight",
  CellTags->"FlattenOne"],
Cell[129834, 5532, 154, 6, 43, "Usage",
  CellTags->"FlattenOne"],
Cell[129991, 5540, 70, 1, 33, "Notes",
  CellTags->"FlattenOne"],
Cell[130064, 5543, 153, 7, 33, "Notes",
  CellTags->"FlattenOne"],

Cell[CellGroupData[{
Cell[130242, 5554, 68, 1, 59, "ExampleSection",
  CellTags->"FlattenOne"],
Cell[130313, 5557, 91, 1, 70, "ExampleText",
  CellTags->"FlattenOne"],

Cell[CellGroupData[{
Cell[130429, 5562, 96, 2, 70, "Input",
  CellTags->"FlattenOne"],
Cell[130528, 5566, 111, 3, 70, "Output",
  CellTags->"FlattenOne"]
}, Open  ]],

Cell[CellGroupData[{
Cell[130676, 5574, 137, 3, 70, "Input",
  CellTags->"FlattenOne"],
Cell[130816, 5579, 503, 15, 70, "Output",
  CellTags->"FlattenOne"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[131380, 5601, 60, 1, 42, "ObjectName",
  CellTags->"Frequencies"],
Cell[131443, 5604, 62, 1, 74, "Highlight",
  CellTags->"Frequencies"],
Cell[131508, 5607, 197, 6, 43, "Usage",
  CellTags->"Frequencies"],
Cell[131708, 5615, 165, 6, 33, "Notes",
  CellTags->"Frequencies"],

Cell[CellGroupData[{
Cell[131898, 5625, 69, 1, 59, "ExampleSection",
  CellTags->"Frequencies"],
Cell[131970, 5628, 94, 1, 70, "ExampleText",
  CellTags->"Frequencies"],

Cell[CellGroupData[{
Cell[132089, 5633, 199, 5, 70, "Input",
  CellTags->"Frequencies"],
Cell[132291, 5640, 134, 3, 70, "Output",
  CellTags->"Frequencies"],
Cell[132428, 5645, 420, 15, 70, "Output",
  CellTags->"Frequencies"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[132909, 5667, 64, 1, 42, "ObjectName",
  CellTags->"FromBitVector"],
Cell[132976, 5670, 64, 1, 74, "Highlight",
  CellTags->"FromBitVector"],
Cell[133043, 5673, 212, 8, 43, "Usage",
  CellTags->"FromBitVector"],
Cell[133258, 5683, 97, 1, 33, "Notes",
  CellTags->"FromBitVector"],
Cell[133358, 5686, 168, 7, 33, "Notes",
  CellTags->"FromBitVector"],

Cell[CellGroupData[{
Cell[133551, 5697, 71, 1, 59, "ExampleSection",
  CellTags->"FromBitVector"],
Cell[133625, 5700, 100, 1, 70, "ExampleText",
  CellTags->"FromBitVector"],

Cell[CellGroupData[{
Cell[133750, 5705, 92, 2, 70, "Input",
  CellTags->"FromBitVector"],
Cell[133845, 5709, 185, 4, 70, "Output",
  CellTags->"FromBitVector"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134067, 5718, 131, 3, 70, "Input",
  CellTags->"FromBitVector"],
Cell[134201, 5723, 142, 3, 70, "Output",
  CellTags->"FromBitVector"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[134404, 5733, 52, 1, 42, "ObjectName",
  CellTags->"FromEps"],
Cell[134459, 5736, 58, 1, 74, "Highlight",
  CellTags->"FromEps"],
Cell[134520, 5739, 279, 11, 43, "Usage",
  CellTags->"FromEps"],
Cell[134802, 5752, 96, 1, 33, "Notes",
  CellTags->"FromEps"],
Cell[134901, 5755, 150, 7, 33, "Notes",
  CellTags->"FromEps"],

Cell[CellGroupData[{
Cell[135076, 5766, 65, 1, 59, "ExampleSection",
  CellTags->"FromEps"],
Cell[135144, 5769, 86, 1, 70, "ExampleText",
  CellTags->"FromEps"],

Cell[CellGroupData[{
Cell[135255, 5774, 132, 3, 70, "Input",
  CellTags->"FromEps"],
Cell[135390, 5779, 138, 3, 70, "Output",
  CellTags->"FromEps"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[135589, 5789, 74, 1, 42, "ObjectName",
  CellTags->"FromIdentityString"],
Cell[135666, 5792, 69, 1, 74, "Highlight",
  CellTags->"FromIdentityString"],
Cell[135738, 5795, 236, 8, 43, "Usage",
  CellTags->"FromIdentityString"],
Cell[135977, 5805, 125, 4, 33, "Notes",
  CellTags->"FromIdentityString"],
Cell[136105, 5811, 147, 2, 33, "Notes",
  CellTags->"FromIdentityString"],
Cell[136255, 5815, 1040, 39, 75, "Notes",
  CellTags->"FromIdentityString"],

Cell[CellGroupData[{
Cell[137320, 5858, 76, 1, 59, "ExampleSection",
  CellTags->"FromIdentityString"],
Cell[137399, 5861, 106, 1, 70, "ExampleText",
  CellTags->"FromIdentityString"],
Cell[137508, 5864, 116, 2, 70, "Input",
  CellTags->"FromIdentityString"],

Cell[CellGroupData[{
Cell[137649, 5870, 96, 2, 70, "Input",
  CellTags->"FromIdentityString"],
Cell[137748, 5874, 500, 13, 70, "Output",
  CellTags->"FromIdentityString"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138285, 5892, 116, 2, 70, "Input",
  CellTags->"FromIdentityString"],
Cell[138404, 5896, 516, 13, 70, "Output",
  CellTags->"FromIdentityString"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[138981, 5916, 60, 1, 42, "ObjectName",
  CellTags->"GenerateCSM"],
Cell[139044, 5919, 62, 1, 74, "Highlight",
  CellTags->"GenerateCSM"],
Cell[139109, 5922, 232, 8, 64, "Usage",
  CellTags->"GenerateCSM"],
Cell[139344, 5932, 280, 10, 80, "Notes",
  CellTags->"GenerateCSM"],
Cell[139627, 5944, 212, 6, 54, "Notes",
  CellTags->"GenerateCSM"],
Cell[139842, 5952, 143, 5, 33, "Notes",
  CellTags->"GenerateCSM"],
Cell[139988, 5959, 285, 9, 54, "Notes",
  CellTags->"GenerateCSM"],
Cell[140276, 5970, 125, 4, 33, "Notes",
  CellTags->"GenerateCSM"],
Cell[140404, 5976, 164, 7, 33, "Notes",
  CellTags->"GenerateCSM"],

Cell[CellGroupData[{
Cell[140593, 5987, 69, 1, 59, "ExampleSection",
  CellTags->"GenerateCSM"],
Cell[140665, 5990, 134, 4, 70, "ExampleText",
  CellTags->"GenerateCSM"],
Cell[140802, 5996, 190, 5, 70, "Input",
  CellTags->"GenerateCSM"],

Cell[CellGroupData[{
Cell[141017, 6005, 285, 8, 70, "Input",
  CellTags->"GenerateCSM"],
Cell[141305, 6015, 108, 3, 70, "Output",
  CellTags->"GenerateCSM"],
Cell[141416, 6020, 661, 19, 70, "Output",
  CellTags->"GenerateCSM"],
Cell[142080, 6041, 420, 12, 70, "Output",
  CellTags->"GenerateCSM"]
}, Open  ]],
Cell[142515, 6056, 71, 1, 70, "ExampleText",
  CellTags->"GenerateCSM"],

Cell[CellGroupData[{
Cell[142611, 6061, 285, 6, 70, "Input",
  CellTags->"GenerateCSM"],
Cell[142899, 6069, 273, 5, 70, "Output",
  CellTags->"GenerateCSM"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[143233, 6081, 58, 1, 42, "ObjectName",
  CellTags->"GenerateSG"],
Cell[143294, 6084, 61, 1, 74, "Highlight",
  CellTags->"GenerateSG"],
Cell[143358, 6087, 183, 6, 43, "Usage",
  CellTags->"GenerateSG"],
Cell[143544, 6095, 442, 13, 152, "Notes",
  CellTags->"GenerateSG"],
Cell[143989, 6110, 154, 5, 33, "Notes",
  CellTags->"GenerateSG"],
Cell[144146, 6117, 389, 15, 54, "Notes",
  CellTags->"GenerateSG"],
Cell[144538, 6134, 172, 5, 33, "Notes",
  CellTags->"GenerateSG"],
Cell[144713, 6141, 120, 4, 33, "Notes",
  CellTags->"GenerateSG"],
Cell[144836, 6147, 261, 6, 54, "Notes",
  CellTags->"GenerateSG"],
Cell[145100, 6155, 161, 4, 33, "Notes",
  CellTags->"GenerateSG"],
Cell[145264, 6161, 407, 19, 33, "Notes",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{
Cell[145696, 6184, 68, 1, 59, "ExampleSection",
  CellTags->"GenerateSG"],
Cell[145767, 6187, 131, 4, 70, "ExampleText",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{
Cell[145923, 6195, 136, 6, 70, "Input",
  CellTags->"GenerateSG"],
Cell[146062, 6203, 139, 3, 70, "Output"],
Cell[146204, 6208, 59, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146300, 6215, 70, 2, 70, "Input"],
Cell[146373, 6219, 86, 2, 70, "Output"]
}, Open  ]],
Cell[146474, 6224, 140, 4, 70, "ExampleText",
  CellTags->"GenerateSG"],
Cell[146617, 6230, 145, 4, 70, "Input",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{
Cell[146787, 6238, 104, 3, 70, "Input",
  CellTags->"GenerateSG"],
Cell[146894, 6243, 678, 18, 70, "Output",
  CellTags->"GenerateSG"]
}, Open  ]],
Cell[147587, 6264, 149, 4, 70, "ExampleText",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{
Cell[147761, 6272, 108, 3, 70, "Input",
  CellTags->"GenerateSG"],
Cell[147872, 6277, 95, 3, 70, "Output",
  CellTags->"GenerateSG"]
}, Open  ]],
Cell[147982, 6283, 170, 4, 70, "ExampleText",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{
Cell[148177, 6291, 102, 3, 70, "Input",
  CellTags->"GenerateSG"],
Cell[148282, 6296, 1094, 25, 70, "Output",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149413, 6326, 115, 3, 70, "Input",
  CellTags->"GenerateSG"],
Cell[149531, 6331, 89, 3, 70, "Output",
  CellTags->"GenerateSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149657, 6339, 138, 3, 70, "Input",
  CellTags->"GenerateSG"],
Cell[149798, 6344, 788, 21, 70, "Output",
  CellTags->"GenerateSG"]
}, Open  ]],
Cell[150601, 6368, 166, 4, 70, "ExampleText",
  CellTags->"GenerateSG"],
Cell[150770, 6374, 139, 3, 70, "Input",
  CellTags->"GenerateSG"],
Cell[150912, 6379, 157, 4, 70, "Input",
  CellTags->"GenerateSG"],

Cell[CellGroupData[{
Cell[151094, 6387, 140, 4, 70, "Input",
  CellTags->"GenerateSG"],
Cell[151237, 6393, 88, 3, 70, "Output",
  CellTags->"GenerateSG"],
Cell[151328, 6398, 119, 3, 70, "Output",
  CellTags->"GenerateSG"]
}, Open  ]],
Cell[151462, 6404, 249, 8, 70, "ExampleText",
  Evaluatable->False,
  CellTags->"GenerateSG"],

Cell[CellGroupData[{
Cell[151736, 6416, 331, 8, 70, "Input",
  CellTags->"GenerateSG"],
Cell[152070, 6426, 1736, 45, 70, "Output",
  CellTags->"GenerateSG"],
Cell[153809, 6473, 1549, 37, 70, "Output",
  CellTags->"GenerateSG"]
}, Open  ]],
Cell[155373, 6513, 227, 8, 70, "ExampleText",
  Evaluatable->False,
  CellTags->"GenerateSG"],

Cell[CellGroupData[{
Cell[155625, 6525, 100, 3, 70, "Input",
  CellTags->"GenerateSG"],
Cell[155728, 6530, 90, 3, 70, "Output",
  CellTags->"GenerateSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[155879, 6540, 54, 1, 42, "ObjectName",
  CellTags->"GreenHQT"],
Cell[155936, 6543, 59, 1, 74, "Highlight",
  CellTags->"GreenHQT"],
Cell[155998, 6546, 250, 10, 43, "Usage",
  CellTags->"GreenHQT"],
Cell[156251, 6558, 500, 19, 33, "Notes",
  CellTags->"GreenHQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156788, 6582, 54, 1, 42, "ObjectName",
  CellTags->"GreenJQT"],
Cell[156845, 6585, 59, 1, 74, "Highlight",
  CellTags->"GreenJQT"],
Cell[156907, 6588, 250, 10, 43, "Usage",
  CellTags->"GreenJQT"],
Cell[157160, 6600, 500, 19, 33, "Notes",
  CellTags->"GreenJQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157697, 6624, 54, 1, 42, "ObjectName",
  CellTags->"GreenLQT"],
Cell[157754, 6627, 59, 1, 74, "Highlight",
  CellTags->"GreenLQT"],
Cell[157816, 6630, 250, 10, 43, "Usage",
  CellTags->"GreenLQT"],
Cell[158069, 6642, 500, 19, 33, "Notes",
  CellTags->"GreenLQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158606, 6666, 54, 1, 42, "ObjectName",
  CellTags->"GreenRQT"],
Cell[158663, 6669, 59, 1, 74, "Highlight",
  CellTags->"GreenRQT"],
Cell[158725, 6672, 250, 10, 43, "Usage",
  CellTags->"GreenRQT"],
Cell[158978, 6684, 500, 19, 33, "Notes",
  CellTags->"GreenRQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159515, 6708, 54, 1, 42, "ObjectName",
  CellTags->"GridLine"],
Cell[159572, 6711, 59, 1, 74, "Highlight",
  CellTags->"GridLine"],
Cell[159634, 6714, 218, 8, 43, "Usage",
  CellTags->"GridLine"],
Cell[159855, 6724, 353, 11, 104, "Notes",
  CellTags->"GridLine"],
Cell[160211, 6737, 90, 1, 33, "Notes",
  CellTags->"GridLine"],
Cell[160304, 6740, 259, 11, 33, "Notes",
  CellTags->"GridLine"],

Cell[CellGroupData[{
Cell[160588, 6755, 66, 1, 59, "ExampleSection",
  CellTags->"GridLine"],
Cell[160657, 6758, 62, 1, 70, "ExampleText",
  CellTags->"GridLine"],

Cell[CellGroupData[{
Cell[160744, 6763, 114, 3, 70, "Input",
  CellTags->"GridLine"],
Cell[160861, 6768, 1135, 75, 70, 958, 69, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"GridLine"]
}, Open  ]],
Cell[162011, 6846, 80, 1, 70, "ExampleText",
  CellTags->"GridLine"],
Cell[162094, 6849, 325, 8, 70, "Input",
  CellTags->"GridLine"],

Cell[CellGroupData[{
Cell[162444, 6861, 81, 2, 70, "Input",
  CellTags->"GridLine"],
Cell[162528, 6865, 1241, 83, 70, 1063, 77, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"GridLine"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[163830, 6955, 58, 1, 42, "ObjectName",
  CellTags->"GridPoints"],
Cell[163891, 6958, 61, 1, 74, "Highlight",
  CellTags->"GridPoints"],
Cell[163955, 6961, 221, 8, 43, "Usage",
  CellTags->"GridPoints"],
Cell[164179, 6971, 458, 14, 128, "Notes",
  CellTags->"GridPoints"],
Cell[164640, 6987, 91, 1, 33, "Notes",
  CellTags->"GridPoints"],
Cell[164734, 6990, 257, 11, 33, "Notes",
  CellTags->"GridPoints"],

Cell[CellGroupData[{
Cell[165016, 7005, 68, 1, 59, "ExampleSection",
  CellTags->"GridPoints"],
Cell[165087, 7008, 65, 1, 70, "ExampleText",
  CellTags->"GridPoints"],

Cell[CellGroupData[{
Cell[165177, 7013, 144, 4, 70, "Input",
  CellTags->"GridPoints"],
Cell[165324, 7019, 1249, 69, 70, 1070, 63, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"GridPoints"]
}, Open  ]],
Cell[166588, 7091, 72, 1, 70, "ExampleText",
  CellTags->"GridPoints"],

Cell[CellGroupData[{
Cell[166685, 7096, 355, 7, 70, "Input",
  CellTags->"GridPoints"],
Cell[167043, 7105, 8471, 468, 70, 8292, 462, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"GridPoints"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[175575, 7580, 58, 1, 42, "ObjectName",
  CellTags->"HClassSize"],
Cell[175636, 7583, 61, 1, 74, "Highlight",
  CellTags->"HClassSize"],
Cell[175700, 7586, 173, 6, 43, "Usage",
  CellTags->"HClassSize"],
Cell[175876, 7594, 110, 5, 33, "Notes",
  CellTags->"HClassSize"],
Cell[175989, 7601, 271, 11, 33, "Notes",
  CellTags->"HClassSize"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176297, 7617, 52, 1, 42, "ObjectName",
  CellTags->"HClassT"],
Cell[176352, 7620, 58, 1, 74, "Highlight",
  CellTags->"HClassT"],
Cell[176413, 7623, 206, 8, 43, "Usage",
  CellTags->"HClassT"],
Cell[176622, 7633, 79, 1, 33, "Notes",
  CellTags->"HClassT"],
Cell[176704, 7636, 149, 7, 33, "Notes",
  CellTags->"HClassT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176890, 7648, 60, 1, 42, "ObjectName",
  CellTags->"HTrivialQSG"],
Cell[176953, 7651, 62, 1, 74, "Highlight",
  CellTags->"HTrivialQSG"],
Cell[177018, 7654, 165, 6, 43, "Usage",
  CellTags->"HTrivialQSG"],
Cell[177186, 7662, 692, 27, 54, "Notes",
  CellTags->"HTrivialQSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[177915, 7694, 68, 1, 42, "ObjectName",
  CellTags->"HueRasterColors"],
Cell[177986, 7697, 66, 1, 74, "Highlight",
  CellTags->"HueRasterColors"],
Cell[178055, 7700, 179, 6, 43, "Usage",
  CellTags->"HueRasterColors"],
Cell[178237, 7708, 132, 5, 33, "Notes",
  CellTags->"HueRasterColors"],
Cell[178372, 7715, 400, 15, 33, "Notes",
  CellTags->"HueRasterColors"],

Cell[CellGroupData[{
Cell[178797, 7734, 73, 1, 59, "ExampleSection",
  CellTags->"HueRasterColors"],
Cell[178873, 7737, 76, 1, 70, "ExampleText",
  CellTags->"HueRasterColors"],
Cell[178952, 7740, 142, 3, 70, "Input",
  CellTags->"HueRasterColors"],

Cell[CellGroupData[{
Cell[179119, 7747, 151, 4, 70, "Input",
  CellTags->"HueRasterColors"],
Cell[179273, 7753, 7350, 171, 70, 7170, 165, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"HueRasterColors"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[186684, 7931, 50, 1, 42, "ObjectName",
  CellTags->"IdealT"],
Cell[186737, 7934, 57, 1, 74, "Highlight",
  CellTags->"IdealT"],
Cell[186797, 7937, 220, 8, 43, "Usage",
  CellTags->"IdealT"],
Cell[187020, 7947, 73, 1, 33, "Notes",
  CellTags->"IdealT"],
Cell[187096, 7950, 257, 11, 33, "Notes",
  CellTags->"IdealT"],

Cell[CellGroupData[{
Cell[187378, 7965, 64, 1, 59, "ExampleSection",
  CellTags->"IdealT"],
Cell[187445, 7968, 125, 4, 70, "ExampleText",
  CellTags->"IdealT"],
Cell[187573, 7974, 108, 3, 70, "Input",
  CellTags->"IdealT"],

Cell[CellGroupData[{
Cell[187706, 7981, 107, 3, 70, "Input",
  CellTags->"IdealT"],
Cell[187816, 7986, 117, 3, 70, "Output",
  CellTags->"IdealT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[187970, 7994, 107, 3, 70, "Input",
  CellTags->"IdealT"],
Cell[188080, 7999, 354, 6, 70, "Output",
  CellTags->"IdealT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[188495, 8012, 50, 1, 42, "ObjectName",
  CellTags->"IdemQT"],
Cell[188548, 8015, 57, 1, 74, "Highlight",
  CellTags->"IdemQT"],
Cell[188608, 8018, 161, 6, 43, "Usage",
  CellTags->"IdemQT"],
Cell[188772, 8026, 341, 15, 33, "Notes",
  CellTags->"IdemQT"],

Cell[CellGroupData[{
Cell[189138, 8045, 64, 1, 59, "ExampleSection",
  CellTags->"IdemQT"],
Cell[189205, 8048, 91, 1, 70, "ExampleText",
  CellTags->"IdemQT"],
Cell[189299, 8051, 115, 3, 70, "Input",
  CellTags->"IdemQT"],

Cell[CellGroupData[{
Cell[189439, 8058, 99, 3, 70, "Input",
  CellTags->"IdemQT"],
Cell[189541, 8063, 210, 5, 70, "Output",
  CellTags->"IdemQT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[189812, 8075, 50, 1, 42, "ObjectName",
  CellTags->"IdemSG"],
Cell[189865, 8078, 57, 1, 74, "Highlight",
  CellTags->"IdemSG"],
Cell[189925, 8081, 163, 6, 43, "Usage",
  CellTags->"IdemSG"],
Cell[190091, 8089, 73, 1, 33, "Notes",
  CellTags->"IdemSG"],
Cell[190167, 8092, 341, 15, 33, "Notes",
  CellTags->"IdemSG"],

Cell[CellGroupData[{
Cell[190533, 8111, 64, 1, 59, "ExampleSection",
  CellTags->"IdemSG"],
Cell[190600, 8114, 91, 1, 70, "ExampleText",
  CellTags->"IdemSG"],
Cell[190694, 8117, 108, 3, 70, "Input",
  CellTags->"IdemSG"],

Cell[CellGroupData[{
Cell[190827, 8124, 89, 3, 70, "Input",
  CellTags->"IdemSG"],
Cell[190919, 8129, 210, 5, 70, "Output",
  CellTags->"IdemSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[191190, 8141, 50, 1, 42, "ObjectName",
  CellTags->"ImageT"],
Cell[191243, 8144, 57, 1, 74, "Highlight",
  CellTags->"ImageT"],
Cell[191303, 8147, 171, 6, 43, "Usage",
  CellTags->"ImageT"],
Cell[191477, 8155, 106, 5, 33, "Notes",
  CellTags->"ImageT"],
Cell[191586, 8162, 457, 19, 33, "Notes",
  CellTags->"ImageT"],

Cell[CellGroupData[{
Cell[192068, 8185, 64, 1, 59, "ExampleSection",
  CellTags->"ImageT"],
Cell[192135, 8188, 91, 1, 70, "ExampleText",
  CellTags->"ImageT"],

Cell[CellGroupData[{
Cell[192251, 8193, 197, 5, 70, "Input",
  CellTags->"ImageT"],
Cell[192451, 8200, 1404, 37, 70, "Output",
  CellTags->"ImageT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[193916, 8244, 66, 1, 42, "ObjectName",
  CellTags->"IndToWitnesses"],
Cell[193985, 8247, 65, 1, 74, "Highlight",
  CellTags->"IndToWitnesses"],
Cell[194053, 8250, 253, 7, 70, "Usage",
  CellTags->"IndToWitnesses"],
Cell[194309, 8259, 225, 6, 33, "Notes",
  CellTags->"IndToWitnesses"],
Cell[194537, 8267, 262, 11, 33, "Notes",
  CellTags->"IndToWitnesses"],

Cell[CellGroupData[{
Cell[194824, 8282, 72, 1, 59, "ExampleSection",
  CellTags->"IndToWitnesses"],
Cell[194899, 8285, 76, 1, 70, "ExampleText",
  CellTags->"IndToWitnesses"],

Cell[CellGroupData[{
Cell[195000, 8290, 130, 3, 70, "Input",
  CellTags->"IndToWitnesses"],
Cell[195133, 8295, 83, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[195277, 8304, 56, 1, 42, "ObjectName",
  CellTags->"InGroupQT"],
Cell[195336, 8307, 60, 1, 74, "Highlight",
  CellTags->"InGroupQT"],
Cell[195399, 8310, 169, 6, 43, "Usage",
  CellTags->"InGroupQT"],
Cell[195571, 8318, 344, 15, 33, "Notes",
  CellTags->"InGroupQT"],

Cell[CellGroupData[{
Cell[195940, 8337, 67, 1, 59, "ExampleSection",
  CellTags->"InGroupQT"],
Cell[196010, 8340, 94, 1, 70, "ExampleText",
  CellTags->"InGroupQT"],
Cell[196107, 8343, 118, 3, 70, "Input",
  CellTags->"InGroupQT"],

Cell[CellGroupData[{
Cell[196250, 8350, 109, 3, 70, "Input",
  CellTags->"InGroupQT"],
Cell[196362, 8355, 357, 6, 70, "Output",
  CellTags->"InGroupQT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[196780, 8368, 56, 1, 42, "ObjectName",
  CellTags->"InGroupSG"],
Cell[196839, 8371, 60, 1, 74, "Highlight",
  CellTags->"InGroupSG"],
Cell[196902, 8374, 218, 8, 43, "Usage",
  CellTags->"InGroupSG"],
Cell[197123, 8384, 76, 1, 33, "Notes",
  CellTags->"InGroupSG"],
Cell[197202, 8387, 344, 15, 33, "Notes",
  CellTags->"InGroupSG"],

Cell[CellGroupData[{
Cell[197571, 8406, 67, 1, 59, "ExampleSection",
  CellTags->"InGroupSG"],
Cell[197641, 8409, 94, 1, 70, "ExampleText",
  CellTags->"InGroupSG"],
Cell[197738, 8412, 111, 3, 70, "Input",
  CellTags->"InGroupSG"],

Cell[CellGroupData[{
Cell[197874, 8419, 123, 4, 70, "Input",
  CellTags->"InGroupSG"],
Cell[198000, 8425, 213, 5, 70, "Output",
  CellTags->"InGroupSG"],
Cell[198216, 8432, 357, 6, 70, "Output",
  CellTags->"InGroupSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[198610, 8443, 118, 3, 70, "Input",
  CellTags->"InGroupSG"],
Cell[198731, 8448, 163, 4, 70, "Output",
  CellTags->"InGroupSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[198955, 8459, 54, 1, 42, "ObjectName",
  CellTags->"InverseT"],
Cell[199012, 8462, 59, 1, 74, "Highlight",
  CellTags->"InverseT"],
Cell[199074, 8465, 163, 6, 43, "Usage",
  CellTags->"InverseT"],
Cell[199240, 8473, 142, 5, 33, "Notes",
  CellTags->"InverseT"],
Cell[199385, 8480, 247, 11, 33, "Notes",
  CellTags->"InverseT"],

Cell[CellGroupData[{
Cell[199657, 8495, 66, 1, 59, "ExampleSection",
  CellTags->"InverseT"],
Cell[199726, 8498, 95, 1, 70, "ExampleText",
  CellTags->"InverseT"],

Cell[CellGroupData[{
Cell[199846, 8503, 141, 5, 70, "Input",
  CellTags->"InverseT"],
Cell[199990, 8510, 563, 16, 70, "Output",
  CellTags->"InverseT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[200614, 8533, 62, 1, 42, "ObjectName",
  CellTags->"IrreducibleQ"],
Cell[200679, 8536, 63, 1, 74, "Highlight",
  CellTags->"IrreducibleQ"],
Cell[200745, 8539, 228, 8, 43, "Usage",
  CellTags->"IrreducibleQ"],
Cell[200976, 8549, 139, 5, 33, "Notes",
  CellTags->"IrreducibleQ"],
Cell[201118, 8556, 275, 11, 33, "Notes",
  CellTags->"IrreducibleQ"],

Cell[CellGroupData[{
Cell[201418, 8571, 70, 1, 59, "ExampleSection",
  CellTags->"IrreducibleQ"],
Cell[201491, 8574, 74, 1, 70, "ExampleText",
  CellTags->"IrreducibleQ"],
Cell[201568, 8577, 126, 3, 70, "Input",
  CellTags->"IrreducibleQ"],

Cell[CellGroupData[{
Cell[201719, 8584, 166, 4, 70, "Input",
  CellTags->"IrreducibleQ"],
Cell[201888, 8590, 92, 3, 70, "Output",
  CellTags->"IrreducibleQ"],
Cell[201983, 8595, 91, 3, 70, "Output",
  CellTags->"IrreducibleQ"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[202135, 8605, 60, 1, 42, "ObjectName",
  CellTags->"JTrivialQSG"],
Cell[202198, 8608, 62, 1, 74, "Highlight",
  CellTags->"JTrivialQSG"],
Cell[202263, 8611, 164, 6, 43, "Usage",
  CellTags->"JTrivialQSG"],
Cell[202430, 8619, 92, 1, 33, "Notes",
  CellTags->"JTrivialQSG"],
Cell[202525, 8622, 142, 5, 33, "Notes",
  CellTags->"JTrivialQSG"],
Cell[202670, 8629, 692, 27, 54, "Notes",
  CellTags->"JTrivialQSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203399, 8661, 58, 1, 42, "ObjectName",
  CellTags->"JTrivialSG"],
Cell[203460, 8664, 61, 1, 74, "Highlight",
  CellTags->"JTrivialSG"],
Cell[203524, 8667, 186, 5, 64, "Usage",
  CellTags->"JTrivialSG"],
Cell[203713, 8674, 185, 6, 33, "Notes",
  CellTags->"JTrivialSG"],
Cell[203901, 8682, 484, 19, 33, "Notes",
  CellTags->"JTrivialSG"],

Cell[CellGroupData[{
Cell[204410, 8705, 68, 1, 59, "ExampleSection",
  CellTags->"JTrivialSG"],
Cell[204481, 8708, 75, 1, 70, "ExampleText",
  CellTags->"JTrivialSG"],

Cell[CellGroupData[{
Cell[204581, 8713, 97, 3, 70, "Input",
  CellTags->"JTrivialSG"],
Cell[204681, 8718, 318, 6, 70, "Output",
  CellTags->"JTrivialSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[205036, 8729, 100, 3, 70, "Input",
  CellTags->"JTrivialSG"],
Cell[205139, 8734, 236, 5, 70, "Output",
  CellTags->"JTrivialSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[205412, 8744, 82, 2, 70, "Input",
  CellTags->"JTrivialSG"],
Cell[205497, 8748, 89, 3, 70, "Output",
  CellTags->"JTrivialSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[205647, 8758, 66, 1, 42, "ObjectName",
  CellTags->"KernelImageToT"],
Cell[205716, 8761, 65, 1, 74, "Highlight",
  CellTags->"KernelImageToT"],
Cell[205784, 8764, 167, 4, 43, "Usage",
  CellTags->"KernelImageToT"],
Cell[205954, 8770, 145, 4, 33, "Notes",
  CellTags->"KernelImageToT"],
Cell[206102, 8776, 467, 19, 33, "Notes",
  CellTags->"KernelImageToT"],

Cell[CellGroupData[{
Cell[206594, 8799, 72, 1, 59, "ExampleSection",
  CellTags->"KernelImageToT"],
Cell[206669, 8802, 128, 4, 70, "ExampleText",
  CellTags->"KernelImageToT"],

Cell[CellGroupData[{
Cell[206822, 8810, 88, 2, 70, "Input",
  CellTags->"KernelImageToT"],
Cell[206913, 8814, 122, 3, 70, "Output",
  CellTags->"KernelImageToT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207072, 8822, 145, 4, 70, "Input",
  CellTags->"KernelImageToT"],
Cell[207220, 8828, 112, 3, 70, "Output",
  CellTags->"KernelImageToT"],
Cell[207335, 8833, 135, 3, 70, "Output",
  CellTags->"KernelImageToT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207507, 8841, 111, 3, 70, "Input",
  CellTags->"KernelImageToT"],
Cell[207621, 8846, 122, 3, 70, "Output",
  CellTags->"KernelImageToT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[207804, 8856, 52, 1, 42, "ObjectName",
  CellTags->"KernelT"],
Cell[207859, 8859, 58, 1, 74, "Highlight",
  CellTags->"KernelT"],
Cell[207920, 8862, 155, 6, 43, "Usage",
  CellTags->"KernelT"],
Cell[208078, 8870, 107, 5, 33, "Notes",
  CellTags->"KernelT"],
Cell[208188, 8877, 233, 6, 54, "Notes",
  CellTags->"KernelT"],
Cell[208424, 8885, 456, 19, 33, "Notes",
  CellTags->"KernelT"],

Cell[CellGroupData[{
Cell[208905, 8908, 65, 1, 59, "ExampleSection",
  CellTags->"KernelT"],
Cell[208973, 8911, 93, 1, 70, "ExampleText",
  CellTags->"KernelT"],

Cell[CellGroupData[{
Cell[209091, 8916, 197, 5, 70, "Input",
  CellTags->"KernelT"],
Cell[209291, 8923, 1589, 37, 70, "Output",
  CellTags->"KernelT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[210941, 8967, 66, 1, 42, "ObjectName",
  CellTags->"KPermutationsR"],
Cell[211010, 8970, 65, 1, 74, "Highlight",
  CellTags->"KPermutationsR"],
Cell[211078, 8973, 249, 8, 64, "Usage",
  CellTags->"KPermutationsR"],
Cell[211330, 8983, 193, 8, 33, "Notes",
  CellTags->"KPermutationsR"],
Cell[211526, 8993, 277, 11, 33, "Notes",
  CellTags->"KPermutationsR"],
Cell[211806, 9006, 171, 7, 33, "Notes",
  CellTags->"KPermutationsR"],

Cell[CellGroupData[{
Cell[212002, 9017, 72, 1, 59, "ExampleSection",
  CellTags->"KPermutationsR"],
Cell[212077, 9020, 83, 1, 70, "ExampleText",
  CellTags->"KPermutationsR"],

Cell[CellGroupData[{
Cell[212185, 9025, 97, 2, 70, "Input",
  CellTags->"KPermutationsR"],
Cell[212285, 9029, 422, 7, 70, "Output",
  CellTags->"KPermutationsR"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212744, 9041, 96, 2, 70, "Input",
  CellTags->"KPermutationsR"],
Cell[212843, 9045, 237, 5, 70, "Output",
  CellTags->"KPermutationsR"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[213141, 9057, 64, 1, 42, "ObjectName",
  CellTags->"LabelEdgeList"],
Cell[213208, 9060, 64, 1, 74, "Highlight",
  CellTags->"LabelEdgeList"],
Cell[213275, 9063, 181, 6, 43, "Usage",
  CellTags->"LabelEdgeList"],
Cell[213459, 9071, 96, 1, 33, "Notes",
  CellTags->"LabelEdgeList"],
Cell[213558, 9074, 245, 11, 33, "Notes",
  CellTags->"LabelEdgeList"],

Cell[CellGroupData[{
Cell[213828, 9089, 71, 1, 59, "ExampleSection",
  CellTags->"LabelEdgeList"],
Cell[213902, 9092, 89, 1, 70, "ExampleText",
  CellTags->"LabelEdgeList"],

Cell[CellGroupData[{
Cell[214016, 9097, 88, 2, 70, "Input",
  CellTags->"LabelEdgeList"],
Cell[214107, 9101, 270, 8, 70, "Output",
  CellTags->"LabelEdgeList"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214414, 9114, 117, 3, 70, "Input",
  CellTags->"LabelEdgeList"],
Cell[214534, 9119, 279, 8, 70, "Output",
  CellTags->"LabelEdgeList"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[214874, 9134, 58, 1, 42, "ObjectName",
  CellTags->"LeftIdealT"],
Cell[214935, 9137, 61, 1, 74, "Highlight",
  CellTags->"LeftIdealT"],
Cell[214999, 9140, 167, 4, 43, "Usage",
  CellTags->"LeftIdealT"],
Cell[215169, 9146, 77, 1, 33, "Notes",
  CellTags->"LeftIdealT"],
Cell[215249, 9149, 253, 11, 33, "Notes",
  CellTags->"LeftIdealT"],

Cell[CellGroupData[{
Cell[215527, 9164, 68, 1, 59, "ExampleSection",
  CellTags->"LeftIdealT"],
Cell[215598, 9167, 134, 4, 70, "ExampleText",
  CellTags->"LeftIdealT"],
Cell[215735, 9173, 112, 3, 70, "Input",
  CellTags->"LeftIdealT"],

Cell[CellGroupData[{
Cell[215872, 9180, 115, 3, 70, "Input",
  CellTags->"LeftIdealT"],
Cell[215990, 9185, 97, 3, 70, "Output",
  CellTags->"LeftIdealT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[216124, 9193, 115, 3, 70, "Input",
  CellTags->"LeftIdealT"],
Cell[216242, 9198, 188, 4, 70, "Output",
  CellTags->"LeftIdealT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[216491, 9209, 58, 1, 42, "ObjectName",
  CellTags->"LeftNullQT"],
Cell[216552, 9212, 61, 1, 74, "Highlight",
  CellTags->"LeftNullQT"],
Cell[216616, 9215, 205, 8, 43, "Usage",
  CellTags->"LeftNullQT"],
Cell[216824, 9225, 53, 1, 33, "Notes",
  CellTags->"LeftNullQT"],
Cell[216880, 9228, 163, 7, 33, "Notes",
  CellTags->"LeftNullQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217080, 9240, 58, 1, 42, "ObjectName",
  CellTags->"LeftNullSG"],
Cell[217141, 9243, 61, 1, 74, "Highlight",
  CellTags->"LeftNullSG"],
Cell[217205, 9246, 162, 6, 43, "Usage",
  CellTags->"LeftNullSG"],
Cell[217370, 9254, 77, 1, 33, "Notes",
  CellTags->"LeftNullSG"],
Cell[217450, 9257, 340, 15, 33, "Notes",
  CellTags->"LeftNullSG"],

Cell[CellGroupData[{
Cell[217815, 9276, 68, 1, 59, "ExampleSection",
  CellTags->"LeftNullSG"],
Cell[217886, 9279, 123, 4, 70, "ExampleText",
  CellTags->"LeftNullSG"],
Cell[218012, 9285, 92, 2, 70, "Input",
  CellTags->"LeftNullSG"],

Cell[CellGroupData[{
Cell[218129, 9291, 98, 3, 70, "Input",
  CellTags->"LeftNullSG"],
Cell[218230, 9296, 88, 3, 70, "Output",
  CellTags->"LeftNullSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[218379, 9306, 56, 1, 42, "ObjectName",
  CellTags->"LeftOneQT"],
Cell[218438, 9309, 60, 1, 74, "Highlight",
  CellTags->"LeftOneQT"],
Cell[218501, 9312, 207, 8, 43, "Usage",
  CellTags->"LeftOneQT"],
Cell[218711, 9322, 160, 7, 33, "Notes",
  CellTags->"LeftOneQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218908, 9334, 56, 1, 42, "ObjectName",
  CellTags->"LeftOneSG"],
Cell[218967, 9337, 60, 1, 74, "Highlight",
  CellTags->"LeftOneSG"],
Cell[219030, 9340, 165, 6, 43, "Usage",
  CellTags->"LeftOneSG"],
Cell[219198, 9348, 76, 1, 33, "Notes",
  CellTags->"LeftOneSG"],
Cell[219277, 9351, 430, 19, 33, "Notes",
  CellTags->"LeftOneSG"],

Cell[CellGroupData[{
Cell[219732, 9374, 67, 1, 59, "ExampleSection",
  CellTags->"LeftOneSG"],
Cell[219802, 9377, 138, 4, 70, "ExampleText",
  CellTags->"LeftOneSG"],
Cell[219943, 9383, 91, 2, 70, "Input",
  CellTags->"LeftOneSG"],

Cell[CellGroupData[{
Cell[220059, 9389, 95, 3, 70, "Input",
  CellTags->"LeftOneSG"],
Cell[220157, 9394, 96, 3, 70, "Output",
  CellTags->"LeftOneSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[220314, 9404, 66, 1, 42, "ObjectName",
  CellTags->"LocallyCommQSG"],
Cell[220383, 9407, 65, 1, 74, "Highlight",
  CellTags->"LocallyCommQSG"],
Cell[220451, 9410, 175, 6, 43, "Usage",
  CellTags->"LocallyCommQSG"],
Cell[220629, 9418, 232, 9, 33, "Notes",
  CellTags->"LocallyCommQSG"],
Cell[220864, 9429, 695, 27, 54, "Notes",
  CellTags->"LocallyCommQSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[221596, 9461, 66, 1, 42, "ObjectName",
  CellTags->"LocallyIdemQSG"],
Cell[221665, 9464, 65, 1, 74, "Highlight",
  CellTags->"LocallyIdemQSG"],
Cell[221733, 9467, 147, 4, 43, "Usage",
  CellTags->"LocallyIdemQSG"],
Cell[221883, 9473, 231, 9, 33, "Notes",
  CellTags->"LocallyIdemQSG"],
Cell[222117, 9484, 689, 27, 54, "Notes",
  CellTags->"LocallyIdemQSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[222843, 9516, 60, 1, 42, "ObjectName",
  CellTags->"LongestPath"],
Cell[222906, 9519, 62, 1, 74, "Highlight",
  CellTags->"LongestPath"],
Cell[222971, 9522, 189, 6, 43, "Usage",
  CellTags->"LongestPath"],
Cell[223163, 9530, 227, 9, 58, "Notes",
  CellTags->"LongestPath"],
Cell[223393, 9541, 166, 5, 33, "Notes",
  CellTags->"LongestPath"],
Cell[223562, 9548, 151, 4, 33, "Notes",
  CellTags->"LongestPath"],
Cell[223716, 9554, 204, 5, 54, "Notes",
  CellTags->"LongestPath"],
Cell[223923, 9561, 286, 11, 33, "Notes",
  CellTags->"LongestPath"],

Cell[CellGroupData[{
Cell[224234, 9576, 69, 1, 59, "ExampleSection",
  CellTags->"LongestPath"],
Cell[224306, 9579, 72, 1, 70, "ExampleText",
  CellTags->"LongestPath"],
Cell[224381, 9582, 184, 6, 70, "Input",
  CellTags->"LongestPath"],

Cell[CellGroupData[{
Cell[224590, 9592, 103, 3, 70, "Input",
  CellTags->"LongestPath"],
Cell[224696, 9597, 87, 3, 70, "Output",
  CellTags->"LongestPath"]
}, Open  ]],
Cell[224798, 9603, 86, 1, 70, "ExampleText",
  CellTags->"LongestPath"],

Cell[CellGroupData[{
Cell[224909, 9608, 120, 3, 70, "Input",
  CellTags->"LongestPath"],
Cell[225032, 9613, 104, 3, 70, "Output",
  CellTags->"LongestPath"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[225197, 9623, 52, 1, 42, "ObjectName",
  CellTags->"LShiftT"],
Cell[225252, 9626, 58, 1, 74, "Highlight",
  CellTags->"LShiftT"],
Cell[225313, 9629, 170, 6, 43, "Usage",
  CellTags->"LShiftT"],
Cell[225486, 9637, 486, 19, 33, "Notes",
  CellTags->"LShiftT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226009, 9661, 62, 1, 42, "ObjectName",
  CellTags->"MakeAlphabet"],
Cell[226074, 9664, 63, 1, 74, "Highlight",
  CellTags->"MakeAlphabet"],
Cell[226140, 9667, 234, 10, 43, "Usage",
  CellTags->"MakeAlphabet"],
Cell[226377, 9679, 166, 5, 33, "Notes",
  CellTags->"MakeAlphabet"],
Cell[226546, 9686, 469, 19, 33, "Notes",
  CellTags->"MakeAlphabet"],

Cell[CellGroupData[{
Cell[227040, 9709, 70, 1, 59, "ExampleSection",
  CellTags->"MakeAlphabet"],
Cell[227113, 9712, 93, 1, 70, "ExampleText",
  CellTags->"MakeAlphabet"],

Cell[CellGroupData[{
Cell[227231, 9717, 112, 5, 70, "Input",
  CellTags->"MakeAlphabet"],
Cell[227346, 9724, 98, 3, 70, "Output",
  CellTags->"MakeAlphabet"],
Cell[227447, 9729, 262, 8, 70, "Output",
  CellTags->"MakeAlphabet"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[227770, 9744, 70, 1, 42, "ObjectName",
  CellTags->"MakeFullAlphabet"],
Cell[227843, 9747, 67, 1, 74, "Highlight",
  CellTags->"MakeFullAlphabet"],
Cell[227913, 9750, 319, 12, 64, "Usage",
  CellTags->"MakeFullAlphabet"],
Cell[228235, 9764, 170, 5, 33, "Notes",
  CellTags->"MakeFullAlphabet"],
Cell[228408, 9771, 465, 19, 33, "Notes",
  CellTags->"MakeFullAlphabet"],

Cell[CellGroupData[{
Cell[228898, 9794, 74, 1, 59, "ExampleSection",
  CellTags->"MakeFullAlphabet"],
Cell[228975, 9797, 97, 1, 70, "ExampleText",
  CellTags->"MakeFullAlphabet"],

Cell[CellGroupData[{
Cell[229097, 9802, 120, 5, 70, "Input",
  CellTags->"MakeFullAlphabet"],
Cell[229220, 9809, 107, 3, 70, "Output",
  CellTags->"MakeFullAlphabet"],
Cell[229330, 9814, 275, 8, 70, "Output",
  CellTags->"MakeFullAlphabet"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[229666, 9829, 56, 1, 42, "ObjectName",
  CellTags->"MakeIndex"],
Cell[229725, 9832, 60, 1, 74, "Highlight",
  CellTags->"MakeIndex"],
Cell[229788, 9835, 220, 8, 43, "Usage",
  CellTags->"MakeIndex"],
Cell[230011, 9845, 129, 6, 33, "Notes",
  CellTags->"MakeIndex"],
Cell[230143, 9853, 116, 2, 33, "Notes",
  CellTags->"MakeIndex"],
Cell[230262, 9857, 205, 6, 33, "Notes",
  CellTags->"MakeIndex"],
Cell[230470, 9865, 160, 7, 33, "Notes",
  CellTags->"MakeIndex"],

Cell[CellGroupData[{
Cell[230655, 9876, 67, 1, 59, "ExampleSection",
  CellTags->"MakeIndex"],
Cell[230725, 9879, 71, 1, 70, "ExampleText",
  CellTags->"MakeIndex"],

Cell[CellGroupData[{
Cell[230821, 9884, 135, 3, 70, "Input",
  CellTags->"MakeIndex"],
Cell[230959, 9889, 126, 3, 70, "Output",
  CellTags->"MakeIndex"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[231146, 9899, 62, 1, 42, "ObjectName",
  CellTags->"MakeMonoidSG"],
Cell[231211, 9902, 63, 1, 74, "Highlight",
  CellTags->"MakeMonoidSG"],
Cell[231277, 9905, 194, 6, 43, "Usage",
  CellTags->"MakeMonoidSG"],
Cell[231474, 9913, 163, 7, 33, "Notes",
  CellTags->"MakeMonoidSG"],

Cell[CellGroupData[{
Cell[231662, 9924, 70, 1, 59, "ExampleSection",
  CellTags->"MakeMonoidSG"],
Cell[231735, 9927, 78, 1, 70, "ExampleText",
  CellTags->"MakeMonoidSG"],
Cell[231816, 9930, 134, 3, 70, "Input",
  CellTags->"MakeMonoidSG"],

Cell[CellGroupData[{
Cell[231975, 9937, 102, 3, 70, "Input",
  CellTags->"MakeMonoidSG"],
Cell[232080, 9942, 138, 3, 70, "Output",
  CellTags->"MakeMonoidSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[232279, 9952, 64, 1, 31, "ObjectName",
  CellTags->"MakePlotRange"],
Cell[232346, 9955, 64, 1, 74, "Highlight",
  CellTags->"MakePlotRange"],
Cell[232413, 9958, 190, 6, 43, "Usage",
  CellTags->"MakePlotRange"],
Cell[232606, 9966, 91, 1, 33, "Notes",
  CellTags->"MakePlotRange"]
}, Open  ]],

Cell[CellGroupData[{
Cell[232734, 9972, 54, 1, 42, "ObjectName",
  CellTags->"Merge12T"],
Cell[232791, 9975, 59, 1, 74, "Highlight",
  CellTags->"Merge12T"],
Cell[232853, 9978, 161, 6, 43, "Usage",
  CellTags->"Merge12T"],
Cell[233017, 9986, 101, 1, 33, "Notes",
  CellTags->"Merge12T"],
Cell[233121, 9989, 350, 15, 33, "Notes",
  CellTags->"Merge12T"]
}, Open  ]],

Cell[CellGroupData[{
Cell[233508, 10009, 56, 1, 42, "ObjectName",
  CellTags->"MinusEins"],
Cell[233567, 10012, 59, 1, 74, "Highlight",
  CellTags->"MinusEins"],
Cell[233629, 10015, 159, 7, 43, "Usage",
  CellTags->"MinusEins"],
Cell[233791, 10024, 114, 5, 33, "Notes",
  CellTags->"MinusEins"],
Cell[233908, 10031, 346, 15, 33, "Notes",
  CellTags->"MinusEins"]
}, Open  ]],

Cell[CellGroupData[{
Cell[234291, 10051, 56, 1, 42, "ObjectName",
  CellTags->"MinusZwei"],
Cell[234350, 10054, 59, 1, 74, "Highlight",
  CellTags->"MinusZwei"],
Cell[234412, 10057, 170, 6, 43, "Usage",
  CellTags->"MinusZwei"],
Cell[234585, 10065, 114, 5, 33, "Notes",
  CellTags->"MinusZwei"],
Cell[234702, 10072, 346, 15, 33, "Notes",
  CellTags->"MinusZwei"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235085, 10092, 56, 1, 42, "ObjectName",
  CellTags->"MonoidQSG"],
Cell[235144, 10095, 60, 1, 74, "Highlight",
  CellTags->"MonoidQSG"],
Cell[235207, 10098, 160, 6, 43, "Usage",
  CellTags->"MonoidQSG"],
Cell[235370, 10106, 694, 27, 54, "Notes",
  CellTags->"MonoidQSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236101, 10138, 62, 1, 42, "ObjectName",
  CellTags->"NilpotentQSG"],
Cell[236166, 10141, 63, 1, 74, "Highlight",
  CellTags->"NilpotentQSG"],
Cell[236232, 10144, 218, 6, 64, "Usage",
  CellTags->"NilpotentQSG"],
Cell[236453, 10152, 691, 27, 54, "Notes",
  CellTags->"NilpotentQSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[237181, 10184, 64, 1, 42, "ObjectName",
  CellTags->"NonDecreasing"],
Cell[237248, 10187, 64, 1, 74, "Highlight",
  CellTags->"NonDecreasing"],
Cell[237315, 10190, 289, 11, 43, "Usage",
  CellTags->"NonDecreasing"],
Cell[237607, 10203, 282, 11, 33, "Notes",
  CellTags->"NonDecreasing"],

Cell[CellGroupData[{
Cell[237914, 10218, 71, 1, 59, "ExampleSection",
  CellTags->"NonDecreasing"],
Cell[237988, 10221, 176, 6, 70, "ExampleText",
  CellTags->"NonDecreasing"],

Cell[CellGroupData[{
Cell[238189, 10231, 90, 2, 70, "Input",
  CellTags->"NonDecreasing"],
Cell[238282, 10235, 491, 8, 70, "Output",
  CellTags->"NonDecreasing"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[238834, 10250, 72, 1, 42, "ObjectName",
  CellTags->"NonTransientGraph"],
Cell[238909, 10253, 68, 1, 74, "Highlight",
  CellTags->"NonTransientGraph"],
Cell[238980, 10256, 178, 6, 43, "Usage",
  CellTags->"NonTransientGraph"],
Cell[239161, 10264, 261, 6, 54, "Notes",
  CellTags->"NonTransientGraph"],
Cell[239425, 10272, 155, 5, 33, "Notes",
  CellTags->"NonTransientGraph"],
Cell[239583, 10279, 416, 15, 33, "Notes",
  CellTags->"NonTransientGraph"],

Cell[CellGroupData[{
Cell[240024, 10298, 75, 1, 59, "ExampleSection",
  CellTags->"NonTransientGraph"],
Cell[240102, 10301, 94, 1, 70, "ExampleText",
  CellTags->"NonTransientGraph"],
Cell[240199, 10304, 237, 6, 70, "Input",
  CellTags->"NonTransientGraph"],

Cell[CellGroupData[{
Cell[240461, 10314, 143, 4, 70, "Input",
  CellTags->"NonTransientGraph"],
Cell[240607, 10320, 266, 8, 70, "Output",
  CellTags->"NonTransientGraph"],
Cell[240876, 10330, 117, 3, 70, "Output",
  CellTags->"NonTransientGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[241054, 10340, 66, 1, 42, "ObjectName",
  CellTags->"NormalizeGraph"],
Cell[241123, 10343, 65, 1, 74, "Highlight",
  CellTags->"NormalizeGraph"],
Cell[241191, 10346, 174, 6, 43, "Usage",
  CellTags->"NormalizeGraph"],
Cell[241368, 10354, 201, 5, 54, "Notes",
  CellTags->"NormalizeGraph"],
Cell[241572, 10361, 130, 4, 33, "Notes",
  CellTags->"NormalizeGraph"],
Cell[241705, 10367, 355, 15, 33, "Notes",
  CellTags->"NormalizeGraph"],

Cell[CellGroupData[{
Cell[242085, 10386, 72, 1, 59, "ExampleSection",
  CellTags->"NormalizeGraph"],
Cell[242160, 10389, 179, 5, 70, "ExampleText",
  CellTags->"NormalizeGraph"],

Cell[CellGroupData[{
Cell[242364, 10398, 193, 5, 70, "Input",
  CellTags->"NormalizeGraph"],
Cell[242560, 10405, 263, 8, 70, "Output",
  CellTags->"NormalizeGraph"],
Cell[242826, 10415, 114, 3, 70, "Output",
  CellTags->"NormalizeGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242977, 10423, 147, 4, 70, "Input",
  CellTags->"NormalizeGraph"],
Cell[243127, 10429, 263, 8, 70, "Output",
  CellTags->"NormalizeGraph"],
Cell[243393, 10439, 99, 3, 70, "Output",
  CellTags->"NormalizeGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[243553, 10449, 50, 1, 42, "ObjectName",
  CellTags->"NullQT"],
Cell[243606, 10452, 57, 1, 74, "Highlight",
  CellTags->"NullQT"],
Cell[243666, 10455, 202, 8, 43, "Usage",
  CellTags->"NullQT"],
Cell[243871, 10465, 148, 7, 33, "Notes",
  CellTags->"NullQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[244056, 10477, 50, 1, 42, "ObjectName",
  CellTags->"NullSG"],
Cell[244109, 10480, 57, 1, 74, "Highlight",
  CellTags->"NullSG"],
Cell[244169, 10483, 170, 6, 43, "Usage",
  CellTags->"NullSG"],
Cell[244342, 10491, 441, 19, 33, "Notes",
  CellTags->"NullSG"],

Cell[CellGroupData[{
Cell[244808, 10514, 64, 1, 59, "ExampleSection",
  CellTags->"NullSG"],
Cell[244875, 10517, 69, 1, 70, "ExampleText",
  CellTags->"NullSG"],
Cell[244947, 10520, 545, 10, 70, "Input",
  CellTags->"NullSG"],

Cell[CellGroupData[{
Cell[245517, 10534, 118, 4, 70, "Input",
  CellTags->"NullSG"],
Cell[245638, 10540, 103, 3, 70, "Output",
  CellTags->"NullSG"],
Cell[245744, 10545, 264, 5, 70, "Output",
  CellTags->"NullSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[246069, 10557, 54, 1, 31, "ObjectName",
  CellTags->"NumEdges"],
Cell[246126, 10560, 59, 1, 74, "Highlight",
  CellTags->"NumEdges"],
Cell[246188, 10563, 161, 6, 43, "Usage",
  CellTags->"NumEdges"],
Cell[246352, 10571, 338, 15, 33, "Notes",
  CellTags->"NumEdges"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246727, 10591, 60, 1, 42, "ObjectName",
  CellTags->"NumVertices"],
Cell[246790, 10594, 62, 1, 74, "Highlight",
  CellTags->"NumVertices"],
Cell[246855, 10597, 170, 6, 43, "Usage",
  CellTags->"NumVertices"],
Cell[247028, 10605, 335, 15, 33, "Notes",
  CellTags->"NumVertices"]
}, Open  ]],

Cell[CellGroupData[{
Cell[247400, 10625, 48, 1, 42, "ObjectName",
  CellTags->"OneQT"],
Cell[247451, 10628, 56, 1, 74, "Highlight",
  CellTags->"OneQT"],
Cell[247510, 10631, 206, 8, 43, "Usage",
  CellTags->"OneQT"],
Cell[247719, 10641, 233, 11, 33, "Notes",
  CellTags->"OneQT"],

Cell[CellGroupData[{
Cell[247977, 10656, 63, 1, 59, "ExampleSection",
  CellTags->"OneQT"],
Cell[248043, 10659, 96, 1, 70, "ExampleText",
  CellTags->"OneQT"],
Cell[248142, 10662, 205, 5, 70, "Input",
  CellTags->"OneQT"],

Cell[CellGroupData[{
Cell[248372, 10671, 121, 3, 70, "Input",
  CellTags->"OneQT"],
Cell[248496, 10676, 122, 3, 70, "Output",
  CellTags->"OneQT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[248679, 10686, 48, 1, 42, "ObjectName",
  CellTags->"OneSG"],
Cell[248730, 10689, 56, 1, 74, "Highlight",
  CellTags->"OneSG"],
Cell[248789, 10692, 164, 6, 43, "Usage",
  CellTags->"OneSG"],
Cell[248956, 10700, 233, 11, 33, "Notes",
  CellTags->"OneSG"],

Cell[CellGroupData[{
Cell[249214, 10715, 63, 1, 59, "ExampleSection",
  CellTags->"OneSG"],
Cell[249280, 10718, 94, 1, 70, "ExampleText",
  CellTags->"OneSG"],

Cell[CellGroupData[{
Cell[249399, 10723, 89, 2, 70, "Input",
  CellTags->"OneSG"],
Cell[249491, 10727, 279, 6, 70, "Output",
  CellTags->"OneSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[249807, 10738, 88, 3, 70, "Input",
  CellTags->"OneSG"],
Cell[249898, 10743, 96, 3, 70, "Output",
  CellTags->"OneSG"]
}, Open  ]],
Cell[250009, 10749, 104, 2, 70, "ExampleText",
  CellTags->"OneSG"],

Cell[CellGroupData[{
Cell[250138, 10755, 122, 3, 70, "Input",
  CellTags->"OneSG"],
Cell[250263, 10760, 119, 3, 70, "Output",
  CellTags->"OneSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[250419, 10768, 88, 3, 70, "Input",
  CellTags->"OneSG"],
Cell[250510, 10773, 83, 3, 70, "Output",
  CellTags->"OneSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[250630, 10781, 94, 3, 70, "Input",
  CellTags->"OneSG"],
Cell[250727, 10786, 117, 3, 70, "Output",
  CellTags->"OneSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[250905, 10796, 46, 1, 42, "ObjectName",
  CellTags->"OneT"],
Cell[250954, 10799, 55, 1, 74, "Highlight",
  CellTags->"OneT"],
Cell[251012, 10802, 226, 8, 43, "Usage",
  CellTags->"OneT"],
Cell[251241, 10812, 199, 6, 33, "Notes",
  CellTags->"OneT"],
Cell[251443, 10820, 234, 11, 33, "Notes",
  CellTags->"OneT"],

Cell[CellGroupData[{
Cell[251702, 10835, 62, 1, 59, "ExampleSection",
  CellTags->"OneT"],
Cell[251767, 10838, 83, 1, 70, "ExampleText",
  CellTags->"OneT"],

Cell[CellGroupData[{
Cell[251875, 10843, 71, 2, 70, "Input",
  CellTags->"OneT"],
Cell[251949, 10847, 96, 3, 70, "Output",
  CellTags->"OneT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252082, 10855, 112, 3, 70, "Input",
  CellTags->"OneT"],
Cell[252197, 10860, 84, 3, 70, "Output",
  CellTags->"OneT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[252342, 10870, 50, 1, 42, "ObjectName",
  CellTags->"OrderT"],
Cell[252395, 10873, 57, 1, 74, "Highlight",
  CellTags->"OrderT"],
Cell[252455, 10876, 125, 4, 43, "Usage",
  CellTags->"OrderT"],
Cell[252583, 10882, 247, 11, 33, "Notes",
  CellTags->"OrderT"],

Cell[CellGroupData[{
Cell[252855, 10897, 64, 1, 59, "ExampleSection",
  CellTags->"OrderT"],
Cell[252922, 10900, 121, 4, 70, "ExampleText",
  CellTags->"OrderT"],
Cell[253046, 10906, 91, 2, 70, "Input",
  CellTags->"OrderT"],

Cell[CellGroupData[{
Cell[253162, 10912, 154, 4, 70, "Input",
  CellTags->"OrderT"],
Cell[253319, 10918, 276, 5, 70, "Output",
  CellTags->"OrderT"],
Cell[253598, 10925, 389, 14, 70, "Output",
  CellTags->"OrderT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[254048, 10946, 62, 1, 31, "ObjectName",
  CellTags->"PairsToRules"],
Cell[254113, 10949, 63, 1, 74, "Highlight",
  CellTags->"PairsToRules"],
Cell[254179, 10952, 130, 4, 43, "Usage",
  CellTags->"PairsToRules"],
Cell[254312, 10958, 565, 19, 33, "Notes",
  CellTags->"PairsToRules"],

Cell[CellGroupData[{
Cell[254902, 10981, 70, 1, 59, "ExampleSection",
  CellTags->"PairsToRules"],
Cell[254975, 10984, 103, 1, 48, "ExampleText",
  CellTags->"PairsToRules"],
Cell[255081, 10987, 212, 4, 60, "Input",
  CellTags->"PairsToRules"],

Cell[CellGroupData[{
Cell[255318, 10995, 119, 3, 37, "Input",
  CellTags->"PairsToRules"],
Cell[255440, 11000, 526, 15, 144, "Output",
  CellTags->"PairsToRules"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[256027, 11022, 48, 1, 31, "ObjectName",
  CellTags->"Pairs"],
Cell[256078, 11025, 56, 1, 74, "Highlight",
  CellTags->"Pairs"],
Cell[256137, 11028, 227, 8, 43, "Usage",
  CellTags->"Pairs"],
Cell[256367, 11038, 94, 4, 33, "Notes",
  CellTags->"Pairs"],
Cell[256464, 11044, 151, 5, 33, "Notes",
  CellTags->"Pairs"],
Cell[256618, 11051, 93, 1, 33, "Notes",
  CellTags->"Pairs"],
Cell[256714, 11054, 207, 7, 33, "Notes",
  CellTags->"Pairs"],

Cell[CellGroupData[{
Cell[256946, 11065, 63, 1, 59, "ExampleSection",
  CellTags->"Pairs"],
Cell[257012, 11068, 62, 1, 70, "ExampleText",
  CellTags->"Pairs"],

Cell[CellGroupData[{
Cell[257099, 11073, 86, 2, 70, "Input",
  CellTags->"Pairs"],
Cell[257188, 11077, 105, 3, 70, "Output",
  CellTags->"Pairs"]
}, Open  ]],

Cell[CellGroupData[{
Cell[257330, 11085, 94, 2, 70, "Input",
  CellTags->"Pairs"],
Cell[257427, 11089, 114, 3, 70, "Output",
  CellTags->"Pairs"]
}, Open  ]],

Cell[CellGroupData[{
Cell[257578, 11097, 76, 2, 70, "Input",
  CellTags->"Pairs"],
Cell[257657, 11101, 83, 3, 70, "Output",
  CellTags->"Pairs"]
}, Open  ]],

Cell[CellGroupData[{
Cell[257777, 11109, 77, 2, 70, "Input",
  CellTags->"Pairs"],
Cell[257857, 11113, 210, 5, 70, "Message",
  CellTags->"Pairs"],
Cell[258070, 11120, 90, 3, 70, "Output",
  CellTags->"Pairs"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[258221, 11130, 70, 1, 42, "ObjectName",
  CellTags->"PartitionCumRest"],
Cell[258294, 11133, 67, 1, 74, "Highlight",
  CellTags->"PartitionCumRest"],
Cell[258364, 11136, 279, 10, 64, "Usage",
  CellTags->"PartitionCumRest"],
Cell[258646, 11148, 149, 5, 33, "Notes",
  CellTags->"PartitionCumRest"]
}, Open  ]],

Cell[CellGroupData[{
Cell[258832, 11158, 58, 1, 42, "ObjectName",
  CellTags->"Partitions"],
Cell[258893, 11161, 61, 1, 74, "Highlight",
  CellTags->"Partitions"],
Cell[258957, 11164, 153, 6, 43, "Usage",
  CellTags->"Partitions"],
Cell[259113, 11172, 218, 8, 33, "Notes",
  CellTags->"Partitions"],
Cell[259334, 11182, 261, 11, 33, "Notes",
  CellTags->"Partitions"],

Cell[CellGroupData[{
Cell[259620, 11197, 68, 1, 59, "ExampleSection",
  CellTags->"Partitions"],
Cell[259691, 11200, 144, 6, 70, "ExampleText",
  CellTags->"Partitions"],

Cell[CellGroupData[{
Cell[259860, 11210, 82, 2, 70, "Input",
  CellTags->"Partitions"],
Cell[259945, 11214, 169, 4, 70, "Output",
  CellTags->"Partitions"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[260175, 11225, 56, 1, 42, "ObjectName",
  CellTags->"PathGraph"],
Cell[260234, 11228, 60, 1, 74, "Highlight",
  CellTags->"PathGraph"],
Cell[260297, 11231, 170, 6, 43, "Usage",
  CellTags->"PathGraph"],
Cell[260470, 11239, 225, 9, 58, "Notes",
  CellTags->"PathGraph"],
Cell[260698, 11250, 141, 5, 33, "Notes",
  CellTags->"PathGraph"],
Cell[260842, 11257, 256, 11, 33, "Notes",
  CellTags->"PathGraph"],

Cell[CellGroupData[{
Cell[261123, 11272, 67, 1, 59, "ExampleSection",
  CellTags->"PathGraph"],
Cell[261193, 11275, 74, 1, 70, "ExampleText",
  CellTags->"PathGraph"],

Cell[CellGroupData[{
Cell[261292, 11280, 101, 3, 70, "Input",
  CellTags->"PathGraph"],
Cell[261396, 11285, 344, 10, 70, "Output",
  CellTags->"PathGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261777, 11300, 115, 3, 70, "Input",
  CellTags->"PathGraph"],
Cell[261895, 11305, 110, 3, 70, "Output",
  CellTags->"PathGraph"]
}, Open  ]],
Cell[262020, 11311, 84, 1, 70, "ExampleText",
  CellTags->"PathGraph"],

Cell[CellGroupData[{
Cell[262129, 11316, 120, 3, 70, "Input",
  CellTags->"PathGraph"],
Cell[262252, 11321, 355, 10, 70, "Output",
  CellTags->"PathGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[262644, 11336, 139, 3, 70, "Input",
  CellTags->"PathGraph"],
Cell[262786, 11341, 91, 3, 70, "Output",
  CellTags->"PathGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[262938, 11351, 62, 1, 31, "ObjectName",
  CellTags->"PermuteGraph"],
Cell[263003, 11354, 63, 1, 74, "Highlight",
  CellTags->"PermuteGraph"],
Cell[263069, 11357, 186, 8, 43, "Usage",
  CellTags->"PermuteGraph"],
Cell[263258, 11367, 125, 5, 33, "Notes",
  CellTags->"PermuteGraph"],
Cell[263386, 11374, 155, 7, 33, "Notes",
  CellTags->"PermuteGraph"],

Cell[CellGroupData[{
Cell[263566, 11385, 70, 1, 59, "ExampleSection",
  CellTags->"PermuteGraph"],
Cell[263639, 11388, 126, 4, 70, "ExampleText",
  CellTags->"PermuteGraph"],

Cell[CellGroupData[{
Cell[263790, 11396, 87, 2, 70, "Input",
  CellTags->"PermuteGraph"],
Cell[263880, 11400, 285, 8, 70, "Output",
  CellTags->"PermuteGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264202, 11413, 131, 3, 70, "Input",
  CellTags->"PermuteGraph"],
Cell[264336, 11418, 285, 8, 70, "Output",
  CellTags->"PermuteGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[264682, 11433, 62, 1, 31, "ObjectName",
  CellTags->"PlotFunction"],
Cell[264747, 11436, 63, 1, 74, "Highlight",
  CellTags->"PlotFunction"],
Cell[264813, 11439, 256, 10, 43, "Usage",
  CellTags->"PlotFunction"],
Cell[265072, 11451, 442, 14, 128, "Notes",
  CellTags->"PlotFunction"],
Cell[265517, 11467, 168, 7, 33, "Notes",
  CellTags->"PlotFunction"],

Cell[CellGroupData[{
Cell[265710, 11478, 70, 1, 59, "ExampleSection",
  CellTags->"PlotFunction"],
Cell[265783, 11481, 90, 1, 70, "ExampleText",
  CellTags->"PlotFunction"],

Cell[CellGroupData[{
Cell[265898, 11486, 174, 4, 70, "Input",
  CellTags->"PlotFunction"],
Cell[266075, 11492, 2953, 193, 70, 2772, 187, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PlotFunction"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[269089, 11692, 58, 1, 42, "ObjectName",
  CellTags->"PlotMatrix"],
Cell[269150, 11695, 61, 1, 74, "Highlight",
  CellTags->"PlotMatrix"],
Cell[269214, 11698, 163, 6, 43, "Usage",
  CellTags->"PlotMatrix"],
Cell[269380, 11706, 528, 15, 200, "Notes",
  CellTags->"PlotMatrix"],
Cell[269911, 11723, 156, 5, 33, "Notes",
  CellTags->"PlotMatrix"],
Cell[270070, 11730, 139, 5, 33, "Notes",
  CellTags->"PlotMatrix"],
Cell[270212, 11737, 142, 5, 33, "Notes",
  CellTags->"PlotMatrix"],
Cell[270357, 11744, 140, 5, 33, "Notes",
  CellTags->"PlotMatrix"],
Cell[270500, 11751, 179, 5, 33, "Notes",
  CellTags->"PlotMatrix"],
Cell[270682, 11758, 199, 6, 54, "Notes",
  CellTags->"PlotMatrix"],
Cell[270884, 11766, 171, 5, 33, "Notes",
  CellTags->"PlotMatrix"],
Cell[271058, 11773, 185, 7, 33, "Notes",
  CellTags->"PlotMatrix"],
Cell[271246, 11782, 373, 15, 33, "Notes",
  CellTags->"PlotMatrix"],

Cell[CellGroupData[{
Cell[271644, 11801, 68, 1, 59, "ExampleSection",
  CellTags->"PlotMatrix"],
Cell[271715, 11804, 96, 1, 70, "ExampleText",
  CellTags->"PlotMatrix"],
Cell[271814, 11807, 110, 2, 70, "Input",
  CellTags->"PlotMatrix"],

Cell[CellGroupData[{
Cell[271949, 11813, 103, 3, 70, "Input",
  CellTags->"PlotMatrix"],
Cell[272055, 11818, 1491, 83, 70, 1316, 77, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PlotMatrix"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[273607, 11908, 62, 1, 42, "ObjectName",
  CellTags->"PlotRelation"],
Cell[273672, 11911, 63, 1, 74, "Highlight",
  CellTags->"PlotRelation"],
Cell[273738, 11914, 263, 10, 43, "Usage",
  CellTags->"PlotRelation"],
Cell[274004, 11926, 531, 16, 130, "Notes",
  CellTags->"PlotRelation"],
Cell[274538, 11944, 254, 11, 33, "Notes",
  CellTags->"PlotRelation"],

Cell[CellGroupData[{
Cell[274817, 11959, 70, 1, 59, "ExampleSection",
  CellTags->"PlotRelation"],
Cell[274890, 11962, 90, 1, 70, "ExampleText",
  CellTags->"PlotRelation"],
Cell[274983, 11965, 142, 3, 70, "Input",
  CellTags->"PlotRelation"],

Cell[CellGroupData[{
Cell[275150, 11972, 132, 3, 70, "Input",
  CellTags->"PlotRelation"],
Cell[275285, 11977, 3102, 203, 70, 2921, 197, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PlotRelation"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[278448, 12187, 60, 1, 31, "ObjectName",
  CellTags->"PlotTDGraph"],
Cell[278511, 12190, 62, 1, 74, "Highlight",
  CellTags->"PlotTDGraph"],
Cell[278576, 12193, 252, 9, 43, "Usage",
  CellTags->"PlotTDGraph"],
Cell[278831, 12204, 530, 16, 130, "Notes",
  CellTags->"PlotTDGraph"],
Cell[279364, 12222, 155, 5, 33, "Notes",
  CellTags->"PlotTDGraph"],
Cell[279522, 12229, 221, 7, 33, "Notes",
  CellTags->"PlotTDGraph"],
Cell[279746, 12238, 284, 11, 33, "Notes",
  CellTags->"PlotTDGraph"],

Cell[CellGroupData[{
Cell[280055, 12253, 69, 1, 59, "ExampleSection",
  CellTags->"PlotTDGraph"],
Cell[280127, 12256, 189, 6, 70, "ExampleText",
  CellTags->"PlotTDGraph"],

Cell[CellGroupData[{
Cell[280341, 12266, 447, 10, 70, "Input",
  CellTags->"PlotTDGraph"],
Cell[280791, 12278, 484, 12, 70, "Output",
  CellTags->"PlotTDGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[281312, 12295, 108, 3, 70, "Input",
  CellTags->"PlotTDGraph"],
Cell[281423, 12300, 1985, 145, 70, 1805, 139, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PlotTDGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[283445, 12450, 163, 4, 70, "Input",
  CellTags->"PlotTDGraph"],
Cell[283611, 12456, 2567, 204, 70, 2387, 198, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"PlotTDGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[286239, 12667, 48, 1, 42, "ObjectName",
  CellTags->"PlotT"],
Cell[286290, 12670, 56, 1, 74, "Highlight",
  CellTags->"PlotT"],
Cell[286349, 12673, 190, 8, 43, "Usage",
  CellTags->"PlotT"],
Cell[286542, 12683, 223, 9, 58, "Notes",
  CellTags->"PlotT"],
Cell[286768, 12694, 121, 5, 33, "Notes",
  CellTags->"PlotT"],
Cell[286892, 12701, 101, 5, 33, "Notes",
  CellTags->"PlotT"],
Cell[286996, 12708, 348, 15, 33, "Notes",
  CellTags->"PlotT"],

Cell[CellGroupData[{
Cell[287369, 12727, 63, 1, 59, "ExampleSection",
  CellTags->"PlotT"],
Cell[287435, 12730, 98, 1, 70, "ExampleText",
  CellTags->"PlotT"],

Cell[CellGroupData[{
Cell[287558, 12735, 79, 2, 70, "Input",
  CellTags->"PlotT"],
Cell[287640, 12739, 92, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[287769, 12746, 72, 2, 70, "Input"],
Cell[287844, 12750, 4189, 300, 70, 4036, 295, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[292094, 13057, 62, 1, 42, "ObjectName",
  CellTags->"PositionList"],
Cell[292159, 13060, 63, 1, 74, "Highlight",
  CellTags->"PositionList"],
Cell[292225, 13063, 240, 8, 43, "Usage",
  CellTags->"PositionList"],
Cell[292468, 13073, 169, 7, 33, "Notes",
  CellTags->"PositionList"],

Cell[CellGroupData[{
Cell[292662, 13084, 70, 1, 59, "ExampleSection",
  CellTags->"PositionList"],
Cell[292735, 13087, 132, 4, 70, "ExampleText",
  CellTags->"PositionList"],

Cell[CellGroupData[{
Cell[292892, 13095, 108, 2, 70, "Input",
  CellTags->"PositionList"],
Cell[293003, 13099, 155, 4, 70, "Output",
  CellTags->"PositionList"]
}, Open  ]],

Cell[CellGroupData[{
Cell[293195, 13108, 143, 4, 70, "Input",
  CellTags->"PositionList"],
Cell[293341, 13114, 166, 4, 70, "Output",
  CellTags->"PositionList"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[293568, 13125, 60, 1, 42, "ObjectName",
  CellTags->"PositionOne"],
Cell[293631, 13128, 62, 1, 74, "Highlight",
  CellTags->"PositionOne"],
Cell[293696, 13131, 162, 6, 43, "Usage",
  CellTags->"PositionOne"],
Cell[293861, 13139, 59, 1, 33, "Notes",
  CellTags->"PositionOne"]
}, Open  ]],

Cell[CellGroupData[{
Cell[293957, 13145, 54, 1, 42, "ObjectName",
  CellTags->"PowerSet"],
Cell[294014, 13148, 59, 1, 74, "Highlight",
  CellTags->"PowerSet"],
Cell[294076, 13151, 186, 8, 43, "Usage",
  CellTags->"PowerSet"],
Cell[294265, 13161, 136, 5, 33, "Notes",
  CellTags->"PowerSet"],
Cell[294404, 13168, 136, 6, 33, "Notes",
  CellTags->"PowerSet"],
Cell[294543, 13176, 201, 7, 33, "Notes",
  CellTags->"PowerSet"],

Cell[CellGroupData[{
Cell[294769, 13187, 66, 1, 59, "ExampleSection",
  CellTags->"PowerSet"],
Cell[294838, 13190, 146, 6, 70, "ExampleText",
  CellTags->"PowerSet"],

Cell[CellGroupData[{
Cell[295009, 13200, 86, 2, 70, "Input",
  CellTags->"PowerSet"],
Cell[295098, 13204, 232, 5, 70, "Output",
  CellTags->"PowerSet"]
}, Open  ]],

Cell[CellGroupData[{
Cell[295367, 13214, 88, 2, 70, "Input",
  CellTags->"PowerSet"],
Cell[295458, 13218, 132, 3, 70, "Output",
  CellTags->"PowerSet"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[295651, 13228, 60, 1, 31, "ObjectName",
  CellTags->"PrintDClass"],
Cell[295714, 13231, 62, 1, 74, "Highlight",
  CellTags->"PrintDClass"],
Cell[295779, 13234, 154, 6, 43, "Usage",
  CellTags->"PrintDClass"],
Cell[295936, 13242, 111, 5, 33, "Notes",
  CellTags->"PrintDClass"],
Cell[296050, 13249, 134, 4, 33, "Notes",
  CellTags->"PrintDClass"],
Cell[296187, 13255, 358, 15, 33, "Notes",
  CellTags->"PrintDClass"],

Cell[CellGroupData[{
Cell[296570, 13274, 69, 1, 59, "ExampleSection",
  CellTags->"PrintDClass"],
Cell[296642, 13277, 78, 1, 70, "ExampleText",
  CellTags->"PrintDClass"],
Cell[296723, 13280, 380, 7, 70, "Input",
  CellTags->"PrintDClass"],

Cell[CellGroupData[{
Cell[297128, 13291, 100, 3, 70, "Input",
  CellTags->"PrintDClass"],
Cell[297231, 13296, 152, 4, 70, "Print",
  CellTags->"PrintDClass"],
Cell[297386, 13302, 313, 6, 70, "Print",
  CellTags->"PrintDClass"],
Cell[297702, 13310, 276, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[297981, 13320, 152, 4, 70, "Print",
  CellTags->"PrintDClass"],
Cell[298136, 13326, 95, 3, 70, "Print",
  CellTags->"PrintDClass"],
Cell[298234, 13331, 205, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[298442, 13338, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[298678, 13345, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[298985, 13355, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[299221, 13362, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[299528, 13372, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[299764, 13379, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[300071, 13389, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[300307, 13396, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[300614, 13406, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[300850, 13413, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[301157, 13423, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[301393, 13430, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[301700, 13440, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[301936, 13447, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[302243, 13457, 103, 3, 70, "Print",
  CellTags->"PrintDClass"],
Cell[302349, 13462, 205, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[302557, 13469, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[302793, 13476, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[303100, 13486, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[303336, 13493, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[303643, 13503, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[303879, 13510, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[304186, 13520, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[304422, 13527, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[304729, 13537, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[304965, 13544, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[305272, 13554, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[305508, 13561, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[305815, 13571, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[306051, 13578, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[306358, 13588, 103, 3, 70, "Print",
  CellTags->"PrintDClass"],
Cell[306464, 13593, 205, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[306672, 13600, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[306908, 13607, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[307215, 13617, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[307451, 13624, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[307758, 13634, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[307994, 13641, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[308301, 13651, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[308537, 13658, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[308844, 13668, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[309080, 13675, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[309387, 13685, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[309623, 13692, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[309930, 13702, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[310166, 13709, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[310473, 13719, 103, 3, 70, "Print",
  CellTags->"PrintDClass"],
Cell[310579, 13724, 205, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[310787, 13731, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[311023, 13738, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[311330, 13748, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[311566, 13755, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[311873, 13765, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[312109, 13772, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[312416, 13782, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[312652, 13789, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[312959, 13799, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[313195, 13806, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[313502, 13816, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[313738, 13823, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[314045, 13833, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[314281, 13840, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[314588, 13850, 103, 3, 70, "Print",
  CellTags->"PrintDClass"],
Cell[314694, 13855, 205, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[314902, 13862, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[315138, 13869, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[315445, 13879, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[315681, 13886, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[315988, 13896, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[316224, 13903, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[316531, 13913, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[316767, 13920, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[317074, 13930, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[317310, 13937, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[317617, 13947, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[317853, 13954, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[318160, 13964, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[318396, 13971, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[318703, 13981, 103, 3, 70, "Print",
  CellTags->"PrintDClass"],
Cell[318809, 13986, 205, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[319017, 13993, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[319253, 14000, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[319560, 14010, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[319796, 14017, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[320103, 14027, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[320339, 14034, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[320646, 14044, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[320882, 14051, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[321189, 14061, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[321425, 14068, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[321732, 14078, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[321968, 14085, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[322275, 14095, 233, 5, 70, "Print",
  CellTags->"PrintDClass"],
Cell[322511, 14102, 304, 8, 70, "Print",
  CellTags->"PrintDClass"],
Cell[322818, 14112, 103, 3, 70, "Print",
  CellTags->"PrintDClass"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[322982, 14122, 66, 1, 31, "ObjectName",
  CellTags->"PrintEquations"],
Cell[323051, 14125, 65, 1, 74, "Highlight",
  CellTags->"PrintEquations"],
Cell[323119, 14128, 153, 4, 43, "Usage",
  CellTags->"PrintEquations"],
Cell[323275, 14134, 279, 10, 80, "Notes",
  CellTags->"PrintEquations"],
Cell[323557, 14146, 149, 5, 33, "Notes",
  CellTags->"PrintEquations"],
Cell[323709, 14153, 458, 19, 33, "Notes",
  CellTags->"PrintEquations"],

Cell[CellGroupData[{
Cell[324192, 14176, 72, 1, 59, "ExampleSection",
  CellTags->"PrintEquations"],
Cell[324267, 14179, 142, 4, 70, "ExampleText",
  CellTags->"PrintEquations"],
Cell[324412, 14185, 159, 4, 70, "Input",
  CellTags->"PrintEquations"],

Cell[CellGroupData[{
Cell[324596, 14193, 99, 3, 70, "Input",
  CellTags->"PrintEquations"],
Cell[324698, 14198, 92, 3, 70, "Output",
  CellTags->"PrintEquations"]
}, Open  ]],
Cell[324805, 14204, 102, 1, 70, "ExampleText",
  CellTags->"PrintEquations"],

Cell[CellGroupData[{
Cell[324932, 14209, 169, 4, 70, "Input",
  CellTags->"PrintEquations"],
Cell[325104, 14215, 1780, 38, 70, "Output",
  CellTags->"PrintEquations"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[326945, 14260, 66, 1, 42, "ObjectName",
  CellTags->"PrintWitnesses"],
Cell[327014, 14263, 65, 1, 74, "Highlight",
  CellTags->"PrintWitnesses"],
Cell[327082, 14266, 204, 6, 43, "Usage",
  CellTags->"PrintWitnesses"],
Cell[327289, 14274, 458, 19, 33, "Notes",
  CellTags->"PrintWitnesses"],

Cell[CellGroupData[{
Cell[327772, 14297, 72, 1, 59, "ExampleSection",
  CellTags->"PrintWitnesses"],
Cell[327847, 14300, 142, 4, 70, "ExampleText",
  CellTags->"PrintWitnesses"],
Cell[327992, 14306, 159, 4, 70, "Input",
  CellTags->"PrintWitnesses"],

Cell[CellGroupData[{
Cell[328176, 14314, 109, 3, 70, "Input",
  CellTags->"PrintWitnesses"],
Cell[328288, 14319, 1720, 39, 70, "Output",
  CellTags->"PrintWitnesses"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[330069, 14365, 62, 1, 42, "ObjectName",
  CellTags->"ProductGraph"],
Cell[330134, 14368, 63, 1, 74, "Highlight",
  CellTags->"ProductGraph"],
Cell[330200, 14371, 234, 8, 43, "Usage",
  CellTags->"ProductGraph"],
Cell[330437, 14381, 227, 9, 58, "Notes",
  CellTags->"ProductGraph"],
Cell[330667, 14392, 604, 22, 54, "Notes",
  CellTags->"ProductGraph"],
Cell[331274, 14416, 320, 11, 33, "Notes",
  CellTags->"ProductGraph"],
Cell[331597, 14429, 305, 11, 33, "Notes",
  CellTags->"ProductGraph"],

Cell[CellGroupData[{
Cell[331927, 14444, 70, 1, 59, "ExampleSection",
  CellTags->"ProductGraph"],
Cell[332000, 14447, 98, 1, 70, "ExampleText",
  CellTags->"ProductGraph"],
Cell[332101, 14450, 160, 4, 70, "Input",
  CellTags->"ProductGraph"],

Cell[CellGroupData[{
Cell[332286, 14458, 111, 3, 70, "Input",
  CellTags->"ProductGraph"],
Cell[332400, 14463, 430, 11, 70, "Output",
  CellTags->"ProductGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[332867, 14479, 99, 3, 70, "Input",
  CellTags->"ProductGraph"],
Cell[332969, 14484, 193, 4, 70, "Output",
  CellTags->"ProductGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[333199, 14493, 118, 3, 70, "Input",
  CellTags->"ProductGraph"],
Cell[333320, 14498, 127, 3, 70, "Output",
  CellTags->"ProductGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[333484, 14506, 118, 3, 70, "Input",
  CellTags->"ProductGraph"],
Cell[333605, 14511, 109, 3, 70, "Output",
  CellTags->"ProductGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[333751, 14519, 117, 3, 70, "Input",
  CellTags->"ProductGraph"],
Cell[333871, 14524, 135, 3, 70, "Output",
  CellTags->"ProductGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[334067, 14534, 76, 1, 42, "ObjectName",
  CellTags->"ProductLabeledGraph"],
Cell[334146, 14537, 70, 1, 74, "Highlight",
  CellTags->"ProductLabeledGraph"],
Cell[334219, 14540, 227, 8, 43, "Usage",
  CellTags->"ProductLabeledGraph"],
Cell[334449, 14550, 495, 16, 54, "Notes",
  CellTags->"ProductLabeledGraph"],
Cell[334947, 14568, 298, 11, 33, "Notes",
  CellTags->"ProductLabeledGraph"],

Cell[CellGroupData[{
Cell[335270, 14583, 77, 1, 59, "ExampleSection",
  CellTags->"ProductLabeledGraph"],
Cell[335350, 14586, 210, 5, 70, "ExampleText",
  CellTags->"ProductLabeledGraph"],

Cell[CellGroupData[{
Cell[335585, 14595, 235, 6, 70, "Input",
  CellTags->"ProductLabeledGraph"],
Cell[335823, 14603, 368, 10, 70, "Output",
  CellTags->"ProductLabeledGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[336228, 14618, 128, 3, 70, "Input",
  CellTags->"ProductLabeledGraph"],
Cell[336359, 14623, 493, 12, 70, "Output",
  CellTags->"ProductLabeledGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[336889, 14640, 125, 3, 70, "Input",
  CellTags->"ProductLabeledGraph"],
Cell[337017, 14645, 156, 4, 70, "Output",
  CellTags->"ProductLabeledGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[337210, 14654, 103, 3, 70, "Input",
  CellTags->"ProductLabeledGraph"],
Cell[337316, 14659, 254, 8, 70, "Output",
  CellTags->"ProductLabeledGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[337631, 14674, 72, 1, 31, "ObjectName",
  CellTags->"RandomPermutation"],
Cell[337706, 14677, 68, 1, 74, "Highlight",
  CellTags->"RandomPermutation"],
Cell[337777, 14680, 197, 6, 43, "Usage",
  CellTags->"RandomPermutation"],
Cell[337977, 14688, 178, 7, 33, "Notes",
  CellTags->"RandomPermutation"],

Cell[CellGroupData[{
Cell[338180, 14699, 75, 1, 59, "ExampleSection",
  CellTags->"RandomPermutation"],
Cell[338258, 14702, 159, 6, 70, "ExampleText",
  CellTags->"RandomPermutation"],

Cell[CellGroupData[{
Cell[338442, 14712, 96, 2, 70, "Input",
  CellTags->"RandomPermutation"],
Cell[338541, 14716, 123, 3, 70, "Output",
  CellTags->"RandomPermutation"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[338725, 14726, 52, 1, 31, "ObjectName",
  CellTags->"RandomT"],
Cell[338780, 14729, 58, 1, 74, "Highlight",
  CellTags->"RandomT"],
Cell[338841, 14732, 132, 4, 43, "Usage",
  CellTags->"RandomT"],
Cell[338976, 14738, 73, 1, 33, "Notes",
  CellTags->"RandomT"],
Cell[339052, 14741, 142, 7, 33, "Notes",
  CellTags->"RandomT"],

Cell[CellGroupData[{
Cell[339219, 14752, 65, 1, 59, "ExampleSection",
  CellTags->"RandomT"],
Cell[339287, 14755, 74, 1, 70, "ExampleText",
  CellTags->"RandomT"],

Cell[CellGroupData[{
Cell[339386, 14760, 89, 2, 70, "Input",
  CellTags->"RandomT"],
Cell[339478, 14764, 231, 5, 70, "Output",
  CellTags->"RandomT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[339770, 14776, 48, 1, 42, "ObjectName",
  CellTags->"RankT"],
Cell[339821, 14779, 56, 1, 74, "Highlight",
  CellTags->"RankT"],
Cell[339880, 14782, 105, 5, 33, "Notes",
  CellTags->"RankT"],
Cell[339988, 14789, 196, 6, 43, "Usage",
  CellTags->"RankT"],
Cell[340187, 14797, 105, 5, 33, "Notes",
  CellTags->"RankT"],
Cell[340295, 14804, 458, 19, 33, "Notes",
  CellTags->"RankT"],

Cell[CellGroupData[{
Cell[340778, 14827, 63, 1, 59, "ExampleSection",
  CellTags->"RankT"],
Cell[340844, 14830, 90, 1, 70, "ExampleText",
  CellTags->"RankT"],

Cell[CellGroupData[{
Cell[340959, 14835, 149, 4, 70, "Input",
  CellTags->"RankT"],
Cell[341111, 14841, 1186, 37, 70, "Output",
  CellTags->"RankT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[342358, 14885, 56, 1, 42, "ObjectName",
  CellTags->"RegularQT"],
Cell[342417, 14888, 60, 1, 74, "Highlight",
  CellTags->"RegularQT"],
Cell[342480, 14891, 204, 8, 43, "Usage",
  CellTags->"RegularQT"],
Cell[342687, 14901, 155, 7, 33, "Notes",
  CellTags->"RegularQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[342879, 14913, 56, 1, 42, "ObjectName",
  CellTags->"RegularSG"],
Cell[342938, 14916, 60, 1, 74, "Highlight",
  CellTags->"RegularSG"],
Cell[343001, 14919, 166, 6, 43, "Usage",
  CellTags->"RegularSG"],
Cell[343170, 14927, 81, 1, 33, "Notes",
  CellTags->"RegularSG"],
Cell[343254, 14930, 256, 11, 33, "Notes",
  CellTags->"RegularSG"],

Cell[CellGroupData[{
Cell[343535, 14945, 67, 1, 59, "ExampleSection",
  CellTags->"RegularSG"],
Cell[343605, 14948, 104, 1, 70, "ExampleText",
  CellTags->"RegularSG"],
Cell[343712, 14951, 145, 4, 70, "Input",
  CellTags->"RegularSG"],

Cell[CellGroupData[{
Cell[343882, 14959, 95, 3, 70, "Input",
  CellTags->"RegularSG"],
Cell[343980, 14964, 99, 3, 70, "Output",
  CellTags->"RegularSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[344116, 14972, 92, 3, 70, "Input",
  CellTags->"RegularSG"],
Cell[344211, 14977, 99, 3, 70, "Output",
  CellTags->"RegularSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[344371, 14987, 70, 1, 42, "ObjectName",
  CellTags->"RelationToMatrix"],
Cell[344444, 14990, 67, 1, 74, "Highlight",
  CellTags->"RelationToMatrix"],
Cell[344514, 14993, 245, 8, 64, "Usage",
  CellTags->"RelationToMatrix"],
Cell[344762, 15003, 98, 1, 33, "Notes",
  CellTags->"RelationToMatrix"],
Cell[344863, 15006, 108, 1, 33, "Notes",
  CellTags->"RelationToMatrix"],
Cell[344974, 15009, 830, 31, 54, "Notes",
  CellTags->"RelationToMatrix"],

Cell[CellGroupData[{
Cell[345829, 15044, 74, 1, 59, "ExampleSection",
  CellTags->"RelationToMatrix"],
Cell[345906, 15047, 86, 1, 70, "ExampleText",
  CellTags->"RelationToMatrix"],

Cell[CellGroupData[{
Cell[346017, 15052, 108, 2, 70, "Input",
  CellTags->"RelationToMatrix"],
Cell[346128, 15056, 326, 6, 70, "Output",
  CellTags->"RelationToMatrix"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[346515, 15069, 70, 1, 31, "ObjectName",
  CellTags->"RemoveDuplicates"],
Cell[346588, 15072, 67, 1, 74, "Highlight",
  CellTags->"RemoveDuplicates"],
Cell[346658, 15075, 168, 6, 43, "Usage",
  CellTags->"RemoveDuplicates"],
Cell[346829, 15083, 236, 9, 58, "Notes",
  CellTags->"RemoveDuplicates"],
Cell[347068, 15094, 186, 5, 33, "Notes",
  CellTags->"RemoveDuplicates"],
Cell[347257, 15101, 278, 8, 54, "Notes",
  CellTags->"RemoveDuplicates"],

Cell[CellGroupData[{
Cell[347560, 15113, 74, 1, 59, "ExampleSection",
  CellTags->"RemoveDuplicates"],
Cell[347637, 15116, 79, 1, 70, "ExampleText",
  CellTags->"RemoveDuplicates"],

Cell[CellGroupData[{
Cell[347741, 15121, 97, 2, 70, "Input",
  CellTags->"RemoveDuplicates"],
Cell[347841, 15125, 121, 3, 70, "Output",
  CellTags->"RemoveDuplicates"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347999, 15133, 109, 3, 70, "Input",
  CellTags->"RemoveDuplicates"],
Cell[348111, 15138, 103, 3, 70, "Output",
  CellTags->"RemoveDuplicates"]
}, Open  ]],

Cell[CellGroupData[{
Cell[348251, 15146, 120, 3, 70, "Input",
  CellTags->"RemoveDuplicates"],
Cell[348374, 15151, 119, 3, 70, "Output",
  CellTags->"RemoveDuplicates"]
}, Open  ]],

Cell[CellGroupData[{
Cell[348530, 15159, 145, 3, 70, "Input",
  CellTags->"RemoveDuplicates"],
Cell[348678, 15164, 123, 3, 70, "Output",
  CellTags->"RemoveDuplicates"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[348862, 15174, 62, 1, 31, "ObjectName",
  CellTags->"RemoveVertex"],
Cell[348927, 15177, 63, 1, 74, "Highlight",
  CellTags->"RemoveVertex"],
Cell[348993, 15180, 189, 8, 43, "Usage",
  CellTags->"RemoveVertex"],
Cell[349185, 15190, 135, 5, 33, "Notes",
  CellTags->"RemoveVertex"],
Cell[349323, 15197, 155, 7, 33, "Notes",
  CellTags->"RemoveVertex"],

Cell[CellGroupData[{
Cell[349503, 15208, 70, 1, 59, "ExampleSection",
  CellTags->"RemoveVertex"],
Cell[349576, 15211, 113, 2, 70, "ExampleText",
  CellTags->"RemoveVertex"],

Cell[CellGroupData[{
Cell[349714, 15217, 86, 2, 70, "Input",
  CellTags->"RemoveVertex"],
Cell[349803, 15221, 328, 10, 70, "Output",
  CellTags->"RemoveVertex"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350168, 15236, 113, 3, 70, "Input",
  CellTags->"RemoveVertex"],
Cell[350284, 15241, 284, 8, 70, "Output",
  CellTags->"RemoveVertex"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350605, 15254, 168, 4, 70, "Input",
  CellTags->"RemoveVertex"],
Cell[350776, 15260, 111, 3, 70, "Output",
  CellTags->"RemoveVertex"],
Cell[350890, 15265, 99, 3, 70, "Output",
  CellTags->"RemoveVertex"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[351050, 15275, 64, 1, 42, "ObjectName",
  CellTags->"RenumberRules"],
Cell[351117, 15278, 64, 1, 74, "Highlight",
  CellTags->"RenumberRules"],
Cell[351184, 15281, 241, 8, 64, "Usage",
  CellTags->"RenumberRules"],
Cell[351428, 15291, 273, 10, 80, "Notes",
  CellTags->"RenumberRules"],
Cell[351704, 15303, 157, 7, 33, "Notes",
  CellTags->"RenumberRules"],
Cell[351864, 15312, 172, 5, 33, "Notes",
  CellTags->"RenumberRules"],
Cell[352039, 15319, 162, 7, 33, "Notes",
  CellTags->"RenumberRules"],

Cell[CellGroupData[{
Cell[352226, 15330, 71, 1, 59, "ExampleSection",
  CellTags->"RenumberRules"],
Cell[352300, 15333, 82, 1, 70, "ExampleText",
  CellTags->"RenumberRules"],

Cell[CellGroupData[{
Cell[352407, 15338, 98, 2, 70, "Input",
  CellTags->"RenumberRules"],
Cell[352508, 15342, 470, 8, 70, "Output",
  CellTags->"RenumberRules"]
}, Open  ]],
Cell[352993, 15353, 121, 3, 70, "Input",
  CellTags->"RenumberRules"],

Cell[CellGroupData[{
Cell[353139, 15360, 102, 3, 70, "Input",
  CellTags->"RenumberRules"],
Cell[353244, 15365, 183, 4, 70, "Output",
  CellTags->"RenumberRules"]
}, Open  ]],

Cell[CellGroupData[{
Cell[353464, 15374, 137, 3, 70, "Input",
  CellTags->"RenumberRules"],
Cell[353604, 15379, 132, 3, 70, "Output",
  CellTags->"RenumberRules"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[353797, 15389, 62, 1, 42, "ObjectName",
  CellTags->"ReplaceParts"],
Cell[353862, 15392, 63, 1, 74, "Highlight",
  CellTags->"ReplaceParts"],
Cell[353928, 15395, 150, 4, 43, "Usage",
  CellTags->"ReplaceParts"],
Cell[354081, 15401, 67, 1, 33, "Notes",
  CellTags->"ReplaceParts"]
}, Open  ]],

Cell[CellGroupData[{
Cell[354185, 15407, 62, 1, 42, "ObjectName",
  CellTags->"ReverseGraph"],
Cell[354250, 15410, 63, 1, 74, "Highlight",
  CellTags->"ReverseGraph"],
Cell[354316, 15413, 160, 6, 43, "Usage",
  CellTags->"ReverseGraph"],
Cell[354479, 15421, 126, 4, 33, "Notes",
  CellTags->"ReverseGraph"],
Cell[354608, 15427, 255, 11, 33, "Notes",
  CellTags->"ReverseGraph"],

Cell[CellGroupData[{
Cell[354888, 15442, 70, 1, 59, "ExampleSection",
  CellTags->"ReverseGraph"],
Cell[354961, 15445, 81, 1, 70, "ExampleText",
  CellTags->"ReverseGraph"],

Cell[CellGroupData[{
Cell[355067, 15450, 87, 2, 70, "Input",
  CellTags->"ReverseGraph"],
Cell[355157, 15454, 285, 8, 70, "Output",
  CellTags->"ReverseGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[355479, 15467, 102, 3, 70, "Input",
  CellTags->"ReverseGraph"],
Cell[355584, 15472, 285, 8, 70, "Output",
  CellTags->"ReverseGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[355906, 15485, 131, 3, 70, "Input",
  CellTags->"ReverseGraph"],
Cell[356040, 15490, 410, 11, 70, "Output",
  CellTags->"ReverseGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[356511, 15508, 60, 1, 42, "ObjectName",
  CellTags->"RightIdealT"],
Cell[356574, 15511, 62, 1, 74, "Highlight",
  CellTags->"RightIdealT"],
Cell[356639, 15514, 170, 4, 43, "Usage",
  CellTags->"RightIdealT"],
Cell[356812, 15520, 78, 1, 33, "Notes",
  CellTags->"RightIdealT"],
Cell[356893, 15523, 252, 11, 33, "Notes",
  CellTags->"RightIdealT"],

Cell[CellGroupData[{
Cell[357170, 15538, 69, 1, 59, "ExampleSection",
  CellTags->"RightIdealT"],
Cell[357242, 15541, 136, 4, 70, "ExampleText",
  CellTags->"RightIdealT"],
Cell[357381, 15547, 113, 3, 70, "Input",
  CellTags->"RightIdealT"],

Cell[CellGroupData[{
Cell[357519, 15554, 117, 3, 70, "Input",
  CellTags->"RightIdealT"],
Cell[357639, 15559, 122, 3, 70, "Output",
  CellTags->"RightIdealT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[357798, 15567, 117, 3, 70, "Input",
  CellTags->"RightIdealT"],
Cell[357918, 15572, 201, 4, 70, "Output",
  CellTags->"RightIdealT"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[358180, 15583, 60, 1, 31, "ObjectName",
  CellTags->"RightNullQT"],
Cell[358243, 15586, 62, 1, 74, "Highlight",
  CellTags->"RightNullQT"],
Cell[358308, 15589, 218, 8, 43, "Usage",
  CellTags->"RightNullQT"],
Cell[358529, 15599, 432, 19, 33, "Notes",
  CellTags->"RightNullQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[358998, 15623, 60, 1, 42, "ObjectName",
  CellTags->"RightNullSG"],
Cell[359061, 15626, 62, 1, 74, "Highlight",
  CellTags->"RightNullSG"],
Cell[359126, 15629, 164, 6, 43, "Usage",
  CellTags->"RightNullSG"],
Cell[359293, 15637, 78, 1, 33, "Notes",
  CellTags->"RightNullSG"],
Cell[359374, 15640, 473, 19, 33, "Notes",
  CellTags->"RightNullSG"],

Cell[CellGroupData[{
Cell[359872, 15663, 69, 1, 59, "ExampleSection",
  CellTags->"RightNullSG"],
Cell[359944, 15666, 154, 4, 70, "ExampleText",
  CellTags->"RightNullSG"],
Cell[360101, 15672, 94, 2, 70, "Input",
  CellTags->"RightNullSG"],

Cell[CellGroupData[{
Cell[360220, 15678, 100, 3, 70, "Input",
  CellTags->"RightNullSG"],
Cell[360323, 15683, 123, 3, 70, "Output",
  CellTags->"RightNullSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[360507, 15693, 58, 1, 42, "ObjectName",
  CellTags->"RightOneQT"],
Cell[360568, 15696, 61, 1, 74, "Highlight",
  CellTags->"RightOneQT"],
Cell[360632, 15699, 220, 8, 43, "Usage",
  CellTags->"RightOneQT"],
Cell[360855, 15709, 431, 19, 33, "Notes",
  CellTags->"RightOneQT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[361323, 15733, 58, 1, 42, "ObjectName",
  CellTags->"RightOneSG"],
Cell[361384, 15736, 61, 1, 74, "Highlight",
  CellTags->"RightOneSG"],
Cell[361448, 15739, 168, 6, 43, "Usage",
  CellTags->"RightOneSG"],
Cell[361619, 15747, 77, 1, 33, "Notes",
  CellTags->"RightOneSG"],
Cell[361699, 15750, 431, 19, 33, "Notes",
  CellTags->"RightOneSG"],

Cell[CellGroupData[{
Cell[362155, 15773, 68, 1, 59, "ExampleSection",
  CellTags->"RightOneSG"],
Cell[362226, 15776, 140, 4, 70, "ExampleText",
  CellTags->"RightOneSG"],
Cell[362369, 15782, 92, 2, 70, "Input",
  CellTags->"RightOneSG"],

Cell[CellGroupData[{
Cell[362486, 15788, 97, 3, 70, "Input",
  CellTags->"RightOneSG"],
Cell[362586, 15793, 97, 3, 70, "Output",
  CellTags->"RightOneSG"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[362744, 15803, 54, 1, 42, "ObjectName",
  CellTags->"RootList"],
Cell[362801, 15806, 59, 1, 74, "Highlight",
  CellTags->"RootList"],
Cell[362863, 15809, 360, 13, 45, "Usage",
  CellTags->"RootList"],
Cell[363226, 15824, 131, 5, 33, "Notes",
  CellTags->"RootList"],
Cell[363360, 15831, 265, 11, 33, "Notes",
  CellTags->"RootList"],

Cell[CellGroupData[{
Cell[363650, 15846, 66, 1, 59, "ExampleSection",
  CellTags->"RootList"],
Cell[363719, 15849, 79, 1, 70, "ExampleText",
  CellTags->"RootList"],

Cell[CellGroupData[{
Cell[363823, 15854, 116, 3, 70, "Input",
  CellTags->"RootList"],
Cell[363942, 15859, 128, 3, 70, "Output",
  CellTags->"RootList"]
}, Open  ]],

Cell[CellGroupData[{
Cell[364107, 15867, 93, 3, 70, "Input",
  CellTags->"RootList"],
Cell[364203, 15872, 92, 3, 70, "Output",
  CellTags->"RootList"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[364356, 15882, 52, 1, 42, "ObjectName",
  CellTags->"RShiftT"],
Cell[364411, 15885, 58, 1, 74, "Highlight",
  CellTags->"RShiftT"],
Cell[364472, 15888, 173, 6, 43, "Usage",
  CellTags->"RShiftT"],
Cell[364648, 15896, 486, 19, 33, "Notes",
  CellTags->"RShiftT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[365171, 15920, 62, 1, 42, "ObjectName",
  CellTags->"RulesToPairs"],
Cell[365236, 15923, 63, 1, 74, "Highlight",
  CellTags->"RulesToPairs"],
Cell[365302, 15926, 138, 4, 43, "Usage",
  CellTags->"RulesToPairs"],
Cell[365443, 15932, 565, 19, 33, "Notes",
  CellTags->"RulesToPairs"],

Cell[CellGroupData[{
Cell[366033, 15955, 70, 1, 59, "ExampleSection",
  CellTags->"RulesToPairs"],
Cell[366106, 15958, 100, 1, 70, "ExampleText",
  CellTags->"RulesToPairs"],
Cell[366209, 15961, 241, 5, 70, "Input",
  CellTags->"RulesToPairs"],

Cell[CellGroupData[{
Cell[366475, 15970, 102, 3, 70, "Input",
  CellTags->"RulesToPairs"],
Cell[366580, 15975, 173, 4, 70, "Output",
  CellTags->"RulesToPairs"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[366814, 15986, 72, 1, 31, "ObjectName",
  CellTags->"SeedConfiguration"],
Cell[366889, 15989, 68, 1, 74, "Highlight",
  CellTags->"SeedConfiguration"],
Cell[366960, 15992, 180, 4, 43, "Usage",
  CellTags->"SeedConfiguration"],
Cell[367143, 15998, 247, 9, 58, "Notes",
  CellTags->"SeedConfiguration"],
Cell[367393, 16009, 132, 4, 33, "Notes",
  CellTags->"SeedConfiguration"],
Cell[367528, 16015, 109, 1, 33, "Notes",
  CellTags->"SeedConfiguration"],
Cell[367640, 16018, 262, 11, 33, "Notes",
  CellTags->"SeedConfiguration"],

Cell[CellGroupData[{
Cell[367927, 16033, 75, 1, 59, "ExampleSection",
  CellTags->"SeedConfiguration"],
Cell[368005, 16036, 81, 1, 70, "ExampleText",
  CellTags->"SeedConfiguration"],

Cell[CellGroupData[{
Cell[368111, 16041, 102, 2, 70, "Input",
  CellTags->"SeedConfiguration"],
Cell[368216, 16045, 122, 3, 70, "Output",
  CellTags->"SeedConfiguration"]
}, Open  ]],

Cell[CellGroupData[{
Cell[368375, 16053, 114, 2, 70, "Input",
  CellTags->"SeedConfiguration"],
Cell[368492, 16057, 122, 3, 70, "Output",
  CellTags->"SeedConfiguration"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[368675, 16067, 64, 1, 42, "ObjectName",
  CellTags->"SelectOptions"],
Cell[368742, 16070, 64, 1, 74, "Highlight",
  CellTags->"SelectOptions"],
Cell[368809, 16073, 222, 8, 43, "Usage",
  CellTags->"SelectOptions"],
Cell[369034, 16083, 192, 6, 33, "Notes",
  CellTags->"SelectOptions"]
}, Open  ]],

Cell[CellGroupData[{
Cell[369263, 16094, 56, 1, 42, "ObjectName",
  CellTags->"SelectorQ"],
Cell[369322, 16097, 60, 1, 74, "Highlight",
  CellTags->"SelectorQ"],
Cell[369385, 16100, 229, 8, 43, "Usage",
  CellTags->"SelectorQ"],
Cell[369617, 16110, 231, 9, 33, "Notes",
  CellTags->"SelectorQ"],
Cell[369851, 16121, 162, 7, 33, "Notes",
  CellTags->"SelectorQ"],

Cell[CellGroupData[{
Cell[370038, 16132, 67, 1, 59, "ExampleSection",
  CellTags->"SelectorQ"],
Cell[370108, 16135, 174, 6, 70, "ExampleText",
  CellTags->"SelectorQ"],
Cell[370285, 16143, 137, 3, 70, "Input",
  CellTags->"SelectorQ"],

Cell[CellGroupData[{
Cell[370447, 16150, 115, 3, 70, "Input",
  CellTags->"SelectorQ"],
Cell[370565, 16155, 88, 3, 70, "Output",
  CellTags->"SelectorQ"]
}, Open  ]],

Cell[CellGroupData[{
Cell[370690, 16163, 114, 3, 70, "Input",
  CellTags->"SelectorQ"],
Cell[370807, 16168, 89, 3, 70, "Output",
  CellTags->"SelectorQ"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[370957, 16178, 62, 1, 42, "ObjectName",
  CellTags->"ShortestPath"],
Cell[371022, 16181, 63, 1, 74, "Highlight",
  CellTags->"ShortestPath"],
Cell[371088, 16184, 278, 10, 64, "Usage",
  CellTags->"ShortestPath"],
Cell[371369, 16196, 228, 9, 58, "Notes",
  CellTags->"ShortestPath"],
Cell[371600, 16207, 137, 5, 33, "Notes",
  CellTags->"ShortestPath"],
Cell[371740, 16214, 250, 11, 33, "Notes",
  CellTags->"ShortestPath"],
Cell[371993, 16227, 379, 15, 33, "Notes",
  CellTags->"ShortestPath"],

Cell[CellGroupData[{
Cell[372397, 16246, 70, 1, 59, "ExampleSection",
  CellTags->"ShortestPath"],
Cell[372470, 16249, 127, 4, 70, "ExampleText",
  CellTags->"ShortestPath"],

Cell[CellGroupData[{
Cell[372622, 16257, 121, 3, 70, "Input",
  CellTags->"ShortestPath"],
Cell[372746, 16262, 438, 11, 70, "Output",
  CellTags->"ShortestPath"]
}, Open  ]],

Cell[CellGroupData[{
Cell[373221, 16278, 104, 3, 70, "Input",
  CellTags->"ShortestPath"],
Cell[373328, 16283, 177, 4, 70, "Output",
  CellTags->"ShortestPath"]
}, Open  ]],

Cell[CellGroupData[{
Cell[373542, 16292, 123, 3, 70, "Input",
  CellTags->"ShortestPath"],
Cell[373668, 16297, 211, 4, 70, "Output",
  CellTags->"ShortestPath"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[373940, 16308, 56, 1, 42, "ObjectName",
  CellTags->"ShowArray"],
Cell[373999, 16311, 60, 1, 74, "Highlight",
  CellTags->"ShowArray"],
Cell[374062, 16314, 231, 8, 43, "Usage",
  CellTags->"ShowArray"],
Cell[374296, 16324, 191, 7, 33, "Notes",
  CellTags->"ShowArray"],
Cell[374490, 16333, 162, 7, 33, "Notes",
  CellTags->"ShowArray"],

Cell[CellGroupData[{
Cell[374677, 16344, 67, 1, 59, "ExampleSection",
  CellTags->"ShowArray"],
Cell[374747, 16347, 75, 1, 70, "ExampleText",
  CellTags->"ShowArray"],
Cell[374825, 16350, 238, 5, 70, "Input",
  CellTags->"ShowArray"],

Cell[CellGroupData[{
Cell[375088, 16359, 76, 2, 70, "Input"],
Cell[375167, 16363, 8524, 641, 70, 8369, 636, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[383752, 17011, 52, 1, 31, "ObjectName",
  CellTags->"Shuffle"],
Cell[383807, 17014, 58, 1, 74, "Highlight",
  CellTags->"Shuffle"],
Cell[383868, 17017, 200, 9, 43, "Usage",
  CellTags->"Shuffle"],
Cell[384071, 17028, 240, 11, 33, "Notes",
  CellTags->"Shuffle"],
Cell[384314, 17041, 270, 11, 33, "Notes",
  CellTags->"Shuffle"],

Cell[CellGroupData[{
Cell[384609, 17056, 65, 1, 59, "ExampleSection",
  CellTags->"Shuffle"],
Cell[384677, 17059, 105, 2, 70, "ExampleText",
  CellTags->"Shuffle"],

Cell[CellGroupData[{
Cell[384807, 17065, 90, 2, 70, "Input",
  CellTags->"Shuffle"],
Cell[384900, 17069, 247, 4, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[385208, 17080, 72, 1, 31, "ObjectName",
  CellTags->"SimplifyEquations"],
Cell[385283, 17083, 68, 1, 74, "Highlight",
  CellTags->"SimplifyEquations"],
Cell[385354, 17086, 226, 6, 64, "Usage",
  CellTags->"SimplifyEquations"],
Cell[385583, 17094, 232, 9, 58, "Notes",
  CellTags->"SimplifyEquations"],
Cell[385818, 17105, 275, 9, 54, "Notes",
  CellTags->"SimplifyEquations"],
Cell[386096, 17116, 288, 11, 33, "Notes",
  CellTags->"SimplifyEquations"],

Cell[CellGroupData[{
Cell[386409, 17131, 75, 1, 59, "ExampleSection",
  CellTags->"SimplifyEquations"],
Cell[386487, 17134, 141, 4, 70, "ExampleText",
  CellTags->"SimplifyEquations"],
Cell[386631, 17140, 161, 4, 70, "Input",
  CellTags->"SimplifyEquations"],

Cell[CellGroupData[{
Cell[386817, 17148, 74, 2, 70, "Input"],
Cell[386894, 17152, 61, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[386992, 17159, 107, 2, 70, "Input"],
Cell[387102, 17163, 1749, 37, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[388912, 17207, 80, 1, 42, "ObjectName",
  CellTags->"SimplifyRewriteSystem"],
Cell[388995, 17210, 72, 1, 74, "Highlight",
  CellTags->"SimplifyRewriteSystem"],
Cell[389070, 17213, 211, 6, 43, "Usage",
  CellTags->"SimplifyRewriteSystem"],
Cell[389284, 17221, 240, 9, 58, "Notes",
  CellTags->"SimplifyRewriteSystem"],
Cell[389527, 17232, 254, 6, 54, "Notes",
  CellTags->"SimplifyRewriteSystem"],
Cell[389784, 17240, 218, 6, 54, "Notes",
  CellTags->"SimplifyRewriteSystem"],
Cell[390005, 17248, 151, 6, 33, "Notes"],

Cell[CellGroupData[{
Cell[390181, 17258, 79, 1, 59, "ExampleSection",
  CellTags->"SimplifyRewriteSystem"],
Cell[390263, 17261, 199, 5, 70, "ExampleText",
  CellTags->"SimplifyRewriteSystem"],
Cell[390465, 17268, 165, 4, 70, "Input",
  CellTags->"SimplifyRewriteSystem"],

Cell[CellGroupData[{
Cell[390655, 17276, 74, 2, 70, "Input"],
Cell[390732, 17280, 61, 2, 70, "Output"]
}, Open  ]],
Cell[390808, 17285, 98, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[390931, 17291, 77, 2, 70, "Input"],
Cell[391011, 17295, 2056, 43, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[393128, 17345, 52, 1, 42, "ObjectName",
  CellTags->"SolveSG"],
Cell[393183, 17348, 58, 1, 74, "Highlight",
  CellTags->"SolveSG"],
Cell[393244, 17351, 237, 8, 64, "Usage",
  CellTags->"SolveSG"],
Cell[393484, 17361, 308, 10, 82, "Notes",
  CellTags->"SolveSG"],
Cell[393795, 17373, 193, 7, 33, "Notes",
  CellTags->"SolveSG"],
Cell[393991, 17382, 158, 7, 33, "Notes",
  CellTags->"SolveSG"],
Cell[394152, 17391, 240, 11, 33, "Notes",
  CellTags->"SolveSG"],

Cell[CellGroupData[{
Cell[394417, 17406, 65, 1, 59, "ExampleSection",
  CellTags->"SolveSG"],
Cell[394485, 17409, 93, 1, 70, "ExampleText",
  CellTags->"SolveSG"],

Cell[CellGroupData[{
Cell[394603, 17414, 89, 2, 70, "Input",
  CellTags->"SolveSG"],
Cell[394695, 17418, 141, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[394873, 17426, 174, 4, 70, "Input"],
Cell[395050, 17432, 72, 2, 70, "Output"],
Cell[395125, 17436, 72, 2, 70, "Output"]
}, Open  ]],
Cell[395212, 17441, 108, 2, 70, "ExampleText",
  CellTags->"SolveSG"],
Cell[395323, 17445, 90, 2, 70, "Input",
  CellTags->"SolveSG"],

Cell[CellGroupData[{
Cell[395438, 17451, 176, 4, 70, "Input"],
Cell[395617, 17457, 96, 2, 70, "Output"],
Cell[395716, 17461, 62, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[395839, 17470, 64, 1, 31, "ObjectName",
  CellTags->"StaircasePlot"],
Cell[395906, 17473, 64, 1, 74, "Highlight",
  CellTags->"StaircasePlot"],
Cell[395973, 17476, 171, 4, 43, "Usage",
  CellTags->"StaircasePlot"],
Cell[396147, 17482, 278, 10, 80, "Notes",
  CellTags->"StaircasePlot"],
Cell[396428, 17494, 128, 5, 33, "Notes",
  CellTags->"StaircasePlot"],
Cell[396559, 17501, 440, 19, 33, "Notes",
  CellTags->"StaircasePlot"],

Cell[CellGroupData[{
Cell[397024, 17524, 71, 1, 59, "ExampleSection",
  CellTags->"StaircasePlot"],
Cell[397098, 17527, 92, 1, 70, "ExampleText",
  CellTags->"StaircasePlot"],

Cell[CellGroupData[{
Cell[397215, 17532, 180, 4, 70, "Input",
  CellTags->"StaircasePlot"],
Cell[397398, 17538, 1583, 103, 70, 1430, 98, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[399042, 17648, 50, 1, 31, "ObjectName",
  CellTags->"Status"],
Cell[399095, 17651, 57, 1, 74, "Highlight",
  CellTags->"Status"],
Cell[399155, 17654, 139, 4, 43, "Usage",
  CellTags->"Status"],

Cell[CellGroupData[{
Cell[399319, 17662, 64, 1, 59, "ExampleSection",
  CellTags->"Status"],
Cell[399386, 17665, 62, 1, 70, "ExampleText",
  CellTags->"Status"],

Cell[CellGroupData[{
Cell[399473, 17670, 73, 2, 70, "Input",
  CellTags->"Status"],
Cell[399549, 17674, 1282, 21, 70, "Print"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[400892, 17702, 92, 1, 42, "ObjectName",
  CellTags->"StronglyConnectedComponents"],
Cell[400987, 17705, 78, 1, 74, "Highlight",
  CellTags->"StronglyConnectedComponents"],
Cell[401068, 17708, 299, 6, 85, "Usage",
  CellTags->"StronglyConnectedComponents"],
Cell[401370, 17716, 316, 10, 80, "Notes",
  CellTags->"StronglyConnectedComponents"],
Cell[401689, 17728, 210, 6, 54, "Notes",
  CellTags->"StronglyConnectedComponents"],
Cell[401902, 17736, 96, 1, 33, "Notes",
  CellTags->"StronglyConnectedComponents"],
Cell[402001, 17739, 504, 19, 33, "Notes",
  CellTags->"StronglyConnectedComponents"],

Cell[CellGroupData[{
Cell[402530, 17762, 85, 1, 59, "ExampleSection",
  CellTags->"StronglyConnectedComponents"],
Cell[402618, 17765, 117, 1, 48, "ExampleText",
  CellTags->"StronglyConnectedComponents"],
Cell[402738, 17768, 246, 6, 60, "Input",
  CellTags->"StronglyConnectedComponents"],

Cell[CellGroupData[{
Cell[403009, 17778, 131, 3, 37, "Input",
  CellTags->"StronglyConnectedComponents"],
Cell[403143, 17783, 141, 3, 30, "Output",
  CellTags->"StronglyConnectedComponents"]
}, Open  ]],

Cell[CellGroupData[{
Cell[403321, 17791, 156, 3, 37, "Input",
  CellTags->"StronglyConnectedComponents"],
Cell[403480, 17796, 121, 3, 30, "Output",
  CellTags->"StronglyConnectedComponents"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[403662, 17806, 54, 1, 42, "ObjectName",
  CellTags->"SubGraph"],
Cell[403719, 17809, 59, 1, 74, "Highlight",
  CellTags->"SubGraph"],
Cell[403781, 17812, 204, 8, 43, "Usage",
  CellTags->"SubGraph"],
Cell[403988, 17822, 225, 9, 58, "Notes",
  CellTags->"SubGraph"],
Cell[404216, 17833, 118, 4, 33, "Notes",
  CellTags->"SubGraph"],
Cell[404337, 17839, 251, 11, 33, "Notes",
  CellTags->"SubGraph"],

Cell[CellGroupData[{
Cell[404613, 17854, 66, 1, 59, "ExampleSection",
  CellTags->"SubGraph"],
Cell[404682, 17857, 122, 4, 70, "ExampleText",
  CellTags->"SubGraph"],

Cell[CellGroupData[{
Cell[404829, 17865, 83, 2, 70, "Input",
  CellTags->"SubGraph"],
Cell[404915, 17869, 301, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[405253, 17883, 99, 2, 70, "Input"],
Cell[405355, 17887, 249, 7, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[405641, 17899, 72, 2, 70, "Input"],
Cell[405716, 17903, 78, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[405831, 17910, 142, 3, 70, "Input"],
Cell[405976, 17915, 69, 2, 70, "Output"],
Cell[406048, 17919, 69, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[406178, 17928, 52, 1, 31, "ObjectName",
  CellTags->"SubsetQ"],
Cell[406233, 17931, 58, 1, 74, "Highlight",
  CellTags->"SubsetQ"],
Cell[406294, 17934, 203, 8, 43, "Usage",
  CellTags->"SubsetQ"],
Cell[406500, 17944, 126, 5, 33, "Notes",
  CellTags->"SubsetQ"],
Cell[406629, 17951, 156, 7, 33, "Notes",
  CellTags->"SubsetQ"],

Cell[CellGroupData[{
Cell[406810, 17962, 65, 1, 59, "ExampleSection",
  CellTags->"SubsetQ"],
Cell[406878, 17965, 78, 1, 70, "ExampleText",
  CellTags->"SubsetQ"],

Cell[CellGroupData[{
Cell[406981, 17970, 91, 2, 70, "Input",
  CellTags->"SubsetQ"],
Cell[407075, 17974, 63, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[407175, 17981, 91, 2, 70, "Input",
  CellTags->"SubsetQ"],
Cell[407269, 17985, 64, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[407394, 17994, 58, 1, 42, "ObjectName",
  CellTags->"SymbolList"],
Cell[407455, 17997, 61, 1, 74, "Highlight",
  CellTags->"SymbolList"],
Cell[407519, 18000, 272, 10, 43, "Usage",
  CellTags->"SymbolList"],
Cell[407794, 18012, 114, 4, 33, "Notes",
  CellTags->"SymbolList"],

Cell[CellGroupData[{
Cell[407933, 18020, 68, 1, 59, "ExampleSection",
  CellTags->"SymbolList"],
Cell[408004, 18023, 67, 1, 70, "ExampleText",
  CellTags->"SymbolList"],

Cell[CellGroupData[{
Cell[408096, 18028, 115, 5, 70, "Input",
  CellTags->"SymbolList"],
Cell[408214, 18035, 94, 2, 70, "Output"],
Cell[408311, 18039, 250, 7, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[408622, 18053, 70, 1, 42, "ObjectName",
  CellTags->"SymmetricGroupSG"],
Cell[408695, 18056, 67, 1, 74, "Highlight",
  CellTags->"SymmetricGroupSG"],
Cell[408765, 18059, 148, 4, 43, "Usage",
  CellTags->"SymmetricGroupSG"],
Cell[408916, 18065, 254, 9, 33, "Notes",
  CellTags->"SymmetricGroupSG"],
Cell[409173, 18076, 389, 15, 33, "Notes",
  CellTags->"SymmetricGroupSG"],

Cell[CellGroupData[{
Cell[409587, 18095, 74, 1, 59, "ExampleSection",
  CellTags->"SymmetricGroupSG"],
Cell[409664, 18098, 87, 1, 70, "ExampleText",
  CellTags->"SymmetricGroupSG"],

Cell[CellGroupData[{
Cell[409776, 18103, 93, 2, 70, "Input",
  CellTags->"SymmetricGroupSG"],
Cell[409872, 18107, 458, 8, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[410391, 18122, 52, 1, 42, "ObjectName",
  CellTags->"TableSG"],
Cell[410446, 18125, 58, 1, 74, "Highlight",
  CellTags->"TableSG"],
Cell[410507, 18128, 157, 4, 43, "Usage",
  CellTags->"TableSG"],
Cell[410667, 18134, 195, 7, 33, "Notes",
  CellTags->"TableSG"],
Cell[410865, 18143, 155, 7, 33, "Notes",
  CellTags->"TableSG"],

Cell[CellGroupData[{
Cell[411045, 18154, 65, 1, 59, "ExampleSection",
  CellTags->"TableSG"],
Cell[411113, 18157, 117, 4, 70, "ExampleText",
  CellTags->"TableSG"],
Cell[411233, 18163, 152, 4, 70, "Input",
  CellTags->"TableSG"],

Cell[CellGroupData[{
Cell[411410, 18171, 74, 2, 70, "Input"],
Cell[411487, 18175, 1160, 25, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[412708, 18207, 56, 1, 42, "ObjectName",
  CellTags->"ToAdjList"],
Cell[412767, 18210, 60, 1, 74, "Highlight",
  CellTags->"ToAdjList"],
Cell[412830, 18213, 166, 6, 43, "Usage",
  CellTags->"ToAdjList"],
Cell[412999, 18221, 123, 4, 33, "Notes",
  CellTags->"ToAdjList"],
Cell[413125, 18227, 151, 4, 33, "Notes",
  CellTags->"ToAdjList"],
Cell[413279, 18233, 346, 15, 33, "Notes",
  CellTags->"ToAdjList"],

Cell[CellGroupData[{
Cell[413650, 18252, 67, 1, 59, "ExampleSection",
  CellTags->"ToAdjList"],
Cell[413720, 18255, 93, 1, 70, "ExampleText",
  CellTags->"ToAdjList"],

Cell[CellGroupData[{
Cell[413838, 18260, 90, 2, 70, "Input",
  CellTags->"ToAdjList"],
Cell[413931, 18264, 434, 11, 70, "Output",
  CellTags->"ToAdjList"]
}, Open  ]],

Cell[CellGroupData[{
Cell[414402, 18280, 131, 3, 70, "Input",
  CellTags->"ToAdjList"],
Cell[414536, 18285, 434, 15, 70, "Output",
  CellTags->"ToAdjList"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[415031, 18307, 60, 1, 31, "ObjectName",
  CellTags->"ToAdjMatrix"],
Cell[415094, 18310, 62, 1, 74, "Highlight",
  CellTags->"ToAdjMatrix"],
Cell[415159, 18313, 172, 6, 43, "Usage",
  CellTags->"ToAdjMatrix"],
Cell[415334, 18321, 141, 4, 33, "Notes",
  CellTags->"ToAdjMatrix"],
Cell[415478, 18327, 344, 15, 33, "Notes",
  CellTags->"ToAdjMatrix"],

Cell[CellGroupData[{
Cell[415847, 18346, 69, 1, 59, "ExampleSection",
  CellTags->"ToAdjMatrix"],
Cell[415919, 18349, 96, 1, 70, "ExampleText",
  CellTags->"ToAdjMatrix"],

Cell[CellGroupData[{
Cell[416040, 18354, 92, 2, 70, "Input",
  CellTags->"ToAdjMatrix"],
Cell[416135, 18358, 409, 10, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[416581, 18373, 108, 2, 70, "Input"],
Cell[416692, 18377, 649, 14, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[417402, 18398, 60, 1, 31, "ObjectName",
  CellTags->"ToBitVector"],
Cell[417465, 18401, 62, 1, 74, "Highlight",
  CellTags->"ToBitVector"],
Cell[417530, 18404, 206, 8, 43, "Usage",
  CellTags->"ToBitVector"],
Cell[417739, 18414, 95, 1, 33, "Notes",
  CellTags->"ToBitVector"],
Cell[417837, 18417, 170, 7, 33, "Notes",
  CellTags->"ToBitVector"],

Cell[CellGroupData[{
Cell[418032, 18428, 69, 1, 59, "ExampleSection",
  CellTags->"ToBitVector"],
Cell[418104, 18431, 99, 1, 70, "ExampleText",
  CellTags->"ToBitVector"],

Cell[CellGroupData[{
Cell[418228, 18436, 92, 2, 70, "Input",
  CellTags->"ToBitVector"],
Cell[418323, 18440, 140, 3, 70, "Output",
  CellTags->"ToBitVector"]
}, Open  ]],

Cell[CellGroupData[{
Cell[418500, 18448, 127, 3, 70, "Input",
  CellTags->"ToBitVector"],
Cell[418630, 18453, 183, 4, 70, "Output",
  CellTags->"ToBitVector"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[418874, 18464, 56, 1, 42, "ObjectName",
  CellTags->"ToClasses"],
Cell[418933, 18467, 60, 1, 74, "Highlight",
  CellTags->"ToClasses"],
Cell[418996, 18470, 236, 8, 43, "Usage",
  CellTags->"ToClasses"],
Cell[419235, 18480, 252, 9, 58, "Notes",
  CellTags->"ToClasses"],
Cell[419490, 18491, 337, 11, 54, "Notes",
  CellTags->"ToClasses"],
Cell[419830, 18504, 156, 6, 33, "Notes"],
Cell[419989, 18512, 263, 11, 33, "Notes",
  CellTags->"ToClasses"],

Cell[CellGroupData[{
Cell[420277, 18527, 67, 1, 59, "ExampleSection",
  CellTags->"ToClasses"],
Cell[420347, 18530, 124, 4, 70, "ExampleText",
  CellTags->"ToClasses"],
Cell[420474, 18536, 139, 3, 70, "Input",
  CellTags->"ToClasses"],

Cell[CellGroupData[{
Cell[420638, 18543, 93, 2, 70, "Input"],
Cell[420734, 18547, 109, 2, 70, "Output"]
}, Open  ]],
Cell[420858, 18552, 90, 1, 70, "ExampleText",
  CellTags->"ToClasses"],

Cell[CellGroupData[{
Cell[420973, 18557, 102, 2, 70, "Input"],
Cell[421078, 18561, 570, 8, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[421685, 18574, 111, 2, 70, "Input"],
Cell[421799, 18578, 109, 2, 70, "Output"]
}, Open  ]],
Cell[421923, 18583, 76, 1, 70, "ExampleText",
  CellTags->"ToClasses"],
Cell[422002, 18586, 86, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[422113, 18592, 113, 2, 70, "Input"],
Cell[422229, 18596, 109, 2, 70, "Output"]
}, Open  ]],
Cell[422353, 18601, 66, 1, 70, "ExampleText",
  CellTags->"ToClasses"],

Cell[CellGroupData[{
Cell[422444, 18606, 110, 2, 70, "Input"],
Cell[422557, 18610, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[422690, 18617, 112, 2, 70, "Input"],
Cell[422805, 18621, 109, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[422975, 18630, 48, 1, 42, "ObjectName",
  CellTags->"ToDAG"],
Cell[423026, 18633, 56, 1, 74, "Highlight",
  CellTags->"ToDAG"],
Cell[423085, 18636, 270, 7, 64, "Usage",
  CellTags->"ToDAG"],
Cell[423358, 18645, 222, 9, 58, "Notes",
  CellTags->"ToDAG"],
Cell[423583, 18656, 486, 19, 33, "Notes",
  CellTags->"ToDAG"],

Cell[CellGroupData[{
Cell[424094, 18679, 63, 1, 59, "ExampleSection",
  CellTags->"ToDAG"],
Cell[424160, 18682, 107, 1, 70, "ExampleText",
  CellTags->"NonTransientGraph"],
Cell[424270, 18685, 237, 6, 70, "Input",
  CellTags->"NonTransientGraph"],

Cell[CellGroupData[{
Cell[424532, 18695, 98, 3, 70, "Input"],
Cell[424633, 18700, 257, 7, 70, "Output"],
Cell[424893, 18709, 99, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[425053, 18718, 58, 1, 42, "ObjectName",
  CellTags->"ToEdgeList"],
Cell[425114, 18721, 61, 1, 74, "Highlight",
  CellTags->"ToEdgeList"],
Cell[425178, 18724, 163, 6, 43, "Usage",
  CellTags->"ToEdgeList"],
Cell[425344, 18732, 345, 15, 33, "Notes",
  CellTags->"ToEdgeList"],

Cell[CellGroupData[{
Cell[425714, 18751, 68, 1, 59, "ExampleSection",
  CellTags->"ToEdgeList"],
Cell[425785, 18754, 105, 1, 70, "ExampleText",
  CellTags->"ToEdgeList"],
Cell[425893, 18757, 358, 7, 70, "Input"],

Cell[CellGroupData[{
Cell[426276, 18768, 85, 2, 70, "Input"],
Cell[426364, 18772, 649, 14, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[427050, 18791, 85, 2, 70, "Input"],
Cell[427138, 18795, 206, 4, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[427405, 18806, 48, 1, 31, "ObjectName",
  CellTags->"ToEps"],
Cell[427456, 18809, 56, 1, 74, "Highlight",
  CellTags->"ToEps"],
Cell[427515, 18812, 202, 8, 43, "Usage",
  CellTags->"ToEps"],
Cell[427720, 18822, 98, 1, 33, "Notes",
  CellTags->"ToEps"],
Cell[427821, 18825, 152, 7, 33, "Notes",
  CellTags->"ToEps"],

Cell[CellGroupData[{
Cell[427998, 18836, 63, 1, 59, "ExampleSection",
  CellTags->"ToEps"],
Cell[428064, 18839, 127, 4, 70, "ExampleText",
  CellTags->"FromEps"],

Cell[CellGroupData[{
Cell[428216, 18847, 100, 3, 70, "Input",
  CellTags->"FromEps"],
Cell[428319, 18852, 69, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[428449, 18861, 70, 1, 31, "ObjectName",
  CellTags->"ToIdentityString"],
Cell[428522, 18864, 67, 1, 74, "Highlight",
  CellTags->"ToIdentityString"],
Cell[428592, 18867, 233, 8, 43, "Usage",
  CellTags->"ToIdentityString"],
Cell[428828, 18877, 289, 11, 33, "Notes",
  CellTags->"ToIdentityString"],

Cell[CellGroupData[{
Cell[429142, 18892, 74, 1, 59, "ExampleSection",
  CellTags->"ToIdentityString"],
Cell[429219, 18895, 83, 1, 70, "ExampleText",
  CellTags->"ToIdentityString"],

Cell[CellGroupData[{
Cell[429327, 18900, 109, 2, 70, "Input",
  CellTags->"ToIdentityString"],
Cell[429439, 18904, 78, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[429578, 18913, 50, 1, 42, "ObjectName",
  CellTags->"ToList"],
Cell[429631, 18916, 57, 1, 74, "Highlight",
  CellTags->"ToList"],
Cell[429691, 18919, 182, 8, 43, "Usage",
  CellTags->"ToList"]
}, Open  ]],

Cell[CellGroupData[{
Cell[429910, 18932, 56, 1, 42, "ObjectName",
  CellTags->"ToTDGraph"],
Cell[429969, 18935, 60, 1, 74, "Highlight",
  CellTags->"ToTDGraph"],
Cell[430032, 18938, 266, 9, 64, "Usage",
  CellTags->"ToTDGraph"],
Cell[430301, 18949, 226, 9, 58, "Notes",
  CellTags->"ToTDGraph"],
Cell[430530, 18960, 77, 1, 33, "Notes",
  CellTags->"ToTDGraph"],
Cell[430610, 18963, 177, 7, 33, "Notes",
  CellTags->"ToTDGraph"],

Cell[CellGroupData[{
Cell[430812, 18974, 67, 1, 59, "ExampleSection",
  CellTags->"ToTDGraph"],
Cell[430882, 18977, 187, 6, 70, "ExampleText",
  CellTags->"ToTDGraph"],

Cell[CellGroupData[{
Cell[431094, 18987, 324, 7, 70, "Input"],
Cell[431421, 18996, 165, 3, 70, "Output"]
}, Open  ]],
Cell[431601, 19002, 90, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[431716, 19008, 64, 1, 70, "Input"],
Cell[431783, 19011, 432, 10, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[432252, 19026, 81, 2, 70, "Input"],
Cell[432336, 19030, 1958, 144, 70, 1805, 139, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[434355, 19181, 70, 1, 42, "ObjectName",
  CellTags->"TransformationSG"],
Cell[434428, 19184, 67, 1, 74, "Highlight",
  CellTags->"TransformationSG"],
Cell[434498, 19187, 186, 6, 43, "Usage",
  CellTags->"TransformationSG"],
Cell[434687, 19195, 254, 8, 33, "Notes",
  CellTags->"TransformationSG"],
Cell[434944, 19205, 384, 15, 33, "Notes",
  CellTags->"TransformationSG"],

Cell[CellGroupData[{
Cell[435353, 19224, 74, 1, 59, "ExampleSection",
  CellTags->"TransformationSG"],
Cell[435430, 19227, 101, 1, 70, "ExampleText",
  CellTags->"TransformationSG"],

Cell[CellGroupData[{
Cell[435556, 19232, 98, 2, 70, "Input",
  CellTags->"TransformationSG"],
Cell[435657, 19236, 414, 6, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[436108, 19247, 74, 2, 70, "Input"],
Cell[436185, 19251, 62, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[436308, 19260, 74, 1, 42, "ObjectName",
  CellTags->"TransientPeriodicT"],
Cell[436385, 19263, 69, 1, 74, "Highlight",
  CellTags->"TransientPeriodicT"],
Cell[436457, 19266, 244, 7, 64, "Usage",
  CellTags->"TransientPeriodicT"],
Cell[436704, 19275, 163, 4, 33, "Notes",
  CellTags->"TransientPeriodicT"],
Cell[436870, 19281, 163, 7, 33, "Notes",
  CellTags->"TransientPeriodicT"],

Cell[CellGroupData[{
Cell[437058, 19292, 76, 1, 59, "ExampleSection",
  CellTags->"TransientPeriodicT"],
Cell[437137, 19295, 160, 4, 70, "ExampleText",
  CellTags->"TransientPeriodicT"],
Cell[437300, 19301, 121, 3, 70, "Input",
  CellTags->"TransientPeriodicT"],

Cell[CellGroupData[{
Cell[437446, 19308, 94, 2, 70, "Input"],
Cell[437543, 19312, 303, 5, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[437883, 19322, 132, 3, 70, "Input"],
Cell[438018, 19327, 467, 15, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[438546, 19349, 72, 1, 31, "ObjectName",
  CellTags->"TransitiveClosure"],
Cell[438621, 19352, 68, 1, 74, "Highlight",
  CellTags->"TransitiveClosure"],
Cell[438692, 19355, 193, 6, 43, "Usage",
  CellTags->"TransitiveClosure"],
Cell[438888, 19363, 238, 9, 58, "Notes",
  CellTags->"TransitiveClosure"],
Cell[439129, 19374, 172, 5, 33, "Notes",
  CellTags->"TransitiveClosure"],
Cell[439304, 19381, 144, 5, 33, "Notes",
  CellTags->"TransitiveClosure"],
Cell[439451, 19388, 402, 15, 33, "Notes",
  CellTags->"TransitiveClosure"],

Cell[CellGroupData[{
Cell[439878, 19407, 75, 1, 59, "ExampleSection",
  CellTags->"TransitiveClosure"],
Cell[439956, 19410, 91, 1, 70, "ExampleText",
  CellTags->"TransitiveClosure"],
Cell[440050, 19413, 348, 6, 70, "Input",
  CellTags->"TransitiveClosure"],

Cell[CellGroupData[{
Cell[440423, 19423, 111, 3, 70, "Input",
  CellTags->"TransitiveClosure"],
Cell[440537, 19428, 682, 15, 70, "Output",
  CellTags->"TransitiveClosure"]
}, Open  ]],

Cell[CellGroupData[{
Cell[441256, 19448, 128, 3, 70, "Input",
  CellTags->"TransitiveClosure"],
Cell[441387, 19453, 682, 15, 70, "Output",
  CellTags->"TransitiveClosure"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[442130, 19475, 66, 1, 42, "ObjectName",
  CellTags->"TranspositionT"],
Cell[442199, 19478, 65, 1, 74, "Highlight",
  CellTags->"TranspositionT"],
Cell[442267, 19481, 278, 10, 43, "Usage",
  CellTags->"TranspositionT"],
Cell[442548, 19493, 122, 5, 33, "Notes",
  CellTags->"TranspositionT"],
Cell[442673, 19500, 253, 11, 33, "Notes",
  CellTags->"TranspositionT"]
}, Open  ]],

Cell[CellGroupData[{
Cell[442963, 19516, 56, 1, 42, "ObjectName",
  CellTags->"TypeGraph"],
Cell[443022, 19519, 60, 1, 74, "Highlight",
  CellTags->"TypeGraph"],
Cell[443085, 19522, 123, 4, 43, "Usage",
  CellTags->"TypeGraph"],
Cell[443211, 19528, 410, 15, 54, "Notes",
  CellTags->"TypeGraph"],
Cell[443624, 19545, 152, 7, 33, "Notes",
  CellTags->"TypeGraph"],

Cell[CellGroupData[{
Cell[443801, 19556, 67, 1, 59, "ExampleSection",
  CellTags->"TypeGraph"],
Cell[443871, 19559, 100, 1, 70, "ExampleText",
  CellTags->"TypeGraph"],
Cell[443974, 19562, 141, 3, 70, "Input",
  CellTags->"TypeGraph"],

Cell[CellGroupData[{
Cell[444140, 19569, 96, 3, 70, "Input",
  CellTags->"TypeGraph"],
Cell[444239, 19574, 86, 3, 70, "Output",
  CellTags->"TypeGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[444362, 19582, 123, 3, 70, "Input",
  CellTags->"TypeGraph"],
Cell[444488, 19587, 86, 3, 70, "Output",
  CellTags->"TypeGraph"]
}, Open  ]],

Cell[CellGroupData[{
Cell[444611, 19595, 125, 3, 70, "Input",
  CellTags->"TypeGraph"],
Cell[444739, 19600, 86, 3, 70, "Output",
  CellTags->"TypeGraph"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[444886, 19610, 60, 1, 42, "ObjectName",
  CellTags->"UnitElement"],
Cell[444949, 19613, 62, 1, 74, "Highlight",
  CellTags->"UnitElement"],
Cell[445014, 19616, 197, 6, 43, "Usage",
  CellTags->"UnitElement"],
Cell[445214, 19624, 210, 6, 54, "Notes",
  CellTags->"UnitElement"],
Cell[445427, 19632, 91, 4, 33, "Notes"],
Cell[445521, 19638, 159, 7, 33, "Notes",
  CellTags->"UnitElement"],

Cell[CellGroupData[{
Cell[445705, 19649, 69, 1, 59, "ExampleSection",
  CellTags->"UnitElement"],
Cell[445777, 19652, 69, 1, 48, "ExampleText",
  CellTags->"UnitElement"],

Cell[CellGroupData[{
Cell[445871, 19657, 91, 2, 40, "Input",
  CellTags->"UnitElement"],
Cell[445965, 19661, 70, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[446072, 19668, 96, 2, 40, "Input",
  CellTags->"UnitElement"],
Cell[446171, 19672, 76, 2, 30, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[446308, 19681, 56, 1, 31, "ObjectName",
  CellTags->"VertexSet"],
Cell[446367, 19684, 60, 1, 74, "Highlight",
  CellTags->"VertexSet"],
Cell[446430, 19687, 158, 6, 43, "Usage",
  CellTags->"VertexSet"],
Cell[446591, 19695, 185, 6, 33, "Notes",
  CellTags->"VertexSet"],
Cell[446779, 19703, 238, 11, 33, "Notes",
  CellTags->"VertexSet"],

Cell[CellGroupData[{
Cell[447042, 19718, 67, 1, 59, "ExampleSection",
  CellTags->"VertexSet"],
Cell[447112, 19721, 101, 1, 70, "ExampleText",
  CellTags->"VertexSet"],
Cell[447216, 19724, 133, 3, 70, "Input",
  CellTags->"VertexSet"],

Cell[CellGroupData[{
Cell[447374, 19731, 71, 2, 70, "Input"],
Cell[447448, 19735, 116, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[447625, 19744, 46, 1, 42, "ObjectName",
  CellTags->"Vier"],
Cell[447674, 19747, 54, 1, 74, "Highlight",
  CellTags->"Vier"],
Cell[447731, 19750, 146, 6, 43, "Usage",
  CellTags->"Vier"],
Cell[447880, 19758, 104, 5, 33, "Notes",
  CellTags->"Vier"],
Cell[447987, 19765, 435, 19, 33, "Notes",
  CellTags->"Vier"]
}, Open  ]],

Cell[CellGroupData[{
Cell[448459, 19789, 54, 1, 42, "ObjectName",
  CellTags->"Warshall"],
Cell[448516, 19792, 59, 1, 74, "Highlight",
  CellTags->"Warshall"],
Cell[448578, 19795, 174, 5, 43, "Usage",
  CellTags->"Warshall"],
Cell[448755, 19802, 229, 9, 58, "Notes",
  CellTags->"Warshall"],
Cell[448987, 19813, 125, 4, 33, "Notes",
  CellTags->"Warshall"],
Cell[449115, 19819, 96, 3, 33, "Notes"],
Cell[449214, 19824, 265, 11, 33, "Notes",
  CellTags->"Warshall"],

Cell[CellGroupData[{
Cell[449504, 19839, 66, 1, 59, "ExampleSection",
  CellTags->"Warshall"],
Cell[449573, 19842, 178, 6, 70, "ExampleText",
  CellTags->"Warshall"],

Cell[CellGroupData[{
Cell[449776, 19852, 135, 5, 70, "Input",
  CellTags->"Warshall"],
Cell[449914, 19859, 481, 12, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[450432, 19876, 86, 2, 70, "Input"],
Cell[450521, 19880, 481, 12, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[451039, 19897, 112, 2, 70, "Input"],
Cell[451154, 19901, 481, 12, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[451696, 19920, 88, 1, 42, "ObjectName",
  CellTags->"WeaklyConnectedComponents"],
Cell[451787, 19923, 76, 1, 74, "Highlight",
  CellTags->"WeaklyConnectedComponents"],
Cell[451866, 19926, 252, 8, 64, "Usage",
  CellTags->"WeaklyConnectedComponents"],
Cell[452121, 19936, 161, 4, 33, "Notes",
  CellTags->"WeaklyConnectedComponents"],
Cell[452285, 19942, 298, 11, 33, "Notes",
  CellTags->"WeaklyConnectedComponents"],

Cell[CellGroupData[{
Cell[452608, 19957, 83, 1, 59, "ExampleSection",
  CellTags->"WeaklyConnectedComponents"],
Cell[452694, 19960, 95, 1, 70, "ExampleText",
  CellTags->"WeaklyConnectedComponents"],

Cell[CellGroupData[{
Cell[452814, 19965, 116, 2, 70, "Input",
  CellTags->"WeaklyConnectedComponents"],
Cell[452933, 19969, 251, 7, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[453221, 19981, 193, 4, 70, "Input"],
Cell[453417, 19987, 73, 2, 70, "Output"],
Cell[453493, 19991, 73, 2, 70, "Output"],
Cell[453569, 19995, 86, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[453716, 20004, 48, 1, 42, "ObjectName",
  CellTags->"WordQ"],
Cell[453767, 20007, 56, 1, 74, "Highlight",
  CellTags->"WordQ"],
Cell[453826, 20010, 143, 4, 43, "Usage",
  CellTags->"WordQ"],
Cell[453972, 20016, 67, 1, 33, "Notes",
  CellTags->"WordQ"],
Cell[454042, 20019, 1945, 79, 96, "Notes",
  CellTags->"WordQ"],

Cell[CellGroupData[{
Cell[456012, 20102, 63, 1, 59, "ExampleSection",
  CellTags->"WordQ"],
Cell[456078, 20105, 72, 1, 70, "ExampleText",
  CellTags->"WordQ"],

Cell[CellGroupData[{
Cell[456175, 20110, 133, 3, 70, "Input",
  CellTags->"WordQ"],
Cell[456311, 20115, 98, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[456470, 20124, 58, 1, 31, "ObjectName",
  CellTags->"WordReduce"],
Cell[456531, 20127, 61, 1, 74, "Highlight",
  CellTags->"WordReduce"],
Cell[456595, 20130, 201, 8, 43, "Usage",
  CellTags->"WordReduce"],
Cell[456799, 20140, 275, 10, 80, "Notes",
  CellTags->"WordReduce"],
Cell[457077, 20152, 53, 1, 33, "Notes",
  CellTags->"WordReduce"],
Cell[457133, 20155, 208, 5, 54, "Notes"],
Cell[457344, 20162, 121, 4, 33, "Notes"],
Cell[457468, 20168, 121, 4, 33, "Notes",
  CellTags->"WordReduce"],
Cell[457592, 20174, 295, 11, 33, "Notes",
  CellTags->"WordReduce"],

Cell[CellGroupData[{
Cell[457912, 20189, 68, 1, 59, "ExampleSection",
  CellTags->"WordReduce"],
Cell[457983, 20192, 72, 1, 70, "ExampleText",
  CellTags->"WordReduce"],
Cell[458058, 20195, 143, 3, 70, "Input",
  CellTags->"WordReduce"],

Cell[CellGroupData[{
Cell[458226, 20202, 98, 2, 70, "Input"],
Cell[458327, 20206, 63, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[458427, 20213, 127, 3, 70, "Input"],
Cell[458557, 20218, 621, 17, 70, "Output"]
}, Open  ]],
Cell[459193, 20238, 99, 1, 70, "ExampleText",
  CellTags->"WordReduce"],

Cell[CellGroupData[{
Cell[459317, 20243, 156, 4, 70, "Input",
  CellTags->"WordReduce"],
Cell[459476, 20249, 115, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[459652, 20258, 46, 1, 42, "ObjectName",
  CellTags->"Zwei"],
Cell[459701, 20261, 54, 1, 74, "Highlight",
  CellTags->"Zwei"],
Cell[459758, 20264, 83, 4, 43, "Usage",
  CellTags->"Zwei"],
Cell[459844, 20270, 104, 5, 33, "Notes",
  CellTags->"Zwei"],
Cell[459951, 20277, 333, 15, 33, "Notes",
  CellTags->"Zwei"]
}, Open  ]],

Cell[CellGroupData[{
Cell[460321, 20297, 44, 1, 42, "ObjectName",
  CellTags->"All"],
Cell[460368, 20300, 33, 0, 74, "Highlight"],
Cell[460404, 20302, 120, 4, 43, "Usage",
  CellTags->"All"],
Cell[460527, 20308, 430, 15, 33, "Notes",
  CellTags->"All"],

Cell[CellGroupData[{
Cell[460982, 20327, 61, 1, 59, "ExampleSection",
  CellTags->"All"],
Cell[461046, 20330, 207, 7, 70, "ExampleText",
  CellTags->"All"],

Cell[CellGroupData[{
Cell[461278, 20341, 105, 2, 70, "Input",
  CellTags->"All"],
Cell[461386, 20345, 2947, 238, 70, 2795, 233, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[464336, 20585, 155, 4, 70, "Output"]
}, Open  ]],
Cell[464506, 20592, 90, 1, 70, "ExampleText",
  CellTags->"All"],

Cell[CellGroupData[{
Cell[464621, 20597, 118, 2, 70, "Input",
  CellTags->"All"],
Cell[464742, 20601, 1792, 123, 70, 1640, 118, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[466537, 20726, 155, 4, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[466753, 20737, 52, 1, 42, "ObjectName",
  CellTags->"Boolean"],
Cell[466808, 20740, 56, 1, 74, "Highlight",
  CellTags->"Boolean"],
Cell[466867, 20743, 242, 7, 64, "Usage",
  CellTags->"Boolean"],
Cell[467112, 20752, 220, 8, 58, "Notes",
  CellTags->"Boolean"],
Cell[467335, 20762, 145, 4, 33, "Notes",
  CellTags->"Boolean"],
Cell[467483, 20768, 176, 7, 33, "Notes",
  CellTags->"Boolean"],

Cell[CellGroupData[{
Cell[467684, 20779, 65, 1, 59, "ExampleSection",
  CellTags->"Boolean"],
Cell[467752, 20782, 72, 1, 70, "ExampleText",
  CellTags->"Boolean"],

Cell[CellGroupData[{
Cell[467849, 20787, 107, 3, 70, "Input",
  CellTags->"Boolean"],
Cell[467959, 20792, 477, 14, 70, "Output",
  CellTags->"Boolean"]
}, Open  ]],
Cell[468451, 20809, 127, 3, 70, "Input",
  CellTags->"Boolean"],

Cell[CellGroupData[{
Cell[468603, 20816, 83, 2, 70, "Input",
  CellTags->"Boolean"],
Cell[468689, 20820, 434, 12, 70, "Output",
  CellTags->"Boolean"]
}, Open  ]],

Cell[CellGroupData[{
Cell[469160, 20837, 86, 2, 70, "Input",
  CellTags->"Boolean"],
Cell[469249, 20841, 434, 12, 70, "Output",
  CellTags->"Boolean"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[469744, 20860, 54, 1, 31, "ObjectName",
  CellTags->"BoundCSM"],
Cell[469801, 20863, 57, 1, 74, "Highlight",
  CellTags->"BoundCSM"],
Cell[469861, 20866, 181, 5, 64, "Usage",
  CellTags->"BoundCSM"],
Cell[470045, 20873, 57, 1, 33, "Notes",
  CellTags->"BoundCSM"],
Cell[470105, 20876, 57, 1, 33, "Notes",
  CellTags->"BoundCSM"]
}, Open  ]],

Cell[CellGroupData[{
Cell[470199, 20882, 54, 1, 42, "ObjectName",
  CellTags->"BoundETW"],
Cell[470256, 20885, 57, 1, 74, "Highlight",
  CellTags->"BoundETW"],
Cell[470316, 20888, 156, 6, 43, "Usage",
  CellTags->"BoundETW"],
Cell[470475, 20896, 56, 1, 33, "Notes",
  CellTags->"BoundETW"],
Cell[470534, 20899, 176, 7, 33, "Notes",
  CellTags->"BoundETW"]
}, Open  ]],

Cell[CellGroupData[{
Cell[470747, 20911, 54, 1, 42, "ObjectName",
  CellTags->"BoundGSG"],
Cell[470804, 20914, 57, 1, 74, "Highlight",
  CellTags->"BoundGSG"],
Cell[470864, 20917, 193, 6, 43, "Usage",
  CellTags->"BoundGSG"],
Cell[471060, 20925, 76, 1, 33, "Notes",
  CellTags->"BoundGSG"],
Cell[471139, 20928, 254, 10, 33, "Notes",
  CellTags->"BoundGSG"]
}, Open  ]],

Cell[CellGroupData[{
Cell[471430, 20943, 52, 1, 42, "ObjectName",
  CellTags->"BoundWR"],
Cell[471485, 20946, 56, 1, 74, "Highlight",
  CellTags->"BoundWR"],
Cell[471544, 20949, 182, 6, 43, "Usage",
  CellTags->"BoundWR"],
Cell[471729, 20957, 55, 1, 33, "Notes",
  CellTags->"BoundWR"],
Cell[471787, 20960, 155, 7, 33, "Notes",
  CellTags->"BoundWR"]
}, Open  ]],

Cell[CellGroupData[{
Cell[471979, 20972, 62, 1, 42, "ObjectName",
  CellTags->"ClosureBound"],
Cell[472044, 20975, 61, 1, 74, "Highlight",
  CellTags->"ClosureBound"],
Cell[472108, 20978, 196, 8, 43, "Usage",
  CellTags->"ClosureBound"],
Cell[472307, 20988, 259, 11, 33, "Notes",
  CellTags->"ClosureBound"]
}, Open  ]],

Cell[CellGroupData[{
Cell[472603, 21004, 46, 1, 42, "ObjectName",
  CellTags->"Cols"],
Cell[472652, 21007, 53, 1, 74, "Highlight",
  CellTags->"Cols"],
Cell[472708, 21010, 137, 6, 43, "Usage",
  CellTags->"Cols"],
Cell[472848, 21018, 160, 7, 33, "Notes",
  CellTags->"Cols"]
}, Open  ]],

Cell[CellGroupData[{
Cell[473045, 21030, 48, 1, 42, "ObjectName",
  CellTags->"Cycle"],
Cell[473096, 21033, 54, 1, 74, "Highlight",
  CellTags->"Cycle"],
Cell[473153, 21036, 188, 6, 43, "Usage",
  CellTags->"Cycle"],
Cell[473344, 21044, 157, 7, 33, "Notes",
  CellTags->"Cycle"]
}, Open  ]],

Cell[CellGroupData[{
Cell[473538, 21056, 54, 1, 42, "ObjectName",
  CellTags->"DClasses"],
Cell[473595, 21059, 57, 1, 74, "Highlight",
  CellTags->"DClasses"],
Cell[473655, 21062, 145, 6, 43, "Usage",
  CellTags->"DClasses"],
Cell[473803, 21070, 108, 5, 33, "Notes",
  CellTags->"DClasses"],
Cell[473914, 21077, 355, 15, 33, "Notes",
  CellTags->"DClasses"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474306, 21097, 52, 1, 42, "ObjectName",
  CellTags->"DoTrace"],
Cell[474361, 21100, 56, 1, 74, "Highlight",
  CellTags->"DoTrace"],
Cell[474420, 21103, 122, 4, 43, "Usage",
  CellTags->"DoTrace"],
Cell[474545, 21109, 572, 23, 54, "Notes",
  CellTags->"DoTrace"]
}, Open  ]],

Cell[CellGroupData[{
Cell[475154, 21137, 44, 1, 42, "ObjectName",
  CellTags->"Eps"],
Cell[475201, 21140, 52, 1, 74, "Highlight",
  CellTags->"Eps"],
Cell[475256, 21143, 115, 4, 43, "Usage",
  CellTags->"Eps"],
Cell[475374, 21149, 171, 6, 33, "Notes",
  CellTags->"Eps"],
Cell[475548, 21157, 238, 8, 33, "Notes",
  CellTags->"Eps"],
Cell[475789, 21167, 284, 11, 54, "Notes",
  CellTags->"Eps"],
Cell[476076, 21180, 141, 7, 33, "Notes",
  CellTags->"Eps"]
}, Open  ]],

Cell[CellGroupData[{
Cell[476254, 21192, 56, 1, 42, "ObjectName",
  CellTags->"Equations"],
Cell[476313, 21195, 58, 1, 74, "Highlight",
  CellTags->"Equations"],
Cell[476374, 21198, 126, 4, 43, "Usage",
  CellTags->"Equations"],
Cell[476503, 21204, 255, 11, 33, "Notes",
  CellTags->"Equations"]
}, Open  ]],

Cell[CellGroupData[{
Cell[476795, 21220, 54, 1, 42, "ObjectName",
  CellTags->"External"],
Cell[476852, 21223, 57, 1, 74, "Highlight",
  CellTags->"External"],
Cell[476912, 21226, 156, 4, 43, "Usage",
  CellTags->"External"],
Cell[477071, 21232, 255, 8, 54, "Notes",
  CellTags->"External"],
Cell[477329, 21242, 120, 5, 33, "Notes",
  CellTags->"External"],
Cell[477452, 21249, 124, 4, 33, "Notes",
  CellTags->"External"],
Cell[477579, 21255, 448, 19, 33, "Notes",
  CellTags->"defaultexternal"]
}, Open  ]],

Cell[CellGroupData[{
Cell[478064, 21279, 50, 1, 42, "ObjectName",
  CellTags->"Filter"],
Cell[478117, 21282, 55, 1, 74, "Highlight",
  CellTags->"Filter"],
Cell[478175, 21285, 201, 5, 64, "Usage",
  CellTags->"Filter"],
Cell[478379, 21292, 76, 1, 33, "Notes",
  CellTags->"Filter"],
Cell[478458, 21295, 116, 4, 33, "Notes",
  CellTags->"Filter"],
Cell[478577, 21301, 159, 7, 33, "Notes",
  CellTags->"Filter"],

Cell[CellGroupData[{
Cell[478761, 21312, 64, 1, 59, "ExampleSection",
  CellTags->"Filter"],
Cell[478828, 21315, 106, 2, 70, "ExampleText",
  CellTags->"Filter"],
Cell[478937, 21319, 233, 4, 70, "Input"],
Cell[479173, 21325, 98, 2, 70, "Input"],
Cell[479274, 21329, 209, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[479508, 21338, 78, 2, 70, "Input"],
Cell[479589, 21342, 7652, 219, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[487302, 21568, 46, 1, 42, "ObjectName",
  CellTags->"Full"],
Cell[487351, 21571, 53, 1, 74, "Highlight",
  CellTags->"Full"],
Cell[487407, 21574, 116, 4, 43, "Usage",
  CellTags->"Full"],
Cell[487526, 21580, 1988, 79, 96, "Notes",
  CellTags->"Full"]
}, Open  ]],

Cell[CellGroupData[{
Cell[489551, 21664, 58, 1, 42, "ObjectName",
  CellTags->"GridOffset"],
Cell[489612, 21667, 59, 1, 74, "Highlight",
  CellTags->"GridOffset"],
Cell[489674, 21670, 147, 6, 43, "Usage",
  CellTags->"GridOffset"],
Cell[489824, 21678, 205, 9, 58, "Notes",
  CellTags->"GridOffset"],
Cell[490032, 21689, 158, 5, 33, "Notes",
  CellTags->"GridOffset"],
Cell[490193, 21696, 159, 7, 33, "Notes",
  CellTags->"GridOffset"]
}, Open  ]],

Cell[CellGroupData[{
Cell[490389, 21708, 48, 1, 42, "ObjectName",
  CellTags->"Index"],
Cell[490440, 21711, 54, 1, 74, "Highlight",
  CellTags->"Index"],
Cell[490497, 21714, 197, 8, 43, "Usage",
  CellTags->"Index"],
Cell[490697, 21724, 235, 11, 33, "Notes",
  CellTags->"Index"]
}, Open  ]],

Cell[CellGroupData[{
Cell[490969, 21740, 46, 1, 42, "ObjectName",
  CellTags->"Kary"],
Cell[491018, 21743, 53, 1, 74, "Highlight",
  CellTags->"Kary"],
Cell[491074, 21746, 256, 9, 43, "Usage",
  CellTags->"Kary"],
Cell[491333, 21757, 160, 7, 33, "Notes",
  CellTags->"Kary"]
}, Open  ]],

Cell[CellGroupData[{
Cell[491530, 21769, 56, 1, 42, "ObjectName",
  CellTags->"LabelGrid"],
Cell[491589, 21772, 58, 1, 74, "Highlight",
  CellTags->"LabelGrid"],
Cell[491650, 21775, 224, 7, 64, "Usage",
  CellTags->"LabelGrid"],
Cell[491877, 21784, 157, 7, 33, "Notes",
  CellTags->"LabelGrid"]
}, Open  ]],

Cell[CellGroupData[{
Cell[492071, 21796, 60, 1, 42, "ObjectName",
  CellTags->"LabelPoints"],
Cell[492134, 21799, 60, 1, 74, "Highlight",
  CellTags->"LabelPoints"],
Cell[492197, 21802, 186, 5, 43, "Usage",
  CellTags->"LabelPoints"],
Cell[492386, 21809, 182, 7, 33, "Notes",
  CellTags->"LabelPoints"],
Cell[492571, 21818, 159, 7, 33, "Notes",
  CellTags->"LabelPoints"]
}, Open  ]],

Cell[CellGroupData[{
Cell[492767, 21830, 56, 1, 42, "ObjectName",
  CellTags->"LineStyle"],
Cell[492826, 21833, 58, 1, 74, "Highlight",
  CellTags->"LineStyle"],
Cell[492887, 21836, 207, 6, 43, "Usage",
  CellTags->"LineStyle"],
Cell[493097, 21844, 134, 5, 33, "Notes",
  CellTags->"LineStyle"],
Cell[493234, 21851, 159, 7, 33, "Notes",
  CellTags->"LineStyle"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493430, 21863, 50, 1, 42, "ObjectName",
  CellTags->"Matrix"],
Cell[493483, 21866, 55, 1, 74, "Highlight",
  CellTags->"Matrix"],
Cell[493541, 21869, 199, 8, 43, "Usage",
  CellTags->"Matrix"],
Cell[493743, 21879, 157, 7, 33, "Notes",
  CellTags->"Matrix"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493937, 21891, 54, 1, 42, "ObjectName",
  CellTags->"MultiCol"],
Cell[493994, 21894, 57, 1, 74, "Highlight",
  CellTags->"MultiCol"],
Cell[494054, 21897, 145, 6, 43, "Usage",
  CellTags->"MultiCol"],
Cell[494202, 21905, 156, 7, 33, "Notes",
  CellTags->"MultiCol"]
}, Open  ]],

Cell[CellGroupData[{
Cell[494395, 21917, 58, 1, 42, "ObjectName",
  CellTags->"NonTrivial"],
Cell[494456, 21920, 59, 1, 74, "Highlight",
  CellTags->"NonTrivial"],
Cell[494518, 21923, 175, 6, 43, "Usage",
  CellTags->"NonTrivial"],
Cell[494696, 21931, 170, 4, 54, "Notes",
  CellTags->"NonTrivial"],
Cell[494869, 21937, 192, 7, 33, "Notes",
  CellTags->"NonTrivial"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495098, 21949, 50, 1, 42, "ObjectName",
  CellTags->"NoRest"],
Cell[495151, 21952, 55, 1, 74, "Highlight",
  CellTags->"NoRest"],
Cell[495209, 21955, 141, 6, 43, "Usage",
  CellTags->"NoRest"],
Cell[495353, 21963, 154, 7, 33, "Notes",
  CellTags->"NoRest"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495544, 21975, 56, 1, 42, "ObjectName",
  CellTags->"Normalize"],
Cell[495603, 21978, 58, 1, 74, "Highlight",
  CellTags->"Normalize"],
Cell[495664, 21981, 137, 4, 43, "Usage",
  CellTags->"Normalize"],
Cell[495804, 21987, 260, 9, 33, "Notes",
  CellTags->"Normalize"],
Cell[496067, 21998, 636, 22, 96, "Notes",
  CellTags->"Normalize"],
Cell[496706, 22022, 268, 11, 33, "Notes",
  CellTags->"Normalize"]
}, Open  ]],

Cell[CellGroupData[{
Cell[497011, 22038, 48, 1, 42, "ObjectName",
  CellTags->"NRows"],
Cell[497062, 22041, 54, 1, 74, "Highlight",
  CellTags->"NRows"],
Cell[497119, 22044, 139, 6, 43, "Usage",
  CellTags->"NRows"],
Cell[497261, 22052, 153, 7, 33, "Notes",
  CellTags->"NRows"]
}, Open  ]],

Cell[CellGroupData[{
Cell[497451, 22064, 46, 1, 42, "ObjectName",
  CellTags->"Opts"],
Cell[497500, 22067, 53, 1, 74, "Highlight",
  CellTags->"Opts"],
Cell[497556, 22070, 142, 6, 43, "Usage",
  CellTags->"Opts"],
Cell[497701, 22078, 85, 1, 33, "Notes",
  CellTags->"Opts"],
Cell[497789, 22081, 160, 7, 33, "Notes",
  CellTags->"Opts"]
}, Open  ]],

Cell[CellGroupData[{
Cell[497986, 22093, 54, 1, 42, "ObjectName",
  CellTags->"OutPairs"],
Cell[498043, 22096, 57, 1, 74, "Highlight",
  CellTags->"OutPairs"],
Cell[498103, 22099, 160, 6, 43, "Usage",
  CellTags->"OutPairs"],
Cell[498266, 22107, 93, 1, 33, "Notes",
  CellTags->"OutPairs"],
Cell[498362, 22110, 168, 7, 33, "Notes",
  CellTags->"OutPairs"]
}, Open  ]],

Cell[CellGroupData[{
Cell[498567, 22122, 54, 1, 42, "ObjectName",
  CellTags->"Periodic"],
Cell[498624, 22125, 57, 1, 74, "Highlight",
  CellTags->"Periodic"],
Cell[498684, 22128, 202, 6, 43, "Usage",
  CellTags->"Periodic"],
Cell[498889, 22136, 112, 5, 33, "Notes",
  CellTags->"Periodic"],
Cell[499004, 22143, 160, 7, 33, "Notes",
  CellTags->"Periodic"]
}, Open  ]],

Cell[CellGroupData[{
Cell[499201, 22155, 60, 1, 42, "ObjectName",
  CellTags->"RasterStyle"],
Cell[499264, 22158, 60, 1, 74, "Highlight",
  CellTags->"RasterStyle"],
Cell[499327, 22161, 203, 6, 43, "Usage",
  CellTags->"RasterStyle"],
Cell[499533, 22169, 214, 9, 33, "Notes",
  CellTags->"RasterStyle"],
Cell[499750, 22180, 270, 11, 33, "Notes",
  CellTags->"RasterStyle"]
}, Open  ]],

Cell[CellGroupData[{
Cell[500057, 22196, 56, 1, 42, "ObjectName",
  CellTags->"Reflexive"],
Cell[500116, 22199, 58, 1, 74, "Highlight",
  CellTags->"Reflexive"],
Cell[500177, 22202, 156, 5, 43, "Usage",
  CellTags->"Reflexive"],
Cell[500336, 22209, 110, 5, 33, "Notes",
  CellTags->"Reflexive"],
Cell[500449, 22216, 176, 7, 33, "Notes",
  CellTags->"Reflexive"]
}, Open  ]],

Cell[CellGroupData[{
Cell[500662, 22228, 60, 1, 42, "ObjectName",
  CellTags->"RegularOnly"],
Cell[500725, 22231, 60, 1, 74, "Highlight",
  CellTags->"RegularOnly"],
Cell[500788, 22234, 169, 6, 43, "Usage",
  CellTags->"RegularOnly"],
Cell[500960, 22242, 189, 6, 33, "Notes",
  CellTags->"RegularOnly"],
Cell[501152, 22250, 186, 5, 54, "Notes",
  CellTags->"RegularOnly"],
Cell[501341, 22257, 256, 11, 33, "Notes",
  CellTags->"RegularOnly"]
}, Open  ]],

Cell[CellGroupData[{
Cell[501634, 22273, 54, 1, 42, "ObjectName",
  CellTags->"Relation"],
Cell[501691, 22276, 57, 1, 74, "Highlight",
  CellTags->"Relation"],
Cell[501751, 22279, 203, 8, 43, "Usage",
  CellTags->"Relation"],
Cell[501957, 22289, 154, 7, 33, "Notes",
  CellTags->"Relation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[502148, 22301, 48, 1, 42, "ObjectName",
  CellTags->"RView"],
Cell[502199, 22304, 54, 1, 74, "Highlight",
  CellTags->"RView"],
Cell[502256, 22307, 111, 4, 43, "Usage",
  CellTags->"RView"],
Cell[502370, 22313, 153, 7, 33, "Notes",
  CellTags->"RView"]
}, Open  ]],

Cell[CellGroupData[{
Cell[502560, 22325, 58, 1, 42, "ObjectName",
  CellTags->"SetClosure"],
Cell[502621, 22328, 59, 1, 74, "Highlight",
  CellTags->"SetClosure"],
Cell[502683, 22331, 245, 8, 64, "Usage",
  CellTags->"SetClosure"],
Cell[502931, 22341, 254, 11, 33, "Notes",
  CellTags->"SetClosure"]
}, Open  ]],

Cell[CellGroupData[{
Cell[503222, 22357, 46, 1, 42, "ObjectName",
  CellTags->"Type"],
Cell[503271, 22360, 53, 1, 74, "Highlight",
  CellTags->"Type"],
Cell[503327, 22363, 137, 6, 43, "Usage",
  CellTags->"Type"],
Cell[503467, 22371, 230, 11, 33, "Notes",
  CellTags->"Type"],
Cell[503700, 22384, 150, 7, 33, "Notes",
  CellTags->"Type"]
}, Open  ]],

Cell[CellGroupData[{
Cell[503887, 22396, 48, 1, 42, "ObjectName",
  CellTags->"Where"],
Cell[503938, 22399, 54, 1, 74, "Highlight",
  CellTags->"Where"],
Cell[503995, 22402, 307, 10, 43, "Usage",
  CellTags->"Where"],
Cell[504305, 22414, 197, 9, 33, "Notes",
  CellTags->"Where"],
Cell[504505, 22425, 140, 7, 33, "Notes",
  CellTags->"Where"],

Cell[CellGroupData[{
Cell[504670, 22436, 63, 1, 59, "ExampleSection",
  CellTags->"Where"],
Cell[504736, 22439, 123, 4, 70, "ExampleText",
  CellTags->"Where"],

Cell[CellGroupData[{
Cell[504884, 22447, 90, 2, 70, "Input",
  CellTags->"Where"],
Cell[504977, 22451, 110, 3, 70, "Output",
  CellTags->"Where"]
}, Open  ]],

Cell[CellGroupData[{
Cell[505124, 22459, 102, 2, 70, "Input",
  CellTags->"Where"],
Cell[505229, 22463, 110, 3, 70, "Output",
  CellTags->"Where"]
}, Open  ]],

Cell[CellGroupData[{
Cell[505376, 22471, 103, 2, 70, "Input",
  CellTags->"Where"],
Cell[505482, 22475, 110, 3, 70, "Output",
  CellTags->"Where"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[505653, 22485, 56, 1, 42, "ObjectName",
  CellTags->"Witnesses"],
Cell[505712, 22488, 60, 1, 74, "Highlight",
  CellTags->"Witnesses"],
Cell[505775, 22491, 235, 7, 64, "Usage",
  CellTags->"Witnesses"],
Cell[506013, 22500, 249, 11, 33, "Notes",
  CellTags->"Witnesses"],

Cell[CellGroupData[{
Cell[506287, 22515, 67, 1, 59, "ExampleSection",
  CellTags->"Witnesses"],
Cell[506357, 22518, 219, 7, 70, "ExampleText",
  CellTags->"Witnesses"],
Cell[506579, 22527, 110, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[506714, 22533, 112, 2, 70, "Input"],
Cell[506829, 22537, 109, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[506975, 22544, 77, 2, 70, "Input"],
Cell[507055, 22548, 96, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[507212, 22557, 42, 1, 42, "ObjectName",
  CellTags->"DC"],
Cell[507257, 22560, 51, 1, 74, "Highlight",
  CellTags->"DC"],
Cell[507311, 22563, 151, 4, 43, "Usage",
  CellTags->"DC"],
Cell[507465, 22569, 216, 8, 33, "Notes",
  CellTags->"DC"],
Cell[507684, 22579, 517, 23, 33, "Notes",
  CellTags->"DC"],

Cell[CellGroupData[{
Cell[508226, 22606, 60, 1, 59, "ExampleSection",
  CellTags->"DC"],
Cell[508289, 22609, 93, 1, 70, "ExampleText",
  CellTags->"DClassToBlocks"],
Cell[508385, 22612, 353, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[508763, 22622, 110, 3, 70, "Input"],
Cell[508876, 22627, 69, 2, 70, "Output"],
Cell[508948, 22631, 62, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[509071, 22640, 44, 1, 42, "ObjectName",
  CellTags->"GEN"],
Cell[509118, 22643, 52, 1, 74, "Highlight",
  CellTags->"GEN"],
Cell[509173, 22646, 190, 6, 43, "Usage",
  CellTags->"GEN"],
Cell[509366, 22654, 251, 11, 33, "Notes",
  CellTags->"GEN"],
Cell[509620, 22667, 309, 15, 33, "Notes",
  CellTags->"GEN"]
}, Open  ]],

Cell[CellGroupData[{
Cell[509966, 22687, 48, 1, 42, "ObjectName",
  CellTags->"Graph"],
Cell[510017, 22690, 54, 1, 74, "Highlight",
  CellTags->"Graph"],
Cell[510074, 22693, 297, 10, 64, "Usage",
  CellTags->"Graph"],
Cell[510374, 22705, 414, 17, 54, "Notes",
  CellTags->"Graph"],
Cell[510791, 22724, 349, 11, 54, "Notes"],
Cell[511143, 22737, 602, 23, 54, "Notes",
  CellTags->"Graph"],

Cell[CellGroupData[{
Cell[511770, 22764, 63, 1, 59, "ExampleSection",
  CellTags->"Graph"],
Cell[511836, 22767, 96, 1, 70, "ExampleText",
  CellTags->"Graph"],
Cell[511935, 22770, 137, 3, 70, "Input",
  CellTags->"Graph"],

Cell[CellGroupData[{
Cell[512097, 22777, 98, 3, 70, "Input"],
Cell[512198, 22782, 92, 2, 70, "Output"],
Cell[512293, 22786, 72, 2, 70, "Output"]
}, Open  ]],
Cell[512380, 22791, 123, 4, 70, "ExampleText",
  CellTags->"Graph"],

Cell[CellGroupData[{
Cell[512528, 22799, 73, 2, 70, "Input"],
Cell[512604, 22803, 301, 9, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[512942, 22817, 71, 2, 70, "Input"],
Cell[513016, 22821, 237, 7, 70, "Output"]
}, Open  ]],
Cell[513268, 22831, 70, 1, 70, "ExampleText",
  CellTags->"Graph"],

Cell[CellGroupData[{
Cell[513363, 22836, 90, 2, 70, "Input"],
Cell[513456, 22840, 69, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[513562, 22847, 89, 2, 70, "Input"],
Cell[513654, 22851, 76, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[513791, 22860, 42, 1, 42, "ObjectName",
  CellTags->"SG"],
Cell[513836, 22863, 51, 1, 74, "Highlight",
  CellTags->"SG"],
Cell[513890, 22866, 124, 4, 43, "Usage",
  CellTags->"SG"],
Cell[514017, 22872, 275, 9, 33, "Notes",
  CellTags->"SG"],
Cell[514295, 22883, 513, 20, 33, "Notes",
  CellTags->"SG"],

Cell[CellGroupData[{
Cell[514833, 22907, 60, 1, 59, "ExampleSection",
  CellTags->"SG"],
Cell[514896, 22910, 112, 4, 70, "ExampleText",
  CellTags->"SG"],

Cell[CellGroupData[{
Cell[515033, 22918, 95, 3, 70, "Input",
  CellTags->"SG"],
Cell[515131, 22923, 140, 3, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[515332, 22933, 40, 1, 42, "ObjectName",
  CellTags->"T"],
Cell[515375, 22936, 50, 1, 74, "Highlight",
  CellTags->"T"],
Cell[515428, 22939, 134, 4, 43, "Usage",
  CellTags->"T"],
Cell[515565, 22945, 182, 7, 33, "Notes",
  CellTags->"T"],
Cell[515750, 22954, 265, 10, 54, "Notes"],
Cell[516018, 22966, 506, 23, 33, "Notes",
  CellTags->"T"],

Cell[CellGroupData[{
Cell[516549, 22993, 59, 1, 59, "ExampleSection",
  CellTags->"T"],
Cell[516611, 22996, 80, 1, 70, "ExampleText",
  CellTags->"T"],

Cell[CellGroupData[{
Cell[516716, 23001, 97, 5, 70, "Input",
  CellTags->"T"],
Cell[516816, 23008, 73, 2, 70, "Output"],
Cell[516892, 23012, 73, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[517002, 23019, 90, 3, 70, "Input"],
Cell[517095, 23024, 73, 2, 70, "Output"],
Cell[517171, 23028, 73, 2, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[517305, 23037, 63, 1, 42, "ObjectName",
  CellTags->"closureBound"],
Cell[517371, 23040, 61, 1, 74, "Highlight",
  CellTags->"closureBound"],
Cell[517435, 23043, 180, 5, 43, "Usage",
  CellTags->"closureBound"],
Cell[517618, 23050, 103, 1, 33, "Notes",
  CellTags->"closureBound"],
Cell[517724, 23053, 154, 7, 33, "Notes",
  CellTags->"closureBound"]
}, Open  ]],

Cell[CellGroupData[{
Cell[517915, 23065, 75, 1, 42, "ObjectName",
  CellTags->"closureSearchBound"],
Cell[517993, 23068, 67, 1, 74, "Highlight",
  CellTags->"closureSearchBound"],
Cell[518063, 23071, 177, 6, 43, "Usage",
  CellTags->"closureSearchBound"],
Cell[518243, 23079, 125, 4, 33, "Notes",
  CellTags->"closureSearchBound"],
Cell[518371, 23085, 172, 7, 33, "Notes",
  CellTags->"closureSearchBound"]
}, Open  ]],

Cell[CellGroupData[{
Cell[518580, 23097, 69, 1, 42, "ObjectName",
  CellTags->"defaultexternal"],
Cell[518652, 23100, 64, 1, 74, "Highlight",
  CellTags->"defaultexternal"],
Cell[518719, 23103, 179, 5, 43, "Usage",
  CellTags->"defaultexternal"],
Cell[518901, 23110, 267, 10, 36, "Notes",
  CellTags->"defaultexternal"],
Cell[519171, 23122, 147, 5, 33, "Notes",
  CellTags->"defaultexternal"],
Cell[519321, 23129, 448, 19, 33, "Notes",
  CellTags->"defaultexternal"]
}, Open  ]],

Cell[CellGroupData[{
Cell[519806, 23153, 59, 1, 42, "ObjectName",
  CellTags->"deffatline"],
Cell[519868, 23156, 59, 1, 74, "Highlight",
  CellTags->"deffatline"],
Cell[519930, 23159, 178, 6, 43, "Usage",
  CellTags->"deffatline"],
Cell[520111, 23167, 148, 5, 33, "Notes",
  CellTags->"deffatline"],
Cell[520262, 23174, 165, 7, 33, "Notes",
  CellTags->"deffatline"]
}, Open  ]],

Cell[CellGroupData[{
Cell[520464, 23186, 67, 1, 42, "ObjectName",
  CellTags->"deflabeloffset"],
Cell[520534, 23189, 63, 1, 74, "Highlight",
  CellTags->"deflabeloffset"],
Cell[520600, 23192, 178, 6, 43, "Usage",
  CellTags->"deflabeloffset"],
Cell[520781, 23200, 68, 1, 33, "Notes",
  CellTags->"deflabeloffset"],
Cell[520852, 23203, 265, 11, 33, "Notes",
  CellTags->"deflabeloffset"]
}, Open  ]],

Cell[CellGroupData[{
Cell[521154, 23219, 63, 1, 42, "ObjectName",
  CellTags->"defpointsize"],
Cell[521220, 23222, 61, 1, 74, "Highlight",
  CellTags->"defpointsize"],
Cell[521284, 23225, 173, 6, 43, "Usage",
  CellTags->"defpointsize"],
Cell[521460, 23233, 150, 5, 33, "Notes",
  CellTags->"defpointsize"],
Cell[521613, 23240, 263, 11, 33, "Notes",
  CellTags->"defpointsize"],

Cell[CellGroupData[{
Cell[521901, 23255, 70, 1, 59, "ExampleSection",
  CellTags->"defpointsize"],
Cell[521974, 23258, 132, 5, 70, "ExampleText",
  CellTags->"defpointsize"],

Cell[CellGroupData[{
Cell[522131, 23267, 95, 2, 70, "Input",
  CellTags->"defpointsize"],
Cell[522229, 23271, 1091, 60, 70, 910, 54, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"defpointsize"]
}, Open  ]],

Cell[CellGroupData[{
Cell[523357, 23336, 149, 4, 70, "Input",
  CellTags->"defpointsize"],
Cell[523509, 23342, 1090, 60, 70, 909, 54, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"defpointsize"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[524660, 23409, 61, 1, 42, "ObjectName",
  CellTags->"defthinline"],
Cell[524724, 23412, 60, 1, 74, "Highlight",
  CellTags->"defthinline"],
Cell[524787, 23415, 173, 6, 43, "Usage",
  CellTags->"defthinline"],
Cell[524963, 23423, 149, 5, 33, "Notes",
  CellTags->"defthinline"],
Cell[525115, 23430, 258, 11, 33, "Notes",
  CellTags->"defthinline"],

Cell[CellGroupData[{
Cell[525398, 23445, 69, 1, 59, "ExampleSection",
  CellTags->"defthinline"],
Cell[525470, 23448, 133, 5, 70, "ExampleText",
  CellTags->"defthinline"],

Cell[CellGroupData[{
Cell[525628, 23457, 92, 2, 70, "Input",
  CellTags->"defthinline"],
Cell[525723, 23461, 1046, 68, 70, 893, 63, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[526806, 23534, 128, 5, 70, "Input",
  CellTags->"defthinline"],
Cell[526937, 23541, 1045, 68, 70, 892, 63, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]],
Cell[527997, 23612, 128, 5, 70, "Input",
  CellTags->"defthinline"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[528174, 23623, 77, 1, 42, "ObjectName",
  CellTags->"dimathReleaseNumber"],
Cell[528254, 23626, 68, 1, 74, "Highlight",
  CellTags->"dimathReleaseNumber"],
Cell[528325, 23629, 164, 4, 43, "Usage",
  CellTags->"dimathReleaseNumber"]
}, Open  ]],

Cell[CellGroupData[{
Cell[528526, 23638, 69, 1, 42, "ObjectName",
  CellTags->"generateSGBound"],
Cell[528598, 23641, 64, 1, 74, "Highlight",
  CellTags->"generateSGBound"],
Cell[528665, 23644, 204, 6, 43, "Usage",
  CellTags->"generateSGBound"],
Cell[528872, 23652, 64, 1, 33, "Notes",
  CellTags->"generateSGBound"],
Cell[528939, 23655, 163, 7, 33, "Notes",
  CellTags->"generateSGBound"]
}, Open  ]],

Cell[CellGroupData[{
Cell[529139, 23667, 67, 1, 42, "ObjectName",
  CellTags->"identitystring"],
Cell[529209, 23670, 63, 1, 74, "Highlight",
  CellTags->"identitystring"],
Cell[529275, 23673, 214, 7, 64, "Usage",
  CellTags->"identitystring"],
Cell[529492, 23682, 121, 4, 33, "Notes",
  CellTags->"identitystring"],
Cell[529616, 23688, 270, 11, 33, "Notes",
  CellTags->"identitystring"]
}, Open  ]],

Cell[CellGroupData[{
Cell[529923, 23704, 59, 1, 42, "ObjectName",
  CellTags->"nullstring"],
Cell[529985, 23707, 59, 1, 74, "Highlight",
  CellTags->"nullstring"],
Cell[530047, 23710, 204, 6, 43, "Usage",
  CellTags->"nullstring"],
Cell[530254, 23718, 116, 4, 33, "Notes",
  CellTags->"nullstring"],
Cell[530373, 23724, 268, 11, 33, "Notes",
  CellTags->"nullstring"]
}, Open  ]],

Cell[CellGroupData[{
Cell[530678, 23740, 69, 1, 42, "ObjectName",
  CellTags->"plotrangeoffset"],
Cell[530750, 23743, 64, 1, 74, "Highlight",
  CellTags->"plotrangeoffset"],
Cell[530817, 23746, 172, 6, 43, "Usage",
  CellTags->"plotrangeoffset"],
Cell[530992, 23754, 69, 1, 33, "Notes",
  CellTags->"plotrangeoffset"],
Cell[531064, 23757, 169, 7, 33, "Notes",
  CellTags->"plotrangeoffset"]
}, Open  ]],

Cell[CellGroupData[{
Cell[531270, 23769, 63, 1, 42, "ObjectName",
  CellTags->"rastercolors"],
Cell[531336, 23772, 61, 1, 74, "Highlight",
  CellTags->"rastercolors"],
Cell[531400, 23775, 172, 5, 43, "Usage",
  CellTags->"rastercolors"],
Cell[531575, 23782, 103, 1, 33, "Notes",
  CellTags->"rastercolors"],
Cell[531681, 23785, 370, 15, 33, "Notes",
  CellTags->"rastercolors"]
}, Open  ]],

Cell[CellGroupData[{
Cell[532088, 23805, 71, 1, 42, "ObjectName",
  CellTags->"rewriteSimpBound"],
Cell[532162, 23808, 65, 1, 74, "Highlight",
  CellTags->"rewriteSimpBound"],
Cell[532230, 23811, 224, 5, 64, "Usage",
  CellTags->"rewriteSimpBound"],
Cell[532457, 23818, 70, 1, 33, "Notes",
  CellTags->"rewriteSimpBound"],
Cell[532530, 23821, 186, 7, 33, "Notes",
  CellTags->"rewriteSimpBound"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

