(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     26845,       1135]*)
(*NotebookOutlinePosition[     41579,       1540]*)
(*  CellTagsIndexPosition[     40508,       1505]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DemolishFA", "ObjectName",
  CellTags->"DemolishFA"],

Cell["Type: function", "Highlight",
  CellTags->"DemolishFA"],

Cell[TextData[{
  StyleBox["DemolishFA[M]", "MR"],
  "  prepares a FSM ",
  StyleBox["M", "MR"],
  " for transmission over the link by removing structured state sets and \
alphabets. "
}], "Usage",
  CellTags->"DemolishFA"],

Cell["\<\
The stripped machine is sent over the link, and the full result is \
constructed from the machine being returned by the link, the actual alphabet \
and the state set. \
\>", "Notes",
  CellTags->"DemolishFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["RebuildFA",
    ButtonData:>"RebuildFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RebuildFA"],

Cell["ExtAccessibleFA", "ObjectName",
  CellTags->"ExtAccessibleFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtAccessibleFA"],

Cell[TextData[{
  StyleBox["ExtAccessibleFA[M,opts]", "MR"],
  "  computes the accessible part of a DFA ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtAccessibleFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtAccessibleFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["AccessibleFA",
    ButtonData:>"AccessibleFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtAccessibleFA"],

Cell["ExtBalancedQCA", "ObjectName",
  CellTags->"ExtBalancedQCA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtBalancedQCA"],

Cell[TextData[{
  StyleBox["ExtBalancedQCA[C,b]", "MR"],
  "  tests if CA ",
  StyleBox["C", "MR"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "-balanced. "
}], "Usage",
  CellTags->"ExtBalancedQCA"],

Cell["\<\
Can be used to speed up injectivity and surjectivity testing of \
cellular automata.\
\>", "Notes",
  CellTags->"ExtBalancedQCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ClassifyCA",
    ButtonData:>"ClassifyCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtBalancedQCA"],

Cell["ExtClassifyCA", "ObjectName",
  CellTags->"ExtClassifyCA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtClassifyCA"],

Cell[TextData[{
  StyleBox["ExtClassifyCA[C]", "MR"],
  "  classifies a cellular automaton C according to the topological \
properties of the global map. "
}], "Usage",
  CellTags->"ExtClassifyCA"],

Cell[TextData[{
  "Return values are as follows: \n",
  Cell[BoxData[GridBox[{
          {"0", 
            StyleBox["nothing",
              "MathCaption"]},
          {"1", 
            StyleBox[\(\(\ \)\(surjective\)\),
              "MathCaption"]},
          {"2", 
            StyleBox["open",
              "MathCaption"]},
          {"3", 
            StyleBox["injective",
              "MathCaption"]}
          }]]]
}], "Notes",
  CellTags->"ExtClassifyCA"],

Cell["\<\
The algorithm uses the product automaton of the corresponding de \
Bruijn automaton and is thus quadratic.\
\>", "Notes",
  CellTags->"ExtClassifyCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ExtBalancedQCA",
    ButtonData:>"ExtBalancedQCA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["ClassifyCA",
    ButtonData:>"ClassifyCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtClassifyCA"],

Cell["ExtComposeCA", "ObjectName",
  CellTags->"ExtComposeCA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtComposeCA"],

Cell[TextData[{
  StyleBox["ExtComposeCA[C1,C2]", "MR"],
  "  computes the composition of to cellular automata ",
  StyleBox["C1", "MR"],
  " and ",
  StyleBox["C2", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtComposeCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ComposeCA",
    ButtonData:>"ComposeCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtComposeCA"],

Cell["ExtDefiniteQFA", "ObjectName",
  CellTags->"ExtDefiniteQFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtDefiniteQFA"],

Cell[TextData[{
  StyleBox["ExtDefiniteQFA[M,opts]", "MR"],
  "  tests whether SA ",
  StyleBox["M", "MR"],
  "  is definite. "
}], "Usage",
  CellTags->"ExtDefiniteQFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Full", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtDefiniteQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["DefiniteQFA",
    ButtonData:>"DefiniteQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtDefiniteQFA"],

Cell["ExtEpsilonEliminationFA", "ObjectName",
  CellTags->"ExtEpsilonEliminationFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtEpsilonEliminationFA"],

Cell[TextData[{
  StyleBox["ExtEpsilonEliminationFA[M,opts]", "MR"],
  "  performs epsilon elimination of an FA ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtEpsilonEliminationFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtEpsilonEliminationFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["EpsilonEliminationFA",
    ButtonData:>"EpsilonEliminationFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtEpsilonEliminationFA"],

Cell["ExtEquivalentQFA", "ObjectName",
  CellTags->"ExtEquivalentQFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtEquivalentQFA"],

Cell[TextData[{
  StyleBox["ExtEquivalentQFA[M1,M2]", "MR"],
  "  checks whether finite states machines ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  " are equivalent (by testing isomorphism of the corresponding minimal \
automata). "
}], "Usage",
  CellTags->"ExtEquivalentQFA"],

Cell["\<\
In the next version this will be replaced by direct equivalence \
testing if both machines are DFAs.\
\>", "Notes",
  CellTags->"ExtEquivalentQFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["EquivalentQFA",
    ButtonData:>"EquivalentQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtEquivalentQFA"],

Cell["ExtGenerateSG", "ObjectName",
  CellTags->"ExtGenerateSG"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtGenerateSG"],

Cell[TextData[{
  StyleBox["ExtGenerateSG[gen,opts]", "MR"],
  "  computes the semigroup generated by generators ",
  StyleBox["gen", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtGenerateSG"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Equations", "\[Rule]", "False", "-"},
          {"DClasses", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtGenerateSG"],

Cell[TextData[{
  "Option ",
  StyleBox["Equations->True", "MR"],
  " causes the canonical rewrite rules to be generated. "
}], "Notes",
  CellTags->"ExtGenerateSG"],

Cell[TextData[{
  "Option ",
  StyleBox["DClasses->True", "MR"],
  " causes the ",
  "regular D-class decomposition to be generated. "
}], "Notes",
  CellTags->"ExtGenerateSG"],

Cell[TextData[{
  "Default alphabet is ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c,  ... }\)]],
  ", currently no other alphabets available."
}], "Notes",
  CellTags->"ExtGenerateSG"],

Cell[TextData[{
  "The data structure used in the external algorithm is a ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-ary trie regardless of the number of generators ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ".  This works well for small values of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " but is catastrophic otherwise.  To be fixed in the next release."
}], "Notes",
  CellTags->"ExtGenerateSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["GenerateSG",
    ButtonData:>"GenerateSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtGenerateSG"],

Cell["ExtIsomorphicQDFA", "ObjectName",
  CellTags->"ExtIsomorphicQDFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtIsomorphicQDFA"],

Cell[TextData[{
  StyleBox["ExtIsomorphicQDFA[M1,M2]", "MR"],
  "  checks whether two DFAs ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  " are isomorphic. "
}], "Usage",
  CellTags->"ExtIsomorphicQDFA"],

Cell["\<\
Works by tryting to construct an isomorphism between the two \
machines. \
\>", "Notes",
  CellTags->"ExtIsomorphicQDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["IsomorphicQDFA",
    ButtonData:>"IsomorphicQDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["EquivalentQFA",
    ButtonData:>"EquivalentQFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtIsomorphicQDFA"],

Cell["ExtLanguageFA", "ObjectName",
  CellTags->"ExtLanguageFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtLanguageFA"],

Cell[TextData[{
  StyleBox["ExtLanguageFA[M,r]", "MR"],
  "  computes the acceptance language of a finite state machine ",
  StyleBox["M", "MR"],
  " for words of length ",
  StyleBox["r", "MR"],
  "."
}], "Usage",
  CellTags->"ExtLanguageFA"],

Cell[TextData[{
  "Generates the language for all word up to and including length -",
  StyleBox["r", "MR"],
  " for negative arguments."
}], "Notes",
  CellTags->"ExtLanguageFA"],

Cell[TextData[{
  "The alphabet is assumed to be ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c,  ... }\)]],
  ". "
}], "Notes",
  CellTags->"ExtLanguageFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["LanguageFA",
    ButtonData:>"LanguageFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtLanguageFA"],

Cell["ExtMinimizeFASize", "ObjectName",
  CellTags->"ExtMinimizeFASize"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtMinimizeFASize"],

Cell[TextData[{
  StyleBox["ExtMinimizeFASize[M]", "MR"],
  "  returns the size of the minimal DFA for ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtMinimizeFASize"],

Cell["\<\
If M is nondeterministic, the power automaton is computed first. \
Then Hopcroft's algorithm is used for state merging, but only the number of \
states is returned. \
\>", "Notes",
  CellTags->"ExtMinimizeFASize"],

Cell["\<\
Since the power automaton may be exponential in size, the time and \
space requirements may be exponential, even though the return value is a \
(small) integer.\
\>", "Notes",
  CellTags->"ExtMinimizeFASize"],

Cell[TextData[{
  "See also ",
  ButtonBox["MinimizeFA",
    ButtonData:>"MinimizeFA",
    ButtonStyle->"AddOnsLink"],
  "and ",
  ButtonBox["ExtMinimizeFA",
    ButtonData:>"ExtMinimizeFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtMinimizeFASize"],

Cell["ExtMinimizeFA", "ObjectName",
  CellTags->"ExtMinimizeFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtMinimizeFA"],

Cell[TextData[{
  StyleBox["ExtMinimizeFA[M,opts]", "MR"],
  "  minimizes a finite state machine ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtMinimizeFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[RuleDelayed]", "$defaultnormalize", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtMinimizeFA"],

Cell[TextData[{
  "If ",
  StyleBox["M", "MR"],
  " is nondeterministic, the power automaton is computed first. Then \
Hopcroft's algorithm is used for state merging."
}], "Notes",
  CellTags->"ExtMinimizeFA"],

Cell["\<\
Since the power automaton may be exponential in size, the time and \
space requirements may be exponential.\
\>", "Notes",
  CellTags->"ExtMinimizeFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["MinimizeFA",
    ButtonData:>"MinimizeFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtMinimizeFA"],

Cell["ExtOrbitCA", "ObjectName",
  CellTags->"ExtOrbitCA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtOrbitCA"],

Cell[TextData[{
  StyleBox["ExtOrbitCA[C,t,pat,opts]", "MR"],
  "  plots the evolution of ",
  StyleBox["pat", "MR"],
  " for ",
  StyleBox["t", "MR"],
  " steps of a 1-dimensional cellular automaton ",
  StyleBox["C", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtOrbitCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Boundary", "\[Rule]", "Cyclic", "Fixed"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtOrbitCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["OrbitCA",
    ButtonData:>"OrbitCA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["EvolutionCA",
    ButtonData:>"EvolutionCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtOrbitCA"],

Cell["ExtProductDFA", "ObjectName",
  CellTags->"ExtProductDFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtProductDFA"],

Cell[TextData[{
  StyleBox["ExtProductDFA[M1,M2,opts]", "MR"],
  "  returns the product of two DFAs M1 and M2 (over the same alphabet). Only \
the accessible part of the full product automaton is generated. "
}], "Usage",
  CellTags->"ExtProductDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "0", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtProductDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ProductFA",
    ButtonData:>"ProductFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtProductDFA"],

Cell["ExtQuotientDFA", "ObjectName",
  CellTags->"ExtQuotientFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtQuotientFA"],

Cell[TextData[{
  StyleBox["ExtQuotientDFA[M1,M2,opts]", "MR"],
  "  returns the quotient automaton of two DFAs ",
  StyleBox["M1", "MR"],
  " and ",
  StyleBox["M2", "MR"],
  " (over the same alphabet). The left quotient of ",
  StyleBox["M2", "MR"],
  " with respect to ",
  StyleBox["M1", "MR"],
  " is calculated. "
}], "Usage",
  CellTags->"ExtQuotientFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "0", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtQuotientFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["QuotientMachineFA",
    ButtonData:>"QuotientMachineFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["QuotientDFA",
    ButtonData:>"QuotientDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtQuotientFA"],

Cell["ExtREToFA", "ObjectName",
  CellTags->"ExtREToFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtREToFA"],

Cell[TextData[{
  StyleBox["ExtREToFA[reg,opts]", "MR"],
  "  converts a regular expression to an finite state machine."
}], "Usage",
  CellTags->"ExtREToFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"EpsElim", "\[Rule]", "True", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtREToFA"],

Cell[TextData[{
  "Has attribute ",
  StyleBox["HoldFirst", "MR"],
  "."
}], "Notes",
  CellTags->"ExtREToFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["RegularExpressionToFA",
    ButtonData:>"RegularExpressionToFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtREToFA"],

Cell["ExtStronglyConnectedComponents", "ObjectName",
  CellTags->"ExtStronglyConnectedComponents"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtStronglyConnectedComponents"],

Cell[TextData[{
  StyleBox["ExtStronglyConnectedComponents[G,opts]", "MR"],
  "  computes the strongly connected components of digraph ",
  StyleBox["G", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtStronglyConnectedComponents"],

Cell["noteworthy", "Notes",
  CellTags->"ExtStronglyConnectedComponents"],

Cell[TextData[{
  "See also ",
  ButtonBox["StronglyConnectedComponents",
    ButtonData:>"StronglyConnectedComponents",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtStronglyConnectedComponents"],

Cell["ExtSyntacticSG", "ObjectName",
  CellTags->"ExtSyntacticSG"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtSyntacticSG"],

Cell[TextData[{
  StyleBox["ExtSyntacticSG[M,opts]", "MR"],
  "  generates the syntactic semigroup of DFA ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtSyntacticSG"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Equations", "\[Rule]", "False", "-"},
          {"DClasses", "\[Rule]", "False", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtSyntacticSG"],

Cell[TextData[{
  "See also ",
  ButtonBox["ExtGenerateSG",
    ButtonData:>"ExtGenerateSG",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["SyntacticSG",
    ButtonData:>"SyntacticSG",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtSyntacticSG"],

Cell["ExtToDFASize", "ObjectName",
  CellTags->"ExtToDFASize"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtToDFASize"],

Cell[TextData[{
  StyleBox["ExtToDFASize[M]", "MR"],
  "  returns the size of the accessible part of the power set machine of ",
  StyleBox["M", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtToDFASize"],

Cell["Has potentially exponential time and space requirement.", "Notes",
  CellTags->"ExtToDFASize"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  " ."
}], "Notes",
  CellTags->"ExtToDFASize"],

Cell["ExtToDFAWitnesses", "ObjectName",
  CellTags->"ExtToDFAWitnesses"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtToDFAWitnesses"],

Cell[TextData[{
  StyleBox["ExtToDFAWitnesses[M]", "MR"],
  "  returns a list of witnesses for the states of the power set machine. "
}], "Usage",
  CellTags->"ExtToDFAWitnesses"],

Cell[TextData[{
  "See also ",
  ButtonBox["ExtToDFA",
    ButtonData:>"ExtToDFA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtToDFAWitnesses"],

Cell["ExtToDFA", "ObjectName",
  CellTags->"ExtToDFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtToDFA"],

Cell[TextData[{
  StyleBox["ExtToDFA[M,opts]", "MR"],
  "  converts finite state machine ",
  StyleBox["M", "MR"],
  " to a DFA. "
}], "Usage",
  CellTags->"ExtToDFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "0", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtToDFA"],

Cell["Has potentially exponential time and space complexity.", "Notes",
  CellTags->"ExtToDFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToDFA",
    ButtonData:>"ToDFA",
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Notes",
  CellTags->"ExtToDFA"],

Cell["ExtToKernelFA", "ObjectName",
  CellTags->"ExtToKernelFA"],

Cell["Type: function external", "Highlight",
  CellTags->"ExtToKernelFA"],

Cell[TextData[{
  StyleBox["ExtToKernelFA[M,L]", "MR"],
  "  computes the kernel automaton of ",
  StyleBox["M", "MR"],
  " where M is an \[Epsilon]-free SA or FA. "
}], "Usage",
  CellTags->"ExtToKernelFA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "1", "-"},
          {"Full", "\[Rule]", "False", "True"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtToKernelFA"],

Cell[TextData[{
  StyleBox["L", "MR"],
  " is a list of sets of states that are the generators of the kernel \
automaton. "
}], "Notes",
  CellTags->"ExtToKernelFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ToKernelFA",
    ButtonData:>"ToKernelFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtToKernelFA"],

Cell["ExtToWelchCA", "ObjectName",
  CellTags->"ExtToWelchCA"],

Cell["Type: function  external", "Highlight",
  CellTags->"ExtToWelchCA"],

Cell[TextData[{
  StyleBox["ExtToWelchCA[C,opts]", "MR"],
  "  computes the Welch indices and Welch automata for a cellular automaton \
",
  StyleBox["C", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtToWelchCA"],

Cell[TextData[{
  "Options",
  "\n",
  Cell[BoxData[GridBox[{
          {"Normalize", "\[Rule]", "1", "-"}
          },
        ColumnWidths->Automatic,
        ColumnAlignments->{Left}]]]
}], "Notes",
  CellTags->"ExtToWelchCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["WelchCA",
    ButtonData:>"WelchCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtToWelchCA"],

Cell["ExtWelchCA", "ObjectName",
  CellTags->"ExtWelchCA"],

Cell["Type: function", "Highlight",
  CellTags->"ExtWelchCA"],

Cell[TextData[{
  StyleBox["ExtWelchCA[C]", "MR"],
  "  computes the Welch indices for a cellular automaton ",
  StyleBox["C", "MR"],
  ". "
}], "Usage",
  CellTags->"ExtWelchCA"],

Cell[TextData[{
  "See also ",
  ButtonBox["ExtToWelchCA",
    ButtonData:>"ExtToWelchCA",
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["WelchCA",
    ButtonData:>"WelchCA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"ExtWelchCA"],

Cell["RebuildFA", "ObjectName",
  CellTags->"RebuildFA"],

Cell["Type: function", "Highlight",
  CellTags->"RebuildFA"],

Cell[TextData[{
  StyleBox["RebuildFA[Mnew,Mold,st,norm]", "MR"],
  "  rebuilds a FSM received from the link."
}], "Usage",
  CellTags->"RebuildFA"],

Cell[TextData[{
  "See also ",
  ButtonBox["DemolishFA",
    ButtonData:>"DemolishFA",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes",
  CellTags->"RebuildFA"],

Cell["SendProgram", "ObjectName",
  CellTags->"SendProgram"],

Cell["Type: function", "Highlight",
  CellTags->"SendProgram"],

Cell[TextData[{
  StyleBox["SendProgram[prog]", "MR"],
  "  sends a command to ",
  StyleBox["aut", "Input"],
  ", the external automata calculator. Uses ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  ". Stringifies arguments and concatenates them in order to produce a string \
suitable for ",
  StyleBox["MLParseProg", "MR"],
  ". This command is used extensively in ",
  StyleBox["extaut.m", "Input"],
  ". "
}], "Usage",
  CellTags->"SendProgram"],

Cell[TextData[{
  StyleBox["SendProgram", "MR"],
  " checks the result returned by ",
  StyleBox["MLParseProg", "MR"],
  ", and flushes the link if need be. "
}], "Notes",
  CellTags->"SendProgram"],

Cell[TextData[{
  "Do not use ",
  StyleBox["SendProgram", "MR"],
  " directly unless you are familiar with the syntax of the input language \
for the automata calculator. The link may break or hang if you send improper \
commands. "
}], "Notes",
  CellTags->"SendProgram"],

Cell[CellGroupData[{

Cell["Further Examples", "ExampleSection",
  CellTags->"SendProgram"],

Cell["\<\
A simple example. This only works if the external code is properly \
installed and the link activated.\
\>", "ExampleText",
  CellTags->"SendProgram"],

Cell[CellGroupData[{

Cell["SendProgram[\"x = (1,2,3)\"]", "Input",
  CellLabel->"In[20]:=",
  CellTags->"SendProgram"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["SendProgram[\"x\"]", "Input",
  CellLabel->"In[21]:=",
  CellTags->"SendProgram"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]]
}, Closed]],

Cell["$linkDebug", "ObjectName",
  CellTags->"linkDebug"],

Cell["Type: sysvar", "Highlight",
  CellTags->"linkDebug"],

Cell[TextData[{
  StyleBox["$linkDebug,", "MR"],
  " if set to ",
  StyleBox["True", "MR"],
  ", causes the actual command string sent to the external parser to be \
displayed."
}], "Usage",
  CellTags->"linkDebug"],

Cell["\<\
This is useful only in debugging, and hopelessly confusing \
otherwise. \
\>", "Notes",
  CellTags->"linkDebug"],

Cell["$maxParseSize", "ObjectName",
  CellTags->"maxParseSize"],

Cell["Type: sysvar", "Highlight",
  CellTags->"maxParseSize"],

Cell[TextData[{
  StyleBox["$maxParseSize", "MR"],
  "  controls the size of the longest possible command string sent to extaut, \
default is 200000. "
}], "Usage",
  CellTags->"maxParseSize"],

Cell[TextData[{
  "Changes must be made in ",
  StyleBox["parser.h", "MR"],
  " (",
  StyleBox["MAX_PARSE_SIZE", "MR"],
  ") and ",
  StyleBox["extaut.m", "Input"],
  ". You will have to recompile the external code for the changes to take \
effect."
}], "Notes",
  CellTags->"maxParseSize"],

Cell["Will be obsolete in the next release. ", "Notes",
  CellTags->"maxParseSize"],

Cell["$res", "ObjectName",
  CellTags->"res"],

Cell["Type: sysvar", "Highlight",
  CellTags->"res"],

Cell[TextData[{
  StyleBox["$res", "MR"],
  "   is used to return results from external computations. In particular in \
case of an error, ",
  StyleBox["$res", "MR"],
  " is set to ",
  StyleBox["$Failure", "MR"],
  "."
}], "Usage",
  CellTags->"res"]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{768, 752},
WindowMargins->{{Automatic, 124}, {32, Automatic}},
LanguageCategory->"Mathematica",
Magnification->1.5,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DemolishFA"->{
    Cell[1754, 51, 58, 1, 42, "ObjectName",
      CellTags->"DemolishFA"],
    Cell[1815, 54, 61, 1, 74, "Highlight",
      CellTags->"DemolishFA"],
    Cell[1879, 57, 223, 7, 64, "Usage",
      CellTags->"DemolishFA"],
    Cell[2105, 66, 218, 5, 54, "Notes",
      CellTags->"DemolishFA"]},
  "RebuildFA"->{
    Cell[2326, 73, 160, 7, 33, "Notes",
      CellTags->"RebuildFA"],
    Cell[23145, 975, 56, 1, 42, "ObjectName",
      CellTags->"RebuildFA"],
    Cell[23204, 978, 60, 1, 74, "Highlight",
      CellTags->"RebuildFA"],
    Cell[23267, 981, 148, 4, 43, "Usage",
      CellTags->"RebuildFA"],
    Cell[23418, 987, 162, 7, 33, "Notes",
      CellTags->"RebuildFA"]},
  "ExtAccessibleFA"->{
    Cell[2489, 82, 68, 1, 42, "ObjectName",
      CellTags->"ExtAccessibleFA"],
    Cell[2560, 85, 75, 1, 74, "Highlight",
      CellTags->"ExtAccessibleFA"],
    Cell[2638, 88, 180, 6, 43, "Usage",
      CellTags->"ExtAccessibleFA"],
    Cell[2821, 96, 255, 9, 58, "Notes",
      CellTags->"ExtAccessibleFA"],
    Cell[3079, 107, 172, 7, 33, "Notes",
      CellTags->"ExtAccessibleFA"]},
  "ExtBalancedQCA"->{
    Cell[3254, 116, 66, 1, 42, "ObjectName",
      CellTags->"ExtBalancedQCA"],
    Cell[3323, 119, 74, 1, 74, "Highlight",
      CellTags->"ExtBalancedQCA"],
    Cell[3400, 122, 216, 9, 43, "Usage",
      CellTags->"ExtBalancedQCA"],
    Cell[3619, 133, 139, 4, 33, "Notes",
      CellTags->"ExtBalancedQCA"],
    Cell[3761, 139, 167, 7, 33, "Notes",
      CellTags->"ExtBalancedQCA"]},
  "ExtClassifyCA"->{
    Cell[3931, 148, 64, 1, 42, "ObjectName",
      CellTags->"ExtClassifyCA"],
    Cell[3998, 151, 73, 1, 74, "Highlight",
      CellTags->"ExtClassifyCA"],
    Cell[4074, 154, 197, 5, 64, "Usage",
      CellTags->"ExtClassifyCA"],
    Cell[4274, 161, 468, 17, 128, "Notes",
      CellTags->"ExtClassifyCA"],
    Cell[4745, 180, 160, 4, 54, "Notes",
      CellTags->"ExtClassifyCA"],
    Cell[4908, 186, 273, 11, 33, "Notes",
      CellTags->"ExtClassifyCA"]},
  "ExtComposeCA"->{
    Cell[5184, 199, 62, 1, 42, "ObjectName",
      CellTags->"ExtComposeCA"],
    Cell[5249, 202, 72, 1, 74, "Highlight",
      CellTags->"ExtComposeCA"],
    Cell[5324, 205, 220, 8, 43, "Usage",
      CellTags->"ExtComposeCA"],
    Cell[5547, 215, 163, 7, 33, "Notes",
      CellTags->"ExtComposeCA"]},
  "ExtDefiniteQFA"->{
    Cell[5713, 224, 66, 1, 42, "ObjectName",
      CellTags->"ExtDefiniteQFA"],
    Cell[5782, 227, 74, 1, 74, "Highlight",
      CellTags->"ExtDefiniteQFA"],
    Cell[5859, 230, 170, 6, 43, "Usage",
      CellTags->"ExtDefiniteQFA"],
    Cell[6032, 238, 230, 9, 58, "Notes",
      CellTags->"ExtDefiniteQFA"],
    Cell[6265, 249, 169, 7, 33, "Notes",
      CellTags->"ExtDefiniteQFA"]},
  "ExtEpsilonEliminationFA"->{
    Cell[6437, 258, 84, 1, 42, "ObjectName",
      CellTags->"ExtEpsilonEliminationFA"],
    Cell[6524, 261, 83, 1, 74, "Highlight",
      CellTags->"ExtEpsilonEliminationFA"],
    Cell[6610, 264, 196, 6, 43, "Usage",
      CellTags->"ExtEpsilonEliminationFA"],
    Cell[6809, 272, 263, 9, 58, "Notes",
      CellTags->"ExtEpsilonEliminationFA"],
    Cell[7075, 283, 196, 7, 33, "Notes",
      CellTags->"ExtEpsilonEliminationFA"]},
  "ExtEquivalentQFA"->{
    Cell[7274, 292, 70, 1, 42, "ObjectName",
      CellTags->"ExtEquivalentQFA"],
    Cell[7347, 295, 76, 1, 74, "Highlight",
      CellTags->"ExtEquivalentQFA"],
    Cell[7426, 298, 297, 9, 64, "Usage",
      CellTags->"ExtEquivalentQFA"],
    Cell[7726, 309, 157, 4, 33, "Notes",
      CellTags->"ExtEquivalentQFA"],
    Cell[7886, 315, 175, 7, 33, "Notes",
      CellTags->"ExtEquivalentQFA"]},
  "ExtGenerateSG"->{
    Cell[8064, 324, 64, 1, 42, "ObjectName",
      CellTags->"ExtGenerateSG"],
    Cell[8131, 327, 73, 1, 74, "Highlight",
      CellTags->"ExtGenerateSG"],
    Cell[8207, 330, 189, 6, 43, "Usage",
      CellTags->"ExtGenerateSG"],
    Cell[8399, 338, 283, 10, 80, "Notes",
      CellTags->"ExtGenerateSG"],
    Cell[8685, 350, 165, 5, 33, "Notes",
      CellTags->"ExtGenerateSG"],
    Cell[8853, 357, 176, 6, 33, "Notes",
      CellTags->"ExtGenerateSG"],
    Cell[9032, 365, 192, 6, 33, "Notes",
      CellTags->"ExtGenerateSG"],
    Cell[9227, 373, 432, 12, 75, "Notes",
      CellTags->"ExtGenerateSG"],
    Cell[9662, 387, 166, 7, 33, "Notes",
      CellTags->"ExtGenerateSG"]},
  "ExtIsomorphicQDFA"->{
    Cell[9831, 396, 72, 1, 42, "ObjectName",
      CellTags->"ExtIsomorphicQDFA"],
    Cell[9906, 399, 77, 1, 74, "Highlight",
      CellTags->"ExtIsomorphicQDFA"],
    Cell[9986, 402, 220, 8, 43, "Usage",
      CellTags->"ExtIsomorphicQDFA"],
    Cell[10209, 412, 131, 4, 33, "Notes",
      CellTags->"ExtIsomorphicQDFA"],
    Cell[10343, 418, 283, 11, 33, "Notes",
      CellTags->"ExtIsomorphicQDFA"]},
  "ExtLanguageFA"->{
    Cell[10629, 431, 64, 1, 42, "ObjectName",
      CellTags->"ExtLanguageFA"],
    Cell[10696, 434, 73, 1, 74, "Highlight",
      CellTags->"ExtLanguageFA"],
    Cell[10772, 437, 243, 8, 64, "Usage",
      CellTags->"ExtLanguageFA"],
    Cell[11018, 447, 179, 5, 33, "Notes",
      CellTags->"ExtLanguageFA"],
    Cell[11200, 454, 163, 6, 33, "Notes",
      CellTags->"ExtLanguageFA"],
    Cell[11366, 462, 166, 7, 33, "Notes",
      CellTags->"ExtLanguageFA"]},
  "ExtMinimizeFASize"->{
    Cell[11535, 471, 72, 1, 42, "ObjectName",
      CellTags->"ExtMinimizeFASize"],
    Cell[11610, 474, 77, 1, 74, "Highlight",
      CellTags->"ExtMinimizeFASize"],
    Cell[11690, 477, 181, 6, 43, "Usage",
      CellTags->"ExtMinimizeFASize"],
    Cell[11874, 485, 223, 5, 54, "Notes",
      CellTags->"ExtMinimizeFASize"],
    Cell[12100, 492, 218, 5, 54, "Notes",
      CellTags->"ExtMinimizeFASize"],
    Cell[12321, 499, 274, 11, 33, "Notes",
      CellTags->"ExtMinimizeFASize"]},
  "ExtMinimizeFA"->{
    Cell[12598, 512, 64, 1, 42, "ObjectName",
      CellTags->"ExtMinimizeFA"],
    Cell[12665, 515, 73, 1, 74, "Highlight",
      CellTags->"ExtMinimizeFA"],
    Cell[12741, 518, 171, 6, 43, "Usage",
      CellTags->"ExtMinimizeFA"],
    Cell[12915, 526, 253, 9, 58, "Notes",
      CellTags->"ExtMinimizeFA"],
    Cell[13171, 537, 209, 6, 54, "Notes",
      CellTags->"ExtMinimizeFA"],
    Cell[13383, 545, 161, 4, 54, "Notes",
      CellTags->"ExtMinimizeFA"],
    Cell[13547, 551, 166, 7, 33, "Notes",
      CellTags->"ExtMinimizeFA"]},
  "ExtOrbitCA"->{
    Cell[13716, 560, 58, 1, 42, "ObjectName",
      CellTags->"ExtOrbitCA"],
    Cell[13777, 563, 70, 1, 74, "Highlight",
      CellTags->"ExtOrbitCA"],
    Cell[13850, 566, 271, 10, 64, "Usage",
      CellTags->"ExtOrbitCA"],
    Cell[14124, 578, 235, 9, 58, "Notes",
      CellTags->"ExtOrbitCA"],
    Cell[14362, 589, 258, 11, 33, "Notes",
      CellTags->"ExtOrbitCA"]},
  "ExtProductDFA"->{
    Cell[14623, 602, 64, 1, 42, "ObjectName",
      CellTags->"ExtProductDFA"],
    Cell[14690, 605, 73, 1, 74, "Highlight",
      CellTags->"ExtProductDFA"],
    Cell[14766, 608, 250, 5, 64, "Usage",
      CellTags->"ExtProductDFA"],
    Cell[15019, 615, 230, 9, 58, "Notes",
      CellTags->"ExtProductDFA"],
    Cell[15252, 626, 164, 7, 33, "Notes",
      CellTags->"ExtProductDFA"]},
  "ExtQuotientFA"->{
    Cell[15419, 635, 65, 1, 42, "ObjectName",
      CellTags->"ExtQuotientFA"],
    Cell[15487, 638, 73, 1, 74, "Highlight",
      CellTags->"ExtQuotientFA"],
    Cell[15563, 641, 361, 12, 64, "Usage",
      CellTags->"ExtQuotientFA"],
    Cell[15927, 655, 230, 9, 58, "Notes",
      CellTags->"ExtQuotientFA"],
    Cell[16160, 666, 281, 11, 33, "Notes",
      CellTags->"ExtQuotientFA"]},
  "ExtREToFA"->{
    Cell[16444, 679, 56, 1, 42, "ObjectName",
      CellTags->"ExtREToFA"],
    Cell[16503, 682, 69, 1, 74, "Highlight",
      CellTags->"ExtREToFA"],
    Cell[16575, 685, 158, 4, 43, "Usage",
      CellTags->"ExtREToFA"],
    Cell[16736, 691, 227, 9, 58, "Notes",
      CellTags->"ExtREToFA"],
    Cell[16966, 702, 110, 5, 33, "Notes",
      CellTags->"ExtREToFA"],
    Cell[17079, 709, 184, 7, 33, "Notes",
      CellTags->"ExtREToFA"]},
  "ExtStronglyConnectedComponents"->{
    Cell[17266, 718, 98, 1, 42, "ObjectName",
      CellTags->"ExtStronglyConnectedComponents"],
    Cell[17367, 721, 90, 1, 74, "Highlight",
      CellTags->"ExtStronglyConnectedComponents"],
    Cell[17460, 724, 226, 6, 64, "Usage",
      CellTags->"ExtStronglyConnectedComponents"],
    Cell[17689, 732, 73, 1, 33, "Notes",
      CellTags->"ExtStronglyConnectedComponents"],
    Cell[17765, 735, 217, 7, 33, "Notes",
      CellTags->"ExtStronglyConnectedComponents"]},
  "ExtSyntacticSG"->{
    Cell[17985, 744, 66, 1, 42, "ObjectName",
      CellTags->"ExtSyntacticSG"],
    Cell[18054, 747, 74, 1, 74, "Highlight",
      CellTags->"ExtSyntacticSG"],
    Cell[18131, 750, 181, 6, 43, "Usage",
      CellTags->"ExtSyntacticSG"],
    Cell[18315, 758, 284, 10, 80, "Notes",
      CellTags->"ExtSyntacticSG"],
    Cell[18602, 770, 274, 11, 33, "Notes",
      CellTags->"ExtSyntacticSG"]},
  "ExtToDFASize"->{
    Cell[18879, 783, 62, 1, 42, "ObjectName",
      CellTags->"ExtToDFASize"],
    Cell[18944, 786, 72, 1, 74, "Highlight",
      CellTags->"ExtToDFASize"],
    Cell[19019, 789, 199, 6, 43, "Usage",
      CellTags->"ExtToDFASize"],
    Cell[19221, 797, 100, 1, 33, "Notes",
      CellTags->"ExtToDFASize"],
    Cell[19324, 800, 156, 7, 33, "Notes",
      CellTags->"ExtToDFASize"]},
  "ExtToDFAWitnesses"->{
    Cell[19483, 809, 72, 1, 42, "ObjectName",
      CellTags->"ExtToDFAWitnesses"],
    Cell[19558, 812, 77, 1, 74, "Highlight",
      CellTags->"ExtToDFAWitnesses"],
    Cell[19638, 815, 179, 4, 43, "Usage",
      CellTags->"ExtToDFAWitnesses"],
    Cell[19820, 821, 255, 11, 33, "Notes",
      CellTags->"ExtToDFAWitnesses"]},
  "ExtToDFA"->{
    Cell[20078, 834, 54, 1, 42, "ObjectName",
      CellTags->"ExtToDFA"],
    Cell[20135, 837, 68, 1, 74, "Highlight",
      CellTags->"ExtToDFA"],
    Cell[20206, 840, 167, 6, 43, "Usage",
      CellTags->"ExtToDFA"],
    Cell[20376, 848, 225, 9, 58, "Notes",
      CellTags->"ExtToDFA"],
    Cell[20604, 859, 95, 1, 33, "Notes",
      CellTags->"ExtToDFA"],
    Cell[20702, 862, 152, 7, 33, "Notes",
      CellTags->"ExtToDFA"]},
  "ExtToKernelFA"->{
    Cell[20857, 871, 64, 1, 42, "ObjectName",
      CellTags->"ExtToKernelFA"],
    Cell[20924, 874, 73, 1, 74, "Highlight",
      CellTags->"ExtToKernelFA"],
    Cell[21000, 877, 207, 6, 43, "Usage",
      CellTags->"ExtToKernelFA"],
    Cell[21210, 885, 278, 10, 80, "Notes",
      CellTags->"ExtToKernelFA"],
    Cell[21491, 897, 165, 5, 33, "Notes",
      CellTags->"ExtToKernelFA"],
    Cell[21659, 904, 166, 7, 33, "Notes",
      CellTags->"ExtToKernelFA"]},
  "ExtToWelchCA"->{
    Cell[21828, 913, 62, 1, 42, "ObjectName",
      CellTags->"ExtToWelchCA"],
    Cell[21893, 916, 73, 1, 74, "Highlight",
      CellTags->"ExtToWelchCA"],
    Cell[21969, 919, 209, 7, 64, "Usage",
      CellTags->"ExtToWelchCA"],
    Cell[22181, 928, 229, 9, 58, "Notes",
      CellTags->"ExtToWelchCA"],
    Cell[22413, 939, 159, 7, 33, "Notes",
      CellTags->"ExtToWelchCA"]},
  "ExtWelchCA"->{
    Cell[22575, 948, 58, 1, 42, "ObjectName",
      CellTags->"ExtWelchCA"],
    Cell[22636, 951, 61, 1, 74, "Highlight",
      CellTags->"ExtWelchCA"],
    Cell[22700, 954, 179, 6, 43, "Usage",
      CellTags->"ExtWelchCA"],
    Cell[22882, 962, 260, 11, 33, "Notes",
      CellTags->"ExtWelchCA"]},
  "SendProgram"->{
    Cell[23583, 996, 60, 1, 42, "ObjectName",
      CellTags->"SendProgram"],
    Cell[23646, 999, 62, 1, 74, "Highlight",
      CellTags->"SendProgram"],
    Cell[23711, 1002, 458, 14, 91, "Usage",
      CellTags->"SendProgram"],
    Cell[24172, 1018, 198, 6, 33, "Notes",
      CellTags->"SendProgram"],
    Cell[24373, 1026, 273, 7, 54, "Notes",
      CellTags->"SendProgram"],
    Cell[24671, 1037, 69, 1, 59, "ExampleSection",
      CellTags->"SendProgram"],
    Cell[24743, 1040, 160, 4, 70, "ExampleText",
      CellTags->"SendProgram"],
    Cell[24928, 1048, 97, 2, 70, "Input",
      CellTags->"SendProgram"],
    Cell[25133, 1059, 87, 2, 70, "Input",
      CellTags->"SendProgram"]},
  "linkDebug"->{
    Cell[25318, 1069, 57, 1, 31, "ObjectName",
      CellTags->"linkDebug"],
    Cell[25378, 1072, 58, 1, 74, "Highlight",
      CellTags->"linkDebug"],
    Cell[25439, 1075, 215, 7, 64, "Usage",
      CellTags->"linkDebug"],
    Cell[25657, 1084, 122, 4, 33, "Notes",
      CellTags->"linkDebug"]},
  "maxParseSize"->{
    Cell[25782, 1090, 63, 1, 42, "ObjectName",
      CellTags->"maxParseSize"],
    Cell[25848, 1093, 61, 1, 74, "Highlight",
      CellTags->"maxParseSize"],
    Cell[25912, 1096, 192, 5, 64, "Usage",
      CellTags->"maxParseSize"],
    Cell[26107, 1103, 290, 10, 57, "Notes",
      CellTags->"maxParseSize"],
    Cell[26400, 1115, 83, 1, 33, "Notes",
      CellTags->"maxParseSize"]},
  "res"->{
    Cell[26486, 1118, 45, 1, 42, "ObjectName",
      CellTags->"res"],
    Cell[26534, 1121, 52, 1, 74, "Highlight",
      CellTags->"res"],
    Cell[26589, 1124, 252, 9, 64, "Usage",
      CellTags->"res"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DemolishFA", 27518, 1153},
  {"RebuildFA", 27827, 1162},
  {"ExtAccessibleFA", 28216, 1173},
  {"ExtBalancedQCA", 28627, 1184},
  {"ExtClassifyCA", 29036, 1195},
  {"ExtComposeCA", 29517, 1208},
  {"ExtDefiniteQFA", 29843, 1217},
  {"ExtEpsilonEliminationFA", 30262, 1228},
  {"ExtEquivalentQFA", 30719, 1239},
  {"ExtGenerateSG", 31138, 1250},
  {"ExtIsomorphicQDFA", 31848, 1269},
  {"ExtLanguageFA", 32275, 1280},
  {"ExtMinimizeFASize", 32764, 1293},
  {"ExtMinimizeFA", 33274, 1306},
  {"ExtOrbitCA", 33832, 1321},
  {"ExtProductDFA", 34228, 1332},
  {"ExtQuotientFA", 34637, 1343},
  {"ExtREToFA", 35044, 1354},
  {"ExtStronglyConnectedComponents", 35522, 1367},
  {"ExtSyntacticSG", 36016, 1378},
  {"ExtToDFASize", 36431, 1389},
  {"ExtToDFAWitnesses", 36839, 1400},
  {"ExtToDFA", 37184, 1409},
  {"ExtToKernelFA", 37638, 1422},
  {"ExtToWelchCA", 38123, 1435},
  {"ExtWelchCA", 38524, 1446},
  {"SendProgram", 38844, 1455},
  {"linkDebug", 39555, 1474},
  {"maxParseSize", 39875, 1483},
  {"res", 40274, 1494}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 58, 1, 42, "ObjectName",
  CellTags->"DemolishFA"],
Cell[1815, 54, 61, 1, 74, "Highlight",
  CellTags->"DemolishFA"],
Cell[1879, 57, 223, 7, 64, "Usage",
  CellTags->"DemolishFA"],
Cell[2105, 66, 218, 5, 54, "Notes",
  CellTags->"DemolishFA"],
Cell[2326, 73, 160, 7, 33, "Notes",
  CellTags->"RebuildFA"],
Cell[2489, 82, 68, 1, 42, "ObjectName",
  CellTags->"ExtAccessibleFA"],
Cell[2560, 85, 75, 1, 74, "Highlight",
  CellTags->"ExtAccessibleFA"],
Cell[2638, 88, 180, 6, 43, "Usage",
  CellTags->"ExtAccessibleFA"],
Cell[2821, 96, 255, 9, 58, "Notes",
  CellTags->"ExtAccessibleFA"],
Cell[3079, 107, 172, 7, 33, "Notes",
  CellTags->"ExtAccessibleFA"],
Cell[3254, 116, 66, 1, 42, "ObjectName",
  CellTags->"ExtBalancedQCA"],
Cell[3323, 119, 74, 1, 74, "Highlight",
  CellTags->"ExtBalancedQCA"],
Cell[3400, 122, 216, 9, 43, "Usage",
  CellTags->"ExtBalancedQCA"],
Cell[3619, 133, 139, 4, 33, "Notes",
  CellTags->"ExtBalancedQCA"],
Cell[3761, 139, 167, 7, 33, "Notes",
  CellTags->"ExtBalancedQCA"],
Cell[3931, 148, 64, 1, 42, "ObjectName",
  CellTags->"ExtClassifyCA"],
Cell[3998, 151, 73, 1, 74, "Highlight",
  CellTags->"ExtClassifyCA"],
Cell[4074, 154, 197, 5, 64, "Usage",
  CellTags->"ExtClassifyCA"],
Cell[4274, 161, 468, 17, 128, "Notes",
  CellTags->"ExtClassifyCA"],
Cell[4745, 180, 160, 4, 54, "Notes",
  CellTags->"ExtClassifyCA"],
Cell[4908, 186, 273, 11, 33, "Notes",
  CellTags->"ExtClassifyCA"],
Cell[5184, 199, 62, 1, 42, "ObjectName",
  CellTags->"ExtComposeCA"],
Cell[5249, 202, 72, 1, 74, "Highlight",
  CellTags->"ExtComposeCA"],
Cell[5324, 205, 220, 8, 43, "Usage",
  CellTags->"ExtComposeCA"],
Cell[5547, 215, 163, 7, 33, "Notes",
  CellTags->"ExtComposeCA"],
Cell[5713, 224, 66, 1, 42, "ObjectName",
  CellTags->"ExtDefiniteQFA"],
Cell[5782, 227, 74, 1, 74, "Highlight",
  CellTags->"ExtDefiniteQFA"],
Cell[5859, 230, 170, 6, 43, "Usage",
  CellTags->"ExtDefiniteQFA"],
Cell[6032, 238, 230, 9, 58, "Notes",
  CellTags->"ExtDefiniteQFA"],
Cell[6265, 249, 169, 7, 33, "Notes",
  CellTags->"ExtDefiniteQFA"],
Cell[6437, 258, 84, 1, 42, "ObjectName",
  CellTags->"ExtEpsilonEliminationFA"],
Cell[6524, 261, 83, 1, 74, "Highlight",
  CellTags->"ExtEpsilonEliminationFA"],
Cell[6610, 264, 196, 6, 43, "Usage",
  CellTags->"ExtEpsilonEliminationFA"],
Cell[6809, 272, 263, 9, 58, "Notes",
  CellTags->"ExtEpsilonEliminationFA"],
Cell[7075, 283, 196, 7, 33, "Notes",
  CellTags->"ExtEpsilonEliminationFA"],
Cell[7274, 292, 70, 1, 42, "ObjectName",
  CellTags->"ExtEquivalentQFA"],
Cell[7347, 295, 76, 1, 74, "Highlight",
  CellTags->"ExtEquivalentQFA"],
Cell[7426, 298, 297, 9, 64, "Usage",
  CellTags->"ExtEquivalentQFA"],
Cell[7726, 309, 157, 4, 33, "Notes",
  CellTags->"ExtEquivalentQFA"],
Cell[7886, 315, 175, 7, 33, "Notes",
  CellTags->"ExtEquivalentQFA"],
Cell[8064, 324, 64, 1, 42, "ObjectName",
  CellTags->"ExtGenerateSG"],
Cell[8131, 327, 73, 1, 74, "Highlight",
  CellTags->"ExtGenerateSG"],
Cell[8207, 330, 189, 6, 43, "Usage",
  CellTags->"ExtGenerateSG"],
Cell[8399, 338, 283, 10, 80, "Notes",
  CellTags->"ExtGenerateSG"],
Cell[8685, 350, 165, 5, 33, "Notes",
  CellTags->"ExtGenerateSG"],
Cell[8853, 357, 176, 6, 33, "Notes",
  CellTags->"ExtGenerateSG"],
Cell[9032, 365, 192, 6, 33, "Notes",
  CellTags->"ExtGenerateSG"],
Cell[9227, 373, 432, 12, 75, "Notes",
  CellTags->"ExtGenerateSG"],
Cell[9662, 387, 166, 7, 33, "Notes",
  CellTags->"ExtGenerateSG"],
Cell[9831, 396, 72, 1, 42, "ObjectName",
  CellTags->"ExtIsomorphicQDFA"],
Cell[9906, 399, 77, 1, 74, "Highlight",
  CellTags->"ExtIsomorphicQDFA"],
Cell[9986, 402, 220, 8, 43, "Usage",
  CellTags->"ExtIsomorphicQDFA"],
Cell[10209, 412, 131, 4, 33, "Notes",
  CellTags->"ExtIsomorphicQDFA"],
Cell[10343, 418, 283, 11, 33, "Notes",
  CellTags->"ExtIsomorphicQDFA"],
Cell[10629, 431, 64, 1, 42, "ObjectName",
  CellTags->"ExtLanguageFA"],
Cell[10696, 434, 73, 1, 74, "Highlight",
  CellTags->"ExtLanguageFA"],
Cell[10772, 437, 243, 8, 64, "Usage",
  CellTags->"ExtLanguageFA"],
Cell[11018, 447, 179, 5, 33, "Notes",
  CellTags->"ExtLanguageFA"],
Cell[11200, 454, 163, 6, 33, "Notes",
  CellTags->"ExtLanguageFA"],
Cell[11366, 462, 166, 7, 33, "Notes",
  CellTags->"ExtLanguageFA"],
Cell[11535, 471, 72, 1, 42, "ObjectName",
  CellTags->"ExtMinimizeFASize"],
Cell[11610, 474, 77, 1, 74, "Highlight",
  CellTags->"ExtMinimizeFASize"],
Cell[11690, 477, 181, 6, 43, "Usage",
  CellTags->"ExtMinimizeFASize"],
Cell[11874, 485, 223, 5, 54, "Notes",
  CellTags->"ExtMinimizeFASize"],
Cell[12100, 492, 218, 5, 54, "Notes",
  CellTags->"ExtMinimizeFASize"],
Cell[12321, 499, 274, 11, 33, "Notes",
  CellTags->"ExtMinimizeFASize"],
Cell[12598, 512, 64, 1, 42, "ObjectName",
  CellTags->"ExtMinimizeFA"],
Cell[12665, 515, 73, 1, 74, "Highlight",
  CellTags->"ExtMinimizeFA"],
Cell[12741, 518, 171, 6, 43, "Usage",
  CellTags->"ExtMinimizeFA"],
Cell[12915, 526, 253, 9, 58, "Notes",
  CellTags->"ExtMinimizeFA"],
Cell[13171, 537, 209, 6, 54, "Notes",
  CellTags->"ExtMinimizeFA"],
Cell[13383, 545, 161, 4, 54, "Notes",
  CellTags->"ExtMinimizeFA"],
Cell[13547, 551, 166, 7, 33, "Notes",
  CellTags->"ExtMinimizeFA"],
Cell[13716, 560, 58, 1, 42, "ObjectName",
  CellTags->"ExtOrbitCA"],
Cell[13777, 563, 70, 1, 74, "Highlight",
  CellTags->"ExtOrbitCA"],
Cell[13850, 566, 271, 10, 64, "Usage",
  CellTags->"ExtOrbitCA"],
Cell[14124, 578, 235, 9, 58, "Notes",
  CellTags->"ExtOrbitCA"],
Cell[14362, 589, 258, 11, 33, "Notes",
  CellTags->"ExtOrbitCA"],
Cell[14623, 602, 64, 1, 42, "ObjectName",
  CellTags->"ExtProductDFA"],
Cell[14690, 605, 73, 1, 74, "Highlight",
  CellTags->"ExtProductDFA"],
Cell[14766, 608, 250, 5, 64, "Usage",
  CellTags->"ExtProductDFA"],
Cell[15019, 615, 230, 9, 58, "Notes",
  CellTags->"ExtProductDFA"],
Cell[15252, 626, 164, 7, 33, "Notes",
  CellTags->"ExtProductDFA"],
Cell[15419, 635, 65, 1, 42, "ObjectName",
  CellTags->"ExtQuotientFA"],
Cell[15487, 638, 73, 1, 74, "Highlight",
  CellTags->"ExtQuotientFA"],
Cell[15563, 641, 361, 12, 64, "Usage",
  CellTags->"ExtQuotientFA"],
Cell[15927, 655, 230, 9, 58, "Notes",
  CellTags->"ExtQuotientFA"],
Cell[16160, 666, 281, 11, 33, "Notes",
  CellTags->"ExtQuotientFA"],
Cell[16444, 679, 56, 1, 42, "ObjectName",
  CellTags->"ExtREToFA"],
Cell[16503, 682, 69, 1, 74, "Highlight",
  CellTags->"ExtREToFA"],
Cell[16575, 685, 158, 4, 43, "Usage",
  CellTags->"ExtREToFA"],
Cell[16736, 691, 227, 9, 58, "Notes",
  CellTags->"ExtREToFA"],
Cell[16966, 702, 110, 5, 33, "Notes",
  CellTags->"ExtREToFA"],
Cell[17079, 709, 184, 7, 33, "Notes",
  CellTags->"ExtREToFA"],
Cell[17266, 718, 98, 1, 42, "ObjectName",
  CellTags->"ExtStronglyConnectedComponents"],
Cell[17367, 721, 90, 1, 74, "Highlight",
  CellTags->"ExtStronglyConnectedComponents"],
Cell[17460, 724, 226, 6, 64, "Usage",
  CellTags->"ExtStronglyConnectedComponents"],
Cell[17689, 732, 73, 1, 33, "Notes",
  CellTags->"ExtStronglyConnectedComponents"],
Cell[17765, 735, 217, 7, 33, "Notes",
  CellTags->"ExtStronglyConnectedComponents"],
Cell[17985, 744, 66, 1, 42, "ObjectName",
  CellTags->"ExtSyntacticSG"],
Cell[18054, 747, 74, 1, 74, "Highlight",
  CellTags->"ExtSyntacticSG"],
Cell[18131, 750, 181, 6, 43, "Usage",
  CellTags->"ExtSyntacticSG"],
Cell[18315, 758, 284, 10, 80, "Notes",
  CellTags->"ExtSyntacticSG"],
Cell[18602, 770, 274, 11, 33, "Notes",
  CellTags->"ExtSyntacticSG"],
Cell[18879, 783, 62, 1, 42, "ObjectName",
  CellTags->"ExtToDFASize"],
Cell[18944, 786, 72, 1, 74, "Highlight",
  CellTags->"ExtToDFASize"],
Cell[19019, 789, 199, 6, 43, "Usage",
  CellTags->"ExtToDFASize"],
Cell[19221, 797, 100, 1, 33, "Notes",
  CellTags->"ExtToDFASize"],
Cell[19324, 800, 156, 7, 33, "Notes",
  CellTags->"ExtToDFASize"],
Cell[19483, 809, 72, 1, 42, "ObjectName",
  CellTags->"ExtToDFAWitnesses"],
Cell[19558, 812, 77, 1, 74, "Highlight",
  CellTags->"ExtToDFAWitnesses"],
Cell[19638, 815, 179, 4, 43, "Usage",
  CellTags->"ExtToDFAWitnesses"],
Cell[19820, 821, 255, 11, 33, "Notes",
  CellTags->"ExtToDFAWitnesses"],
Cell[20078, 834, 54, 1, 42, "ObjectName",
  CellTags->"ExtToDFA"],
Cell[20135, 837, 68, 1, 74, "Highlight",
  CellTags->"ExtToDFA"],
Cell[20206, 840, 167, 6, 43, "Usage",
  CellTags->"ExtToDFA"],
Cell[20376, 848, 225, 9, 58, "Notes",
  CellTags->"ExtToDFA"],
Cell[20604, 859, 95, 1, 33, "Notes",
  CellTags->"ExtToDFA"],
Cell[20702, 862, 152, 7, 33, "Notes",
  CellTags->"ExtToDFA"],
Cell[20857, 871, 64, 1, 42, "ObjectName",
  CellTags->"ExtToKernelFA"],
Cell[20924, 874, 73, 1, 74, "Highlight",
  CellTags->"ExtToKernelFA"],
Cell[21000, 877, 207, 6, 43, "Usage",
  CellTags->"ExtToKernelFA"],
Cell[21210, 885, 278, 10, 80, "Notes",
  CellTags->"ExtToKernelFA"],
Cell[21491, 897, 165, 5, 33, "Notes",
  CellTags->"ExtToKernelFA"],
Cell[21659, 904, 166, 7, 33, "Notes",
  CellTags->"ExtToKernelFA"],
Cell[21828, 913, 62, 1, 42, "ObjectName",
  CellTags->"ExtToWelchCA"],
Cell[21893, 916, 73, 1, 74, "Highlight",
  CellTags->"ExtToWelchCA"],
Cell[21969, 919, 209, 7, 64, "Usage",
  CellTags->"ExtToWelchCA"],
Cell[22181, 928, 229, 9, 58, "Notes",
  CellTags->"ExtToWelchCA"],
Cell[22413, 939, 159, 7, 33, "Notes",
  CellTags->"ExtToWelchCA"],
Cell[22575, 948, 58, 1, 42, "ObjectName",
  CellTags->"ExtWelchCA"],
Cell[22636, 951, 61, 1, 74, "Highlight",
  CellTags->"ExtWelchCA"],
Cell[22700, 954, 179, 6, 43, "Usage",
  CellTags->"ExtWelchCA"],
Cell[22882, 962, 260, 11, 33, "Notes",
  CellTags->"ExtWelchCA"],
Cell[23145, 975, 56, 1, 42, "ObjectName",
  CellTags->"RebuildFA"],
Cell[23204, 978, 60, 1, 74, "Highlight",
  CellTags->"RebuildFA"],
Cell[23267, 981, 148, 4, 43, "Usage",
  CellTags->"RebuildFA"],
Cell[23418, 987, 162, 7, 33, "Notes",
  CellTags->"RebuildFA"],
Cell[23583, 996, 60, 1, 42, "ObjectName",
  CellTags->"SendProgram"],
Cell[23646, 999, 62, 1, 74, "Highlight",
  CellTags->"SendProgram"],
Cell[23711, 1002, 458, 14, 91, "Usage",
  CellTags->"SendProgram"],
Cell[24172, 1018, 198, 6, 33, "Notes",
  CellTags->"SendProgram"],
Cell[24373, 1026, 273, 7, 54, "Notes",
  CellTags->"SendProgram"],

Cell[CellGroupData[{
Cell[24671, 1037, 69, 1, 59, "ExampleSection",
  CellTags->"SendProgram"],
Cell[24743, 1040, 160, 4, 70, "ExampleText",
  CellTags->"SendProgram"],

Cell[CellGroupData[{
Cell[24928, 1048, 97, 2, 70, "Input",
  CellTags->"SendProgram"],
Cell[25028, 1052, 68, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25133, 1059, 87, 2, 70, "Input",
  CellTags->"SendProgram"],
Cell[25223, 1063, 68, 2, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[25318, 1069, 57, 1, 31, "ObjectName",
  CellTags->"linkDebug"],
Cell[25378, 1072, 58, 1, 74, "Highlight",
  CellTags->"linkDebug"],
Cell[25439, 1075, 215, 7, 64, "Usage",
  CellTags->"linkDebug"],
Cell[25657, 1084, 122, 4, 33, "Notes",
  CellTags->"linkDebug"],
Cell[25782, 1090, 63, 1, 42, "ObjectName",
  CellTags->"maxParseSize"],
Cell[25848, 1093, 61, 1, 74, "Highlight",
  CellTags->"maxParseSize"],
Cell[25912, 1096, 192, 5, 64, "Usage",
  CellTags->"maxParseSize"],
Cell[26107, 1103, 290, 10, 57, "Notes",
  CellTags->"maxParseSize"],
Cell[26400, 1115, 83, 1, 33, "Notes",
  CellTags->"maxParseSize"],
Cell[26486, 1118, 45, 1, 42, "ObjectName",
  CellTags->"res"],
Cell[26534, 1121, 52, 1, 74, "Highlight",
  CellTags->"res"],
Cell[26589, 1124, 252, 9, 64, "Usage",
  CellTags->"res"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

